@@ -23,7 +23,7 @@
 #include "eckit/runtime/Tool.h"
 
 #include "atlas/grid/detail/spacing/GaussianSpacing.h"
-#include "atlas/library/Library.h"
+#include "atlas/library.h"
 #include "atlas/runtime/Exception.h"
 
 //------------------------------------------------------------------------------------------------------
