@@ -9,6 +9,7 @@
  */
 
 #pragma once
+#include <type_traits>
 
 #include "atlas/array/gridtools/GridToolsTraits.h"
 #include "atlas/library/config.h"
@@ -84,7 +85,8 @@ public:
 #define FROM_FORTRAN
 #define TO_FORTRAN
 #endif
-    using data_view_t = gridtools::data_view_tt<Value, Rank, ::gridtools::access_mode::ReadWrite>;
+    using data_view_t =
+        gridtools::data_view_tt<typename std::remove_const<Value>::type, Rank, gridtools::get_access_mode<Value>()>;
 
 public:
     IndexView( data_view_t data_view ) : gt_data_view_( data_view ) {
@@ -94,13 +96,13 @@ public:
             size_ = 0;
     }
 
-    template <typename... Coords>
+    template <typename... Coords, typename = typename std::enable_if<( sizeof...( Coords ) == Rank ), int>::type>
     Index ATLAS_HOST_DEVICE operator()( Coords... c ) {
         assert( sizeof...( Coords ) == Rank );
         return INDEX_REF( &gt_data_view_( c... ) );
     }
 
-    template <typename... Coords, typename = typename boost::enable_if_c<( sizeof...( Coords ) == Rank ), int>::type>
+    template <typename... Coords, typename = typename std::enable_if<( sizeof...( Coords ) == Rank ), int>::type>
     ATLAS_HOST_DEVICE Value const operator()( Coords... c ) const {
         return gt_data_view_( c... ) FROM_FORTRAN;
     }
@@ -148,13 +150,13 @@ public:
 
     // -- Access methods
 
-    template <typename... Idx>
-    Index operator()( Idx... idx ) {
+    template <typename... Ints, typename = typename std::enable_if<( sizeof...( Ints ) == Rank ), int>::type>
+    Index operator()( Ints... idx ) {
         check_bounds( idx... );
         return INDEX_REF( &data_[index( idx... )] );
     }
 
-    template <typename... Ints>
+    template <typename... Ints, typename = typename std::enable_if<( sizeof...( Ints ) == Rank ), int>::type>
     const value_type operator()( Ints... idx ) const {
         return data_[index( idx... )] FROM_FORTRAN;
     }
