@@ -8,12 +8,14 @@
  * nor does it submit to any jurisdiction.
  */
 
+/// @file FieldSet.h
 /// @author Willem Deconinck
 /// @author Pedro Maciel
 /// @date Jan 2015
 
 #pragma once
 
+#include <cstdlib>
 #include <iterator>
 #include <map>
 #include <string>
@@ -29,6 +31,8 @@ namespace atlas {
 
 class FieldSet;
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
+
 namespace field {
 
 /**
@@ -51,8 +55,11 @@ public:  // methods
     const std::string& name() const { return name_; }
     std::string& name() { return name_; }
 
-    const Field& operator[]( const idx_t& i ) const { return field( i ); }
-    Field& operator[]( const idx_t& i ) { return field( i ); }
+    const Field& operator[]( const std::int32_t& i ) const { return field( i ); }
+    Field& operator[]( const std::int32_t& i ) { return field( i ); }
+
+    const Field& operator[]( const std::int64_t& i ) const { return field( i ); }
+    Field& operator[]( const std::int64_t& i ) { return field( i ); }
 
     const Field& operator[]( const std::string& name ) const { return field( name ); }
     Field& operator[]( const std::string& name ) { return field( name ); }
@@ -84,6 +91,7 @@ public:  // methods
     const_iterator cend() const { return fields_.end(); }
 
     void haloExchange( bool on_device = false ) const;
+    void adjointHaloExchange( bool on_device = false ) const;
     void set_dirty( bool = true ) const;
 
 protected:                                // data
@@ -92,7 +100,6 @@ protected:                                // data
     std::map<std::string, idx_t> index_;  ///< name-to-index map, to refer fields by name
 };
 
-
 class FieldImpl;
 
 // C wrapper interfaces to C++ routines
@@ -109,13 +116,14 @@ void atlas__FieldSet__halo_exchange( FieldSetImpl* This, int on_device );
 }
 
 }  // namespace field
+#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 
 /**
  * @brief Represents a set of fields, where order is preserved
  */
-class FieldSet : public util::ObjectHandle<field::FieldSetImpl> {
+class FieldSet : DOXYGEN_HIDE( public util::ObjectHandle<field::FieldSetImpl> ) {
 public:  // types
     using iterator       = Implementation::iterator;
     using const_iterator = Implementation::const_iterator;
@@ -134,8 +142,11 @@ public:  // methods
     const std::string& name() const { return get()->name(); }
     std::string& name() { return get()->name(); }
 
-    const Field& operator[]( const idx_t& i ) const { return get()->operator[]( i ); }
-    Field& operator[]( const idx_t& i ) { return get()->operator[]( i ); }
+    const Field& operator[]( const std::int32_t& i ) const { return get()->operator[]( i ); }
+    Field& operator[]( const std::int32_t& i ) { return get()->operator[]( i ); }
+
+    const Field& operator[]( const std::int64_t& i ) const { return get()->operator[]( i ); }
+    Field& operator[]( const std::int64_t& i ) { return get()->operator[]( i ); }
 
     const Field& operator[]( const std::string& name ) const { return get()->operator[]( name ); }
     Field& operator[]( const std::string& name ) { return get()->operator[]( name ); }
