@@ -8,6 +8,7 @@
  * nor does it submit to any jurisdiction.
  */
 
+/// @file FieldInterface.h
 /// @author Willem Deconinck
 /// @date Sep 2014
 
@@ -58,11 +59,12 @@ void atlas__Field__set_levels( FieldImpl* This, int levels );
 void atlas__Field__set_functionspace( FieldImpl* This, const functionspace::FunctionSpaceImpl* functionspace );
 int atlas__Field__host_needs_update( const FieldImpl* This );
 int atlas__Field__device_needs_update( const FieldImpl* This );
-void atlas__Field__clone_to_device( FieldImpl* This );
-void atlas__Field__clone_from_device( FieldImpl* This );
+void atlas__Field__update_device( FieldImpl* This );
+void atlas__Field__update_host( FieldImpl* This );
 void atlas__Field__sync_host_device( FieldImpl* This );
 void atlas__Field__set_dirty( FieldImpl* This, int value );
 void atlas__Field__halo_exchange( FieldImpl* This, int on_device );
+void atlas__Field__adjoint_halo_exchange( FieldImpl* This, int on_device );
 int atlas__Field__dirty( FieldImpl* This );
 int atlas__Field__contiguous( FieldImpl* This );
 }
