@@ -15,6 +15,7 @@
 #include <string>
 
 #include "atlas/grid/Grid.h"
+#include "atlas/grid/detail/grid/Healpix.h"
 #include "atlas/grid/detail/grid/Structured.h"
 
 
@@ -28,21 +29,22 @@ class ReducedGaussianGrid;
 class RegularGaussianGrid;
 class RegularLonLatGrid;
 class ShiftedLonLatGrid;
+class HealpixGrid;
 
 /*
-                                             Grid
-                                               |
-                                    +----------+----------+
-                                    |                     |
-                             StructuredGrid        UnstructuredGrid
-                                    |
-               +--------------------+-----------------------+
-               |                    |                       |
-          ReducedGrid          GaussianGrid            RegularGrid
-               |                 |     |                 |     |
-               +--------+--------+     +--------+--------+     +-----+
-                        |                       |                    |
-               ReducedGaussianGrid     RegularGaussianGrid    RegularLonLatGrid
+                                                 Grid
+												   |
+                                        +----------+----------+
+                                        |                     |
+                                  StructuredGrid       UnstructuredGrid
+                                        |
+                   +--------------------+-----------------------+------------------+
+                   |                    |                       |                  |
+              ReducedGrid          GaussianGrid            RegularGrid        HealpixGrid
+                   |                 |     |                 |     |
+                   +--------+--------+     +--------+--------+     +-----+
+                            |                       |                    |
+                   ReducedGaussianGrid     RegularGaussianGrid    RegularLonLatGrid
 */
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -260,4 +262,22 @@ protected:
 
 //---------------------------------------------------------------------------------------------------------------------
 
+/// @class HealpixGrid
+/// @brief Specialization of StructuredGrid, assuming a global domain
+class HealpixGrid : public StructuredGrid {
+public:
+    using grid_t = grid::detail::grid::Healpix;
+
+public:
+    HealpixGrid( const Grid& );
+    HealpixGrid( int N );
+
+    bool valid() { return grid_; }
+
+private:
+    const grid_t* grid_;
+};
+
+//---------------------------------------------------------------------------------------------------------------------
+
 }  // namespace atlas
