@@ -18,13 +18,10 @@ namespace spacing {
 
 //----------------------------------------------------------------------------------------------------------------------
 
+
 void force_link() {
-    static struct Link {
-        Link() {
-            //SpacingBuilder<meshgenerator::StructuredMeshGenerator>();
-            //SpacingBuilder<meshgenerator::DelaunayMeshGenerator>();
-        }
-    } link;
+    static struct Link { Link() = default; } link;
+    []( const Link& ) {}( link );  // disable unused warnings
 }
 
 //----------------------------------------------------------------------------------------------------------------------
