@@ -51,7 +51,7 @@ public:
     static constexpr idx_t stencil_halo() { return 0; }
 
 public:
-    using Stencil = Stencil3D<2>;
+    using Stencil = grid::Stencil3D<2>;
     struct Weights {
         std::array<std::array<double, 2>, 2> weights_i;
         std::array<double, 2> weights_j;
@@ -88,7 +88,7 @@ public:
     template <typename stencil_t, typename weights_t, typename array_t>
     typename std::enable_if<( array_t::RANK == 2 ), typename array_t::value_type>::type interpolate(
         const stencil_t& stencil, const weights_t& weights, const array_t& input ) const {
-        using Value = typename array_t::value_type;
+        using Value = typename std::remove_const<typename array_t::value_type>::type;
 
         std::array<std::array<idx_t, stencil_width()>, stencil_width()> index;
         const auto& wj = weights.weights_j;
