@@ -26,6 +26,7 @@ class Projection;
 namespace atlas {
 namespace grid {
 class Distribution;
+class Partitioner;
 }  // namespace grid
 }  // namespace atlas
 
@@ -42,15 +43,20 @@ public:
 
     virtual void hash( eckit::Hash& ) const = 0;
 
+    virtual void generate( const Grid&, const grid::Partitioner&, Mesh& ) const;
     virtual void generate( const Grid&, const grid::Distribution&, Mesh& ) const = 0;
     virtual void generate( const Grid&, Mesh& ) const                            = 0;
 
+    Mesh generate( const Grid&, const grid::Partitioner& ) const;
     Mesh generate( const Grid&, const grid::Distribution& ) const;
     Mesh generate( const Grid& ) const;
 
     Mesh operator()( const Grid&, const grid::Distribution& ) const;
+    Mesh operator()( const Grid&, const grid::Partitioner& ) const;
     Mesh operator()( const Grid& ) const;
 
+    virtual std::string type() const = 0;
+
 protected:
     void generateGlobalElementNumbering( Mesh& mesh ) const;
     void setProjection( Mesh&, const Projection& ) const;
