@@ -22,6 +22,7 @@
 #include "atlas/array/MakeView.h"
 #include "atlas/field/Field.h"
 #include "atlas/field/FieldSet.h"
+#include "atlas/field/MissingValue.h"
 #include "atlas/functionspace/FunctionSpace.h"
 #include "atlas/mesh/ElementType.h"
 #include "atlas/mesh/Elements.h"
@@ -38,6 +39,7 @@
 
 using atlas::functionspace::NodeColumns;
 using atlas::util::Metadata;
+using atlas::util::Topology;
 using eckit::PathName;
 
 namespace atlas {
@@ -46,19 +48,16 @@ namespace detail {
 
 namespace {
 
-static double rad2deg = util::Constants::radiansToDegrees();
-
 class GmshFile : public std::ofstream {
 public:
-    GmshFile( const PathName& file_path, std::ios_base::openmode mode,
-              int part = static_cast<int>( mpi::comm().rank() ) ) {
+    GmshFile( const PathName& file_path, std::ios_base::openmode mode, int part = static_cast<int>( mpi::rank() ) ) {
         PathName par_path( file_path );
-        int mpi_size = static_cast<int>( mpi::comm().size() );
-        if ( atlas::mpi::comm().size() == 1 || part == -1 ) {
+        int mpi_size = static_cast<int>( mpi::size() );
+        if ( mpi::size() == 1 || part == -1 ) {
             std::ofstream::open( par_path.localPath(), mode );
         }
         else {
-            if ( atlas::mpi::comm().rank() == 0 ) {
+            if ( mpi::rank() == 0 ) {
                 PathName par_path( file_path );
                 std::ofstream par_file( par_path.localPath(), std::ios_base::out );
                 for ( int p = 0; p < mpi_size; ++p ) {
@@ -107,77 +106,85 @@ void write_header_binary( std::ostream& out ) {
 namespace {  // anonymous
 
 template <typename T>
-array::LocalView<T, 2> make_level_view( const Field& field, int ndata, int jlev ) {
+array::LocalView<const T, 2> make_level_view( const Field& field, int ndata, int jlev ) {
     using namespace array;
     if ( field.levels() ) {
         if ( field.variables() ) {
-            return make_view<T, 3>( field ).slice( Range::to( ndata ), jlev, Range::all() );
+            return make_view<const T, 3>( field ).slice( Range::to( ndata ), jlev, Range::all() );
         }
         else {
-            return make_view<T, 2>( field ).slice( Range::to( ndata ), jlev, Range::dummy() );
+            return make_view<const T, 2>( field ).slice( Range::to( ndata ), jlev, Range::dummy() );
         }
     }
     else {
         if ( field.variables() ) {
-            return make_view<T, 2>( field ).slice( Range::to( ndata ), Range::all() );
+            return make_view<const T, 2>( field ).slice( Range::to( ndata ), Range::all() );
         }
         else {
-            return make_view<T, 1>( field ).slice( Range::to( ndata ), Range::dummy() );
+            return make_view<const T, 1>( field ).slice( Range::to( ndata ), Range::dummy() );
         }
     }
 }
 
-template <typename DATATYPE>
-void write_level( std::ostream& out, const array::ArrayView<gidx_t, 1> gidx,
-                  const array::LocalView<DATATYPE, 2> data ) {
-    int ndata = data.shape( 0 );
-    int nvars = data.shape( 1 );
+template <typename Value, typename GlobalIndex, typename IncludeIndex>
+void write_level( std::ostream& out, GlobalIndex gidx, const array::LocalView<Value, 2>& data, IncludeIndex include ) {
+    using value_type = typename std::remove_const<Value>::type;
+    int ndata        = data.shape( 0 );
+    int nvars        = data.shape( 1 );
     if ( nvars == 1 ) {
         for ( idx_t n = 0; n < ndata; ++n ) {
-            out << gidx( n ) << " " << data( n, 0 ) << "\n";
+            if ( include( n ) ) {
+                out << gidx( n ) << " " << data( n, 0 ) << "\n";
+            }
         }
     }
     else if ( nvars <= 3 ) {
-        std::vector<DATATYPE> data_vec( 3, 0. );
+        std::array<value_type, 3> data_vec;
         for ( idx_t n = 0; n < ndata; ++n ) {
-            out << gidx( n );
-            for ( idx_t v = 0; v < nvars; ++v ) {
-                data_vec[v] = data( n, v );
-            }
-            for ( int v = 0; v < 3; ++v ) {
-                out << " " << data_vec[v];
-            }
-            out << "\n";
-        }
-    }
-    else if ( nvars <= 9 ) {
-        std::vector<DATATYPE> data_vec( 9, 0. );
-        if ( nvars == 4 ) {
-            for ( int n = 0; n < ndata; ++n ) {
-                for ( int i = 0; i < 2; ++i ) {
-                    for ( int j = 0; j < 2; ++j ) {
-                        data_vec[i * 3 + j] = data( n, i * 2 + j );
-                    }
+            if ( include( n ) ) {
+                for ( idx_t v = 0; v < nvars; ++v ) {
+                    data_vec[v] = data( n, v );
                 }
                 out << gidx( n );
-                for ( int v = 0; v < 9; ++v ) {
+                for ( int v = 0; v < 3; ++v ) {
                     out << " " << data_vec[v];
                 }
                 out << "\n";
             }
         }
+    }
+    else if ( nvars <= 9 ) {
+        std::array<value_type, 9> data_vec;
+        if ( nvars == 4 ) {
+            for ( int n = 0; n < ndata; ++n ) {
+                if ( include( n ) ) {
+                    for ( int i = 0; i < 2; ++i ) {
+                        for ( int j = 0; j < 2; ++j ) {
+                            data_vec[i * 3 + j] = data( n, i * 2 + j );
+                        }
+                    }
+                    out << gidx( n );
+                    for ( int v = 0; v < 9; ++v ) {
+                        out << " " << data_vec[v];
+                    }
+                    out << "\n";
+                }
+            }
+        }
         else if ( nvars == 9 ) {
             for ( int n = 0; n < ndata; ++n ) {
-                for ( int i = 0; i < 3; ++i ) {
-                    for ( int j = 0; j < 3; ++j ) {
-                        data_vec[i * 3 + j] = data( n, i * 2 + j );
+                if ( include( n ) ) {
+                    for ( int i = 0; i < 3; ++i ) {
+                        for ( int j = 0; j < 3; ++j ) {
+                            data_vec[i * 3 + j] = data( n, i * 2 + j );
+                        }
                     }
+                    out << gidx( n );
+                    for ( int v = 0; v < 9; ++v ) {
+                        out << " " << data_vec[v];
+                    }
+                    out << "\n";
                 }
-                out << gidx( n );
-                for ( int v = 0; v < 9; ++v ) {
-                    out << " " << data_vec[v];
-                }
-                out << "\n";
             }
         }
         else {
@@ -188,6 +195,10 @@ void write_level( std::ostream& out, const array::ArrayView<gidx_t, 1> gidx,
         ATLAS_NOTIMPLEMENTED;
     }
 }
+template <typename Value, typename GlobalIndex>
+void write_level( std::ostream& out, GlobalIndex gidx, const array::LocalView<Value, 2>& data ) {
+    write_level( out, gidx, data, []( idx_t ) { return true; } );
+}
 
 std::vector<int> get_levels( int nlev, const Metadata& gmsh_options ) {
     std::vector<int> lev;
@@ -242,17 +253,17 @@ int field_vars( int nvars ) {
 }  // namespace
 
 // ----------------------------------------------------------------------------
-template <typename DATATYPE>
+template <typename Value>
 void write_field_nodes( const Metadata& gmsh_options, const functionspace::NodeColumns& function_space,
                         const Field& field, std::ostream& out ) {
     Log::debug() << "writing NodeColumns field " << field.name() << " defined in NodeColumns..." << std::endl;
 
-    bool gather( gmsh_options.get<bool>( "gather" ) && atlas::mpi::comm().size() > 1 );
+    bool gather( gmsh_options.get<bool>( "gather" ) && mpi::size() > 1 );
     // unused: bool binary( !gmsh_options.get<bool>( "ascii" ) );
-    idx_t nlev                       = std::max<idx_t>( 1, field.levels() );
-    idx_t ndata                      = std::min<idx_t>( function_space.nb_nodes(), field.shape( 0 ) );
-    idx_t nvars                      = std::max<idx_t>( 1, field.variables() );
-    array::ArrayView<gidx_t, 1> gidx = array::make_view<gidx_t, 1>( function_space.nodes().global_index() );
+    idx_t nlev  = std::max<idx_t>( 1, field.levels() );
+    idx_t ndata = std::min<idx_t>( function_space.nb_nodes(), field.shape( 0 ) );
+    idx_t nvars = std::max<idx_t>( 1, field.variables() );
+    auto gidx   = array::make_view<gidx_t, 1>( function_space.nodes().global_index() );
     Field gidx_glb;
     Field field_glb;
     if ( gather ) {
@@ -265,11 +276,33 @@ void write_field_nodes( const Metadata& gmsh_options, const functionspace::NodeC
         function_space.gather( field, field_glb );
         ndata = std::min<idx_t>( function_space.nb_nodes_global(), field_glb.shape( 0 ) );
     }
+    auto missing = field::MissingValue( field );
 
     std::vector<int> lev = get_levels( nlev, gmsh_options );
     for ( size_t ilev = 0; ilev < lev.size(); ++ilev ) {
         int jlev = lev[ilev];
-        if ( ( gather && atlas::mpi::comm().rank() == 0 ) || !gather ) {
+        if ( ( gather && mpi::rank() == 0 ) || !gather ) {
+            auto data = gather ? make_level_view<Value>( field_glb, ndata, jlev )
+                               : make_level_view<Value>( field, ndata, jlev );
+            auto include_idx = [&]( idx_t n ) {
+                for ( idx_t v = 0; v < nvars; ++v ) {
+                    if ( missing( data( n, v ) ) ) {
+                        return false;
+                    }
+                }
+                return true;
+            };
+            idx_t ndata_nonmissing = [&] {
+                if ( missing ) {
+                    idx_t c = 0;
+                    for ( idx_t n = 0; n < ndata; ++n ) {
+                        c += include_idx( n );
+                    }
+                    return c;
+                }
+                return ndata;
+            }();
+
             out << "$NodeData\n";
             out << "1\n";
             out << "\"" << field.name() << field_lev( field, jlev ) << "\"\n";
@@ -278,15 +311,79 @@ void write_field_nodes( const Metadata& gmsh_options, const functionspace::NodeC
             out << "4\n";
             out << field_step( field ) << "\n";
             out << field_vars( nvars ) << "\n";
-            out << ndata << "\n";
-            out << atlas::mpi::comm().rank() << "\n";
-            auto data = gather ? make_level_view<DATATYPE>( field_glb, ndata, jlev )
-                               : make_level_view<DATATYPE>( field, ndata, jlev );
-            write_level( out, gidx, data );
+            out << ndata_nonmissing << "\n";
+            out << mpi::rank() << "\n";
+            if ( missing ) {
+                write_level( out, gidx, data, include_idx );
+            }
+            else {
+                write_level( out, gidx, data );
+            }
             out << "$EndNodeData\n";
         }
     }
 }
+
+// ----------------------------------------------------------------------------
+template <typename Value>
+void write_field_nodes( const Metadata& gmsh_options, const functionspace::NoFunctionSpace& function_space,
+                        const Field& field, std::ostream& out ) {
+    Log::debug() << "writing field " << field.name() << " defined without functionspace..." << std::endl;
+
+    // unused: bool binary( !gmsh_options.get<bool>( "ascii" ) );
+    idx_t nlev  = std::max<idx_t>( 1, field.levels() );
+    idx_t ndata = field.shape( 0 );
+    idx_t nvars = std::max<idx_t>( 1, field.variables() );
+    auto gidx   = []( idx_t inode ) { return inode + 1; };
+
+    auto missing = field::MissingValue( field );
+
+    std::vector<int> lev = get_levels( nlev, gmsh_options );
+    for ( size_t ilev = 0; ilev < lev.size(); ++ilev ) {
+        int jlev = lev[ilev];
+
+        auto data        = make_level_view<Value>( field, ndata, jlev );
+        auto include_idx = [&]( idx_t n ) {
+            for ( idx_t v = 0; v < nvars; ++v ) {
+                if ( missing( data( n, v ) ) ) {
+                    return false;
+                }
+            }
+            return true;
+        };
+        idx_t ndata_nonmissing = [&] {
+            if ( missing ) {
+                idx_t c = 0;
+                for ( idx_t n = 0; n < ndata; ++n ) {
+                    c += include_idx( n );
+                }
+                return c;
+            }
+            return ndata;
+        }();
+
+        out << "$NodeData\n";
+        out << "1\n";
+        out << "\"" << field.name() << field_lev( field, jlev ) << "\"\n";
+        out << "1\n";
+        out << field_time( field ) << "\n";
+        out << "4\n";
+        out << field_step( field ) << "\n";
+        out << field_vars( nvars ) << "\n";
+        out << ndata_nonmissing << "\n";
+        out << mpi::rank() << "\n";
+        if ( missing ) {
+            write_level( out, gidx, data, include_idx );
+        }
+        else {
+            write_level( out, gidx, data );
+        }
+        out << "$EndNodeData\n";
+    }
+}
+// ----------------------------------------------------------------------------
+
+
 // ----------------------------------------------------------------------------
 
 void print_field_lev( char field_lev[], int jlev ) {
@@ -309,7 +406,7 @@ void write_field_nodes( const Metadata& gmsh_options, const functionspace::Struc
                         const Field& field, std::ostream& out ) {
     Log::debug() << "writing StructuredColumns field " << field.name() << "..." << std::endl;
 
-    bool gather( gmsh_options.get<bool>( "gather" ) && atlas::mpi::comm().size() > 1 );
+    bool gather( gmsh_options.get<bool>( "gather" ) && mpi::size() > 1 );
     // unused: bool binary( !gmsh_options.get<bool>( "ascii" ) );
     idx_t nlev  = std::max<idx_t>( 1, field.levels() );
     idx_t ndata = std::min<idx_t>( function_space.sizeOwned(), field.shape( 0 ) );
@@ -346,7 +443,7 @@ void write_field_nodes( const Metadata& gmsh_options, const functionspace::Struc
         out << field_step( field ) << "\n";
         out << field_vars( nvars ) << "\n";
         out << ndata << "\n";
-        out << atlas::mpi::comm().rank() << "\n";
+        out << mpi::rank() << "\n";
         auto data = gather ? make_level_view<DATATYPE>( field_glb, ndata, jlev )
                            : make_level_view<DATATYPE>( field, ndata, jlev );
         write_level( out, gidx, data );
@@ -361,12 +458,12 @@ void write_field_elems( const Metadata& gmsh_options, const functionspace::CellC
 #if 1
     Log::debug() << "writing CellColumns field " << field.name() << "..." << std::endl;
 
-    bool gather( gmsh_options.get<bool>( "gather" ) && atlas::mpi::comm().size() > 1 );
+    bool gather( gmsh_options.get<bool>( "gather" ) && mpi::size() > 1 );
     // unused: bool binary( !gmsh_options.get<bool>( "ascii" ) );
-    idx_t nlev                       = std::max<idx_t>( 1, field.levels() );
-    idx_t ndata                      = std::min<idx_t>( function_space.nb_cells(), field.shape( 0 ) );
-    idx_t nvars                      = std::max<idx_t>( 1, field.variables() );
-    array::ArrayView<gidx_t, 1> gidx = array::make_view<gidx_t, 1>( function_space.cells().global_index() );
+    idx_t nlev  = std::max<idx_t>( 1, field.levels() );
+    idx_t ndata = std::min<idx_t>( function_space.nb_cells(), field.shape( 0 ) );
+    idx_t nvars = std::max<idx_t>( 1, field.variables() );
+    auto gidx   = array::make_view<gidx_t, 1>( function_space.cells().global_index() );
     Field gidx_glb;
     Field field_glb;
     if ( gather ) {
@@ -383,7 +480,7 @@ void write_field_elems( const Metadata& gmsh_options, const functionspace::CellC
     std::vector<int> lev = get_levels( nlev, gmsh_options );
     for ( size_t ilev = 0; ilev < lev.size(); ++ilev ) {
         int jlev = lev[ilev];
-        if ( ( gather && atlas::mpi::comm().rank() == 0 ) || !gather ) {
+        if ( ( gather && mpi::rank() == 0 ) || !gather ) {
             out << "$ElementData\n";
             out << "1\n";
             out << "\"" << field.name() << field_lev( field, jlev ) << "\"\n";
@@ -393,7 +490,7 @@ void write_field_elems( const Metadata& gmsh_options, const functionspace::CellC
             out << field_step( field ) << "\n";
             out << field_vars( nvars ) << "\n";
             out << ndata << "\n";
-            out << atlas::mpi::comm().rank() << "\n";
+            out << mpi::rank() << "\n";
             auto data = gather ? make_level_view<DATATYPE>( field_glb, ndata, jlev )
                                : make_level_view<DATATYPE>( field, ndata, jlev );
             write_level( out, gidx, data );
@@ -453,7 +550,7 @@ void write_field_elems(const Metadata& gmsh_options, const FunctionSpace& functi
     if     ( nvars == 1 ) out << nvars << "\n";
     else if( nvars <= 3 ) out << 3     << "\n";
     out << ndata << "\n";
-    out << mpi::comm().rank() << "\n";
+    out << mpi::rank() << "\n";
 
     if( binary )
     {
@@ -520,25 +617,9 @@ void write_field_elems(const Metadata& gmsh_options, const FunctionSpace& functi
   }
 }
 #endif
-// ----------------------------------------------------------------------------
 
 // ----------------------------------------------------------------------------
-// Unused private function, in case for big-endian
-// ----------------------------------------------------------------------------
-#if 0
-void swap_bytes(char *array, int size, int n)
-{
-  char *x = new char[size];
-  for(int i = 0; i < n; i++) {
-    char *a = &array[i * size];
-    memcpy(x, a, size);
-    for(int c = 0; c < size; c++)
-      a[size - 1 - c] = x[c];
-  }
-  delete [] x;
-}
-#endif
-// ----------------------------------------------------------------------------
+
 }  // end anonymous namespace
 
 // ----------------------------------------------------------------------------
@@ -692,7 +773,7 @@ void GmshIO::read( const PathName& file_path, Mesh& mesh ) const {
             }
             else {
                 size_t jtype = mesh.cells().add( make_element_type( etype ), netype );
-                elements     = &mesh.edges().elements( jtype );
+                elements     = &mesh.cells().elements( jtype );
             }
 
             size_t nnodes_per_elem            = elements->element_type().nb_nodes();
@@ -730,7 +811,7 @@ void GmshIO::read( const PathName& file_path, Mesh& mesh ) const {
 
         int nb_quads  = nb_etype[QUAD];
         int nb_triags = nb_etype[TRIAG];
-        int nb_edges  = nb_etype[LINE];
+        //int nb_edges  = nb_etype[LINE];
 
         mesh::Elements& quads  = mesh.cells().elements( mesh.cells().add( make_element_type( QUAD ), nb_quads ) );
         mesh::Elements& triags = mesh.cells().elements( mesh.cells().add( make_element_type( TRIAG ), nb_triags ) );
@@ -752,7 +833,7 @@ void GmshIO::read( const PathName& file_path, Mesh& mesh ) const {
         // Now read all elements
         file.seekg( position, std::ios::beg );
         int gn0, gn1, gn2, gn3;
-        int quad = 0, triag = 0, edge = 0;
+        int quad = 0, triag = 0;
         int ntags, tags[100];
         for ( int e = 0; e < nb_elements; ++e ) {
             file >> g >> etype >> ntags;
@@ -765,7 +846,7 @@ void GmshIO::read( const PathName& file_path, Mesh& mesh ) const {
                     std::max( part, *std::max_element( tags + 3, tags + ntags - 1 ) );  // one positive, others negative
             }
 
-            idx_t enodes[4];
+            idx_t enodes[4] = {-1, -1, -1, -1};
 
             switch ( etype ) {
                 case ( QUAD ):
@@ -812,16 +893,26 @@ void GmshIO::read( const PathName& file_path, Mesh& mesh ) const {
 }
 
 void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
-    int part = mesh.metadata().has( "part" ) ? mesh.metadata().get<size_t>( "part" ) : atlas::mpi::comm().rank();
+    int part           = mesh.metadata().has( "part" ) ? mesh.metadata().get<size_t>( "part" ) : mpi::rank();
     bool include_ghost = options.get<bool>( "ghost" ) && options.get<bool>( "elements" );
 
-    std::string nodes_field = options.get<std::string>( "nodes" );
+    bool land_water_flag = options.has( "water" ) || options.has( "land" );
+    bool include_water   = options.getBool( "water", false );
+    bool include_land    = options.getBool( "land", false );
 
-    const mesh::Nodes& nodes            = mesh.nodes();
-    array::ArrayView<double, 2> coords  = array::make_view<double, 2>( nodes.field( nodes_field ) );
-    array::ArrayView<gidx_t, 1> glb_idx = array::make_view<gidx_t, 1>( nodes.global_index() );
+    std::string nodes_field  = options.get<std::string>( "nodes" );
+    const mesh::Nodes& nodes = mesh.nodes();
 
-    const idx_t surfdim = coords.shape( 1 );  // nb of variables in coords
+    const Field coords_field = nodes.field( nodes_field );
+    array::ArrayT<double> dummy_double( 1, 1 );
+    array::ArrayT<idx_t> dummy_idx( 1, 1 );
+    bool coords_is_idx = coords_field.datatype().kind() == array::make_datatype<idx_t>().kind();
+    auto coords        = array::make_view<const double, 2>( coords_is_idx ? dummy_double : coords_field.array() );
+    auto coords_idx    = array::make_view<const idx_t, 2>( coords_is_idx ? coords_field.array() : dummy_idx );
+
+    auto glb_idx = array::make_view<gidx_t, 1>( nodes.global_index() );
+
+    const idx_t surfdim = nodes.field( nodes_field ).shape( 1 );  // nb of variables in coords
 
     bool include_patch = ( surfdim == 3 );
 
@@ -854,8 +945,15 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
     for ( idx_t n = 0; n < nb_nodes; ++n ) {
         gidx_t g = glb_idx( n );
 
-        for ( idx_t d = 0; d < surfdim; ++d ) {
-            xyz[d] = coords( n, d );
+        if ( coords_is_idx ) {
+            for ( idx_t d = 0; d < surfdim; ++d ) {
+                xyz[d] = coords_idx( n, d );
+            }
+        }
+        else {
+            for ( idx_t d = 0; d < surfdim; ++d ) {
+                xyz[d] = coords( n, d );
+            }
         }
 
         if ( binary ) {
@@ -885,22 +983,37 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
         idx_t nb_elements( 0 );
         for ( const mesh::HybridElements* hybrid : grouped_elements ) {
             nb_elements += hybrid->size();
-            const array::ArrayView<int, 1> hybrid_halo  = array::make_view<int, 1>( hybrid->halo() );
-            const array::ArrayView<int, 1> hybrid_flags = array::make_view<int, 1>( hybrid->flags() );
-            auto hybrid_patch                           = [&]( idx_t e ) {
-                return mesh::Nodes::Topology::check( hybrid_flags( e ), mesh::Nodes::Topology::PATCH );
-            };
-            auto exclude = [&]( idx_t e ) {
-                if ( !include_ghost && hybrid_halo( e ) ) {
-                    return true;
+            const auto hybrid_halo  = array::make_view<int, 1>( hybrid->halo() );
+            const auto hybrid_flags = array::make_view<int, 1>( hybrid->flags() );
+
+            auto include = [&]( idx_t e ) {
+                auto topology = Topology::view( hybrid_flags( e ) );
+                if ( land_water_flag && not( include_water && include_land ) ) {
+                    if ( include_water && !topology.check( Topology::WATER ) ) {
+                        return false;
+                    }
+                    if ( include_land && !topology.check( Topology::LAND ) ) {
+                        return false;
+                    }
                 }
-                if ( !include_patch && hybrid_patch( e ) ) {
-                    return true;
+                if ( not include_ghost ) {
+                    if ( topology.check( Topology::GHOST ) || hybrid_halo( e ) ) {
+                        return false;
+                    }
                 }
-                return false;
+                if ( not include_patch ) {
+                    if ( topology.check( Topology::PATCH ) ) {
+                        return false;
+                    }
+                }
+                if ( topology.check( Topology::INVALID ) ) {
+                    return false;
+                }
+                return true;
             };
+
             for ( idx_t e = 0; e < hybrid->size(); ++e ) {
-                if ( exclude( e ) ) {
+                if ( not include( e ) ) {
                     --nb_elements;
                 }
             }
@@ -930,8 +1043,35 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
 
                 auto elems_glb_idx   = elements.view<gidx_t, 1>( elements.global_index() );
                 auto elems_partition = elements.view<int, 1>( elements.partition() );
-                auto elems_halo      = elements.view<int, 1>( elements.halo() );
 
+                auto elems_halo  = elements.view<int, 1>( elements.halo() );
+                auto elems_flags = elements.view<int, 1>( elements.flags() );
+
+                auto include = [&]( idx_t e ) {
+                    auto topology = Topology::view( elems_flags( e ) );
+                    if ( land_water_flag && not( include_water && include_land ) ) {
+                        if ( include_water && !topology.check( Topology::WATER ) ) {
+                            return false;
+                        }
+                        if ( include_land && !topology.check( Topology::LAND ) ) {
+                            return false;
+                        }
+                    }
+                    if ( not include_ghost ) {
+                        if ( topology.check( Topology::GHOST ) || elems_halo( e ) ) {
+                            return false;
+                        }
+                    }
+                    if ( not include_patch ) {
+                        if ( topology.check( Topology::PATCH ) ) {
+                            return false;
+                        }
+                    }
+                    if ( topology.check( Topology::INVALID ) ) {
+                        return false;
+                    }
+                    return true;
+                };
                 if ( binary ) {
                     idx_t nb_elems = elements.size();
                     if ( !include_ghost ) {
@@ -968,7 +1108,7 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
                     ss_elem_info << " " << gmsh_elem_type << " 4 1 1 1 ";
                     std::string elem_info = ss_elem_info.str();
                     for ( idx_t elem = 0; elem < elements.size(); ++elem ) {
-                        if ( include_ghost || !elems_halo( elem ) ) {
+                        if ( include( elem ) ) {
                             file << elems_glb_idx( elem ) << elem_info << elems_partition( elem );
                             for ( idx_t n = 0; n < node_connectivity.cols(); ++n ) {
                                 file << " " << glb_idx( node_connectivity( elem, n ) );
@@ -996,13 +1136,13 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
 
         write( nodes.partition(), function_space, mesh_info, std::ios_base::out );
 
-        if ( nodes.has_field( "dual_volumes" ) ) {
-            write( nodes.field( "dual_volumes" ), function_space, mesh_info, std::ios_base::app );
+        std::vector<std::string> extra_fields = {"dual_volumes", "dual_delta_sph", "lsm", "core", "ghost", "halo"};
+        for ( auto& f : extra_fields ) {
+            if ( nodes.has_field( f ) ) {
+                write( nodes.field( f ), function_space, mesh_info, std::ios_base::app );
+            }
         }
 
-        if ( nodes.has_field( "dual_delta_sph" ) ) {
-            write( nodes.field( "dual_delta_sph" ), function_space, mesh_info, std::ios_base::app );
-        }
 
         //[next] if( mesh.has_function_space("edges") )
         //[next] {
@@ -1030,13 +1170,12 @@ void GmshIO::write( const Mesh& mesh, const PathName& file_path ) const {
 // ----------------------------------------------------------------------------
 void GmshIO::write( const Field& field, const PathName& file_path, openmode mode ) const {
     if ( !field.functionspace() ) {
-        std::stringstream msg;
-        msg << "Field [" << field.name() << "] has no functionspace";
-
-        throw_AssertionFailed( msg.str(), Here() );
+        FieldSet fieldset;
+        fieldset.add( field );
+        write( fieldset, field.functionspace(), file_path, mode );
     }
 
-    if ( functionspace::NodeColumns( field.functionspace() ) ) {
+    else if ( functionspace::NodeColumns( field.functionspace() ) ) {
         FieldSet fieldset;
         fieldset.add( field );
         write( fieldset, field.functionspace(), file_path, mode );
@@ -1069,6 +1208,16 @@ void GmshIO::write_delegate( const Field& field, const functionspace::NodeColumn
     fieldset.add( field );
     write_delegate( fieldset, functionspace, file_path, mode );
 }
+
+// ----------------------------------------------------------------------------
+
+void GmshIO::write_delegate( const Field& field, const functionspace::NoFunctionSpace& functionspace,
+                             const eckit::PathName& file_path, GmshIO::openmode mode ) const {
+    FieldSet fieldset;
+    fieldset.add( field );
+    write_delegate( fieldset, functionspace, file_path, mode );
+}
+
 // ----------------------------------------------------------------------------
 
 // ----------------------------------------------------------------------------
@@ -1089,7 +1238,45 @@ void GmshIO::write_delegate( const FieldSet& fieldset, const functionspace::Node
         mode |= std::ios_base::binary;
     }
     bool gather = options.has( "gather" ) ? options.get<bool>( "gather" ) : false;
-    GmshFile file( file_path, mode, gather ? -1 : int( atlas::mpi::comm().rank() ) );
+    GmshFile file( file_path, mode, gather ? -1 : int( mpi::rank() ) );
+
+    // Header
+    if ( is_new_file ) {
+        write_header_ascii( file );
+    }
+
+    // field::Fields
+    for ( idx_t field_idx = 0; field_idx < fieldset.size(); ++field_idx ) {
+        const Field& field = fieldset[field_idx];
+        Log::debug() << "writing field " << field.name() << " to gmsh file " << file_path << std::endl;
+
+        if ( field.datatype() == array::DataType::int32() ) {
+            write_field_nodes<int>( options, functionspace, field, file );
+        }
+        else if ( field.datatype() == array::DataType::int64() ) {
+            write_field_nodes<long>( options, functionspace, field, file );
+        }
+        else if ( field.datatype() == array::DataType::real32() ) {
+            write_field_nodes<float>( options, functionspace, field, file );
+        }
+        else if ( field.datatype() == array::DataType::real64() ) {
+            write_field_nodes<double>( options, functionspace, field, file );
+        }
+
+        file << std::flush;
+    }
+    file.close();
+}
+
+void GmshIO::write_delegate( const FieldSet& fieldset, const functionspace::NoFunctionSpace& functionspace,
+                             const eckit::PathName& file_path, GmshIO::openmode mode ) const {
+    bool is_new_file = ( mode != std::ios_base::app || !file_path.exists() );
+    bool binary( !options.get<bool>( "ascii" ) );
+    if ( binary ) {
+        mode |= std::ios_base::binary;
+    }
+    bool gather = options.has( "gather" ) ? options.get<bool>( "gather" ) : false;
+    GmshFile file( file_path, mode, gather ? -1 : int( mpi::rank() ) );
 
     // Header
     if ( is_new_file ) {
@@ -1127,7 +1314,7 @@ void GmshIO::write_delegate( const FieldSet& fieldset, const functionspace::Cell
         mode |= std::ios_base::binary;
     }
     bool gather = options.has( "gather" ) ? options.get<bool>( "gather" ) : false;
-    GmshFile file( file_path, mode, gather ? -1 : int( atlas::mpi::comm().rank() ) );
+    GmshFile file( file_path, mode, gather ? -1 : int( mpi::rank() ) );
 
     // Header
     if ( is_new_file ) {
@@ -1170,7 +1357,7 @@ void GmshIO::write_delegate( const FieldSet& fieldset, const functionspace::Stru
 
     bool gather = options.has( "gather" ) ? options.get<bool>( "gather" ) : false;
 
-    GmshFile file( file_path, mode, gather ? -1 : int( atlas::mpi::comm().rank() ) );
+    GmshFile file( file_path, mode, gather ? -1 : int( mpi::rank() ) );
 
     // Header
     if ( is_new_file ) {
@@ -1214,6 +1401,9 @@ void GmshIO::write( const FieldSet& fieldset, const FunctionSpace& funcspace, co
     else if ( functionspace::CellColumns( funcspace ) ) {
         write_delegate( fieldset, functionspace::CellColumns( funcspace ), file_path, mode );
     }
+    else if ( not funcspace ) {
+        write_delegate( fieldset, functionspace::NoFunctionSpace(), file_path, mode );
+    }
     else {
         ATLAS_NOTIMPLEMENTED;
     }
