@@ -18,6 +18,7 @@
 
 namespace atlas {
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 [[noreturn]] void throw_NotImplemented( const eckit::CodeLocation& );
 [[noreturn]] void throw_NotImplemented( const std::string&, const eckit::CodeLocation& );
 
@@ -31,6 +32,7 @@ namespace atlas {
 [[noreturn]] void throw_CantOpenFile( const std::string& );
 [[noreturn]] void throw_CantOpenFile( const std::string&, const eckit::CodeLocation& );
 
+[[noreturn]] void throw_OutOfRange( const std::string& varname, idx_t index, idx_t size );
 [[noreturn]] void throw_OutOfRange( const std::string& varname, idx_t index, idx_t size, const eckit::CodeLocation& );
 
 namespace detail {
@@ -39,7 +41,8 @@ inline void Assert( bool success, const char* code, const char* file, int line,
         throw_AssertionFailed( code, eckit::CodeLocation( file, line, func ) );
     }
 }
-inline void Assert( bool success, const char* code, const char* msg, const char* file, int line, const char* func ) {
+inline void Assert( bool success, const char* code, const std::string& msg, const char* file, int line,
+                    const char* func ) {
     if ( not success ) {
         throw_AssertionFailed( code, msg, eckit::CodeLocation( file, line, func ) );
     }
@@ -51,8 +54,9 @@ inline void Assert( bool success, const char* code, const char* msg, const char*
 
 #define ATLAS_NOTIMPLEMENTED ::atlas::throw_NotImplemented( Here() )
 
-#define ATLAS_ASSERT_NOMSG( code ) ::atlas::detail::Assert( ( code ), #code, __FILE__, __LINE__, __func__ )
-#define ATLAS_ASSERT_MSG( code, msg ) ::atlas::detail::Assert( ( code ), #code, msg, __FILE__, __LINE__, __func__ )
+#define ATLAS_ASSERT_NOMSG( code ) ::atlas::detail::Assert( bool( code ), #code, __FILE__, __LINE__, __func__ )
+#define ATLAS_ASSERT_MSG( code, msg ) \
+    ::atlas::detail::Assert( bool( code ), #code, std::string( msg ), __FILE__, __LINE__, __func__ )
 
 #define ATLAS_ASSERT( ... ) __ATLAS_SPLICE( __ATLAS_ASSERT_, __ATLAS_NARG( __VA_ARGS__ ) )( __VA_ARGS__ )
 #define __ATLAS_ASSERT_1 ATLAS_ASSERT_NOMSG
@@ -64,3 +68,5 @@ inline void Assert( bool success, const char* code, const char* msg, const char*
         ss << WHAT;                                   \
         ::atlas::throw_Exception( ss.str(), Here() ); \
     }
+
+#endif
