@@ -9,12 +9,17 @@
  */
 
 #include "atlas/trans/ifs/LegendreCacheCreatorIFS.h"
+
+#include <cmath>
 #include <sstream>
 #include <string>
+
+#include "eckit/utils/MD5.h"
+
 #include "atlas/grid.h"
 #include "atlas/option.h"
+#include "atlas/runtime/Exception.h"
 #include "atlas/trans/Trans.h"
-#include "eckit/utils/MD5.h"
 
 namespace atlas {
 namespace trans {
@@ -32,9 +37,12 @@ std::string truncate( const std::string& str ) {
 
 std::string hash( const Grid& grid ) {
     eckit::MD5 h;
-    if ( StructuredGrid( grid ) && not grid.projection() ) {
-        auto g = StructuredGrid( grid );
-        h.add( g.y().data(), g.y().size() * sizeof( double ) );
+
+    StructuredGrid structured( grid );
+    if ( structured && not grid.projection() ) {
+        for ( auto& y : structured.y() ) {
+            h.add( std::lround( y * 1.e8 ) );
+        }
     }
     else {
         grid.hash( h );
@@ -42,6 +50,19 @@ std::string hash( const Grid& grid ) {
     return truncate( h.digest() );
 }
 
+std::string hash_pl( const Grid& grid ) {
+    eckit::MD5 h;
+
+    StructuredGrid structured( grid );
+    ATLAS_ASSERT( structured );
+
+    for ( auto& n : structured.nx() ) {
+        h.add( long( n ) );
+    }
+
+    return truncate( h.digest() );
+}
+
 std::string hash( const eckit::Configuration& config ) {
     eckit::MD5 h;
 
@@ -57,13 +78,13 @@ std::string LegendreCacheCreatorIFS::uid() const {
     if ( unique_identifier_.empty() ) {
         std::ostringstream stream;
         stream << "ifs-T" << truncation_ << "-";
-        if ( GaussianGrid( grid_ ) ) {
+        GaussianGrid gaussian( grid_ );
+        if ( gaussian ) {
             if ( RegularGaussianGrid( grid_ ) ) {
-                stream << "RegularGaussianN" << GaussianGrid( grid_ ).N();
+                stream << "RegularGaussianN" << gaussian.N();
             }
             else {
-                stream << "ReducedGaussianN" << GaussianGrid( grid_ ).N() << "-PL";
-                stream << hash( grid_ );
+                stream << "ReducedGaussianN" << gaussian.N() << "-PL" << hash_pl( grid_ );
             }
         }
         else if ( RegularLonLatGrid( grid_ ) ) {
@@ -103,9 +124,7 @@ bool LegendreCacheCreatorIFS::supported() const {
 
 LegendreCacheCreatorIFS::LegendreCacheCreatorIFS( const Grid& grid, int truncation,
                                                   const eckit::Configuration& config ) :
-    grid_( grid ),
-    truncation_( truncation ),
-    config_( config ) {}
+    grid_( grid ), truncation_( truncation ), config_( config ) {}
 
 void LegendreCacheCreatorIFS::create( const std::string& path ) const {
     Trans( grid_, truncation_, config_ | option::type( "ifs" ) | option::write_legendre( path ) );
