@@ -14,17 +14,17 @@
 namespace atlas {
 
 void PointLonLat::normalise() {
-    constexpr NormaliseLongitude normalize_from_zero;
+    constexpr util::NormaliseLongitude normalize_from_zero;
     lon() = normalize_from_zero( lon() );
 }
 
 void PointLonLat::normalise( double west ) {
-    NormaliseLongitude normalize_from_west( west );
+    util::NormaliseLongitude normalize_from_west( west );
     lon() = normalize_from_west( lon() );
 }
 
 void PointLonLat::normalise( double west, double east ) {
-    NormaliseLongitude normalize_between_west_and_east( west, east );
+    util::NormaliseLongitude normalize_between_west_and_east( west, east );
     lon() = normalize_between_west_and_east( lon() );
 }
 
