@@ -24,18 +24,18 @@ namespace util {
 
 //------------------------------------------------------------------------------------------------------
 
-SphericalPolygon::SphericalPolygon( const Polygon& poly, const atlas::Field& lonlat ) :
-    PolygonCoordinates( poly, lonlat, false ) {}
+SphericalPolygon::SphericalPolygon( const PartitionPolygon& partition_polygon ) :
+    PolygonCoordinates( partition_polygon.xy(), false ) {}
 
 SphericalPolygon::SphericalPolygon( const std::vector<PointLonLat>& points ) : PolygonCoordinates( points ) {}
 
-bool SphericalPolygon::contains( const PointLonLat& P ) const {
+bool SphericalPolygon::contains( const Point2& P ) const {
     using eckit::types::is_approximately_equal;
 
     ATLAS_ASSERT( coordinates_.size() >= 2 );
 
     // check first bounding box
-    if ( coordinatesMax_.lon() <= P.lon() || P.lon() < coordinatesMin_.lon() ) {
+    if ( coordinatesMax_[LON] <= P[LON] || P[LON] < coordinatesMin_[LON] ) {
         return false;
     }
 
@@ -44,30 +44,29 @@ bool SphericalPolygon::contains( const PointLonLat& P ) const {
 
     // loop on polygon edges
     for ( size_t i = 1; i < coordinates_.size(); ++i ) {
-        const PointLonLat& A = coordinates_[i - 1];
-        const PointLonLat& B = coordinates_[i];
+        const Point2& A = coordinates_[i - 1];
+        const Point2& B = coordinates_[i];
 
         // test if P is on/above/below of a great circle containing A,B
-        const bool APB = ( A.lon() <= P.lon() && P.lon() < B.lon() );
-        const bool BPA = ( B.lon() <= P.lon() && P.lon() < A.lon() );
+        const bool APB = ( A[LON] <= P[LON] && P[LON] < B[LON] );
+        const bool BPA = ( B[LON] <= P[LON] && P[LON] < A[LON] );
 
         if ( APB != BPA ) {
             const double lat = [&] {
-                if ( is_approximately_equal( A.lat(), B.lat() ) &&
-                     is_approximately_equal( std::abs( A.lat() ), 90. ) ) {
-                    return A.lat();
+                if ( is_approximately_equal( A[LAT], B[LAT] ) && is_approximately_equal( std::abs( A[LAT] ), 90. ) ) {
+                    return A[LAT];
                 }
                 else {
-                    return util::Earth::greatCircleLatitudeGivenLongitude( A, B, P.lon() );
+                    return util::Earth::greatCircleLatitudeGivenLongitude( A, B, P[LON] );
                 }
             }();
 
             ATLAS_ASSERT( !std::isnan( lat ) );
-            if ( is_approximately_equal( P.lat(), lat ) ) {
+            if ( is_approximately_equal( P[LAT], lat ) ) {
                 return true;
             }
 
-            wn += ( P.lat() > lat ? -1 : 1 ) * ( APB ? -1 : 1 );
+            wn += ( P[LAT] > lat ? -1 : 1 ) * ( APB ? -1 : 1 );
         }
     }
 
