@@ -15,7 +15,7 @@
 #include <vector>
 
 #include "atlas/grid/Grid.h"
-#include "atlas/library/Library.h"
+#include "atlas/library.h"
 #include "atlas/library/config.h"
 #include "atlas/mesh/Mesh.h"
 #include "atlas/meshgenerator.h"
@@ -32,7 +32,7 @@ using namespace atlas::output;
 #define NLONG 128
 
 int main( int argc, char** argv ) {
-    atlas::Library::instance().initialise( argc, argv );
+    atlas::initialize( argc, argv );
     Grid grid( "L33x11" );
 
     // Build a mesh from grid
@@ -42,6 +42,7 @@ int main( int argc, char** argv ) {
     Gmsh gmsh( "earth.msh", util::Config( "coordinates", "xyz" ) );
     gmsh.write( mesh );
 
-    atlas::Library::instance().finalise();
+    atlas::finalize();
+    atlas::mpi::finalize();
     return 0;
 }
