@@ -24,12 +24,12 @@
 #include "atlas/grid/Partitioner.h"
 #include "atlas/grid/detail/partitioner/EqualRegionsPartitioner.h"
 #include "atlas/grid/detail/partitioner/TransPartitioner.h"
-#include "atlas/library/Library.h"
 #include "atlas/mesh/Mesh.h"
 #include "atlas/mesh/Nodes.h"
 #include "atlas/meshgenerator.h"
 #include "atlas/output/Gmsh.h"
 #include "atlas/parallel/mpi/mpi.h"
+#include "atlas/trans/LegendreCacheCreator.h"
 #include "atlas/trans/Trans.h"
 #include "atlas/trans/VorDivToUV.h"
 #include "atlas/trans/detail/TransFactory.h"
@@ -54,7 +54,9 @@ namespace test {
 
 struct AtlasTransEnvironment : public AtlasTestEnvironment {
     AtlasTransEnvironment( int argc, char* argv[] ) : AtlasTestEnvironment( argc, argv ) {
-        if ( mpi::comm().size() == 1 ) trans_use_mpi( false );
+        if ( mpi::comm().size() == 1 ) {
+            trans_use_mpi( false );
+        }
         trans_init();
     }
 
@@ -63,19 +65,20 @@ struct AtlasTransEnvironment : public AtlasTestEnvironment {
 
 //-----------------------------------------------------------------------------
 
-void read_rspecg( trans::TransImpl& trans, std::vector<double>& rspecg, std::vector<int>& nfrom, int& nfld ) {
+void read_rspecg( const trans::TransImpl& trans, std::vector<double>& rspecg, std::vector<int>& nfrom, int& nfld ) {
     Log::info() << "read_rspecg ...\n";
     nfld = 2;
     if ( mpi::comm().rank() == 0 ) {
-        rspecg.resize( nfld * trans.spectralCoefficients() );
-        for ( size_t i = 0; i < trans.spectralCoefficients(); ++i ) {
+        rspecg.resize( nfld * trans.nb_spectral_coefficients_global() );
+        for ( size_t i = 0; i < trans.nb_spectral_coefficients_global(); ++i ) {
             rspecg[i * nfld + 0] = ( i == 0 ? 1. : 0. );  // scalar field 1
             rspecg[i * nfld + 1] = ( i == 0 ? 2. : 0. );  // scalar field 2
         }
     }
     nfrom.resize( nfld );
-    for ( int jfld = 0; jfld < nfld; ++jfld )
+    for ( int jfld = 0; jfld < nfld; ++jfld ) {
         nfrom[jfld] = 1;
+    }
 
     Log::info() << "read_rspecg ... done" << std::endl;
 }
@@ -89,6 +92,7 @@ void read_rspecg( Field spec ) {
         int nb_spectral_coefficients_global =
             functionspace::Spectral( spec.functionspace() ).nb_spectral_coefficients_global();
         auto view = array::make_view<double, 2>( spec );
+        ATLAS_ASSERT( view.shape( 0 ) == nb_spectral_coefficients_global );
         ATLAS_ASSERT( view.shape( 1 ) >= 2 );
         for ( int i = 0; i < nb_spectral_coefficients_global; ++i ) {
             view( i, 0 ) = ( i == 0 ? 1. : 0. );  // scalar field 1
@@ -125,27 +129,30 @@ CASE( "test_trans_distribution_matches_atlas" ) {
     if ( mpi::comm().rank() == 0 )  // all tasks do the same, so only one needs to check
     {
         int max_nb_regions_EW( 0 );
-        for ( int j = 0; j < trans_partitioner->nb_bands(); ++j )
+        for ( int j = 0; j < trans_partitioner->nb_bands(); ++j ) {
             max_nb_regions_EW = std::max( max_nb_regions_EW, trans_partitioner->nb_regions( j ) );
+        }
 
         EXPECT( t->n_regions_NS == trans_partitioner->nb_bands() );
         EXPECT( t->n_regions_EW == max_nb_regions_EW );
 
         EXPECT( distribution.nb_partitions() == idx_t( mpi::comm().size() ) );
-        EXPECT( idx_t( distribution.partition().size() ) == g.size() );
+        EXPECT( idx_t( distribution.size() ) == g.size() );
 
         std::vector<int> npts( distribution.nb_partitions(), 0 );
 
-        for ( idx_t j = 0; j < g.size(); ++j )
+        for ( idx_t j = 0; j < g.size(); ++j ) {
             ++npts[distribution.partition( j )];
+        }
 
         EXPECT( t->ngptotg == g.size() );
         EXPECT( t->ngptot == npts[mpi::comm().rank()] );
         EXPECT( t->ngptotmx == *std::max_element( npts.begin(), npts.end() ) );
 
         // array::LocalView<int,1> n_regions ( trans.n_regions() ) ;
-        for ( int j = 0; j < trans_partitioner->nb_bands(); ++j )
+        for ( int j = 0; j < trans_partitioner->nb_bands(); ++j ) {
             EXPECT( t->n_regions[j] == trans_partitioner->nb_regions( j ) );
+        }
     }
 }
 
@@ -207,6 +214,8 @@ CASE( "test_distspec" ) {
     trans.gathgrid( nfld, nto.data(), rgp.data(), rgpg.data() );
 
     if ( mpi::comm().rank() == 0 ) {
+        ATLAS_DEBUG_VAR( specnorms[0] );
+        ATLAS_DEBUG_VAR( specnorms[1] );
         EXPECT( eckit::types::is_approximately_equal( specnorms[0], 1., 1.e-10 ) );
         EXPECT( eckit::types::is_approximately_equal( specnorms[1], 2., 1.e-10 ) );
     }
@@ -224,10 +233,23 @@ CASE( "test_distspec_speconly" ) {
 
     Field dist = fs.createField( glb );
 
-    fs.scatter( glb, dist );
-    fs.norm( dist, specnorms );
+    if ( not dist.contiguous() ) {
+        EXPECT_THROWS_AS( fs.scatter( glb, dist ), eckit::Exception );
+        if ( mpi::comm().size() == 1 ) {
+            dist = glb;
+            EXPECT_THROWS_AS( fs.norm( dist, specnorms ), eckit::Exception );
+        }
+        return;
+    }
+    else {
+        EXPECT_NO_THROW( fs.scatter( glb, dist ) );
+        EXPECT_NO_THROW( fs.norm( dist, specnorms ) );
+    }
+
 
     if ( mpi::comm().rank() == 0 ) {
+        ATLAS_DEBUG_VAR( specnorms[0] );
+        ATLAS_DEBUG_VAR( specnorms[1] );
         EXPECT( eckit::types::is_approximately_equal( specnorms[0], 1., 1.e-10 ) );
         EXPECT( eckit::types::is_approximately_equal( specnorms[1], 2., 1.e-10 ) );
     }
@@ -334,7 +356,18 @@ CASE( "test_nomesh" ) {
         spg( imag ) = ( n == 0 ? 0 : -m * spectral.truncation() + n );
     } );
 
-    EXPECT_NO_THROW( spectral.scatter( spfg, spf ) );
+    if ( not spf.contiguous() ) {
+        EXPECT_THROWS_AS( spectral.scatter( spfg, spf ), eckit::Exception );
+        if ( mpi::comm().size() == 1 ) {
+            spf = spfg;
+        }
+        else {
+            return;
+        }
+    }
+    else {
+        EXPECT_NO_THROW( spectral.scatter( spfg, spf ) );
+    }
 
     array::ArrayView<double, 1> sp = array::make_view<double, 1>( spf );
 
@@ -362,7 +395,18 @@ CASE( "test_nomesh" ) {
 
     EXPECT_NO_THROW( trans.dirtrans( gpf, spf ) );
 
-    EXPECT_NO_THROW( spectral.gather( spf, spfg ) );
+    if ( not spf.contiguous() ) {
+        EXPECT_THROWS_AS( spectral.gather( spf, spfg ), eckit::Exception );
+        if ( mpi::comm().size() == 1 ) {
+            spfg = spf;
+        }
+        else {
+            return;
+        }
+    }
+    else {
+        EXPECT_NO_THROW( spectral.gather( spf, spfg ) );
+    }
 
     spectral.parallel_for( option::global(), [&]( idx_t real, idx_t imag, int n ) {
         EXPECT( is_approximately_equal( spg( real ), ( n == 0 ? 4. : 0. ), 0.001 ) );
@@ -502,8 +546,9 @@ CASE( "test_trans_VorDivToUV" ) {
         // TODO: initialise field_vor and field_div with something meaningful
         field_vor[2 * nfld] = 1.;
         Log::info() << "vor: " << std::endl;
-        for ( int j = 0; j < nfld * nspec2; j++ )
+        for ( int j = 0; j < nfld * nspec2; j++ ) {
             Log::info() << field_vor[j] << " ";
+        }
         Log::info() << std::endl;
 
         // With IFS
@@ -519,8 +564,9 @@ CASE( "test_trans_VorDivToUV" ) {
             // TODO: do some meaningful checks
             Log::info() << "Trans library" << std::endl;
             Log::info() << "U: " << std::endl;
-            for ( int j = 0; j < nfld * nspec2; j++ )
+            for ( int j = 0; j < nfld * nspec2; j++ ) {
                 Log::info() << field_U[j] << " ";
+            }
             Log::info() << std::endl;
         }
 
@@ -537,13 +583,116 @@ CASE( "test_trans_VorDivToUV" ) {
             // TODO: do some meaningful checks
             Log::info() << "Local transform" << std::endl;
             Log::info() << "U: " << std::endl;
-            for ( int j = 0; j < nfld * nspec2; j++ )
+            for ( int j = 0; j < nfld * nspec2; j++ ) {
                 Log::info() << field_U[j] << " ";
+            }
             Log::info() << std::endl;
         }
     }
 }
 
+#ifdef TRANS_HAVE_IO
+CASE( "ATLAS-256: Legendre coefficient expected unique identifiers" ) {
+    if ( mpi::comm().size() == 1 ) {
+        util::Config options;
+        options.set( option::type( "ifs" ) );
+        options.set( "flt", false );
+
+        auto uids = {
+            // clang-format off
+            "ifs-T20-RegularGaussianN320-OPT4189816c2e",
+            "ifs-T20-RegularGaussianN640-OPT4189816c2e",
+            "ifs-T20-RegularGaussianN1280-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN320-PL52955330f8-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN640-PL296ba3f6fb-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN1280-PL9e14f63837-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN320-PL440b952c43-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN640-PLcbba2659c1-OPT4189816c2e",
+            "ifs-T20-ReducedGaussianN1280-PL8eadc35e89-OPT4189816c2e",
+            "ifs-T20-L360x181-OPT4189816c2e",
+            "ifs-T20-L3600x1801-OPT4189816c2e",
+            "ifs-T639-RegularGaussianN320-OPT4189816c2e",
+            "ifs-T639-RegularGaussianN640-OPT4189816c2e",
+            "ifs-T639-RegularGaussianN1280-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN320-PL52955330f8-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN640-PL296ba3f6fb-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN1280-PL9e14f63837-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN320-PL440b952c43-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN640-PLcbba2659c1-OPT4189816c2e",
+            "ifs-T639-ReducedGaussianN1280-PL8eadc35e89-OPT4189816c2e",
+            "ifs-T639-L360x181-OPT4189816c2e",
+            "ifs-T639-L3600x1801-OPT4189816c2e",
+            "ifs-T1279-RegularGaussianN320-OPT4189816c2e",
+            "ifs-T1279-RegularGaussianN640-OPT4189816c2e",
+            "ifs-T1279-RegularGaussianN1280-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN320-PL52955330f8-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN640-PL296ba3f6fb-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN1280-PL9e14f63837-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN320-PL440b952c43-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN640-PLcbba2659c1-OPT4189816c2e",
+            "ifs-T1279-ReducedGaussianN1280-PL8eadc35e89-OPT4189816c2e",
+            "ifs-T1279-L360x181-OPT4189816c2e",
+            "ifs-T1279-L3600x1801-OPT4189816c2e",
+            "ifs-T20-grid-800ac12540-OPT4189816c2e",
+            "ifs-T20-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T20-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T20-grid-800ac12540-OPT4189816c2e",
+            "ifs-T20-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T20-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T20-grid-800ac12540-OPT4189816c2e",
+            "ifs-T20-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T20-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T20-grid-7824deccdf-OPT4189816c2e",
+            "ifs-T20-grid-7d1771559e-OPT4189816c2e",
+            "ifs-T639-grid-800ac12540-OPT4189816c2e",
+            "ifs-T639-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T639-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T639-grid-800ac12540-OPT4189816c2e",
+            "ifs-T639-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T639-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T639-grid-800ac12540-OPT4189816c2e",
+            "ifs-T639-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T639-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T639-grid-7824deccdf-OPT4189816c2e",
+            "ifs-T639-grid-7d1771559e-OPT4189816c2e",
+            "ifs-T1279-grid-800ac12540-OPT4189816c2e",
+            "ifs-T1279-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T1279-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T1279-grid-800ac12540-OPT4189816c2e",
+            "ifs-T1279-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T1279-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T1279-grid-800ac12540-OPT4189816c2e",
+            "ifs-T1279-grid-0915e0f040-OPT4189816c2e",
+            "ifs-T1279-grid-7c400822f0-OPT4189816c2e",
+            "ifs-T1279-grid-7824deccdf-OPT4189816c2e",
+            "ifs-T1279-grid-7d1771559e-OPT4189816c2e",
+            // clang-format on
+        };
+        auto uid = uids.begin();
+
+        auto domains    = std::vector<Domain>{GlobalDomain(), RectangularDomain( {-10, 10}, {-20, 20} )};
+        auto spectral_T = std::vector<int>{20, 639, 1279};
+        auto grids      = std::vector<std::string>{"F320", "F640", "F1280", "N320", "N640", "N1280",
+                                              "O320", "O640", "O1280", "L90",  "L900"};
+        for ( auto& domain : domains ) {
+            for ( int T : spectral_T ) {
+                for ( auto name : grids ) {
+                    Log::info() << "Case name:" << name << ", T:" << T << ", domain:" << domain << ", UID:'" << *uid
+                                << "'" << std::endl;
+
+                    Grid grid( name, domain );
+                    auto test = trans::LegendreCacheCreator( grid, T, options ).uid();
+                    ATLAS_DEBUG_VAR( test );
+                    EXPECT( test == *uid );
+
+                    uid++;
+                }
+            }
+        }
+    }
+}
+#endif
+
 //-----------------------------------------------------------------------------
 
 }  // namespace test
