@@ -14,7 +14,6 @@
 #include "eckit/utils/MD5.h"
 
 #include "atlas/grid.h"
-#include "atlas/library/Library.h"
 #include "atlas/option.h"
 #include "atlas/parallel/mpi/mpi.h"
 #include "atlas/runtime/Trace.h"
@@ -263,6 +262,104 @@ CASE( "test cache creator in memory" ) {
     auto trans2 = Trans( cache, grid_global, truncation );
 }
 
+CASE( "ATLAS-256: Legendre coefficient expected unique identifiers" ) {
+    util::Config options;
+    options.set( option::type( "local" ) );
+    options.set( "flt", false );
+
+    auto uids = {
+        // clang-format off
+        "local-T20-GaussianN320-OPT4189816c2e",
+        "local-T20-GaussianN640-OPT4189816c2e",
+        "local-T20-GaussianN1280-OPT4189816c2e",
+        "local-T20-GaussianN320-OPT4189816c2e",
+        "local-T20-GaussianN640-OPT4189816c2e",
+        "local-T20-GaussianN1280-OPT4189816c2e",
+        "local-T20-GaussianN320-OPT4189816c2e",
+        "local-T20-GaussianN640-OPT4189816c2e",
+        "local-T20-GaussianN1280-OPT4189816c2e",
+        "local-T20-L-ny181-OPT4189816c2e",
+        "local-T20-L-ny1801-OPT4189816c2e",
+        "local-T639-GaussianN320-OPT4189816c2e",
+        "local-T639-GaussianN640-OPT4189816c2e",
+        "local-T639-GaussianN1280-OPT4189816c2e",
+        "local-T639-GaussianN320-OPT4189816c2e",
+        "local-T639-GaussianN640-OPT4189816c2e",
+        "local-T639-GaussianN1280-OPT4189816c2e",
+        "local-T639-GaussianN320-OPT4189816c2e",
+        "local-T639-GaussianN640-OPT4189816c2e",
+        "local-T639-GaussianN1280-OPT4189816c2e",
+        "local-T639-L-ny181-OPT4189816c2e",
+        "local-T639-L-ny1801-OPT4189816c2e",
+        "local-T1279-GaussianN320-OPT4189816c2e",
+        "local-T1279-GaussianN640-OPT4189816c2e",
+        "local-T1279-GaussianN1280-OPT4189816c2e",
+        "local-T1279-GaussianN320-OPT4189816c2e",
+        "local-T1279-GaussianN640-OPT4189816c2e",
+        "local-T1279-GaussianN1280-OPT4189816c2e",
+        "local-T1279-GaussianN320-OPT4189816c2e",
+        "local-T1279-GaussianN640-OPT4189816c2e",
+        "local-T1279-GaussianN1280-OPT4189816c2e",
+        "local-T1279-L-ny181-OPT4189816c2e",
+        "local-T1279-L-ny1801-OPT4189816c2e",
+        "local-T20-grid-800ac12540-OPT4189816c2e",
+        "local-T20-grid-0915e0f040-OPT4189816c2e",
+        "local-T20-grid-7c400822f0-OPT4189816c2e",
+        "local-T20-grid-800ac12540-OPT4189816c2e",
+        "local-T20-grid-0915e0f040-OPT4189816c2e",
+        "local-T20-grid-7c400822f0-OPT4189816c2e",
+        "local-T20-grid-800ac12540-OPT4189816c2e",
+        "local-T20-grid-0915e0f040-OPT4189816c2e",
+        "local-T20-grid-7c400822f0-OPT4189816c2e",
+        "local-T20-grid-7824deccdf-OPT4189816c2e",
+        "local-T20-grid-7d1771559e-OPT4189816c2e",
+        "local-T639-grid-800ac12540-OPT4189816c2e",
+        "local-T639-grid-0915e0f040-OPT4189816c2e",
+        "local-T639-grid-7c400822f0-OPT4189816c2e",
+        "local-T639-grid-800ac12540-OPT4189816c2e",
+        "local-T639-grid-0915e0f040-OPT4189816c2e",
+        "local-T639-grid-7c400822f0-OPT4189816c2e",
+        "local-T639-grid-800ac12540-OPT4189816c2e",
+        "local-T639-grid-0915e0f040-OPT4189816c2e",
+        "local-T639-grid-7c400822f0-OPT4189816c2e",
+        "local-T639-grid-7824deccdf-OPT4189816c2e",
+        "local-T639-grid-7d1771559e-OPT4189816c2e",
+        "local-T1279-grid-800ac12540-OPT4189816c2e",
+        "local-T1279-grid-0915e0f040-OPT4189816c2e",
+        "local-T1279-grid-7c400822f0-OPT4189816c2e",
+        "local-T1279-grid-800ac12540-OPT4189816c2e",
+        "local-T1279-grid-0915e0f040-OPT4189816c2e",
+        "local-T1279-grid-7c400822f0-OPT4189816c2e",
+        "local-T1279-grid-800ac12540-OPT4189816c2e",
+        "local-T1279-grid-0915e0f040-OPT4189816c2e",
+        "local-T1279-grid-7c400822f0-OPT4189816c2e",
+        "local-T1279-grid-7824deccdf-OPT4189816c2e",
+        "local-T1279-grid-7d1771559e-OPT4189816c2e",
+        // clang-format on
+    };
+    auto uid = uids.begin();
+
+    auto domains    = std::vector<Domain>{GlobalDomain(), RectangularDomain( {-10, 10}, {-20, 20} )};
+    auto spectral_T = std::vector<int>{20, 639, 1279};
+    auto grids      = std::vector<std::string>{"F320", "F640", "F1280", "N320", "N640", "N1280",
+                                          "O320", "O640", "O1280", "L90",  "L900"};
+    for ( auto& domain : domains ) {
+        for ( int T : spectral_T ) {
+            for ( auto name : grids ) {
+                Log::info() << "Case name:'" << name << "', T:" << T << ", domain:" << domain << ", UID:'" << *uid
+                            << "'" << std::endl;
+
+                Grid grid( name, domain );
+                auto test = trans::LegendreCacheCreator( grid, T, options ).uid();
+                ATLAS_DEBUG_VAR( test );
+                EXPECT( test == *uid );
+
+                uid++;
+            }
+        }
+    }
+}
+
 }  // namespace test
 }  // namespace atlas
 
