@@ -15,30 +15,26 @@
 namespace eckit {
 
 
-template<class Point>
+template <class Point>
 class BSPHyperPlane {
 
     Point normal_;
     double d_;
+
 public:
+    BSPHyperPlane() : normal_(), d_() {}
 
-    BSPHyperPlane():
-        normal_(), d_() {}
-
-    BSPHyperPlane(const Point& normal, const Point& point):
+    BSPHyperPlane(const Point& normal, const Point& point) :
         normal_(Point::normalize(normal)), d_(-Point::dot(normal_, point)) {}
 
-    double position(const Point& p) const {
-        return Point::dot(p, normal_) + d_;
-    }
+    double position(const Point& p) const { return Point::dot(p, normal_) + d_; }
 
     const Point& normal() const { return normal_; }
     double d() const { return d_; }
 };
 
 
-
-} // end namespace
+}  // namespace eckit
 
 
 #endif
