@@ -24,6 +24,8 @@
 #include "eckit/log/Bytes.h"
 #include "eckit/log/Progress.h"
 #include "eckit/log/Timer.h"
+#include "eckit/runtime/Metrics.h"
+
 
 namespace eckit {
 
@@ -91,12 +93,15 @@ Length DataHandle::saveInto(DataHandle& other, TransferWatcher& watcher) {
         static const long bufsize = Resource<long>("doubleBufferSize", 10 * 1024 * 1024 / 20);
         static const long count   = Resource<long>("doubleBufferCount", 20);
 
+        Metrics::set("double_buffering", true);
+
         DblBuffer buf(count, bufsize, watcher);
         return buf.copy(*this, other);
     }
     else {
 
-        static const long bufsize = Resource<long>("bufferSize;$ECKIT_DATAHANDLE_SAVEINTO_BUFFER_SIZE", 64 * 1024 * 1024);
+        static const long bufsize =
+            Resource<long>("bufferSize;$ECKIT_DATAHANDLE_SAVEINTO_BUFFER_SIZE", 64 * 1024 * 1024);
 
         Buffer buffer(bufsize);
         // ResizableBuffer buffer(bufsize);
@@ -173,6 +178,15 @@ Length DataHandle::saveInto(DataHandle& other, TransferWatcher& watcher) {
             throw ReadError(name() + " into " + other.name() + " " + os.str());
         }
 
+        this->collectMetrics("source");
+        other.collectMetrics("target");
+        Metrics::set("size", total);
+        Metrics::set("time", timer.elapsed());
+        Metrics::set("read_time", readTime);
+        Metrics::set("write_time", writeTime);
+        Metrics::set("double_buffering", false);
+
+
         return total;
     }
 }
@@ -231,6 +245,14 @@ std::string DataHandle::title() const {
     return className();
 }
 
+std::string DataHandle::metricsTag() const {
+    return title();
+}
+
+void DataHandle::collectMetrics(const std::string& what) const {
+    Metrics::set(what, this->metricsTag());
+}
+
 template <>
 Streamable* Reanimator<DataHandle>::ressucitate(Stream& s) const {
     return nullptr;
@@ -316,7 +338,7 @@ Length DataHandle::estimate() {
     return 0;
 }
 
-Length DataHandle::openForRead()             {
+Length DataHandle::openForRead() {
     std::ostringstream os;
     os << "DataHandle::openForRead() [" << *this << "]";
     throw NotImplemented(os.str(), Here());
@@ -334,7 +356,7 @@ void DataHandle::openForAppend(const Length&) {
     throw NotImplemented(os.str(), Here());
 }
 
-long DataHandle::read(void*, long)       {
+long DataHandle::read(void*, long) {
     std::ostringstream os;
     os << "DataHandle::read() [" << *this << "]";
     throw NotImplemented(os.str(), Here());
@@ -401,7 +423,6 @@ void DataHandle::hash(MD5& md5) const {
 }
 
 
-
 //----------------------------------------------------------------------------------------------------------------------
 
 
