@@ -11,7 +11,6 @@
 
 #include <numeric>
 
-#include "eckit/filesystem/marsfs/MarsFSPath.h"
 #include "eckit/io/cluster/NodeInfo.h"
 #include "eckit/log/Log.h"
 
@@ -217,6 +216,9 @@ Offset PartFileHandle::seek(const Offset& offset) {
     return seekto;
 }
 
+bool PartFileHandle::canSeek() const {
+    return true;
+}
 
 bool PartFileHandle::merge(DataHandle* other) {
     if (other->isEmpty())
@@ -270,6 +272,10 @@ std::string PartFileHandle::title() const {
     return os.str();
 }
 
+std::string PartFileHandle::metricsTag() const {
+    return PathName::metricsTag(path_);
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace eckit
