@@ -18,9 +18,7 @@ namespace eckit {
 
 OStreamTarget::OStreamTarget(std::ostream& out) : out_(out) {}
 
-OStreamTarget::~OStreamTarget() {
-    //    std::cerr << "OStreamTarget::~OStreamTarget()" << std::endl;
-}
+OStreamTarget::~OStreamTarget() {}
 
 void OStreamTarget::write(const char* start, const char* end) {
     out_.write(start, end - start);
