@@ -17,11 +17,11 @@
 #include "eckit/log/BigNum.h"
 #include "eckit/log/Bytes.h"
 #include "eckit/log/Seconds.h"
+#include "eckit/runtime/Main.h"
 #include "eckit/runtime/Monitor.h"
 #include "eckit/runtime/PipeApplication.h"
 #include "eckit/serialisation/PipeStream.h"
 #include "eckit/serialisation/Stream.h"
-#include "eckit/runtime/Main.h"
 
 
 namespace eckit {
@@ -29,10 +29,7 @@ namespace eckit {
 //----------------------------------------------------------------------------------------------------------------------
 
 PipeApplication::PipeApplication(int argc, char** argv, const char* homeenv) :
-    Application(argc, argv, homeenv),
-    in_("-in", -1),
-    out_("-out", -1),
-    terminate_(false) {
+    Application(argc, argv, homeenv), in_("-in", -1), out_("-out", -1), terminate_(false) {
     // Establish relationship with 'parent' thread for the monitoring
 
     long parent = Resource<long>("-parent", 0);
@@ -89,8 +86,12 @@ void PipeApplication::run() {
         }
 
         try {
-            bool end_;
-            pipe >> end_;  // End of batch marker
+            bool end_;  // End of batch marker
+
+            if (!pipe.next(end_)) {
+                Log::info() << "End of input, exiting" << std::endl;
+                return;
+            }
             if (end_)
                 endBatch();
             else
@@ -184,7 +185,14 @@ void PipeApplication::launch(const std::string& name, int input, int output) {
 
 
     PathName app = Main::instance().argv(0);
-    PathName cmd = app.dirName() / name;
+    PathName dir = app.dirName();
+    PathName cmd;
+    if (std::string(dir) == ".") {
+        cmd = name;
+    }
+    else {
+        cmd = dir / name;
+    }
 
     Log::debug() << "execlp(" << cmd.localPath() << ',' << cmd.baseName().localPath() << ',' << "-in," << in << ','
                  << "-out," << out << ',' << "-parent," << par << ")" << std::endl;
@@ -208,7 +216,7 @@ void PipeApplication::launch(const std::string& name, int input, int output) {
     snprintf(command, 1024, "%s", cmd.localPath());
     snprintf(basename, 1024, "%s", cmd.baseName().localPath());
 
-    ::execlp(command, basename, "-in", in, "-out", out, "-parent", par, (void*)0);
+    ::execlp(command, basename, "-in", in, "-out", out, "-parent", par, nullptr);
 
     std::cerr << "Exec failed " << cmd << Log::syserr << std::endl;
 
