@@ -16,10 +16,10 @@
 
 #include "eckit/eckit.h"
 
-#ifdef ECKIT_HAVE_XXHASH
+#ifdef eckit_HAVE_XXHASH
 #include <xxhash.h>
 #else
-#error "eckit was not configured with xxHash, xxHash is disabled. Use conditional ECKIT_HAVE_XXHASH from eckit/eckit.h"
+#error "eckit was not configured with xxHash, xxHash is disabled. Use conditional eckit_HAVE_XXHASH from eckit/eckit.h"
 #endif
 
 #include "eckit/utils/Hash.h"
@@ -29,31 +29,31 @@ namespace eckit {
 class xxHash : public Hash {
 
 public:  // types
+    xxHash();
 
-  xxHash();
+    explicit xxHash(const char*);
+    explicit xxHash(const std::string&);
 
-  explicit xxHash(const char*);
-  explicit xxHash(const std::string&);
+    xxHash(const void* data, size_t len);
 
-  xxHash(const void* data, size_t len);
+    virtual ~xxHash() override;
 
-  virtual ~xxHash();
+    virtual void reset() const;
 
-  virtual void reset() const;
+    virtual digest_t compute(const void*, long);
 
-  virtual digest_t compute(const void*, long);
+    virtual void update(const void*, long);
 
-  virtual void update(const void*, long);
+    virtual digest_t digest() const;
 
-  virtual digest_t digest() const;
-
-  template<class T>
-  xxHash& operator<<(const T& x) { add(x); return *this; }
-
-private: // members
-
-  XXH64_state_t* ctx_;
+    template <class T>
+    xxHash& operator<<(const T& x) {
+        add(x);
+        return *this;
+    }
 
+private:  // members
+    XXH64_state_t* ctx_;
 };
 
 }  // end namespace eckit
