@@ -8,6 +8,7 @@
  * does it submit to any jurisdiction.
  */
 
+#include <unistd.h>
 #include <string>
 
 #include "eckit/types/Types.h"
@@ -250,6 +251,22 @@ CASE("Create a unique path") {
     EXPECT(!unique.exists());
 }
 
+CASE("Check link") {
+
+    LocalPathName unique = LocalPathName::unique(LocalPathName::cwd());
+    unique.mkdir();
+
+    LocalPathName linkpath = LocalPathName::cwd() + "link";
+
+    ::symlink(unique.c_str(), linkpath.c_str());
+
+    EXPECT(linkpath.exists());
+    EXPECT(linkpath.isLink());
+
+    unique.rmdir();
+    linkpath.unlink();
+}
+
 std::string tidy(const std::string& p) {
     return LocalPathName(p).path();
 }
