@@ -33,8 +33,6 @@ extern base_class *dhsbase;
 extern base_class *flatfilebase;
 extern base_class *multibase;
 extern base_class *apibase;
-extern base_class *odbbase;
-extern base_class *odbdirect;
 
 static base_class **bases[] = {
 	&nullbase,
@@ -46,11 +44,7 @@ static base_class **bases[] = {
 #if !defined(NOFDB5)
     &fdb5base,
 #endif
-#if defined(ODBDIRECT)
-    &odbdirect,
-#endif
-    &odbbase,
-#if defined(HAVE_RPC)
+#if mars_client_HAVE_RPC
     &netbase,
 #endif
 	/* &cachebase, */
