@@ -1067,14 +1067,13 @@ static err dhs_odb_check(dhsdata *dhs, request* original_req)
 	const char *s;
 	int q = 0;
 
-	unsigned long long cnt = 0;
 	while(e == 0 && (s = get_value(dhs->req, "SOURCE", q++)) != NULL)
 	{
 		const char *fileName = no_quotes(s);
 		marslog(LOG_INFO, "Scanning and analysing ODB file '%s'", fileName);
 		request *r = empty_request(0);
 
-		if ((e = odb_to_request_from_file(r, fileName, &cnt)) != 0)
+        if ((e = odb_to_request_from_file(r, fileName)) != 0)
 		{
 			marslog(LOG_EROR, "odb_to_request_from_file: %d", e);
 			return e;
@@ -1108,7 +1107,7 @@ static err dhs_odb_check(dhsdata *dhs, request* original_req)
 	return e;
 }
 
-#ifdef HAVE_NETCDF
+#if mars_client_HAVE_NETCDF
 static err dhs_netcdf_check(dhsdata *dhs,request* original_req)
 {
     int i = 0;
@@ -2723,7 +2722,7 @@ static err  dhs_open(void *data,request *r,request *e,int mode)
 			}
             else
             {
-#ifdef HAVE_NETCDF
+#if mars_client_HAVE_NETCDF
                 if(source_is_netcdf(r)) {
                     dhs->netcdf = true;
                     if((error = dhs_netcdf_check(dhs,r)) != NOERR)
