@@ -23,8 +23,8 @@
 #include "eckit/log/Log.h"
 #include "eckit/runtime/Main.h"
 
-#include "metkit/MarsRequest.h"
-#include "metkit/types/TypeAny.h"
+#include "metkit/mars/MarsRequest.h"
+#include "metkit/mars/TypeAny.h"
 
 #include "fdb5/LibFdb5.h"
 #include "fdb5/api/FDB.h"
@@ -140,7 +140,7 @@ static err  fdb5_open(void *data, request *r, request *ev, int mode)
 
             parameter *p = r->params;
 
-            metkit::MarsRequest req("retrieve");
+            metkit::mars::MarsRequest req("retrieve");
 
             while(p)
             {
@@ -159,7 +159,7 @@ static err  fdb5_open(void *data, request *r, request *ev, int mode)
                     v = v->next;
                 }
 
-                req.setValuesTyped(new metkit::TypeAny(name), x);
+                req.setValuesTyped(new metkit::mars::TypeAny(name), x);
 
                 marslog(LOG_DBUG, "key %s = %s", p->name, p->values->name);
 
