@@ -12,9 +12,9 @@
 #include "mars_client_config.h"
 #include "mars_client_version.h"
 
-const char* odb_api_version();
-unsigned int odb_api_format_version_major();
-unsigned int odb_api_format_version_minor();
+#ifdef ODB_SUPPORT
+#include "odc/api/odc.h"
+#endif
 
 err pproc_print_version();
 
@@ -101,8 +101,9 @@ pghpf_init(&zz);
 #endif
 
 #ifdef ODB_SUPPORT
-	marslog(LOG_INFO,"Using odb_api version: %s (file format version: %ld.%ld)",
-		odb_api_version(), (long) odb_api_format_version_major(), (long) odb_api_format_version_minor());
+    const char* ver;
+    odc_version(&ver);
+    marslog(LOG_INFO,"Using odc version: %s", ver);
 #endif
 
 #ifndef NOFDB5
