@@ -16,7 +16,7 @@
 #include <setjmp.h>
 #include <time.h>
 
-#ifdef HAVE_RPC
+#if mars_client_HAVE_RPC
 
 #ifdef sgi
 #include <bstring.h>
