@@ -15,14 +15,15 @@
 extern "C" {
 #endif
 
-#ifdef ODB_SUPPORT
+#include "mars.h"
+
 ///
 /// \file odb.h
 ///
 /// @author Piotr Kuchta, ECMWF May 2009
 ///
 
-err odb_to_request_from_file(request *r, const char *fileName, unsigned long long *cnt);
+err odb_to_request_from_file(request *r, const char *fileName);
 err odb_compare_attributes_of_first_request(request*, request*);
 long long odb_filter(const char *, FILE *fin, FILE *fout, long long total_to_read);
 
@@ -31,5 +32,3 @@ long long odb_filter(const char *, FILE *fin, FILE *fout, long long total_to_rea
 #ifdef __cplusplus
 }  // extern "C" 
 #endif
-
-#endif
