@@ -586,8 +586,8 @@ void marsinit(int *argc, char **argv, void *addr, int count, option opts[])
 		marsexit(e);
 	}
 
-#ifdef HAVE_UDP_STATS
-	mars_eckit_init(argc, argv);
+#if mars_client_HAVE_UDP_STATS
+        mars_eckit_init(argc, argv);
 #endif
 }
 
