@@ -529,7 +529,7 @@ err vector_postproc(ppbuffer_t *pp, long *nbuffer)
 
 		}
 
-		/* If MARS_USE_INTUVP set and deriving U/V, convertion + interpolation
+		/* If MARS_USE_INTUVP set and deriving U/V, conversion + interpolation
 		has already been done
 		*/
 		if(mars.use_intuvp && is_wind(p) && (ppdata.derive_uv > 0))
@@ -899,6 +899,7 @@ static err obs_scalar_postproc(char *buffer,long inlen,long *outlen)
 		int i;
 		int ok = 1;
 		unsigned int keylength = 0;
+		int version;
 
 		/* Move to next BUFR */
 		while( (p[0]!='B' || p[1]!='U' || p[2]!='F' || p[3]!='R') && inlen>0)
@@ -909,6 +910,8 @@ static err obs_scalar_postproc(char *buffer,long inlen,long *outlen)
 
 		if(inlen <= 0) break;
 
+		version = p[7];
+
 		if (!get_packed_key(p,keyptr))
 		{
 			ok = 0;
@@ -1073,7 +1076,6 @@ static err obs_scalar_postproc(char *buffer,long inlen,long *outlen)
 		}
 #endif
 
-
 #ifdef ECMWF
 		if(ok && mars.restriction)
 		{
@@ -1104,7 +1106,7 @@ static err obs_scalar_postproc(char *buffer,long inlen,long *outlen)
 			char* sec1_start = p;
 			if((unsigned char)sec1_start[7]>1) sec1_start += 8;
 			else sec1_start += 4;
-			if(SEC1_FLAGS(sec1_start)== 0)
+			if(SEC1_FLAGS(sec1_start, version)== 0)
 			{
 				marslog(LOG_WARN,"Report %d has no key but was included",
 					ppdata.in_count+1);
@@ -1123,7 +1125,7 @@ static err obs_scalar_postproc(char *buffer,long inlen,long *outlen)
 			set_key_length(&key,len);
 
 			klength = key_length(p,keyptr);
-			if (SEC1_FLAGS(p)!= 0)
+			if (SEC1_FLAGS(p, version)!= 0)
 			{
 				if(len <= 4 || len > inlen ||
 				p[klength-4] != '7' ||
@@ -1342,7 +1344,7 @@ err PProcEMOS::makeuv(char *vo,char *d,long inlen,char *u,char *v,long *outlen)
 	if(mars.grib_postproc == 0)
 	{
 		marslog(LOG_EROR,"Env variable MARS_GRIB_POSTPROC has been set to 0");
-		marslog(LOG_EROR,"and convertion to U/V requested");
+		marslog(LOG_EROR,"and conversion to U/V requested");
 		return POSTPROC_ERROR;
 	}
 
