@@ -8,6 +8,9 @@
  * does it submit to any jurisdiction.
  */
 
+#include "mars_client_config.h"
+
+#include "hash.h"
 
 /* tcp.c */
 void socket_buffers(int s);
@@ -38,8 +41,10 @@ udpinfo *udp_call(const char *host, int port);
 void udp_free(udpinfo *info);
 
 /* service.c */
+#if mars_client_HAVE_RPC
 err encode_request(const request *r, XDR *x);
 request *decode_request(XDR *x);
+#endif /* mars_client_HAVE_RPC */
 void destroy_service(svc *s);
 err svc_connect(svc *s);
 svc *create_service(const char *name);
@@ -95,9 +100,11 @@ request *get_preferences(svc *s, const char *name);
 void set_preferences(svc *s, request *r, const char *name);
 
 /* queue.c */
+#if mars_client_HAVE_RPC
 err encode_netblk(XDR *x, netblk *blk);
 err decode_netblk(XDR *x, netblk *blk);
 void free_netblk(netblk *blk);
+#endif
 err qmonitor(char *fmt, ...);
 err qenter(request *r);
 err qleave(void);
@@ -308,11 +315,6 @@ int hypercube_field_count(const hypercube *a);
 int hypercube_cube_size(const hypercube *a);
 int hypercube_compare(const hypercube *a, const hypercube *b);
 
-/* hash.c */
-void hash_stat(void);
-char *strcache(const char *name);
-void strfree(char *name);
-
 /* memory.c */
 int getpagesize(void);
 void mem_exit_on_failure(boolean n);
