@@ -415,8 +415,8 @@ void flush_statistics(const request *r, const request *env)
 		locked_write(extfile, buf, strlen(buf));
 	}
 
-#ifdef HAVE_UDP_STATS
-	send_udp_statistics(statistics, env, r);
+#if mars_client_HAVE_UDP_STATS
+        send_udp_statistics(statistics, env, r);
 #endif
 
 	/* Free statistics */
