@@ -894,7 +894,7 @@ err send_remote_targets()
     return e;
 }
 
-#ifndef HAVE_NETCDF
+#if !mars_client_HAVE_NETCDF
 
 netcdf_target *netcdf_target_new(const char *path, const char *format, int more_flags) {
     marslog(LOG_EROR, "Error calling netcdf_target_new, NETCDF not supported");
