@@ -162,7 +162,7 @@ const char *user(const char *s)
 		return u;
 	}
 
-#ifdef HAVE_MARS_USER_ENVIRONMENT
+#if mars_client_HAVE_MARS_USER_ENVIRONMENT
 	const char *p = getenv("MARS_USER");
 	if(p) {
 		u = strcache(p);
