@@ -240,13 +240,15 @@ protected slots:
     void subsetChangedInGoto(int value);
     void messageSelectedInMap(int);
     void navigateUncompressedChanged(bool);
+    void keyProfileReady();
+    void keyProfileLoadFinished();
 
 signals:
     void newMessageSelected(int);
     void keyProfileChanged();
     void messageNumDetermined();
 
-private:
+private:  
     BufrMetaData* data_;
     MvQMessagePanel* messagePanel_;
     MvQBufrDumpPanel* dumpPanel_;
