@@ -724,7 +724,7 @@ void BufrFilterEditor::paintEvent(QPaintEvent* event)
 
 void BufrFilterEditor::loadInit()
 {
-    std::string fName = metview::shareDirFile("BufrFilterDef.json");
+    std::string fName = metview::appDefDirFile("BufrFilterDef.json");
 
     QFile fIn(fName.c_str());
     if (!fIn.open(QIODevice::ReadOnly | QIODevice::Text)) {
