@@ -40,9 +40,7 @@ IconClass::IconClass(const string& name, request* r, const IconClass* sup) :
 
 IconClass::~IconClass()
 {
-    // Never called
     classes.erase(name_);
-    free_all_requests(request_);
 }
 
 void IconClass::scan(ClassScanner& s)
