@@ -759,15 +759,15 @@ vector<IconObjectH> IconObject::subObjects(const string& param, const Request& r
         IconObjectH o = 0;
 
         if (a) {
-            a.print();
-            if (b)
-                cout << b << endl;
+//            a.print();
+//            if (b)
+//                cout << b << endl;
 
             more = true;
             // Embbeded object:
             // We need to create a temporary
 
-            cout << "Embedded object" << endl;
+//            cout << "Embedded object" << endl;
             o = IconFactory::create(this, a);
         }
 
@@ -776,8 +776,8 @@ vector<IconObjectH> IconObject::subObjects(const string& param, const Request& r
             // Real object
             string name = makeFullName(b);
             o           = search(name);
-            if (o == 0)
-                cout << "Cannot find " << name << endl;
+//            if (o == 0)
+//                cout << "Cannot find " << name << endl;
         }
 
         if (o != 0)
@@ -819,9 +819,9 @@ void IconObject::setSubObjects(const string& name,
         else {
             string rel = relativeName(o);
             r(name.c_str()) += rel.c_str();
-            cout << "subObjects " << *this << endl;
-            cout << " subObjects " << *o << endl;
-            cout << " subObjects " << rel << endl;
+//            cout << "subObjects " << *this << endl;
+//            cout << " subObjects " << *o << endl;
+//            cout << " subObjects " << rel << endl;
         }
     }
 
