@@ -13,7 +13,6 @@
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QMap>
-
 #include <QLabel>
 #include <QLineEdit>
 #include <QMenu>
@@ -21,6 +20,7 @@
 #include <QPainter>
 #include <QPair>
 #include <QPlainTextEdit>
+#include <QStyleOptionViewItem>
 #include <QToolButton>
 #include <QVBoxLayout>
 
@@ -61,7 +61,7 @@ void MvQBookmarksDelegate::paint(QPainter* painter, const QStyleOptionViewItem&
                                  const QModelIndex& index) const
 {
     if (index.column() == 0) {
-        QStyleOptionViewItemV4 vopt(option);
+        QStyleOptionViewItem vopt(option);
         initStyleOption(&vopt, index);
 
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
