@@ -310,7 +310,7 @@ void MvQDetailedFolderView::slotEntered(const QModelIndex& index)
 
 void MvQDetailedFolderView::leaveEvent(QEvent* event)
 {
-    itemInfo_ = QString();
+    itemInfo_ = nullptr;
     emit itemEntered(itemInfo_);
     QWidget::leaveEvent(event);
 }
@@ -379,8 +379,8 @@ void MvQDetailedFolderView::mousePressEvent(QMouseEvent* event)
 
 void MvQDetailedFolderView::mouseMoveEvent(QMouseEvent* event)
 {
-    if (!itemInfo_.isEmpty() && !indexAt(event->pos()).isValid()) {
-        itemInfo_ = QString();
+    if (itemInfo_ && !indexAt(event->pos()).isValid()) {
+        itemInfo_ = nullptr;
         emit itemEntered(itemInfo_);
     }
 
