@@ -9,6 +9,7 @@
 
 #include "MvQEditor.h"
 
+#include <QtGlobal>
 #include <QAction>
 #include <QActionGroup>
 #include <QApplication>
@@ -665,6 +666,9 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
             this, SLOT(slotButtonClicked(QAbstractButton*)));
 
     vb->addWidget(buttonBox_);
+
+    // to ignore ESC key
+    installEventFilter(this);
 }
 
 
@@ -672,13 +676,64 @@ MvQEditor::~MvQEditor()
 {
 }
 
+
+bool MvQEditor::eventFilter(QObject *obj, QEvent * event)
+{
+    if(static_cast<MvQEditor*>(obj)  == this &&
+       event->type() == QEvent::KeyPress && ((QKeyEvent*)event)->key() == Qt::Key_Escape )
+    {
+        return true;
+    }
+    return false;
+}
+
+
+void MvQEditor::setupLineFilter()
+{
+    auto label = new QLabel(this);
+    label->setPixmap(QPixmap(":/desktop/filter_decor.svg"));
+    toolbarLeft_->insertWidget(nullptr, label);
+
+    filterLe_ = new QLineEdit(this);
+    filterLe_->setPlaceholderText("Filter ...");
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+    filterLe_->setClearButtonEnabled(true);
+#endif
+
+    toolbarLeft_->insertWidget(nullptr, filterLe_);
+
+    filterCountLabel_ = new QLabel(this);
+    filterCountLabel_->setProperty("filterCount", "1");
+    toolbarLeft_->insertWidget(nullptr, filterCountLabel_);
+
+    connect(filterLe_, SIGNAL(textChanged(QString)),
+            this, SLOT(slotFilterItems(QString)));
+}
+
+void MvQEditor::updateFilterCountLabel()
+{
+    if (filterLe_) {
+        if (filterLe_->text().isEmpty()) {
+            filterCountLabel_->clear();
+        } else {
+            int cnt = filterNonMatchCount();
+            if (cnt == 0) {
+                filterCountLabel_->clear();
+            } else {
+                filterCountLabel_->setText("(" + QString::number(cnt) + " hidden)");
+            }
+        }
+    }
+}
+
 void MvQEditor::setupShowDisabledActions()
 {
     showDisabledAc_ = new QAction(this);
     showDisabledAc_->setText(tr("Show disabled parameters"));
     showDisabledAc_->setCheckable(true);
     showDisabledAc_->setChecked(false);
-    toolbarLeft_->addAction(showDisabledAc_);
+    showDisabledAc_->setIcon(QPixmap(":/desktop/show_disabled.svg"));
+    toolbarRight_->addAction(showDisabledAc_);
 
     MvRequest r = MvApplication::getExpandedPreferences();
     if (const char* c = r("SHOW_DISABLED_PARAMETERS_IN_ICON_EDITORS")) {
@@ -690,7 +745,6 @@ void MvQEditor::setupShowDisabledActions()
             this, SLOT(slotShowDisabled(bool)));
 }
 
-
 bool MvQEditor::showDisabled() const
 {
     return (showDisabledAc_) ? showDisabledAc_->isChecked() : false;
@@ -725,6 +779,7 @@ void MvQEditor::changed()
         savePb_->setEnabled(true);
         resetPb_->setEnabled(true);
         viewAg_->setEnabled(false);
+        updateFilterCountLabel();
     }
 
     //resetPb_->setEnabled(true);
