@@ -51,8 +51,10 @@
 #include "MvRequest.h"
 #include "FolderSettings.h"
 #include "IconClass.h"
+#include "IconDescription.h"
 #include "Items.h"
 #include "Path.h"
+#include "PreviewPanel.h"
 #include "Folder.h"
 #include "Tools.h"
 
@@ -142,8 +144,8 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     connect(folderPanel_, SIGNAL(pathChanged()),
             this, SLOT(slotPathChanged()));
 
-    connect(folderPanel_, SIGNAL(itemInfoChanged(QString)),
-            this, SLOT(slotItemInfo(QString)));
+    connect(folderPanel_, SIGNAL(itemInfoChanged(IconObject*)),
+            this, SLOT(slotItemInfo(IconObject*)));
 
 
     //Search panel below the folders
@@ -155,18 +157,27 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
 
     searchPanel_->hide();
 
-    //Init splitters
     mainSplitter_->setCollapsible(1, false);
 
+    //-----------------------------
+    // Right hand side -- sidebar
+    //-----------------------------
+
+    previewPanel_ = new PreviewPanel(this);
+
+    mainSplitter_->addWidget(previewPanel_);
+    mainSplitter_->setCollapsible(2, false);
+    folderPanel_->setPreviewPanel(previewPanel_);
+    previewPanel_->hide();
+
+    //Init splitters
     int spWidth = mainSplitter_->size().width();
     if (spWidth > 0) {
         QList<int> spSize;
-        spSize << 150;
-        spSize << spWidth - spSize[0];
+        spSize << 150 << spWidth - 2*150 << 150;
         mainSplitter_->setSizes(spSize);
     }
 
-
     //-----------------------------
     // Bottom part  -- drawers
     //-----------------------------
@@ -174,8 +185,8 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     drawerPanel_ = new MvQFolderDrawerPanel(this);
     mainLayout->addWidget(drawerPanel_);
 
-    connect(drawerPanel_, SIGNAL(itemEntered(QString)),
-            this, SLOT(slotItemInfo(QString)));
+    connect(drawerPanel_, SIGNAL(itemEntered(IconObject*)),
+            this, SLOT(slotItemInfo(IconObject*)));
 
     //--------------------------------------
     // Setup actions for toolbars and menus
@@ -204,7 +215,7 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     connectBookmarksObject(bookmarksMenu);
     connectBookmarksObject(bookmarksPanel_);
 
-    MvQEditorListMenu* editorListMenu = new MvQEditorListMenu(findMenu(MvQMainWindow::EditorMenu));
+    new MvQEditorListMenu(findMenu(MvQMainWindow::EditorMenu));
 
     connect(searchPanel_, SIGNAL(iconSelected(IconObject*)),
             folderPanel_, SLOT(slotShowIconInCurrent(IconObject*)));
@@ -622,6 +633,27 @@ void MvQFileBrowser::setupViewActions()
     connect(sidebarAg_, SIGNAL(triggered(QAction*)),
             this, SLOT(slotSidebar(QAction*)));
 
+    //-----------------------------------
+    // Preview panel
+    //-----------------------------------
+
+    //Preview
+    action = new QAction(this);
+    action->setObjectName(QString::fromUtf8("actionPreview"));
+    action->setCheckable(true);
+    action->setChecked(false);  //!!!
+    action->setText(tr("&Preview"));
+    action->setIcon(QPixmap(QString::fromUtf8(":/desktop/preview.svg")));
+    action->setShortcut(tr("Ctrl+P"));
+    actionPreview_ = action;
+    //sidebarAg_->addAction(action);
+
+    connect(previewPanel_, SIGNAL(closePanel()),
+            this, SLOT(slotClosePreview()));
+
+    connect(actionPreview_, SIGNAL(toggled(bool)),
+           previewPanel_, SLOT(setVisible(bool)));
+
     //-------------------------------
     // Bottom part
     //-------------------------------
@@ -776,6 +808,7 @@ void MvQFileBrowser::setupViewActions()
         menuItems_[menuType].push_back(new MvQMenuItem(sidebarAg_->actions().at(0)));
     }
 
+    menuItems_[menuType].push_back(new MvQMenuItem(actionPreview_));
     menuItems_[menuType].push_back(new MvQMenuItem(actionDrawers_, MvQMenuItem::MenuTarget));
     menuItems_[menuType].push_back(new MvQMenuItem(actionStatusbar_, MvQMenuItem::MenuTarget));
 
@@ -1048,9 +1081,10 @@ void MvQFileBrowser::updateViewModeStatus(Desktop::FolderViewMode mode)
     }
 }
 
-void MvQFileBrowser::slotItemInfo(QString msg)
+void MvQFileBrowser::slotItemInfo(IconObject* obj)
 {
-    itemInfoLabel_->setText(msg);
+    itemInfoLabel_->setText(IconDescription::Instance()->info(obj));
+    previewPanel_->setItem(obj);
 }
 
 void MvQFileBrowser::slotPreferences()
@@ -1225,6 +1259,12 @@ void MvQFileBrowser::updateSearchPanel(bool)
     searchPanel_->targetChanged();
 }
 
+void MvQFileBrowser::slotClosePreview()
+{
+    previewPanel_->hide();
+    actionPreview_->setChecked(false);
+}
+
 //=============================================
 //
 // Icon size
@@ -1367,6 +1407,7 @@ void MvQFileBrowser::init(MvQFileBrowser* browser)
         sidebarAg_->actions().at(index)->setChecked(true);
     }
 
+    actionPreview_->setChecked(browser->actionPreview_->isChecked());
     actionDrawers_->setChecked(browser->actionDrawers_->isChecked());
     actionStatusbar_->setChecked(browser->actionStatusbar_->isChecked());
 }
@@ -1399,6 +1440,7 @@ void MvQFileBrowser::writeSettings(QSettings& settings)
     }
 
     settings.setValue("sidebar", sidebarIndex);
+    settings.setValue("previewStatus", actionPreview_->isChecked());
     settings.setValue("drawersStatus", actionDrawers_->isChecked());
     settings.setValue("statusbar", actionStatusbar_->isChecked());
 
@@ -1437,6 +1479,13 @@ void MvQFileBrowser::readSettings(QSettings& settings)
         }
     }
 
+    if (settings.value("previewStatus").isNull()) {
+        actionPreview_->setChecked(false);
+    }
+    else {
+        actionPreview_->setChecked(settings.value("previewStatus").toBool());
+    }
+
     if (settings.value("drawersStatus").isNull()) {
         actionDrawers_->setChecked(true);
     }
