@@ -38,12 +38,6 @@
 
 QHash<IconObject::IconStatus, QColor> MvQFolderModel::statusColour_;
 QColor MvQFolderModel::fadedColour_;
-QString MvQFolderModel::infoNameColour_;
-QString MvQFolderModel::infoTypeColour_;
-QString MvQFolderModel::infoSizeColour_;
-QString MvQFolderModel::infoTimeColour_;
-QString MvQFolderModel::infoLinkLabelColour_;
-QString MvQFolderModel::infoLinkTargetColour_;
 
 MvQFolderModel::MvQFolderModel(QObject* parent) :
     QAbstractItemModel(parent)
@@ -76,13 +70,6 @@ void MvQFolderModel::init()
         statusColour_[IconObject::ErrorStatus]   = QColor(255, 0, 0);
 
         fadedColour_ = MvQTheme::colour("itemview_main", "faded_text");
-
-        infoNameColour_       = MvQTheme::colour("icon_info", "name").name();
-        infoTypeColour_       = MvQTheme::colour("icon_info", "type").name();
-        infoSizeColour_       = MvQTheme::colour("icon_info", "size").name();
-        infoTimeColour_       = MvQTheme::colour("icon_info", "time").name();
-        infoLinkLabelColour_  = MvQTheme::colour("icon_info", "linkLabel").name();
-        infoLinkTargetColour_ = MvQTheme::colour("icon_info", "linkTarget").name();
     }
 }
 
@@ -659,50 +646,6 @@ void MvQFolderModel::createNewFolder()
     IconClass::find("FOLDER").createOne(folder_);
 }
 
-QString MvQFolderModel::objectInfo(const QModelIndex& index)
-{
-    IconObject* obj = objectFromIndex(index);
-    if (obj) {
-        //Icon name
-        QString txt = "<b><font color=\"" + infoNameColour_ + "\">";
-
-        if (obj->isLink()) {
-            txt += "<i>";
-        }
-
-        txt += QString::fromStdString(obj->name());
-
-        if (obj->isLink()) {
-            txt += "</i>";
-        }
-
-        txt += "</font> ";
-
-        //icon class
-        txt += " <font color=\"" + infoTypeColour_ + "\">(" + QString::fromStdString(obj->editorClass().name()) + ") </font> ";
-
-        //file size
-        if (!obj->isFolder()) {
-            txt += "<font color=\"" + infoSizeColour_ + "\">" + formatFileSize(obj->path().sizeInBytes()) + " </font> ";
-        }
-
-        //date and tyme
-        txt += " <font color=\"" + infoTimeColour_ + "\">" + formatFileDate(obj->path().lastModified()) + " </font> ";
-
-        //symlink target
-        if (obj->isLink()) {
-            txt += "<font color=\"" + infoLinkLabelColour_ + "\"> link: </font> ";
-            txt += "<font color=\"" + infoLinkTargetColour_ + "\"><i>" + QString::fromStdString(obj->path().symlinkTarget()) + " </i></font> ";
-        }
-
-        txt += "</b>";
-
-        return txt;
-    }
-
-    return QString();
-}
-
 QString MvQFolderModel::formatFileSize(qint64 size) const
 {
     return MvQFileInfo::formatSize(size);
