@@ -42,6 +42,7 @@
 #include "IconClass.h"
 #include "IconObject.h"
 #include "Path.h"
+#include "PreviewPanel.h"
 #include "MvRequest.h"
 
 
@@ -81,10 +82,12 @@ MvQTabWidget::MvQTabWidget(QWidget* parent) :
     prevAc_ = new QAction(this);
     prevAc_->setText("Go backward in tab history");
     prevAc_->setShortcut(tr("Ctrl+Shift+Left"));
+    prevAc_->setIcon(QPixmap(":/desktop/triangle_left.svg"));
 
     nextAc_ = new QAction(this);
     nextAc_->setText("Go forward in tab history");
     nextAc_->setShortcut(QKeySequence(tr("Ctrl+Shift+Right")));
+    nextAc_->setIcon(QPixmap(":/desktop/triangle_right.svg"));
 
     QList<QAction*> acLst;
     acLst << prevAc_ << nextAc_;
@@ -97,6 +100,16 @@ MvQTabWidget::MvQTabWidget(QWidget* parent) :
     recentTb_->setToolTip(tr("Most recent tabs"));
     hb->addWidget(recentTb_);
 
+    prevTabTb_ = new QToolButton(this);
+    prevTabTb_->setAutoRaise(true);
+    prevTabTb_->setDefaultAction(prevAc_);
+    hb->addWidget(prevTabTb_);
+
+    nextTabTb_ = new QToolButton(this);
+    nextTabTb_->setAutoRaise(true);
+    nextTabTb_->setDefaultAction(nextAc_);
+    hb->addWidget(nextTabTb_);
+
     //Tab list menu
     tabListTb_ = new QToolButton(this);
     tabListTb_->setAutoRaise(true);
@@ -590,8 +603,8 @@ MvQFolderWidget* MvQFolderPanel::addWidget(QString path)
     connect(fw, SIGNAL(desktopCommandRequested(QString, QPoint)),
             this, SLOT(slotDesktopCommand(QString, QPoint)));
 
-    connect(fw, SIGNAL(itemInfoChanged(QString)),
-            this, SIGNAL(itemInfoChanged(QString)));
+    connect(fw, SIGNAL(itemInfoChanged(IconObject*)),
+            this, SIGNAL(itemInfoChanged(IconObject*)));
 
     return fw;
 }
@@ -670,6 +683,10 @@ void MvQFolderPanel::slotCurrentWidgetChanged(int /*index*/)
         tabNavigation_->add(currentFolderPath());
         checkTabNavigationStatus(tabNavigation_->hasPrev(), tabNavigation_->hasNext());
     }
+
+    if (previewPanel_) {
+        previewPanel_->clear();
+    }
 }
 
 void MvQFolderPanel::slotLookupOrOpenInTab(QString path)
