@@ -103,11 +103,10 @@ bool MvQFolderViewBase::changeFolder(Folder* folder, int iconSize)
     return retVal;
 }
 
-QString MvQFolderViewBase::itemInfo(const QModelIndex& index, IndexType indexType)
+IconObject* MvQFolderViewBase::itemInfo(const QModelIndex& index, IndexType indexType)
 {
     QModelIndex folderIndex = (indexType == FilterModelIndex) ? filterModel_->mapToSource(index) : index;
-
-    return folderModel_->objectInfo(folderIndex);
+    return folderModel_->objectFromIndex(folderIndex);
 }
 
 void MvQFolderViewBase::handleDoubleClick(const QModelIndex& index)
