@@ -171,7 +171,7 @@ void MvQIconDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
     if (index.column() == 0) {
         bool blink = (blinkCnt_ != -1 && (index == blinkIndex_ && blinkCnt_ % 2 == 0));
 
-        QStyleOptionViewItemV4 vopt(option);
+        QStyleOptionViewItem vopt(option);
         initStyleOption(&vopt, index);
 
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
@@ -261,7 +261,7 @@ void MvQDetailedViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
     if (index.column() <= 5) {
         bool blink = (blinkCnt_ != -1 && (index == blinkIndex_ && blinkCnt_ % 2 == 0));
 
-        QStyleOptionViewItemV4 vopt(option);
+        QStyleOptionViewItem vopt(option);
         initStyleOption(&vopt, index);
 
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
@@ -334,4 +334,4 @@ QSize MvQDetailedViewDelegate::sizeHint(const QStyleOptionViewItem& option, cons
 {
     QSize size = QStyledItemDelegate::sizeHint(option, index);
     return size + QSize(0, 4);
-}
\ No newline at end of file
+}
