@@ -285,14 +285,14 @@ void MvQIconItem::hoverEnterEvent(QGraphicsSceneHoverEvent*)
 {
     hover_ = true;
     update();
-    view_->itemEntered(this);
+    view_->notifyItemEntered(this);
 }
 
 void MvQIconItem::hoverLeaveEvent(QGraphicsSceneHoverEvent*)
 {
     hover_ = false;
     update();
-    view_->itemLeft(this);
+    view_->notifyItemLeft(this);
 }
 
 void MvQIconItem::setDropTarget(bool t)
@@ -562,14 +562,14 @@ void MvQIconFolderView::selectOnlyOneItem(QGraphicsItem* item)
 // Keypress, shortcut and context menu
 //-----------------------------------------
 
-void MvQIconFolderView::itemEntered(MvQIconItem* item)
+void MvQIconFolderView::notifyItemEntered(MvQIconItem* item)
 {
     emit itemEntered(itemInfo(item->index(), FilterModelIndex));
 }
 
-void MvQIconFolderView::itemLeft(MvQIconItem* /*item*/)
+void MvQIconFolderView::notifyItemLeft(MvQIconItem* /*item*/)
 {
-    emit itemEntered(QString());
+    emit itemEntered(nullptr);
 }
 
 MvQContextItemSet* MvQIconFolderView::cmSet()
