@@ -26,6 +26,7 @@
 #include <QStackedWidget>
 #include <QStyle>
 #include <QStyleOption>
+#include <QStyleOptionViewItem>
 #include <QToolButton>
 #include <QVBoxLayout>
 #include <QDrag>
@@ -52,7 +53,7 @@ void MvQNewIconDelegate::paint(QPainter* painter, const QStyleOptionViewItem& op
                                const QModelIndex& index) const
 {
     if (index.column() == 0) {
-        QStyleOptionViewItemV4 vopt(option);
+        QStyleOptionViewItem vopt(option);
         initStyleOption(&vopt, index);
 
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
