@@ -615,12 +615,8 @@ QVariant MvQPageItem::itemChange(GraphicsItemChange change, const QVariant& valu
 
 void MvQPageItem::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
-    QPointF oriPos  = pos();
-    QPointF dragPos = mapToParent(event->pos());
-
     QGraphicsItem::mousePressEvent(event);
     QGraphicsItem::mouseReleaseEvent(event);
-
     view_->pagePressed(this, event);
 }
 
