@@ -584,7 +584,10 @@ void Service::HandleProgress(request* r)
 {
     const char* x = get_value(r, "SOURCE_REF", 0);
     long ref      = x ? atol(x) : -1;
-
+#if 0
+    marslog(LOG_INFO, "progress %ld", ref);
+    print_all_requests(r);
+#endif
     NotifyMonitor("PROGRESS", r);
     Service* s = Find(ref);
     if (s)
@@ -901,7 +904,7 @@ struct
 void Service::Dispatch(request* r)
 {
     lastcall_ = time(NULL);
-    for (int i = 0; i < NUMBER(handlers); i++)
+    for (size_t i = 0; i < NUMBER(handlers); i++)
         if (handlers[i].name == r->name)
             (this->*handlers[i].proc)(r);
 }
@@ -913,8 +916,10 @@ void Service::ProcessIncoming()
     request* r       = NULL;
     static int first = 1;
 
+//    marslog(LOG_INFO, "Service incoming: %s", name_);
+
     if (first) {
-        for (int i = 0; i < NUMBER(handlers); i++)
+        for (size_t i = 0; i < NUMBER(handlers); i++)
             handlers[i].name = strcache(handlers[i].name);
         first = 0;
     }
