@@ -103,7 +103,7 @@ void MvFlexpartGrid::convert()
     //std::cout << "TIME " << itime << std::endl;
     r.skipRecMarker();
 
-    bool splitByRelease = (static_cast<int>(header_.release.size()) == header_.specPointNum);
+    //bool splitByRelease = (static_cast<int>(header_.release.size()) == header_.specPointNum);
 
     //Loop for number of releaspoints for which a different output shall be created
     for (int specPoint = 0; specPoint < header_.specPointNum; specPoint++) {
