@@ -7,6 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <QtGlobal>
 #include <QApplication>
 #include <QAction>
 #include <QButtonGroup>
@@ -17,6 +18,7 @@
 #include <QFile>
 #include <QHBoxLayout>
 #include <QLabel>
+#include <QLineEdit>
 #include <QPushButton>
 #include <QSettings>
 #include <QSpinBox>
@@ -35,6 +37,7 @@
 #include "GribMetaData.h"
 #include "MvKeyProfile.h"
 
+#include "DocHighlighter.h"
 #include "MvQAbout.h"
 #include "MvQArrowSpinWidget.h"
 #include "MvQFileInfoLabel.h"
@@ -44,10 +47,8 @@
 #include "MvQKeyProfileTree.h"
 #include "MvQLogPanel.h"
 #include "MvQMethods.h"
-//#include "MvQTextEditSearchLine.h"
 #include "MvQTreeView.h"
 #include "MvQTreeExpandState.h"
-//#include "MvQTreeViewSearchLine.h"
 
 #include "MessageControlPanel.h"
 #include "PlainTextWidget.h"
@@ -181,9 +182,7 @@ void MvQGribMainPanel::readSettings(QSettings& settings)
 MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     QWidget(parent),
     currentMsg_(-1),
-    data_(0),
-    //debugDumpLoaded_(false),
-    messageCanBeDecoded_(true)
+    data_(0)
 {
     gribNameSpace_ << "Default"
                    << "geography"
@@ -236,12 +235,25 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     nsCombo_->setCurrentIndex(-1);
     mvDumpLayout->addWidget(w);
 
+    //filter
+    mvDumpFilter_ =new QLineEdit(this);
+    mvDumpFilter_->setPlaceholderText(tr("Filter"));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+    mvDumpFilter_->setClearButtonEnabled(true);
+#endif
+
+    connect(mvDumpFilter_, SIGNAL(textChanged(QString)),
+            this, SLOT(slotMvDumpFilter(QString)));
+
+    mvDumpLayout->addWidget(mvDumpFilter_, 1);
+
     //Message tree
     mvDumpModel_     = new MvQGribMvDumpModel(this);
     mvDumpSortModel_ = new QSortFilterProxyModel(this);
     mvDumpSortModel_->setSourceModel(mvDumpModel_);
     mvDumpSortModel_->setDynamicSortFilter(true);
     mvDumpSortModel_->setFilterRole(Qt::UserRole);
+    mvDumpSortModel_->setFilterCaseSensitivity(Qt::CaseInsensitive);
     mvDumpSortModel_->setFilterFixedString("1");
     mvDumpSortModel_->setFilterKeyColumn(0);
 
@@ -310,6 +322,9 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     stdDumpBrowser_->setProperty("mvStyle", "fileContents");
     stdDumpStacked_->addWidget(stdDumpBrowser_);
 
+    //The document becomes the owner of the highlighter
+    new DocHighlighter(stdDumpBrowser_->editor()->document(),"gribStdDump");
+
     connect(stdGroup_, SIGNAL(buttonClicked(int)),
             stdDumpStacked_, SLOT(setCurrentIndex(int)));
 
@@ -368,6 +383,9 @@ MvQGribDumpPanel::MvQGribDumpPanel(QWidget* parent) :
     wmoDumpBrowser_->setProperty("mvStyle", "fileContents");
     wmoDumpStacked_->addWidget(wmoDumpBrowser_);
 
+    //The document becomes the owner of the highlighter
+    new DocHighlighter(wmoDumpBrowser_->editor()->document(),"gribWmoDump");
+
     connect(wmoGroup_, SIGNAL(buttonClicked(int)),
             wmoDumpStacked_, SLOT(setCurrentIndex(int)));
 
@@ -745,8 +763,17 @@ void MvQGribDumpPanel::slotCurrentDumpChanged(int index)
 
 void MvQGribDumpPanel::slotSetGribNameSpace(const QString& ns)
 {
-    if (mvDumpModel_)
+    if (mvDumpModel_) {
+        mvDumpFilter_->setVisible(ns == "Default");
         mvDumpModel_->setGribNameSpace(ns);
+    }
+}
+
+void MvQGribDumpPanel::slotMvDumpFilter(QString txt)
+{
+    if (mvDumpModel_) {
+        mvDumpModel_->setFilter(txt);
+    }
 }
 
 void MvQGribDumpPanel::slotValueRowSpinChanged(int rowNumber)
@@ -830,7 +857,7 @@ void MvQGribDumpPanel::readSettings(QSettings& settings)
 //
 //==========================================================
 
-GribExaminer::GribExaminer(string& tmpfilename, QWidget* parent) :
+GribExaminer::GribExaminer(QWidget* parent) :
 #ifdef ECCODES_UI
     MvQAbstractMessageExaminer("codes_ui", MvQAbstractMessageExaminer::GribType, parent)
 #else
@@ -873,8 +900,6 @@ GribExaminer::GribExaminer(string& tmpfilename, QWidget* parent) :
     connect(mainPanel_, SIGNAL(messageNumDetermined()),
             this, SLOT(updateFileInfoLabel()));
 
-    //tmpfilename_ = tmpfilename;
-
     //Set up panel
     //setupGotoPanel();
     //setupDumpPanel();
