@@ -69,6 +69,16 @@ void MvQGribMvDumpModel::setGribNameSpace(QString ns)
     endResetModel();
 }
 
+void MvQGribMvDumpModel::setFilter(QString txt)
+{
+    beginResetModel();
+
+    filter_ = txt;
+
+    //Reset the model (views will be notified)
+    endResetModel();
+}
+
 int MvQGribMvDumpModel::columnCount(const QModelIndex& /* parent */) const
 {
     return 3;
@@ -101,8 +111,12 @@ QVariant MvQGribMvDumpModel::data(const QModelIndex& index, int role) const
             return QVariant();
 
         GribItem* item = data_->item().at(index.row());
+        QString name = QString::fromStdString(item->name());
         if (gribNameSpace_ == "Default") {
-            if (QString::fromStdString(item->name()).contains(".") == false) {
+            if (!filter_.isEmpty() && !name.contains(filter_, Qt::CaseInsensitive))
+                return QString::number(0);
+
+            if (name.contains(".") == false) {
                 return QString::number(1);
             }
             else {
@@ -110,7 +124,7 @@ QVariant MvQGribMvDumpModel::data(const QModelIndex& index, int role) const
             }
         }
         else {
-            if (QString::fromStdString(item->name()).startsWith(gribNameSpace_ + ".")) {
+            if (name.startsWith(gribNameSpace_ + ".")) {
                 return QString::number(1);
             }
             else {
