@@ -25,7 +25,8 @@ HovToolkit::HovToolkit() :
     netcdf_(0),
     xint_(0),
     expand_(false),
-    netcdfIn_(0)
+    netcdfIn_(0),
+    procType_(HOV_DATA_MODULE)  // default value for option EXPAND
 {
     //empty
 }
@@ -191,9 +192,14 @@ MvRequest HovToolkit::CreateOutputRequest()
     // Create the View request taking values from the input application
     MvRequest viewReq = CreateViewRequest();
 
-    // Save min/max date. This info is important if the dates in the
-    // original View are 'automatic'.
-    MvDate dd(dateMinD_);
+    // Save min/max date. This info is important if the dates in the original
+    // View are 'automatic'.
+    // Below, use value GetRefTime() instead of dateMinD_. Variavel dateMinD_
+    // stores the minimum date value of the current input data file. Variavel
+    // refTime_ (reference time) stores the minimum date value of the first
+    // input data file. These two values are the same for applications LINE,
+    // AREA and HEIGHT but not for EXPAND.
+    MvDate dd(GetRefTime());
     viewReq("DATE_MIN") = dd.magicsDate().c_str();
     dd                  = dateMaxD_;
     viewReq("DATE_MAX") = dd.magicsDate().c_str();
@@ -870,6 +876,7 @@ bool HovToolkit::IsVisualise()
     else
         return true;
 }
+
 bool HovToolkit::IsDataModule(const char* verb)
 {
     return (verb && (strcmp(verb, "LINE_HOVM") == 0 ||
