@@ -106,10 +106,6 @@ CBufr::CBufr(request* s) :
 
 CBufr::~CBufr()
 {
-    mars.debug = true;
-    print_all_requests(r);
-    mars.debug = false;
-
     const char* t = get_value(r, "TEMPORARY", 0);
     const char* p = get_value(r, "PATH", 0);
     if (t && p) {
@@ -240,26 +236,28 @@ void CGeopts::load(void)
     //  is probably a geopoints structure in memory, or with zero count!
 }
 
-void CGeopts::unload(void)
+void CGeopts::unload(bool doFree)
 {
     //	if( gpts.count() > 0 || (r == NULL))
     //	  {
-    if (r == NULL) {
-        char* path = marstmp();
-        gpts.write(path);
+    if (doFree) {
+        if (r == NULL) {
+            char* path = marstmp();
+            gpts.write(path);
 
-        r = empty_request("GEOPOINTS");
-        set_value(r, "TEMPORARY", "1");
-        set_value(r, "PATH", "%s", path);
+            r = empty_request("GEOPOINTS");
+            set_value(r, "TEMPORARY", "1");
+            set_value(r, "PATH", "%s", path);
+        }
+
+        gpts.unload();
     }
-
-    gpts.unload();
     //	  }
 }
 
 int CGeopts::Write(FILE* f)
 {
-    unload();
+    unload(true);
     return CopyFile(get_value(r, "PATH", 0), f);
 }
 
@@ -309,13 +307,28 @@ CGeopts::CGeopts(MvGeoPoints& gptsIn) :
 }
 
 
-CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid) :
+CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid, bool storeLocs) :
     InPool(tgeopts)
 {
     r = NULL;
     p->load();
-    gpts.newReservedSize(p->gpts.count());
-    gpts.format(p->gpts.format(), p->nValCols());
+    eGeoFormat fmt = (storeLocs)
+                     ? eGeoNCols
+                     : p->gpts.format();
+    eGeoCopyMode copyMode = (fmt == eGeoNCols)
+                            ? eGeoCopyCoordinatesOnly
+                            : eGeoCopyAll;
+
+
+    gpts.copy(p->gpts, copyMode); // make a copy of the input geopoints
+
+    if (storeLocs) {
+        gpts.format(eGeoNCols, 3);
+        gpts.addColName("value");
+        gpts.addColName("nearest_latitude");
+        gpts.addColName("nearest_longitude");
+    }
+
 
     field* g = get_field(v, n, expand_mem);
 
@@ -336,10 +349,20 @@ CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid
     n = 0;
     for (int i = 0; i < p->gpts.count(); i++) {
         double x = DBL_MAX;
-        MvGeoP1 pt = p->gpts[i];
-        if (!pt.latlon_missing()) {  // if lat/lon are missing, then it will be DBL_MAX
+        double near_lat = DBL_MAX;
+        double near_lon = DBL_MAX;
+        MvGeoP1 &pt = gpts[i];
+        // if lat/lon are missing, then it will be DBL_MAX
+        if (!pt.latlon_missing() && pt.isLocationValid()) {  // if lat/lon are missing, then it will be DBL_MAX
             if (nearest) {
-                x = fld->nearestGridpoint(pt.lon_x(), pt.lat_y(), nearestValid);
+                if (storeLocs) {
+                    MvGridPoint gridp = fld->nearestGridpointInfo(pt.lon_x(), pt.lat_y(), nearestValid);
+                    near_lat = gridp.loc_.latitude();
+                    near_lon = gridp.loc_.longitude();
+                    x = gridp.value_;
+                }
+                else
+                    x = fld->nearestGridpoint(pt.lon_x(), pt.lat_y(), nearestValid);
             }
             else {
                 x = fld->interpolateAt(pt.lon_x(), pt.lat_y());
@@ -358,7 +381,12 @@ CGeopts::CGeopts(CGeopts* p, fieldset* v, int n, bool nearest, bool nearestValid
         pt.time(tim);
         pt.height(level);
 
-        gpts[n] = pt;
+        if (storeLocs) {
+            pt.value(x);
+            pt.value(near_lat, 1);
+            pt.value(near_lon, 2);
+        }
+
         n++;
     }
 
@@ -423,7 +451,7 @@ CGeopts::~CGeopts()
 
 void CGeopts::ToRequest(request*& s)
 {
-    unload();
+    unload(true);
 
     // Initialise hidden parameters
     if (!get_value(r, "_CLASS", 0))
@@ -1696,11 +1724,12 @@ Value GeoFromGribFunction1::Execute(int, Value* arg)
     arg[0].GetValue(v);
     arg[1].GetValue(g);
 
-    return Value(new CGeopts(g, v, 0, false, false));
+    return Value(new CGeopts(g, v, 0, false, false, false));
 }
 
 //===========================================================================
 //                                          this one looks for nearest points
+// takes (fieldset, geopoints) as args
 class GeoFromGribFunction2 : public Function
 {
 public:
@@ -1717,19 +1746,25 @@ Value GeoFromGribFunction2::Execute(int arity, Value* arg)
     arg[0].GetValue(v);
     arg[1].GetValue(g);
 
-    return Value(new CGeopts(g, v, 0, true, false));
+    return Value(new CGeopts(g, v, 0, true, false, false));
 }
 
+// takes (fieldset, geopoints, string) as args
 class GeoFromGribFunction3 : public Function
 {
 public:
     GeoFromGribFunction3(const char* n) :
-        Function(n, 3, tgrib, tgeopts, tstring), optionString_("valid") {}
+        Function(n), 
+                 validOptionString_("valid"), storeLocsOptionString_("store_locs"),
+                 valid_(false), storeLocs_(false) {}
     int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 
 protected:
-    std::string optionString_;
+    std::string validOptionString_;
+    std::string storeLocsOptionString_;
+    bool valid_;
+    bool storeLocs_;
 };
 
 int GeoFromGribFunction3::ValidArguments(int arity, Value* arg)
@@ -1739,14 +1774,22 @@ int GeoFromGribFunction3::ValidArguments(int arity, Value* arg)
     if (arg[0].GetType() != tgrib || arg[1].GetType() != tgeopts)
         return false;
 
-    // the 3rd arg is a string parameter
-    if (arg[2].GetType() == tstring) {
-        const char* tmpCh;
-        arg[2].GetValue(tmpCh);
-        if (!tmpCh || strcmp(tmpCh,optionString_.c_str()) != 0)
+    // the 3rd and optional 4th args are string parameters
+    for (int a = 2; a <= arity-1; a++) {
+        if (arg[a].GetType() == tstring) {
+            const char* tmpCh;
+            arg[a].GetValue(tmpCh);
+            if (tmpCh) {
+                if (strcmp(tmpCh,validOptionString_.c_str()) == 0)
+                    valid_ = true;
+                if (strcmp(tmpCh,storeLocsOptionString_.c_str()) == 0)
+                    storeLocs_ = true;
+            }
+            if (!valid_ && !storeLocs_)
+                return false;
+        } else {
             return false;
-    } else {
-        return false;
+        }
     }
     return true;
 }
@@ -1758,7 +1801,7 @@ Value GeoFromGribFunction3::Execute(int arity, Value* arg)
     arg[0].GetValue(v);
     arg[1].GetValue(g);
 
-    return Value(new CGeopts(g, v, 0, true, true));
+    return Value(new CGeopts(g, v, 0, true, valid_, storeLocs_));
 }
 
 
@@ -1858,6 +1901,9 @@ Value SubGeoFunction::Execute(int, Value* arg)
                 std::string colName(p->valueColumnName(i));
                 set_value(r, colName.c_str(), "%g", g.ivalue(i));
             }
+
+            if (!g.isStnIdEmpty())
+                set_value(r, "__strings", "%s", "stnid");
         }
 
 
@@ -1958,7 +2004,7 @@ Value GribGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(v);
         arg[1].GetValue(g);
 
-        CGeopts* p = new CGeopts(g, v, 0, false, false);
+        CGeopts* p = new CGeopts(g, v, 0, false, false, false);
 
 
         // for each point,
@@ -1978,7 +2024,7 @@ Value GribGeoBinOp::Execute(int, Value* arg)
         arg[0].GetValue(g);
         arg[1].GetValue(v);
 
-        CGeopts* p = new CGeopts(g, v, 0, false, false);
+        CGeopts* p = new CGeopts(g, v, 0, false, false, false);
 
 
         // for each point,
@@ -2517,6 +2563,7 @@ Value GeoCreateFunction::Execute(int arity, Value* arg)
             // at least the first value column should have a name by default
             if (nv >= 1 && (efmt == eGeoNCols)) {
                 gnew->addColName("value");
+                gnew->fillValueColumnNames();
             }
         }
 
@@ -3037,7 +3084,8 @@ Value GeoMetadataFunction::Execute(int, Value* arg)
     }
     else {
         g->unload();
-        return Value();
+        request* r = empty_request(NULL); // return an empty request if no metadata
+        return Value(r);
     }
 }
 
