@@ -15,7 +15,7 @@
 #include <MvMiscelaneous.h>
 
 #if defined(METVIEW_ODB)
-#include "odb_api/odbcapi.h"
+#include <odc/api/odc.h>
 #endif
 
 #if defined(HAVE_PPROC_MIR)
@@ -774,24 +774,24 @@ Value ExamineFunction::Execute(int, Value* arg)
     // check the data type and lauch the correct examiner
     if (arg[0].GetType() == tgrib) {
         verb    = "GRIB";
-        service = "GribExaminer";
+        service = "UiAppManager";
     }
     else if (arg[0].GetType() == tbufr) {
         verb    = "BUFR";
-        service = "BufrExaminer";
+        service = "UiAppManager";
     }
     else if (arg[0].GetType() == tnetcdf) {
         verb    = "NETCDF";
-        service = "NcExaminer";
+        service = "UiAppManager";
     }
     else if (arg[0].GetType() == todb) {
         verb    = "ODB_DB";
-        service = "OdbExaminer";
+        service = "UiAppManager";
     }
 
     else if (arg[0].GetType() == tgeopts) {
         verb    = "GEOPOINTS";
-        service = "GeopExaminer";
+        service = "UiAppManager";
     }
     else {
         // should never actually get here if the guards in ValidArguments are correct
@@ -822,6 +822,7 @@ Value ExamineFunction::Execute(int, Value* arg)
     r.setVerb(verb);
     const char* path = get_value(finalreq, "PATH", 0);
     r("PATH")        = path;
+    r("_ACTION")     = "examine";
     v                = Value(service, r);
 
 #else
@@ -1126,11 +1127,11 @@ Value MetviewVersionFunction::Execute(int arity, Value* arg)
 
 
 #if defined(METVIEW_ODB)
-    const char* odbapi_version = odb_api_version();
-    set_value(r, "odb_api_version", "%s", odbapi_version);
+    const char* odc_ver;
+    odc_version(&odc_ver);
+    set_value(r, "odc_version", "%s", odc_ver);
 #endif
 
-
     return Value(r);
 }
 
