@@ -74,6 +74,48 @@ enum eVectorIndexType
 CArray::ValuesType CVector::defaultValtype = CArray::VALUES_F64;
 std::map<std::string, CArray::ValuesType> CArray::valtypes;
 
+
+// helper function to allow multiple ways for the user to input numbers, but
+// to always receive them as a vector
+
+argtype numberListOrVectorArgAsVector(Context *Owner, Value &arg, CVector **result)
+{
+    // get the list of percentiles and put them into a vector if not already one
+    vtype type = arg.GetType();
+    switch (type) {
+        case tvector: {
+            arg.GetValue(*result);
+            return tvector;
+            break;
+        }
+        case tlist: {
+            // call a Macro function to convert from a list to a vector
+            char* vectorConstructorFn = strcache("vector");
+            Owner->Push(arg);
+            Owner->CallFunction(vectorConstructorFn, 1);
+            Value y = Owner->Pop();
+            y.GetValue(*result);
+            (*result)->Attach();  // to avoid deletion when 'y' is deleted
+            return tlist;
+            break;
+        }
+        case tnumber: {
+            double d;
+            arg.GetValue(d);
+            (*result) = new CVector(1);
+            (*result)->setIndexedValue(0, d);
+            return tnumber;
+            break;
+        }
+        default: {
+            return terror;
+        }
+    }
+}
+
+
+
+
 CArray::ValuesType CArray::valuesTypeFromString(const std::string& s)
 {
     std::map<std::string, CArray::ValuesType>::iterator it = CArray::valtypes.find(s);
@@ -2302,11 +2344,76 @@ Value MeanVectorFunction::Execute(int, Value* arg)
         return Value();
 }
 
+//=============================================================================
 
 class VectorPercentileFunction : public Function
 {
 public:
-    VectorPercentileFunction(const char* n, int m) :
+    VectorPercentileFunction(const char* n) :
+        Function(n, 1, tvector)
+    {
+        info = "Returns a set of percentiles of a vector";
+    };
+    virtual int ValidArguments(int arity, Value* arg);
+    virtual Value Execute(int arity, Value* arg);
+};
+
+int VectorPercentileFunction::ValidArguments(int arity, Value* arg)
+{
+    if (arity != 2)
+        return false;
+
+    if (arg[0].GetType() != tvector)
+        return false;
+
+    if (arg[1].GetType() != tlist && arg[1].GetType() != tvector && arg[1].GetType() != tnumber)
+        return false;
+
+    return true;
+}
+
+/*
+ * Input: a single vector, and a percentile or list/vector of percentiles
+ * Output: a vector of 'p' numbers
+ */
+Value VectorPercentileFunction::Execute(int, Value* arg)
+{
+    CVector* inputVector;
+    CVector* percents;
+    bool multiple_percs = true;  // result will be a single number or a vector
+
+    arg[0].GetValue(inputVector);
+
+
+    // get the list of percentiles and put them into a vector if not already one
+    argtype t = numberListOrVectorArgAsVector(Owner(), arg[1], &percents);
+    if (t == tnumber)
+        multiple_percs = false;
+    if (t == terror)
+        return Error("Percentile: bad data type for second argument, %d", t);
+
+
+    int numPercentiles  = percents->Count();
+
+    CVector* resultPercentiles = new CVector(numPercentiles);
+
+
+    inputVector->Percentile((*percents), CVector::PERCENTILE_NEAREST, (*resultPercentiles));
+
+    if (multiple_percs)
+        return Value(resultPercentiles);
+    else
+        return Value((*resultPercentiles)[0]);
+}
+
+
+
+//=============================================================================
+
+class ListOfVectorPercentileFunction : public Function
+{
+public:
+    ListOfVectorPercentileFunction(const char* n) :
         Function(n, 1, tvector)
     {
         info = "Returns a set of percentiles of a list of vector variables";
@@ -2315,7 +2422,7 @@ public:
     virtual Value Execute(int arity, Value* arg);
 };
 
-int VectorPercentileFunction::ValidArguments(int arity, Value* arg)
+int ListOfVectorPercentileFunction::ValidArguments(int arity, Value* arg)
 {
     //	if (arity != 2 && arity != 3) return false;  // if we do multiple interpolation types
     if (arity != 2)
@@ -2340,7 +2447,7 @@ int VectorPercentileFunction::ValidArguments(int arity, Value* arg)
  * Terminology: each inout vector is a 1-dimensional 'column', so we compute percentiles from
  *              the data values along each 'row'
  */
-Value VectorPercentileFunction::Execute(int, Value* arg)
+Value ListOfVectorPercentileFunction::Execute(int, Value* arg)
 {
     CList* listOfInputVectors;
     CVector* percents;
@@ -2350,34 +2457,12 @@ Value VectorPercentileFunction::Execute(int, Value* arg)
 
 
     // get the list of percentiles and put them into a vector if not already one
-    vtype type = arg[1].GetType();
-    switch (type) {
-        case tvector: {
-            arg[1].GetValue(percents);
-            break;
-        }
-        case tlist: {
-            // call a Macro function to convert from a list to a vector
-            char* vectorConstructorFn = strcache("vector");
-            Owner()->Push(arg[1]);
-            Owner()->CallFunction(vectorConstructorFn, 1);
-            Value y = Owner()->Pop();
-            y.GetValue(percents);
-            percents->Attach();  // to avoid deletion when 'y' is deleted
-            break;
-        }
-        case tnumber: {
-            double d;
-            arg[1].GetValue(d);
-            percents = new CVector(1);
-            percents->setIndexedValue(0, d);
-            resultIsList = false;
-            break;
-        }
-        default: {
-            return Error("Percentile: bad data type for second argument, %d", type);
-        }
-    }
+    argtype t = numberListOrVectorArgAsVector(Owner(), arg[1], &percents);
+    if (t == tnumber)
+        resultIsList = false;
+    if (t == terror)
+        return Error("Percentile: bad data type for second argument, %d", t);
+
 
     int numPercentiles = percents->Count();
     int numVectors     = listOfInputVectors->Count();
@@ -2483,7 +2568,8 @@ static void install(Context* c)
     c->AddFunction(new MinMaxValueVectorFunction("minvalue", 0));
     c->AddFunction(new MeanVectorFunction("mean", 1));
     c->AddFunction(new MeanVectorFunction("sum", 0));
-    c->AddFunction(new VectorPercentileFunction("percentile", 0));
+    c->AddFunction(new ListOfVectorPercentileFunction("percentile"));
+    c->AddFunction(new VectorPercentileFunction("percentile"));
 
     // binary operations
 
