@@ -13,7 +13,9 @@
 
 
 #include <stdio.h>
-
+#ifdef METVIEW_ODB_NEW
+#include <eckit/runtime/Main.h>
+#endif
 #include "macro.h"
 #include "script.h"
 #include "cbufr.h"
@@ -36,6 +38,13 @@ public:
 };
 
 
+#ifdef METVIEW_ODB_NEW
+void init_odb(int argc, char **argv)
+{
+        eckit::Main::initialise(argc, argv);
+}
+#endif
+
 extern "C" {
 
 PythonScript* metviewPythonScript;
@@ -51,6 +60,9 @@ int mp_init(int argc, char** argv)
 {
     if (!doneInit) {
         marsinit(&argc, argv, 0, 0, 0);
+#ifdef METVIEW_ODB_NEW
+        init_odb(argc, argv);
+#endif
         metviewPythonScript = new PythonScript();
 
         // if we don't do this, then for some requests sent to uPlot,
@@ -60,7 +72,6 @@ int mp_init(int argc, char** argv)
         getcwd(pwd, sizeof(pwd) - 1);
         //Script::MacroPath(makepath(pwd,"PythonScript.py"));  // dummy filename
         Script::MacroMainPath(makepath(pwd, "PythonScript.py"));  // dummy filename
-
         doneInit = true;
     }
     return 0;
@@ -436,7 +447,7 @@ int p_get_req_num_params(Value* val)
     val->GetValue(r);
     if (r) {
         MvRequest req(r, false, false);  // clone=false, free_req_on_destroy=false
-        return req.countParameters();
+        return req.countParameters(false); //includeHidden=false
     }
     else
         return 0;  // NULL request pointer -> no parameters
