@@ -236,6 +236,10 @@ void SetValue(request* r, const char* param, Value& val)
         default:
             val.GetValue(u);
             set_subrequest(r, param, u);
+
+            // this is a data-type value, so we should record that we have a new
+            // reference to it
+            val.GetContent()->Attach();
             break;
     }
 }
@@ -818,6 +822,19 @@ void PlotterFunction::SetPlotter(const char* p)
 
 //=============================================================================
 
+// Get the value of a parameter name from a request structure
+// The input request can be originated from different sources, including a 
+// Macro definition structure or a Macro read_request function.
+// The search procedure to find the parameter name in the request follows this
+// sequence:
+// 1) use the original parameter name
+// 2) convert parameter name to capital letters (request defined as a
+//    definition structure in Macro is given in capital letters)
+// 3) make sure the parameter name is right. If the name is not found in the 
+//    related definition file then guess a new name
+// 4) expand the request and get the default value
+// 5) return nil
+
 class RequestGetElemFunction : public Function
 {
 public:
@@ -835,7 +852,6 @@ Value RequestGetElemFunction::Execute(int, Value* arg)
     arg[0].GetValue(r);
     arg[1].GetValue(p);
 
-
     if ((s = get_subrequest(r, p, 0))) {
         Value v;
         v.SetContent(s);           // This will force expension of "DATA",..
@@ -845,45 +861,68 @@ Value RequestGetElemFunction::Execute(int, Value* arg)
         return v;
     }
 
-    // If the request has a language file
-    // first expand the parameter name and get the defaults
-
-    SimpleRequestFunction* f = (SimpleRequestFunction*)ObjsCache.Find(r->name);
-    if (f != 0) {
-        s = empty_request(r->name);
-        s = f->Expand(s, ~EXPAND_NO_DEFAULT & ~EXPAND_NO_OFF);
-
-        // Make sure the parameter name is right
-
-        parameter* q = closest_parameter(
-            closest_verb(f->GetLanguage(), r->name),
-            p);
-
-        if (q)
-            p = q->name;
-    }
-
-
+    // First, search the parameter name in the request
     int n = count_values(r, p);
+    if (n == 0) {
+        // Second, search the input parameter name in capital letters
+        string sp = p;
+        for(int i = 0; i < sp.length(); i++)
+            sp[i] = toupper(sp[i]);
 
-    if (n == 0 && s != 0) {
-        // Use language
-        r = s;
+        p = strcache(sp.c_str());
         n = count_values(r, p);
+        if (n == 0) {
+            // Third, make sure the parameter name is correct
+            // Check if request has a language file
+            SimpleRequestFunction* f = (SimpleRequestFunction*)ObjsCache.Find(r->name);
+            if (f == 0)
+                return Value();   //return nil
+
+            // Get the closest parameter name
+            parameter* q = closest_parameter(
+               closest_verb(f->GetLanguage(), r->name), p);
+            if (q)
+                p = q->name;
+
+            n = count_values(r, p);
+            if (n == 0) {
+                // Fourth, expand the request and get the default value
+                s = empty_request(r->name);
+                s = f->Expand(s, ~EXPAND_NO_DEFAULT & ~EXPAND_NO_OFF);
+
+                // Use language
+                r = s;
+                n = count_values(r, p);
+                if (n == 0)
+                    return Value();
+            }
+        }
     }
 
-    if (n == 0)
-        return Value();  // return nil
     if (n > 1)
         l = new CList(n);
 
-    Date d;
-
     parameter* par = find_parameter(r, p);
     if (par == NULL)
         return Value();
+
+
     value* vi = par->values;
 
+    // if the hidden item "__strings" exists, then it will tell us
+    // if this parameter should be returned as a string, regardless of
+    // the usual interpretation of parameter values
+
+    parameter* stringpar = find_parameter(r, "__strings");
+    if (stringpar) {
+        value* svi = stringpar->values;
+        //const char* svn = par->name;
+        if (!strcmp(svi->name, p))
+            return Value(vi->name);
+    }
+
+
+    Date d;
     for (int i = 0; i < n; i++) {
         const char* q = vi->name;
         Value v;
@@ -911,6 +950,7 @@ Value RequestGetElemFunction::Execute(int, Value* arg)
     free_all_requests(s);
     return Value(l);
 }
+
 //=============================================================================
 
 class ComplexRequestFunction : public Function
