@@ -698,6 +698,40 @@ void Value::SetContent(request* r)
     SetContent(c);
 }
 
+void Value::SetContentRequest(request* r)
+{
+    if (r == 0) {
+        SetContent(new CNil);
+        return;
+    }
+
+    request* s = r;
+    int n = 0;
+    while (s) {
+        s = s->next;
+        n++;
+    };
+
+    Content* c;
+    CList* l = 0;
+    l = new CList(n);
+
+    int i = 0;
+    while (r) {
+        s = r->next;
+        r->next = 0;
+
+        c = new CRequest(r);
+        (*l)[i++] = Value(c);
+
+        r->next = s;
+        r       = s;
+    }
+
+    c = l;
+    SetContent(c);
+}
+
 const char* Content::TypeName(void)
 {
     return Value::TypeName(type);
