@@ -366,7 +366,7 @@ void ReplyObserver::callService(const string& service, const MvRequest& r)
 QString MacroEdit::emptyString_;  // used as a default argument to findString()
 
 
-MacroEdit::MacroEdit(QString& appName, QWidget* parent, QString* fileToLoad) :
+MacroEdit::MacroEdit(QString appName, QWidget* parent, QString* fileToLoad) :
     QMainWindow(parent),
     appName_(appName),
     fontSize_(11),
@@ -2783,7 +2783,7 @@ void MacroEdit::writeSettings()
     settings.setValue("showLineNumbers", textEditor->showLineNumbers());
     settings.setValue("autoInsertLicence", autoInsertLicence_);
     //settings.setValue("sidebar", actionSideBar->isChecked() && actionSideBar->isEnabled());
-    settings.setValue("sidebarSplitter", sidebarSplitter->saveState());
+    settings.setValue("sidebarSplitter_v1", sidebarSplitter->saveState());
 
     if (EditorTheme* t = EditorTheme::current())
         settings.setValue("theme", t->name());
@@ -2822,8 +2822,8 @@ void MacroEdit::readSettings()
     autoInsertLicence    = settings.value("autoInsertLicence", false).toBool();
     QString theme        = settings.value("theme").toString();
 
-    if (settings.contains("sidebarSplitter"))
-        sidebarSplitter->restoreState(settings.value("sidebarSplitter").toByteArray());
+    if (settings.contains("sidebarSplitter_v1"))
+        sidebarSplitter->restoreState(settings.value("sidebarSplitter_v1").toByteArray());
     else {
         Q_ASSERT(sidebarSplitter->count() == 2);
         if (sidebarSplitter->count() == 2) {
