@@ -189,7 +189,7 @@ class MacroEdit : public QMainWindow, private Ui::MainWindow
     Q_OBJECT
 
 public:
-    MacroEdit(QString& appName, QWidget* parent = 0, QString* fileToLoad = NULL);
+    MacroEdit(QString appName, QWidget* parent = 0, QString* fileToLoad = NULL);
     ~MacroEdit();
     void metview_dnd();
     void loadTextFile(const QString& fileToLoad);
