@@ -53,6 +53,8 @@ public:
     QStringList defaultValues() const;
     int numValues() const;
     QString valueName(int i) const;
+    void toYaml(std::ofstream&);
+    const MvIconParameter& iconParam() const {return param_;}
 
 protected:
     void next(const MvIconParameter&, const char* first, const char* second);
