@@ -16,14 +16,13 @@
 #include "MvQColourWidget.h"
 #include "MvQMethods.h"
 #include "MvQTreeView.h"
+#include "MvMiscelaneous.h"
 
-#ifdef METVIEW_QT_WEBENGINE
-#include <QWebEngineView>
-#endif
-
+#include <QtGlobal>
 #include <QItemSelectionModel>
 #include <QTreeView>
 #include <QVBoxLayout>
+#include <QMessageBox>
 
 #include "ui_VerbFunctionHelpWidget.h"
 
@@ -387,14 +386,10 @@ void VerbFunctionHelpValueModel::clear()
 VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
     QWidget(parent),
     ui_(new Ui::VerbFunctionHelpWidget),
-#ifdef METVIEW_QT_WEBENGINE
-        docView_(nullptr),
-#endif
     editorTheme_(nullptr),
     language_(nullptr),
     currentEditor_(nullptr),
-    extendSelection_(true),
-    docLoaded_(false)
+    extendSelection_(true)
 {
     ui_->setupUi(this);
 
@@ -420,6 +415,13 @@ VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
     // Param list tab
     //-------------------------------
 
+    // we have a tab widget with one tab only - it is a leftover from
+    // a version with multiple tabs!
+    // we simply hide the tabbar pretenting we do not have tabs at all
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
+    ui_->tab->setTabBarAutoHide(true);
+#endif
+
     paramModel_ = new VerbFunctionHelpParamModel(this);
     ui_->paramTree->setModel(paramModel_);
 
@@ -429,33 +431,6 @@ VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
     connect(ui_->paramTree->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
             this,SLOT(slotParamSelected(QModelIndex, QModelIndex)));
 
-    //-------------------------------
-    // Documentation tab
-    //-------------------------------
-
-    //QVBoxLayout *docVb = new QVBoxLayout(ui_->docHolderW);
-    //docVb->setContentsMargins(0,0,0,0);
-    //docVb->setSpacing(0);
-
-#ifdef METVIEW_QT_WEBENGINE
-    if (MvQ::hasOpenGLSupport())  {
-        docView_ = new QWebEngineView(this);
-        docVb->addWidget(docView_);
-    } else {
-        MessageLabel* label = new MessageLabel(this);
-        label->showWarning(tr("<b>Cannot load</b> web-based documentation viewer! \
-This would require <b>OpenGL support</b>, but it does not seem to be \
-available in the current graphical environment."));
-        docVb->addWidget(label);
-        docVb->addStretch(1);
-    }
-#else
-    //MessageLabel* label = new MessageLabel(this);
-    //label->showWarning(tr("The <b>web documentation view</b> is only avialable when Metview is built with <b>QtWebEngineWidgets</b>."));
-    //docVb->addWidget(label);
-    //docVb->addStretch(1);
-#endif
-
     //-----------------------------------
     // value selector/editor area
     //-----------------------------------
@@ -482,7 +457,7 @@ available in the current graphical environment."));
             this, SLOT(slotExtendSelection(int)));
 
     extendSelection_ = true;
-    ui_->extendSelectionCheckBox->setChecked(extendSelection_?Qt::Checked:Qt::Unchecked);
+    ui_->extendSelectionCheckBox->setChecked(extendSelection_);
 
     connect(ui_->insertPb,SIGNAL(clicked()),
             this, SLOT(slotInsert()));
@@ -490,13 +465,13 @@ available in the current graphical environment."));
     connect(ui_->copyPb,SIGNAL(clicked()),
             this, SLOT(slotCopy()));
 
+    connect(ui_->webDocPb,SIGNAL(clicked()),
+            this, SLOT(slotWebDoc()));
+
     updateButtonStatus();
 
     ui_->tab->setCurrentIndex(0);
 
-    connect(ui_->tab, SIGNAL(currentChanged(int)),
-            this, SLOT(slotTabIndexChanged(int)));
-
     //Adjust  tree columns
     QFont f;
     QFontMetrics fm(f);
@@ -536,7 +511,6 @@ bool VerbFunctionHelpWidget::showFunction(QString functionName)
     if(!hasData())
         return false;
 
-    docLoaded_=false;
 
     VerbFunctionHelpFunction* fn = language_->functionHelp()->function(functionName);
     if (fn && fn->iconClass()) {
@@ -544,15 +518,9 @@ bool VerbFunctionHelpWidget::showFunction(QString functionName)
         if (fn->numParams() > 0) {
             ui_->paramTree->setCurrentIndex(paramModel_->index(0,0));
         }
-
-        if (ui_->tab->currentIndex() == 1) {
-            loadWebDoc();
-        }
-
         return true;
     }
 
-    clearWebDoc();
     return false;
 }
 
@@ -758,39 +726,18 @@ void VerbFunctionHelpWidget::updateButtonStatus()
     ui_->copyPb->setEnabled(st);
 }
 
-void VerbFunctionHelpWidget::slotTabIndexChanged(int)
+void VerbFunctionHelpWidget::slotWebDoc()
 {
-    if (ui_->tab->currentIndex() == 1) {
-        if (!docLoaded_) {
-            loadWebDoc();
+    if(VerbFunctionHelpFunction* fn = paramModel_->helpData()) {
+        QString web = language_->functionHelp()->iconUrl(fn);
+        std::string err;
+        if (!metview::openInBrowser(web.toStdString(), err)) {
+            QMessageBox::warning(this, "Code editor - Metview",
+                             "Failed to show documentation in web browser!<br><br>" + QString::fromStdString(err));
         }
     }
 }
 
-void VerbFunctionHelpWidget::loadWebDoc()
-{
-    docLoaded_=true;
-#ifdef METVIEW_QT_WEBENGINE
-    if (docView_) {
-        if(VerbFunctionHelpFunction* fn = paramModel_->helpData()) {
-            QString web = language_->functionHelp()->iconUrl(fn);
-            qDebug() << "VerbFunctionHelpWidget::loadWebDoc() -->" << web;
-            docView_->load(QUrl(web));
-        }
-    }
-#endif
-}
-
-void VerbFunctionHelpWidget::clearWebDoc()
-{
-    docLoaded_=false;
-#ifdef METVIEW_QT_WEBENGINE
-    if (docView_) {
-        docView_->load(QUrl());
-    }
-#endif
-}
-
 void VerbFunctionHelpWidget::slotFontSizeDown()
 {
     MvQ::changeFontSize(ui_->paramTree,-1);
