@@ -389,6 +389,8 @@ void MetPlus::serve(MvRequest& in, MvRequest& out)
             if (tempFileNames.size() > 1) {
                 // multiple metgrams - join them into one; format-dependent code here
 
+                std::string mpRunning("MetPlus-> Running: ");
+
                 if (format == "ps") {
                     string psJoinCommand = "psjoin -p ";
 
@@ -398,7 +400,7 @@ void MetPlus::serve(MvRequest& in, MvRequest& out)
 
                     psJoinCommand += " > " + outputFileName;
 
-                    sendProgress("MetPlus-> Running: %s", psJoinCommand.c_str());
+                    sendProgress(mpRunning + psJoinCommand);
                     system(psJoinCommand.c_str());
                 }
 
@@ -410,7 +412,7 @@ void MetPlus::serve(MvRequest& in, MvRequest& out)
                         pdfJoinCommand += tempFileNames[i] + " ";
                     }
 
-                    sendProgress("MetPlus-> Running: %s", pdfJoinCommand.c_str());
+                    sendProgress(mpRunning + pdfJoinCommand);
                     system(pdfJoinCommand.c_str());
                 }
                 else {
