@@ -7,10 +7,6 @@
 
  ***************************** LICENSE END *************************************/
 
-// ObsFilter.cc, vk & br oct-94, rev vk 970729
-//               qa-c++ vk 960725
-
-
 #include "inc_iostream.h"
 #include <time.h>
 #include <vector>
@@ -18,6 +14,8 @@
 #include "Metview.h"
 #include "MvObs.h"
 #include "MvException.h"
+#include "MvMiscelaneous.h"
+#include "MvGeoPoints.h"
 
 const char cTab   = 9;  // ascii code for 'tab'
 const char cComma = ',';
@@ -82,48 +80,34 @@ protected:
     float coordinateRangeValue(const std::string&, float, float, int);
 
 private:
-    long _counter;
+    long _counter{0};
     MvRequest _in;
     MvRequest _data;
     MvObs obs_;
-    MvObsSet* _inSet;
-    MvObsSetIterator* _iter;
+    MvObsSet* _inSet{nullptr};
+    MvObsSetIterator* _iter{nullptr};
     eOutput outType_;
-    MvObsSet* _outBufr;
+    MvObsSet* _outBufr{nullptr};
     ofstream _outFile;
-    eLevel _level;
-    float _firstLevel;
-    float _secondLevel;
-    long _occurrenceIndex;
+    eLevel _level{LVL_Surface};
+    float _firstLevel{0.};
+    float _secondLevel{0.};
+    long _occurrenceIndex{0};
     vector<std::string> param_;
-    ENextReturn _obsOrMsg;  //-- for multisubset msgs (filtering also with subset data?)
-    boolean _includeMissingValues;
-    fortfloat _missingValue;
-    bool failOnError_;
-    bool failOnEmptyOutput_;
+    ENextReturn _obsOrMsg{NR_returnMsg};  //-- for multisubset msgs (filtering also with subset data?)
+    bool _includeMissingValues{false};
+    float _missingValue{GEOPOINTS_MISSING_VALUE};
+    bool failOnError_{true};
+    bool failOnEmptyOutput_{false}; //-- this breaks backwards compatibility
     std::string _coordLevelDescriptor;
-    bool hasAttributeCondition_;
+    bool hasAttributeCondition_{false};
 };
 
 
 //_________________________________________________________
 
 ObsFilter::ObsFilter() :
-    MvService("OBSFILTER"),
-    _counter(0),
-    _inSet(0),
-    _iter(0),
-    _outBufr(0),
-    _level(LVL_Surface),
-    _firstLevel(0.),
-    _secondLevel(0.),
-    _occurrenceIndex(0),
-    _obsOrMsg(NR_returnMsg),  //-- as a default do not study subsets (obs's)
-    _includeMissingValues(false),
-    _missingValue(kBufrMissingValue),
-    failOnError_(true),  //-- this breaks backwards compatibility
-    failOnEmptyOutput_(false),
-    hasAttributeCondition_(false)
+    MvService("OBSFILTER")
 {
 }
 //_________________________________________________________
@@ -182,10 +166,6 @@ void ObsFilter ::getParameterSpecifiers(void)
         _includeMissingValues = true;
         _missingValue         = (double)_in("MISSING_DATA_VALUE");
     }
-    else {
-        _includeMissingValues = false;  // default values
-        _missingValue         = kBufrMissingValue;
-    }
 
     //Check if there are attributes in params
     for (size_t i = 0; i < param_.size(); i++) {
@@ -707,11 +687,19 @@ void ObsFilter ::add()
         }
 
         if (myValue != kBufrMissingValue || _includeMissingValues) {
-            MvLocation myLoc   = obs_.location();
-            TStaticTime myTime = obs_.obsTime();
+            MvLocation myLoc = obs_.location();
+            if (myLoc.latitude() != kBufrMissingValue) {
+                _outFile << myLoc.latitude() << cTab;
+            } else {
+                _outFile << _missingValue << cTab;
+            }
+            if (myLoc.longitude() != kBufrMissingValue) {
+                _outFile << myLoc.longitude() << cTab;
+            } else {
+                _outFile << _missingValue << cTab;
+            }
 
-            _outFile << myLoc.latitude() << cTab;
-            _outFile << myLoc.longitude() << cTab;
+            TStaticTime myTime = obs_.obsTime();
 
             _outFile << _firstLevel << cTab;
 
@@ -784,15 +772,22 @@ void ObsFilter ::add()
                 return;
         }
 
-        MvLocation myLoc   = obs_.location();
+        MvLocation myLoc = obs_.location();
         TStaticTime myTime = obs_.obsTime();
         std::string ident =  obs_.headerIdent();
-        if (ident.empty())
-            ident = "?";
+        ident = metview::stationIdForWritingToFile(ident);
 
         _outFile << ident << cTab;
-        _outFile << myLoc.latitude() << cTab;
-        _outFile << myLoc.longitude() << cTab;
+        if (myLoc.latitude() != kBufrMissingValue) {
+            _outFile << myLoc.latitude() << cTab;
+        } else {
+            _outFile << _missingValue << cTab;
+        }
+        if (myLoc.longitude() != kBufrMissingValue) {
+            _outFile << myLoc.longitude() << cTab;
+        } else {
+            _outFile << _missingValue << cTab;
+        }
 
         _outFile << _firstLevel << cTab;
 
