@@ -19,13 +19,7 @@
 
 #include "MvScanFileType.h"
 
-#ifdef METVIEW_ODB_NEW
-#ifdef ODB_ECKIT
 #include <eckit/exception/Exceptions.h>
-#else
-#include "Exceptions.h"
-#endif
-#endif
 
 using namespace std;
 
@@ -238,15 +232,11 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
         if (odbType == "ODB_NEW") {
             bool notEmpty = true;
             //MvOdb odb(dataPath);
-#ifdef METVIEW_ODB_NEW
             try {
                 notEmpty = MvOdb::retrieveToFile(query, dataPath, outFile);
             }
-#ifdef ODB_ECKIT
             catch (eckit::Exception e)
-#else
-            catch (eclib::Exception e)
-#endif
+
             {
                 stringstream err_s;
                 err_s << "Failed to perform retrieval: " << e.what();
@@ -260,7 +250,6 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                 setError(13);
                 return;
             }
-#endif
         }
         else {
 #ifdef METVIEW_ODB_OLD
@@ -308,7 +297,6 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
              outputFormat == "GEO_XY_VECTOR" ||
              outputFormat == "GEO_POLAR_VECTOR") {
         if (odbType == "ODB_NEW") {
-#ifdef METVIEW_ODB_NEW
             string tmpFile = marstmp();
 
             try {
@@ -321,11 +309,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                     return;
                 }
             }
-#ifdef ODB_ECKIT
             catch (eckit::Exception e)
-#else
-            catch (eclib::Exception e)
-#endif
             {
                 stringstream err_s;
                 err_s << "Failed to perform retrieval: " << e.what();
@@ -333,7 +317,6 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                 setError(13);
                 return;
             }
-#endif
         }
         else {
 #ifdef METVIEW_ODB_OLD
@@ -368,11 +351,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                     return;
                 }
             }
-#ifdef ODB_ECKIT
             catch (eckit::Exception e)
-#else
-            catch (eclib::Exception e)
-#endif
             {
                 stringstream err_s;
                 err_s << "Failed to convert retrieval result into geopoints: " << e.what();
@@ -383,7 +362,6 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
 #endif
         }
 
-
         MvRequest rdata("GEOPOINTS");
         rdata("PATH")      = outFile.c_str();
         rdata("TEMPORARY") = 1;
