@@ -29,10 +29,9 @@
 
 #include <stdlib.h>
 
-#ifdef METVIEW_ODB_NEW
 #include "MvOdb.h"
-#include "odb_api/odbcapi.h"
-#endif
+#include <odc/api/odc.h>
+
 
 #include "MvQAbout.h"
 #include "MvQFileInfoLabel.h"
@@ -518,13 +517,14 @@ void OdbExaminer::slotTabIndexChanged(int index)
 
 void OdbExaminer::slotShowAboutBox()
 {
-    const char* odbapi_version = odb_api_version();
-    QString odbapiVersion(odbapi_version);
+    const char* odc_ver;
+    odc_version(&odc_ver);
+    QString odcVersion(odc_ver);
 
     QMap<MvQAbout::Version, QString> text;
-    text[MvQAbout::OdbApiVersion] = odbapiVersion;
+    text[MvQAbout::OdcVersion] = odcVersion;
 
-    MvQAbout about("ODB Examiner", "", MvQAbout::MetviewVersion | MvQAbout::OdbApiVersion, text);
+    MvQAbout about("ODB Examiner", "", MvQAbout::MetviewVersion | MvQAbout::OdcVersion, text);
     about.exec();
 }
 
