@@ -167,8 +167,6 @@ QString MvQOgcRequest::correctDateTime(QString d)
 
     if (lst.count() == 2) {
         QStringList t = lst[1].split(":");
-        qDebug() << "corr" << t;
-
         if (t.count() == 2) {
             res = lst[0] + "T" + t[0] + ":" + t[1] + ":00";
             //qDebug() << "corr" << res;
@@ -440,8 +438,6 @@ void MvQGetMapRequest::parse()
                 req.replace(frameReq, dimName + "=" + value);
             }
 
-            qDebug() << req;
-
             requestFrame_ << req;
             outFile_ << " ";
             moreIndex = getNextVariation(currentPos, indexRange, indexState, true);
