@@ -193,8 +193,6 @@ MvQWmsClientBase::~MvQWmsClientBase()
 
 QString MvQWmsClientBase::getMimeType(QByteArray ba)
 {
-    qDebug() << "fileType" << ba.mid(0, 8).toHex();
-
     if (ba.mid(0, 8).toHex() == "89504e470d0a1a0a") {
         return "image/png";
     }
@@ -399,7 +397,6 @@ bool MvQWmsGetClient::updateBoundingBox()
     //Current bounding box from the request
     QRectF currentBox;
     QStringList lst = getMapRequest_->item("BBOX").split(",");
-    qDebug() << lst;
     if (lst.count() == 4) {
         currentBox = QRectF(lst[0].toFloat(), lst[1].toFloat(),
                             lst[2].toFloat() - lst[0].toFloat(),
@@ -410,10 +407,6 @@ bool MvQWmsGetClient::updateBoundingBox()
         return false;
     }
 
-
-    qDebug() << "area" << areaL << maxBox << currentBox;
-    qDebug() << "request" << getMapRequest_->request() << getMapRequest_->crs();
-
     //We reached this point only if both view area and
     //bounding box were found!!!!
 
@@ -433,21 +426,15 @@ bool MvQWmsGetClient::updateBoundingBox()
             areaBox = QRectF(areaL[1], areaL[0], areaL[3] - areaL[1], areaL[2] - areaL[0]);
         }
 
-        qDebug() << "CONTAINS" << areaBox << maxBox << currentBox;
-
         if (areaBox.isEmpty()) {
             return false;
         }
 
-        qDebug() << "CONTAINS" << areaBox << maxBox << currentBox;
-
         if (areaBox.intersects(maxBox)) {
             // maxAreaBox = the intersection of the viewable area
             //and the max bounding box for the srs/c
             QRectF maxAreaBox = areaBox.intersected(maxBox);
 
-            qDebug() << "Intersects" << areaBox << maxBox << currentBox << maxAreaBox;
-
             //Find out the relation of the maxAreaBox and the current bounding
             //box in the request
             QRectF resBox;
@@ -474,8 +461,6 @@ void MvQWmsGetClient::runGetMap()
 {
     outFiles_.clear();
 
-    qDebug() << "request" << getMapRequest_->request();
-
     QStringList lst        = getMapRequest_->requestFrame();
     getMapFrameNum_        = lst.count();
     getMapFrameToDownload_ = 0;
@@ -1014,7 +999,6 @@ void MvQWmsUiClient::slotRunGetCapabilities()
         r += "&" + extraGetCapPar_;
     }
 
-    qDebug() << "slotRunGetCapabilities --> request: " << r;
     GuiLog().task() << "Load GetCapabalitites"
                     << " ..in progress";
 
@@ -1074,7 +1058,6 @@ void MvQWmsUiClient::downloadLegend()
         StatusMsgHandler::instance()->show(tr("Load legend"), true);
 
         //Fix for KNMI radar
-        qDebug() << "downloadLegend --> request:" << style_->currentLegend();
         QNetworkRequest netReq(QUrl::fromPercentEncoding(style_->currentLegend().toUtf8()));
         netReq.setOriginatingObject(this);
         //netReq.setRawHeader("Authorization", "Basic " + QByteArray(QString("%1:%2").arg("egows").arg("egows").toAscii()).toBase64());
@@ -1094,7 +1077,6 @@ void MvQWmsUiClient::downloadLogo()
         StatusMsgHandler::instance()->show(tr("Load logo"), true);
 
         //Fix for KNMI radar
-        qDebug() << "downloadLogo --> request:" << node->logo();
         QNetworkRequest netReq(QUrl::fromPercentEncoding(node->logo().toUtf8()));
         netReq.setOriginatingObject(this);
         //netReq.setRawHeader("Authorization", "Basic " + QByteArray(QString("%1:%2").arg("egows").arg("egows").toAscii()).toBase64());
@@ -1189,7 +1171,6 @@ void MvQWmsUiClient::slotSaveInfo()
         rout = r;
     }
 
-    qDebug() << "slotSaveInfo -->";
     rout.print();
 
     // Save info request
@@ -1382,8 +1363,6 @@ void MvQWmsUiClient::slotReplyPreview(QNetworkReply* reply)
             StatusMsgHandler::instance()->failed();
         }
         else {
-            qDebug() << "preview outfile" << outFile;
-
             QImage img = QImage::fromData(ba);
             if (!img.isNull()) {
                 img = img.scaledToWidth(previewSize_.width(), Qt::SmoothTransformation);
@@ -1409,9 +1388,6 @@ void MvQWmsUiClient::slotReplyLegend(QNetworkReply* reply)
 {
     //Here, reply is not necessary the legendReply_ because the
     //request might have been redirected!!
-
-    qDebug() << "MvQWmsUiClient::slotReplyLegend -->";
-
     QNetworkRequest r = reply->request();
     QUrl url          = r.url();
 
@@ -1552,8 +1528,6 @@ bool MvQWmsUiClient::legendDownloadActive()
 
 void MvQWmsUiClient::slotAbortDownloadProcess()
 {
-    qDebug() << "MvQWmsUiClient::slotAbortDownloadProcess -->";
-
     if (getCapReply_ && getCapReply_->isRunning()) {
         GuiLog().task() << "Load GetCapabalitites";
         GuiLog().error() << "Interrupted";
@@ -1618,8 +1592,6 @@ QString MvQWmsUiClient::readVersion()
 
     buffer.close();
 
-    qDebug() << "readVersion --> version: " << result;
-
     //Remove linebreak!!
 
     return result.simplified();
@@ -1687,7 +1659,6 @@ void MvQWmsUiClient::readService()
 
     buffer.close();
 
-    qDebug() << "readService -->" << serviceMeta_;
     //Remove linebreak!!
 }
 
@@ -1719,8 +1690,6 @@ void MvQWmsUiClient::readFormat()
     format_->setDisplayValues(lst);
 
     buffer.close();
-
-    qDebug() << "readFormat --> formats:" << lst;
 }
 
 void MvQWmsUiClient::readLayer()
@@ -1734,8 +1703,6 @@ void MvQWmsUiClient::readLayer()
 
     QDomElement docElem = doc.documentElement();
     readLayer(docElem, layer_->root());
-
-    qDebug() << "Layers ---> ";
 }
 
 void MvQWmsUiClient::readLayer(QDomElement& docElem, MvQOgcNode* parent)
@@ -1842,9 +1809,6 @@ void MvQWmsUiClient::readStyle()
     }
 
     buffer.close();
-
-    qDebug() << "Style ---> ";
-    qDebug() << "\t" << titleLst;
 }
 
 void MvQWmsUiClient::readCrs()
@@ -1908,9 +1872,6 @@ void MvQWmsUiClient::readCrs()
     crs_->setDisplayName(crsDisplayName());
 
     buffer.close();
-
-    qDebug() << "CRS ---> ";
-    qDebug() << "\t" << lst;
 }
 
 void MvQWmsUiClient::readBoundingBox()
@@ -2004,8 +1965,6 @@ void MvQWmsUiClient::readGeographicBoundingBox()
                 query.evaluateTo(&val);
                 att["northBoundLatitude"] = val.simplified();
 
-                qDebug() << att;
-
                 if (geographicBbox_) {
                     delete geographicBbox_;
                 }
@@ -2026,9 +1985,6 @@ void MvQWmsUiClient::readGeographicBoundingBox()
             if (item.isNode()) {
                 QMap<QString, QString> att;
                 query.getAttributes(item, att);
-
-                qDebug() << att;
-
                 if (geographicBbox_) {
                     delete geographicBbox_;
                 }
@@ -2165,9 +2121,6 @@ void MvQWmsUiClient::readAttribution()
     }
 
     buffer.close();
-
-    qDebug() << "Attribution ---> ";
-    qDebug() << "\t" << layerNode->logo();
 }
 
 void MvQWmsUiClient::readException(QByteArray ba, QString& msg)
@@ -2177,8 +2130,6 @@ void MvQWmsUiClient::readException(QByteArray ba, QString& msg)
 
     QXmlResultItems result;
 
-    qDebug() << "Exception" << ba;
-
     //QByteArray ba=xmlMsg.toUtf8();
     QBuffer buffer(&ba);  // This is a QIODevice.
     buffer.open(QIODevice::ReadOnly);
@@ -2289,8 +2240,6 @@ void MvQWmsUiClient::buildGetMapRequest()
         str += dim->currentValues();
     }
 
-    qDebug() << str;
-
     if (!extraGetMapPar_.isEmpty()) {
         str += "&" + extraGetMapPar_;
     }
@@ -2500,8 +2449,6 @@ MvQOgcBoundingBox MvQWmsUiClient::lastBoundingBox() const
 
 MvQOgcBoundingBox* MvQWmsUiClient::currentBoundingBox() const
 {
-    qDebug() << crs_->currentValue();
-
     for (int i = bbox_.count() - 1; i >= 0; i--) {
         if (bbox_[i]->crs() == crs_->currentValue()) {
             return bbox_[i];
