@@ -99,9 +99,8 @@ MvQWmsDimensionGuiItem::MvQWmsDimensionGuiItem(MvQOgcDimension* dim, QString tex
 
     //Populate the list
 
-    QListWidgetItem* item;
     foreach (QString str, values_) {
-        item = new QListWidgetItem(str, list_);
+        new QListWidgetItem(str, list_);
         //item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
         //item->setCheckState(Qt::Unchecked);
     }
@@ -197,8 +196,7 @@ void MvQWmsDimensionGuiItem::slotListItemChanged(QListWidgetItem* item)
 
 void MvQWmsDimensionGuiItem::addValue(QString value)
 {
-    QListWidgetItem* item;
-    item = new QListWidgetItem(value, list_);
+    new QListWidgetItem(value, list_);
     //item->setFlags(Qt::ItemIsSelectable |Qt::ItemIsEnabled);
     //item->setCheckState(Qt::Unchecked);
 }
@@ -778,22 +776,18 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     QVBoxLayout* getCapLayout = new QVBoxLayout;
     w->setLayout(getCapLayout);
 
-    getCapInfo_ = new QTextBrowser;
-    getCapInfo_->setReadOnly(true);
-    getCapInfo_->setLineWrapMode(QTextEdit::NoWrap);
+    getCapInfo_ = new PlainTextWidget(this);
+    getCapInfo_->editor()->setReadOnly(true);
+    getCapInfo_->editor()->setLineWrapMode(QPlainTextEdit::NoWrap);
     getCapLayout->addWidget(getCapInfo_);
 
-#ifdef UI_TODO
-    getCapSearch_ = new MvQTextEditSearchLine(getCapInfo_, tr("&Find:"));
-    getCapLayout->addWidget(getCapSearch_);
-#endif
-    highlighterGetCap_ = new MvQWmsGetCapHighlighter(getCapInfo_->document());
+    highlighterGetCap_ = new MvQWmsGetCapHighlighter(getCapInfo_->editor()->document());
 
     //--------------------------
     // Service meta-data  tab
     //--------------------------
 
-    highlighterGetCap_ = new MvQWmsGetCapHighlighter(getCapInfo_->document());
+    highlighterGetCap_ = new MvQWmsGetCapHighlighter(getCapInfo_->editor()->document());
 
     serviceInfo_ = new QTextBrowser;
     serviceInfo_->setReadOnly(true);
@@ -877,9 +871,6 @@ void MvQWmsClientEditor::setupReqEditPanel()
 
     connect(sigMapper, SIGNAL(mapped(const QString&)),
             this, SLOT(slotReqEdited(const QString&)));
-
-
-    qDebug() << sigMapper;
 }
 
 
@@ -925,8 +916,6 @@ void MvQWmsClientEditor::clearDimension()
     int row = layerParamRowNum_;  //layerGrid_->rowCount();
     row     = row - 1;
 
-    qDebug() << "rows" << layerParamRowNum_ << layerGrid_->rowCount();
-
     //Remove previous dimension widgets from the grid
     for (int i = 0; i < dimensionNum_; i++) {
         QWidget* w;
@@ -1080,8 +1069,6 @@ void MvQWmsClientEditor::initCrsCombo()
     QString cv = client_->crsCurrentDisplayValue();
     int index  = -1;
 
-    qDebug() << cv;
-    qDebug() << values;
     if (!cv.isEmpty()) {
         index = values.indexOf(cv);
     }
@@ -1143,13 +1130,10 @@ void MvQWmsClientEditor::slotSelectUrl(const QString& url)
 
 void MvQWmsClientEditor::checkUrlComboItems()
 {
-    qDebug() << "checkUrlComboItems";
-
     //Duplicates are removed first!
     QMap<QString, int> cntMap;
     for (int i = 0; i < urlCombo_->count(); i++) {
         QString s = urlCombo_->itemText(i);
-        //qDebug() << s;
         if (cntMap.find(s) == cntMap.end()) {
             cntMap[s] = 1;
         }
@@ -1248,7 +1232,7 @@ void MvQWmsClientEditor::slotGetCapabilityLoaded()
     //slotPreviewLoaded(QString());
 
 
-    getCapInfo_->setPlainText(client_->getCapabilityDoc());
+    getCapInfo_->editor()->setPlainText(client_->getCapabilityDoc());
     slotUpdateServiceInfo();
     //serviceInfo_->setPlainText(client_->serviceTitle());
 
@@ -1693,6 +1677,8 @@ void MvQWmsClientEditor::writeSettings()
         settings.setValue("layerTabIndex", layerTab_->currentIndex());
         settings.setValue("layerInfoTabIndex", layerInfoTab_->currentIndex());
 
+        getCapInfo_->writeSettings(settings, "getCapInfo");
+
         QStringList lst;
         for (int i = 0; i < urlCombo_->count(); i++) {
             if (!urlCombo_->itemText(i).isEmpty())
@@ -1736,6 +1722,8 @@ void MvQWmsClientEditor::readSettings()
         ival = settings.value("layerTabIndex").toInt();
         layerTab_->setCurrentIndex(ival);
 
+        getCapInfo_->readSettings(settings, "getCapInfo");
+
         QStringList lst(settings.value("urlCombo").toStringList());
         //lst.remove(client_->url())
         urlCombo_->addItems(lst);
