@@ -1232,11 +1232,14 @@ int CrossS::computeGeographicalPoints(ApplicationInfo& appInfo, MvField* field)
     appInfo.getAreaLine(x1, x2, y1, y2);
     double dellat = ABS(y2 - y1), dellon = ABS(x2 - x1);
 
+    int np=64;
     // Compute initial number of points
-    int np = int(sqrt(dellon * dellon + dellat * dellat) / MIN(fabs(appInfo.GridNS()), fabs(appInfo.GridEW())));
-    if (np <= 0) {
-        setError(1, "CrossSection-> Failed to compute number of grid points. Check data internal representation");
-        return 0;
+    if (appInfo.GridNS() != cValueNotGiven && appInfo.GridEW() != cValueNotGiven) {
+        np = int(sqrt(dellon * dellon + dellat * dellat) / MIN(fabs(appInfo.GridNS()), fabs(appInfo.GridEW())));
+        if (np <= 0) {
+            setError(1, "CrossSection-> Failed to compute number of grid points. Input grid geometry might not be supported!");
+            return 0;
+        }
     }
     np = MAX(np, 64);
 
