@@ -456,48 +456,39 @@ void ApplicationInfo::InterpolateVerticalb(MvField& field, vector<double>& cp, P
 void ApplicationInfo::InterpolateVerticalGHBC(vector<double>& cp, ParamInfo* param, ParamInfo* paramGHBC, vector<double>& yvals)
 {
     if (!interpolate_) {
-        this->getLevelValues(param, cp);
+        // we completely ignore yvals!
+        outputLevels(param->NrLevels());
+        getLevelValues(param, cp);
         return;
     }
 
-    int i;
-    double lpa;
-    double firstval, nextval;
-    LevelInfo *firstlev, *nextlev;
-
-    LevelIterator ii = param->Levels().begin();
-    LevelIterator jj = paramGHBC->Levels().begin();
-    int nrLevels     = this->outputLevels();
+    double lpa, vcVal1, vcVal2;
+    LevelInfo *parLev1, *parLev2;
+    int nrLevels     = outputLevels();
     cp.clear();
     cp.reserve(nrLevels * nrPoints_);
-    for (int k = 0; k < nrLevels; k++, ii++, jj++) {
-        double pk    = yvals[k];                 // pressure level index
-        double* pval = (*ii).second->XValues();  // param X values
+    assert(nrLevels >= 2);
 
-        // Invert Model level data
-        for (i = 0; i < nrPoints_; i++) {
-            // Ignore missing values
-            if (pval[i] >= XMISSING_VALUE) {
-                cp.push_back(XMISSING_VALUE);
-                continue;
-            }
+    //loop for the target levels
+    for (int k = 0; k < nrLevels; k++) {
+        double level = yvals[k];  // target vertical coordinate level
 
-            if (findModelPressureGHBC(param->Levels(), paramGHBC->Levels(), pk, i, firstlev, nextlev, firstval, nextval)) {
-                if (firstlev->XValues()[i] < XMISSING_VALUE && nextlev->XValues()[i] < XMISSING_VALUE) {
-                    if (firstval == 0. && nextval == 0.)
-                        cp.push_back(firstlev->XValues()[i]);
-                    else {
-                        //lpa = log(pk/firstval)/log(nextval/firstval);
-                        lpa = (pk - firstval) / (nextval - firstval);
-                        cp.push_back(firstlev->XValues()[i] + (nextlev->XValues()[i] - firstlev->XValues()[i]) * lpa);
-                    }
-                }
-                else
+        //loop for the xs line points
+        for (int i = 0; i < nrPoints_; i++) {
+            //find the bounding input vc levels for the target level
+            if (findModelPressureGHBC(param->Levels(), paramGHBC->Levels(), level, i,
+                                      parLev1, parLev2, vcVal1, vcVal2)) {
+                if (parLev1->XValues()[i] < XMISSING_VALUE &&
+                    parLev2->XValues()[i] < XMISSING_VALUE) {
+                        lpa = (level - vcVal1) / (vcVal2 - vcVal1);
+                        cp.push_back(parLev1->XValues()[i] + (parLev2->XValues()[i] - parLev1->XValues()[i]) * lpa);
+                } else {
                     cp.push_back(XMISSING_VALUE);
-            }
-            else
+                }
+            } else {
                 cp.push_back(XMISSING_VALUE);
-        }
+            }
+       }
     }
 
     return;
@@ -563,41 +554,82 @@ bool ApplicationInfo::findModelPressure(LevelMap& lmap, double value, double spl
     return false;
 }
 
-bool ApplicationInfo::findModelPressureGHBC(LevelMap& lmap, LevelMap& gmap,
-                                            double value, int indexIn,
-                                            LevelInfo*& l1, LevelInfo*& l2,
-                                            double& val1, double& val2)
+bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLevels,
+                                            double level, int xsPointIdx,
+                                            LevelInfo*& parLev1, LevelInfo*& parLev2,
+                                            double& vcVal1, double& vcVal2)
 {
-    LevelIterator ii = lmap.begin();
-    LevelIterator jj = gmap.begin();
-    double tmpval1, tmpval2;
-    LevelInfo *tmpl1, *tmpl2;
-    LevelInfo *ll1, *ll2;
+    LevelIterator itParLev = parLevels.begin();
+    LevelIterator itVcLev = vcLevels.begin();
 
-    ll1     = (*ii).second;
-    tmpl1   = (*jj).second;
-    tmpval1 = tmpl1->XValues()[indexIn];  //field.meanML_to_Pressure_bySP(splin,(int)(tmpl1->YValue()));
-    ii++;
-    jj++;
+    auto actParLev1 = (*itParLev).second;
+    auto actVcLev1 = (*itVcLev).second;
+    vcVal1 = actVcLev1->XValues()[xsPointIdx];
+    itParLev++;
+    itVcLev++;
+    auto actParLev2 = (*itParLev).second;
+    auto actVcLev2 = (*itVcLev).second;
+    vcVal2 = actVcLev2->XValues()[xsPointIdx];
+    bool vcAscending = vcVal1 < vcVal2;
 
-    for (; jj != gmap.end(); jj++, ii++) {
-        ll2     = (*ii).second;
-        tmpl2   = (*jj).second;
-        tmpval2 = tmpl2->XValues()[indexIn];  //field.meanML_to_Pressure_bySP(splin,(int)(tmpl2->YValue()));
+    //this will allow extrapolation at top/bottom
+    if (extrapolateGHBC_) {
+        if (!vcAscending) {
+            assert(vcVal2 < vcVal1);
+            if (level > vcVal1) {
+                parLev1   = actParLev1;
+                parLev2   = actParLev2;
+                return true;
+            }
+        } else {
+            assert(vcVal1 < vcVal2);
+            if (level < vcVal1) {
+                parLev1   = actParLev1;
+                parLev2   = actParLev2;
+                return true;
+            }
+        }
+    }
 
-        if (isWithinRange(tmpval1, tmpval2, value)) {
-            l1   = ll1;
-            l2   = ll2;
-            val1 = tmpval1;
-            val2 = tmpval2;
+    while(itVcLev != vcLevels.end()) {
+        if (isWithinRange(vcVal1, vcVal2, level)) {
+            parLev1   = actParLev1;
+            parLev2   = actParLev2;
             return true;
         }
 
-        ll1     = ll2;
-        tmpl1   = tmpl2;
-        tmpval1 = tmpval2;
+        itParLev++;
+        itVcLev++;
+
+        if (itVcLev != vcLevels.end()) {
+            actParLev1 = actParLev2;
+            actVcLev1 = actVcLev2;
+            vcVal1 = vcVal2;
+            actParLev2 = (*itParLev).second;
+            actVcLev2 = (*itVcLev).second;
+            vcVal2 = actVcLev2->XValues()[xsPointIdx];
+        }
     }
 
+    //this will allow extrapolation at top/bottom
+    if (extrapolateGHBC_) {
+        if (!vcAscending) {
+            assert(vcVal2 < vcVal1);
+            if (level < vcVal2) {
+                parLev1   = actParLev1;
+                parLev2   = actParLev2;
+                return true;
+            }
+        } else {
+            assert(vcVal1 < vcVal2);
+            if (level > vcVal2) {
+                parLev1   = actParLev1;
+                parLev2   = actParLev2;
+                return true;
+            }
+         }
+     }
+
     return false;
 }
 
@@ -854,15 +886,15 @@ bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const string& k
     else if (levType_ == XS_ML_GHBC)  // handle height-based coordinates
     {
         // Get extra values
-        ParamInfo* parGHBC = this->getParamInfo(params, paramGHBC_, key);
+        ParamInfo* parGHBC = getParamInfo(params, paramGHBC_, key);
         if (!parGHBC)
             return false;
 
         // Compute level values
-        this->computeLevelInfoGHBC(parGHBC, y_values);
+        computeLevelInfoGHBC(parGHBC, y_values);
 
         // Interpolate matrix
-        this->InterpolateVerticalGHBC(cp, resPar, parGHBC, y_values);
+        InterpolateVerticalGHBC(cp, resPar, parGHBC, y_values);
     }
     else {
         // Compute level values
@@ -1041,14 +1073,15 @@ int ApplicationInfo::computeLevelInfo(vector<double>& vals)
     return nOutputLevels_;
 }
 
-int ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
+void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
 {
-    // Convert ML&GHBC to PL using the following algorithm: for each ML value
-    // (1,2,...N) get all the correspondent values and compute the average
+    //Compute the average vertical coordinate value for each input GHBC level
+    //along the cross section line. The result is one coordinate value per level.
     LevelMap lmap = par->Levels();
     int nrLevels  = lmap.size();
     vals.clear();
-    vals.reserve(nrLevels);
+    double minVal = 1E20;
+    double maxVal = -1E20;
     double xval;
     for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++) {
         LevelInfo* lInfo = (*jj).second;
@@ -1059,16 +1092,35 @@ int ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, vector<double>& vals)
             if (xval < XMISSING_VALUE) {
                 dlev += xval;
                 count++;
+                if (xval < minVal)
+                    minVal = xval;
+                if (xval > maxVal)
+                    maxVal = xval;
             }
         }
 
-        double mean = count ? dlev / count : 0.;
+        double mean = (count)?(dlev/count):0.;
         vals.push_back(mean);
     }
 
     nInputLevels_ = nOutputLevels_ = nrLevels;
-
-    return nrLevels;
+    // for extrapolation add min and max to levels
+    //NOTE: for bounded vertical coordinates  (eg. pressure > 0)
+    //we have to be sure the added levels are valid! The problem is
+    //that we do not know anything about the nature of the vertical
+    //coordinate (since it is "generic").
+    if (extrapolateGHBC_ && nrLevels > 1) {
+        double deltaFirst = fabs(vals[0]-vals[1]);
+        double deltaLast = fabs(vals[nrLevels-1]-vals[nrLevels-2]);
+        if (vals[0] < vals[1]) {
+            vals.insert(vals.begin(), minVal-deltaFirst);
+            vals.push_back(maxVal+deltaLast);
+        } else {
+            vals.insert(vals.begin(), maxVal+deltaFirst);
+            vals.push_back(minVal-deltaLast);
+        }
+        nOutputLevels_+=2;
+    }
 }
 
 void ApplicationInfo::getLevelValues(ParamInfo* par, vector<double>& cp)
