@@ -1496,14 +1496,21 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
     const char mySeparator = '\t';
     out << "#GEO" << std::endl;
     if (format != "NCOLS") {
+        int dataColNum=0;
         if (format == "GEOPOINTS") {
             out << "#";
+            dataColNum = 1;
         }
         else if (format == "POLAR_VECTORS" || format == "XY_VECTORS") {
             out << "#FORMAT " << format << std::endl
                 << "#";
+            dataColNum=2;
+        } else {
+            throw MvException("Failed to generate geopoints! Invalid format=" + format + "!");
         }
 
+        assert(dataColNum>0);
+
         out << "latitude" << mySeparator << "longitude" << mySeparator
             << "level" << mySeparator << "date" << mySeparator
             << "time" << mySeparator;
@@ -1516,8 +1523,18 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
         keys.push_back(result_->key(MvKey::DateRole));
         keys.push_back(result_->key(MvKey::TimeRole));
 
-        for (int j = 5; j < static_cast<int>(result_->size()); j++)
-                keys.push_back(result_->key(MvKey::NoRole, j - 5));
+        if (dataColNum == 1)
+            keys.push_back(result_->key(MvKey::NoRole, 0));
+        else {
+            keys.push_back(result_->key(MvKey::NoRole, 0));
+            keys.push_back(result_->key(MvKey::NoRole, 1));
+        }
+
+        for(size_t i=0; i < keys.size(); i++) {
+            if (i!=2 && i !=3 && i != 4 && keys[i] == nullptr)
+                throw MvException("Failed to generate geopoints output for format=" + format +
+                                  "! keys[" + std::to_string(i) + "] == nullptr");
+        }
 
         int nkeys = keys.size();
 
@@ -1526,18 +1543,32 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
             //Using this style caused a crash:
             //out << ((keys[2])?keys[2]->valueAsString(i):"0")
 
-            out << outputToString(keys[0], i) << " ";
-            out << outputToString(keys[1], i) << " ";
-            out << outputToString(keys[2], i) << " ";
-            out << outputToString(keys[3], i) << " ";
+            out << outputToString(keys[0], i) << mySeparator <<
+                   outputToString(keys[1], i) << mySeparator;
 
-            if (keys[4])
-                out << toGeopointsTime(keys[4]->valueAsString(i)) << " ";
+            //level
+            if (keys[2])
+                out << outputToString(keys[2], i) << mySeparator;
             else
-                out << "0 ";
+                out << "0" << mySeparator;
+
+            //date
+            if (keys[3])
+                out << outputToString(keys[3], i) << mySeparator;
+            else
+                out << "0" << mySeparator;
+
+            //time
+            if (keys[4])
+                out << toGeopointsTime(keys[4]->valueAsString(i)) << mySeparator;
+            else
+                out << "0" << mySeparator;
 
             for (int j = 5; j < nkeys; j++) {
-                out << outputToString(keys[j], i) << " ";
+                out << outputToString(keys[j], i);
+                if (j < nkeys-1) {
+                    out << mySeparator;
+                }
             }
 
             out << std::endl;
@@ -1574,6 +1605,12 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
             }
         }
 
+        for(size_t i=0; i <keys.size(); i++) {
+            if (i!=3 && i !=4 && i != 5 && keys[i] == nullptr)
+                throw MvException("Failed to generate geopoints output for format=" + format +
+                                  "! keys[" + std::to_string(i) + "] == nullptr");
+        }
+
         int nkeys = keys.size();
 
         int cnt = result_->valueNum();
@@ -1583,31 +1620,40 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
 
             //station id
             if (keys[0])
-                out << keys[0]->valueAsString(i) << " ";
+                out << metview::stationIdForWritingToFile(keys[0]->valueAsString(i)) << mySeparator;
             else
-                out << "? ";
+                out << "?" << mySeparator;
 
             //lat
-            out << outputToString(keys[1], i) << " ";
+            out << outputToString(keys[1], i) <<  mySeparator;
 
             //lon
-            out << outputToString(keys[2], i) << " ";
+            out << outputToString(keys[2], i) << mySeparator;
 
             //level
-            out << outputToString(keys[3], i) << " ";
+            if (keys[3])
+                out << outputToString(keys[3], i) << mySeparator;
+            else
+                out << "0" << mySeparator;
 
             //date
-            out << outputToString(keys[4], i) << " ";
+            if (keys[4])
+                out << outputToString(keys[4], i) << mySeparator;
+            else
+                out << "0" << mySeparator;
 
             //time
             if (keys[5])
-                out << toGeopointsTime(keys[5]->valueAsString(i)) << " ";
+                out << toGeopointsTime(keys[5]->valueAsString(i)) << mySeparator;
             else
-                out << "0 ";
+                out << "0" << mySeparator;
 
             //the rest
             for (int j = 6; j < nkeys; j++) {
-                out << outputToString(keys[j], i) << " ";
+                out << outputToString(keys[j], i);
+                if (j < nkeys-1) {
+                    out << mySeparator;
+                }
             }
 
             out << std::endl;
