@@ -807,6 +807,128 @@ void BufrMetaData::readMessageKeys(int index, std::set<std::string>& keys)
     fclose(fp);
 }
 
+void BufrMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
+{
+	prof->clearKeyData();
+
+    FILE* fp;
+    codes_handle* ch = NULL;
+    int err          = 0;
+    
+    //open bufr file for reading
+    fp = fopen(fileName_.c_str(), "rb");
+    if (!fp) {
+        //GuiLog().error() << "BufrMetaData::readMessageKeys() ---> Cannot open bufr file: \n        " << fileName_;
+        return;
+    }
+
+    //Get messages form the file
+    while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+        if (!ch) {
+            //GuiLog().error() << "BufrMetaData::readFirstMessageKeys() --->  Unable to create code handle for message count: " << bufr_count + 1;
+            continue;
+        }
+        else {
+            readMessage(prof, ch);
+            codes_handle_delete(ch);
+            fclose(fp);
+            return;
+        }
+    }
+
+    fclose(fp);
+}
+
+void BufrMetaData::readMessage(MvKeyProfile* prof, codes_handle* ch)
+{
+    if (!ch) {
+        //readMessageFailed(prof, msgCnt, profIndex);
+        return;
+    }
+
+    const int MAX_VAL_LEN = 1024;
+    long longValue;
+    char value[MAX_VAL_LEN];
+    string svalue;
+    size_t vlen = MAX_VAL_LEN;
+
+    //long centre;
+    // if (MV_CODES_CHECK(codes_get_long(ch, "bufrHeaderCentre", &centre), 0) == false) {
+    //     //readMessageFailed(prof, msgCnt, profIndex);
+    //     return;
+    // }
+
+    // if (MV_CODES_CHECK(codes_get_long(ch, "section1Flags", &longValue), 0) == false) {
+    //     //readMessageFailed(prof, msgCnt, profIndex);
+    //     return;
+    // }
+
+
+    //bool hasLocal2 = (centre == 98 && longValue != 0);
+
+    for (unsigned int i = 0; i < prof->size(); i++) {
+        size_t len;
+        int keyType;
+        const char* name    = prof->at(i)->name().c_str();
+        std::string strName = prof->at(i)->name();
+        bool foundValue     = false;
+
+        //std::size_t pos;
+        // if ((pos = strName.find(":98")) == strName.size() - 3) {
+        //     if (hasLocal2) {
+        //         strName = strName.substr(0, strName.size() - 3);
+        //         name    = strName.c_str();
+        //     }
+        //     else {
+        //         prof->at(i)->setStringValue(profIndex, "N/A");
+        //         continue;
+        //     }
+        // }
+
+        if (grib_get_native_type(ch, name, &keyType) == CODES_SUCCESS &&
+            grib_get_size(ch, name, &len) == CODES_SUCCESS &&
+            (keyType == CODES_TYPE_STRING || keyType == CODES_TYPE_LONG ||
+             keyType == CODES_TYPE_DOUBLE)) {
+            if (keyType == CODES_TYPE_STRING || len == 1) {
+                if ((prof->at(i)->readIntAsString() == false) &&
+                    keyType == CODES_TYPE_LONG) {
+                    if (codes_get_long(ch, name, &longValue) == CODES_SUCCESS) {
+                        std::stringstream s;
+                        s << longValue;
+                        prof->at(i)->addValue(s.str().c_str());
+                        foundValue = true;
+                    }
+                }
+                else {
+                    vlen = MAX_VAL_LEN;
+                    if (codes_get_string(ch, name, value, &vlen) == CODES_SUCCESS) {
+                        if (prof->at(i)->name() == "section1Flags") {
+                            prof->at(i)->addValue((strcmp(value, "0") == 0) ? "0" : "1");
+                        }
+                        else {
+                            prof->at(i)->addValue(value);
+                        }
+                        foundValue = true;
+                    }
+                }
+            }
+            else {
+                std::stringstream s;
+                s << len;
+                svalue = "Array (" + s.str() + ")";
+                prof->at(i)->addValue(svalue);
+                foundValue = true;
+            }
+        }
+
+        if (!foundValue) {
+            if (prof->at(i)->name() != "MV_Index")
+                prof->at(i)->addValue("N/A");
+        }
+    }
+}
+
+
 void BufrMetaData::readCompressedData(MvKeyProfile* prof, int index, int subsetNum)
 {
     FILE* fp;
