@@ -947,14 +947,39 @@ void GribMetaData::setTotalMessageNum(int num)
     }
 }
 
-
-#if 0
-void GribMetaData::loadKeyProfile(MvKeyProfile *prof)
+void GribMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
 {
 	prof->clearKeyData();
-	readMessages(prof);
+
+    FILE* fp;
+    grib_handle* gh=NULL;
+    int err=0;
+    string cbuff;
+
+    //open grib file for reading
+    fp = fopen(fileName_.c_str(),"r");
+    if(!fp)
+    {
+        //GuiLog().error() << "GribMetaData::readMessages() ---> Cannot open grib file: \n        " << fileName_ << "\n";
+        return;
+    }
+
+    while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
+    {
+        if(!gh)
+        {
+            //GuiLog().error() <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << endl;
+        }
+
+        readMessage(prof,gh);
+
+        if(gh)
+            grib_handle_delete(gh);
+
+        return;
+    }
 }
-#endif
+
 #if 0
 void GribMetaData::readMessages(MvKeyProfile *prof)
 {
