@@ -1403,56 +1403,84 @@ double MvField::west()
 
 double MvField::gridNS()
 {
-    //gribsec2_ll*  s2 = (gribsec2_ll*) &Grib->ksec2[0];
-    double metadatum = mvgrid_->getDouble("jDirectionIncrementInDegrees");  // s2->grid_ns/(double)GRIB_FACTOR;
-    double computed  = (north() - south()) / (numberOfLat() - 1);
-
-    //if( (s2->resolution & cOctetBit1) == 0 )  //-- increments not given?
-    if (!mvgrid_->getLong("jDirectionIncrementGiven"))  //-- increments not given?
-    {
-        return numberOfLat() > 0 ? computed : cValueNotGiven;
+    //TODO: implement this method in MvGrid since it has to be grid specific!!!
+    double suppliedDy = mvgrid_->getDouble("jDirectionIncrementInDegrees");
+    if (fabs(suppliedDy) > 180.) {
+        suppliedDy = cValueNotGiven;
     }
 
-    if (fabs(computed - metadatum) > cGridEpsilon) {
-        cout << "Grid NS: given=" << metadatum << ", computed=" << computed << endl;
+    bool scanNeg = (mvgrid_->getLong("jScansPositively") != 0);
+    double northVal = north();
+    double southVal = south();
+    long numLat = numberOfLat();
+    double computed = cValueNotGiven;
+    if (northVal != cValueNotGiven && southVal != cValueNotGiven &&
+         numLat != GRIB_MISSING_LONG) {
+         computed   = (northVal - southVal) / (numLat - 1);
+    }
+
+    if (suppliedDy != cValueNotGiven && computed != cValueNotGiven) {
+        // This is the case when GRIB header precision is too small
+        if (fabs(computed - suppliedDy) > cGridEpsilon) {
+            return computed;
+        } else {
+            if (scanNeg) {
+                suppliedDy = -suppliedDy;
+            }
+            return suppliedDy;
+        }
+    } else if (suppliedDy != cValueNotGiven) {
+        if (scanNeg) {
+            suppliedDy = -suppliedDy;
+        }
+        return suppliedDy;
+
+    } else if (computed != cValueNotGiven) {
         return computed;
     }
 
-    //if( (s2->scan_mode & cOctetBit2) != 0 )  //-- points scan in +j direction
-    if (mvgrid_->getLong("jScansPositively") != 0)  //-- points scan in +j direction
-    {
-        metadatum = -metadatum;
-    }
-
-    return metadatum;
+    return cValueNotGiven;
 }
 
 double MvField::gridWE()
 {
-    //gribsec2_ll* s2  = (gribsec2_ll*) &Grib->ksec2[0];
-    //double metadatum = s2->grid_ew/(double)GRIB_FACTOR;
+    //TODO: implement this method in MvGrid since it has to be grid specific!!!
     double suppliedDx = mvgrid_->getDouble("iDirectionIncrementInDegrees");
-    double computed   = (east() - west()) / (numberOfLon() - 1);
-
-    //if( (s2->resolution & cOctetBit1) == 0 )  //-- increments not given?
-    if (!mvgrid_->getLong("iDirectionIncrementGiven"))  //-- increments not given?
-    {
-        return (numberOfLon() != GRIB_MISSING_LONG) ? computed : cValueNotGiven;
+    if (fabs(suppliedDx) > 360.) {
+        suppliedDx = cValueNotGiven;
     }
 
-    if (fabs(computed - suppliedDx) > cGridEpsilon) {
-        cout << "Grid WE: given=" << suppliedDx << ", computed=" << computed << endl;
-
-        return computed;  //-- GRIB header precision too small
+    bool scanPos = (mvgrid_->getLong("iScansNegatively") != 0);
+    double eastVal = east();
+    double westVal = west();
+    long numLon = numberOfLon();
+    double computed = cValueNotGiven;
+    if (eastVal != cValueNotGiven && westVal != cValueNotGiven &&
+         numLon != GRIB_MISSING_LONG) {
+         computed   = (eastVal - westVal) / (numLon - 1);
     }
 
-    //if( (s2->scan_mode & cOctetBit1) != 0 )  //-- points scan in -i direction?
-    if (mvgrid_->getLong("iScansNegatively") != 0)  //-- points scan in -i direction
-    {
-        suppliedDx = -suppliedDx;
+    if (suppliedDx != cValueNotGiven && computed != cValueNotGiven) {
+        // This is the case when GRIB header precision is too small
+        if (fabs(computed - suppliedDx) > cGridEpsilon) {
+            return computed;
+        } else {
+            if (scanPos) {
+                suppliedDx = -suppliedDx;
+            }
+            return suppliedDx;
+        }
+    } else if (suppliedDx != cValueNotGiven) {
+        if (scanPos) {
+            suppliedDx = -suppliedDx;
+        }
+        return suppliedDx;
+
+    } else if (computed != cValueNotGiven) {
+        return computed;
     }
 
-    return suppliedDx;
+    return cValueNotGiven;
 }
 
 bool MvField::isDerived()
