@@ -261,8 +261,10 @@ bool MvGeoP1::extract(const char* line, eGeoFormat& geoFmt, MvGeoPoints* gpts)
         // read the co-ordinate values
         for (size_t c = 0; c < gpts->nCoordCols(); c++) {
             eGeoColType t = gpts->colType(c);
-            if (t == eGeoColStnId)
+            if (t == eGeoColStnId) {
                 myInput >> strValue_;
+                strValue_ = metview::stationIdFromFile(strValue_);
+            }
             else if (t == eGeoColLat)
                 myInput >> latitude_;
             else if (t == eGeoColLon)
@@ -451,6 +453,10 @@ void MvGeoP1::location(double lat, double lon)
     }
 }
 
+bool MvGeoP1::isLocationValid() const
+{
+    return (latitude_ <= 90. && latitude_ >= -90. && longitude_ <= 360. && longitude_ >= -360.);
+}
 
 // -- MvGeop1Writer
 // -- Tiny utility class to enable the writing of a single geopoint to file
@@ -528,7 +534,7 @@ ostream& operator<<(ostream& aStream, const MvGeop1Writer& gpw)
                     break;
                 case eGeoColStnId:
                     if (colInfo.hasStnIds_)
-                        aStream << gp.strValueForWritingToFile() << cSeparator;
+                        aStream << metview::stationIdForWritingToFile(gp.strValue())  << cSeparator;
                     break;
                 default:
                     break;
@@ -1115,6 +1121,11 @@ bool MvGeoPoints::load(ifstream& f, const int nmax)
         }
     }
 
+    // Set format info
+    if (gfmt_ == eGeoTraditional && sgfmt_.empty()) {
+        this->setFormat();
+    }
+
     db_info  = false;
     db_query = false;
     metadata = false;
@@ -1144,6 +1155,7 @@ bool MvGeoPoints::load(ifstream& f, const int nmax)
             else if (!strncmp(line, "#GEO", 4))  // start of new geopoints file
             {
                 inSameGpts = false;
+                break;
             }
         }
     }
