@@ -188,9 +188,6 @@ public:
      */
     string strValue() const { return strValue_; }
 
-    //! Returns a string value for writing ; use a missing identifier if empty
-    string strValueForWritingToFile() const { if (strValue_.empty()) return "?"; else return strValue_; }
-
     //! Returns whether the stnid is empty
     bool isStnIdEmpty() const { static std::string empty("?"); return (strValue_.empty() || strValue_ == empty); }
 
@@ -282,6 +279,8 @@ public:
     //! Returns \c true if either the latitude or longitude is missing
     bool latlon_missing() const { return ((lat_y() == GEOPOINTS_MISSING_VALUE) || (lon_x() == GEOPOINTS_MISSING_VALUE)); }
 
+    bool isLocationValid() const;
+
     //! Sets the (first) value missing
     void set_value_missing() { values_[vi_] = GEOPOINTS_MISSING_VALUE; }  // set to missing
 
