@@ -251,6 +251,13 @@ public:
         }
     }
 
+    void setValueAtToMissing(int index)
+    {
+        if (field_) {
+            field_->values[index] = mars.grib_missing_value;
+            field_->bitmap                = true;
+        }
+    }
 
     //! Returns the value of the \c i:th grid point
     double valueAt(int i) const;
@@ -426,6 +433,8 @@ public:
     virtual bool advance();
     bool surroundingGridpoints(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
                                bool canHaveMissing, bool doSort);
+    virtual bool surroundingGridpointsForExtrapolation(double lat_y, double lon_x, std::vector<MvGridPoint>& points,
+                               bool canHaveMissing, bool doSort);
     virtual MvGridPoint nearestGridpoint(double lat_y, double lon_x, bool nearestValid);
     virtual double interpolatePoint(double lat_y, double lon_x, std::vector<MvGridPoint>* surroundingPoints);
     void firstDerivativeX(MvGridBase*);
@@ -452,6 +461,10 @@ private:
     double firstLatY_;
     double lastLonX_;
     double lastLatY_;
+    double southernLat_;
+    double northernLat_;
+    bool globalNS_;
+    bool globalEW_;
 };
 
 //===================================================================
@@ -568,6 +581,30 @@ public:
 };
 
 
+//===================================================================
+//
+// MvMercatorGrid:
+// -------------
+//! \brief MvGrid class for fields in Merctor grid
+//!
+//! This class is for fields in Merctor grid.
+//! It pretty much just does what the MvGridUsingGribIterator class does.
+
+class MvMercatorGrid : public MvGridUsingGribIterator
+{
+public:
+    MvMercatorGrid(field* myfield, field_state oldState, bool memoryToBeReleased);
+    ~MvMercatorGrid() {}
+
+    //! Dummy function. Returns always missing_value.
+    double firstLonX() { return cMvlatLonMissingValue; }
+
+    //! Dummy function. Returns always missing_value.
+    double firstLatY() { return cMvlatLonMissingValue; }
+};
+
+
+
 //===================================================================
 //
 // MvIrregularGrid:
