@@ -331,6 +331,38 @@ std::string replace(const std::string& data, const std::string& oldStr, const st
     return res;
 }
 
+string stationIdForWritingToFile(const std::string &in)
+{
+    static std::string space(" ");
+    static std::string spaceReplacement("\\32\\");
+    static std::string tab("\t");
+    static std::string tabReplacement("\\9\\");
+    if (in.empty())
+        return "?";
+    else {
+        std::string strToWrite = metview::replace(in, space, spaceReplacement);
+        strToWrite = metview::replace(strToWrite, tab, tabReplacement);
+        return strToWrite;
+    }
+}
+
+std::string stationIdFromFile(const std::string &in)
+{
+    static std::string space(" ");
+    static std::string spaceReplacement("\\32\\");
+    static std::string tab("\t");
+    static std::string tabReplacement("\\9\\");
+
+    if (in == "?")
+        return std::string("");
+
+    std::string stnid = metview::replace(in, spaceReplacement, space);
+    stnid = metview::replace(stnid, tabReplacement, tab);
+
+    return stnid;
+}
+
+
 
 bool isNumber(const std::string& v)
 {
@@ -472,4 +504,26 @@ std::string getLastLines(const std::string& fileName, int lastLineNum, std::stri
     return std::string(start, buffer.end());
 }
 
+#ifdef METVIEW
+
+std::string pathFromFieldsetWrittenToDisk (const MvRequest &req)
+{
+    int fff = 0;
+    std::string path;
+    if ((const char*)req("FIELDSET_FROM_FILTER") &&
+    (int)req("FIELDSET_FROM_FILTER") == 1) {
+        fieldset* fs = request_to_fieldset(req);
+        fieldset* z  = copy_fieldset(fs, fs->count, true);
+        save_fieldset(z);
+        request* finalreq = fieldset_to_request(z);
+        path = get_value(finalreq, "PATH", 0);
+    }
+    else {
+        path = (const char *) req("PATH");
+    }
+    return path;
+}
+
+#endif
+
 }  //namespace metview
