@@ -16,6 +16,10 @@
 #include <set>
 #include <vector>
 
+#ifdef METVIEW
+#include "MvRequest.h"
+#endif
+
 namespace metview
 {
 std::string iconDirFile(const std::string& fName);
@@ -44,15 +48,22 @@ inline void removeSpaces(std::string& s) {
     s.erase(remove_if(s.begin(), s.end(), metview::isSpace), s.end());
 }
 
+//! Returns a string value for writing ; use a missing identifier if empty
+//! Used for geopoints stnids
+std::string stationIdForWritingToFile(const std::string &in);
+std::string stationIdFromFile(const std::string &in);
+
 bool isNumber(const std::string& v);
 std::string toBold(int v);
 std::string toBold(float v);
 std::string toBold(const std::string&);
 std::string beautify(const std::string& name);
 inline void toLower(std::string& v) {std::transform(v.begin(), v.end(), v.begin(), ::tolower);}
+inline void toUpper(std::string& v) {std::transform(v.begin(), v.end(), v.begin(), ::toupper);}
 std::string replace(const std::string& data, const std::string& oldStr, const std::string& newStr);
 
 bool isForceMarsLogSet();
+inline bool isPidValid(int pid) {return (pid > 2 && pid < 100000);}
 
 double truncate(double, int);
 
@@ -65,6 +76,11 @@ void writeFileToLog(int, const std::string& fileName, int maxLineNum = -1);
 
 std::string getLastLines(const std::string& fileName, int lastLineNum, std::string& error_msg);
 
+#ifdef METVIEW
+std::string pathFromFieldsetWrittenToDisk (const MvRequest &req);
+#endif
+
+
 inline std::string merge(const std::vector<std::string>& v, const std::string& sep)
 {
     std::string res;
