@@ -1148,42 +1148,6 @@ bool MvNcVar::put_vara(const double* vals, size_t* counts)
     return ncStatus_ == NC_NOERR;
 }
 
-// Now in header file
-#if 0
-template <class T> 
-NcBool MvNcVar::get(vector<T>& vals, const long *counts)
-{
-  if ( !isValid() ) return false;
-
-  NcBool ret_val;
-  int i;
-  int num_values = 1;
-  
-  vals.erase(vals.begin(),vals.end());
-
-  if ( getNumberOfDimensions() >  0 )
-    {
-      for (i=0;i < getNumberOfDimensions();i++)
-	num_values *= counts[i];
-      
-      T *ptr = new T[num_values];
-      
-      ret_val = ncVar_->get(ptr,counts);
-      if ( ret_val )
-	for (i=0;i < num_values;i++)
-	  vals.push_back(ptr[i]);
-      
-      delete [] ptr;
-    }
-  else 
-    {  // Scalar
-      T *scalarval = (T*)values()->base();
-      if ( scalarval )
-	vals.push_back(scalarval[0]);
-    }
-  return ret_val;
-}
-#endif
 
 // Specialize template for Cached. It's convenient to use a vector of
 // Cached when retrieving string variables, but it most be treated
@@ -1194,7 +1158,7 @@ NcBool MvNcVar::get(vector<Cached>& vals, const long* counts, long nvals)
     if (!isValid())
         return false;
 
-    NcBool ret_val;
+    NcBool ret_val = NC_NOERR;
     int i;
     int num_values = 1;
 
