@@ -1072,7 +1072,7 @@ public:
     // File operations
     const string& path() { return path_; }
     int sync() { return ncFile_->sync(); }
-    int close() { return ncFile_->close(); }
+    int close() { return (ncFile_)?ncFile_->close():0; }
 
     int getFillMode() { return ncFile_->getFillMode(); }
 
