@@ -15,28 +15,15 @@
 
 using namespace std;
 
-#ifdef METVIEW_ODB_NEW
+#include <odc/Reader.h>
+#include <odc/Writer.h>
+#include <odc/Select.h>
+#include <odc/core/MetaData.h>
+#include <odc/api/ColumnType.h>
 
-#ifdef ODB_ECKIT
-#include <odb_api/ColumnType.h>
-#include <odb_api/Reader.h>
-#include <odb_api/Writer.h>
-#include <odb_api/Select.h>
-#else
-#include <odb_api/odblib/odb_api.h>
-#endif
 
-using namespace odb;
+//using namespace odb;
 
-extern "C" {
-#ifdef ODB_ECKIT
-#include <odb_api/odbcapi.h>
-#else
-#include <odb_api/odblib/odbcapi.h>
-#endif
-}
-
-#endif
 
 //This include must come after the oda includes, otherwise
 //compilation fails!!
@@ -45,9 +32,7 @@ extern "C" {
 const int intMissingValue   = -2147480000;
 const int floatMissingValue = -2.14748e+09;
 
-#ifdef METVIEW_ODB_NEW
-static map<odb::ColumnType, MvOdbColumn::OdbColumnType> typeMap;
-#endif
+static map<odc::api::ColumnType, MvOdbColumn::OdbColumnType> typeMap;
 
 void MvOdbColumn::setName(string s)
 {
@@ -218,15 +203,16 @@ void MvOdb::init()
     rowNum_       = -1;
 
     if (typeMap.empty() == true) {
-        typeMap[odb::IGNORE]   = MvOdbColumn::None;
-        typeMap[odb::INTEGER]  = MvOdbColumn::Int;
-        typeMap[odb::REAL]     = MvOdbColumn::Float;
-        typeMap[odb::STRING]   = MvOdbColumn::String;
-        typeMap[odb::BITFIELD] = MvOdbColumn::Bitfield;
-        typeMap[odb::DOUBLE]   = MvOdbColumn::Double;
+        typeMap[odc::api::IGNORE]   = MvOdbColumn::None;
+        typeMap[odc::api::INTEGER]  = MvOdbColumn::Int;
+        typeMap[odc::api::REAL]     = MvOdbColumn::Float;
+        typeMap[odc::api::STRING]   = MvOdbColumn::String;
+        typeMap[odc::api::BITFIELD] = MvOdbColumn::Bitfield;
+        typeMap[odc::api::DOUBLE]   = MvOdbColumn::Double;
     }
 
-    odb_start();
+    //odb_start();
+    //odc_initialise_api();
 }
 
 void MvOdb::readMetaData()
@@ -237,11 +223,11 @@ void MvOdb::readMetaData()
     //string SELECT  = "select * from \"" + path_ + "\";";
 
     //ODA oda("");
-    odb::Reader oda(path_);
+    odc::Reader oda(path_);
     //int row=0;
 
     //odb::Reader::iterator end = oda.end();
-    odb::Reader::iterator beg = oda.begin();
+    odc::Reader::iterator beg = oda.begin();
     //Columns
 
     //ODA::iterator it = oda.begin();
@@ -251,7 +237,7 @@ void MvOdb::readMetaData()
 
     //size_t n = beg.columns().size();
 
-    for (odb::MetaData::const_iterator it = beg->columns().begin(); it != beg->columns().end(); ++it) {
+    for (odc::core::MetaData::const_iterator it = beg->columns().begin(); it != beg->columns().end(); ++it) {
         MvOdbColumn* acol = new MvOdbColumn;
 
         //if(rowNum_==0)
@@ -320,10 +306,10 @@ void MvOdb::generateStats(int column)
 {
     int col = column;
 
-    odb::Reader oda(path_);
+    odc::Reader oda(path_);
 
-    odb::Reader::iterator end = oda.end();
-    for (odb::Reader::iterator it = oda.begin(); it != end; ++it) {
+    odc::Reader::iterator end = oda.end();
+    for (odc::Reader::iterator it = oda.begin(); it != end; ++it) {
         if (column_[col]->type() == MvOdbColumn::Float || column_[col]->type() == MvOdbColumn::Int) {
             column_[col]->addToStats((*it)[col]);
         }
@@ -378,10 +364,10 @@ int MvOdb::rowNum()
     }
 
 
-    odb::Reader oda(path_);
+    odc::Reader oda(path_);
 
     //Create iterator
-    odb::Reader::iterator it = oda.begin();
+    odc::Reader::iterator it = oda.begin();
 
     int i = 0;
     for (; it != oda.end(); ++it) {
@@ -463,10 +449,10 @@ const MvOdbColumn* MvOdb::loadColumn(int pos, bool reload)
 
     string sval;
 
-    odb::Reader oda(path_);
+    odc::Reader oda(path_);
 
     //Create iterator
-    odb::Reader::iterator it = oda.begin();
+    odc::Reader::iterator it = oda.begin();
 
     //Jump to the given chunk
     if (chunkSize_ != 0) {
@@ -558,10 +544,10 @@ void MvOdb::loadAllColumns()
 
     string sval;
 
-    odb::Reader oda(path_);
+    odc::Reader oda(path_);
 
     //Create iterator
-    odb::Reader::iterator it = oda.begin();
+    odc::Reader::iterator it = oda.begin();
 
     //Jump to the given chunk
     if (chunkSize_ != 0) {
@@ -672,7 +658,7 @@ void MvOdb::setChunkSize(int chunkSize)
 
 bool MvOdb::retrieveToFile(string query, string inFile, string outFile)
 {
-    odb_start();
+    //odb_start();
 
     string SELECT;
 
@@ -692,12 +678,12 @@ bool MvOdb::retrieveToFile(string query, string inFile, string outFile)
 
     //cout << "Select: " << SELECT << endl;
 
-    odb::Writer<> writer(outFile);
-    odb::Writer<>::iterator outit = writer.begin();
+    odc::Writer<> writer(outFile);
+    odc::Writer<>::iterator outit = writer.begin();
 
-    odb::Select oda(SELECT);
-    odb::Select::iterator it  = oda.begin();
-    odb::Select::iterator end = oda.end();
+    odc::Select oda(SELECT);
+    odc::Select::iterator it  = oda.begin();
+    odc::Select::iterator end = oda.end();
 
     if ((it != end) == false) {
         return false;
@@ -722,15 +708,15 @@ bool MvOdb::toGeopoints(string outFile, string geoType)
     }
 
     //Initialize oda
-    odb_start();
-    odb::Reader oda(path_);
+    //odb_start();
+    odc::Reader oda(path_);
 
     //Create iterator
-    odb::Reader::iterator it = oda.begin();
+    odc::Reader::iterator it = oda.begin();
 
     //Columns
     vector<string> colName;
-    for (odb::MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
+    for (odc::core::MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
         string s = (*itc)->name();
         colName.push_back(s);
     }
