@@ -183,8 +183,15 @@ void MvRequest::unsetParam(const char* pname)
     unset_value(CurrentRequest, pname);
 }
 
-void MvRequest::read(const char* fileNamePath, bool expand)
+void MvRequest::read(const char* fileNamePath, bool expand, bool hidden)
 {
+    //boolean is defined in mars.h as int
+    boolean debugOriVal = mars.debug;
+    if (hidden && !mars.debug) {
+        debugOriVal = mars.debug;
+        mars.debug = 1;
+    }
+
     // Read request using MARS library
     // The problem here is that this function does not expand any
     // subrequests. This expansion will be done manually, if second
@@ -192,27 +199,45 @@ void MvRequest::read(const char* fileNamePath, bool expand)
     free_all_requests(FirstRequest);
     CurrentRequest = FirstRequest = read_request_file(fileNamePath);
 
-    if (!expand)
+    if (!expand) {
+        if (mars.debug != debugOriVal) {
+            mars.debug = debugOriVal;
+        }
         return;
+    }
 
     // Get object request. This will help to find out if a parameter
     // is a subrequest, which in this case will need to be expanded.
     request* obj = this->findRequestObject();
-    if (obj == NULL)
+    if (obj == NULL) {
+        if (mars.debug != debugOriVal) {
+            mars.debug = debugOriVal;
+        }
         return;
+    }
 
     // Expand subrequests
     string path = mdirname(fileNamePath);
     this->importSubObjects(path, obj);
 
-    return;
+    if (mars.debug != debugOriVal) {
+        mars.debug = debugOriVal;
+    }
 }
 
-void MvRequest::save(const char* file) const
+void MvRequest::save(const char* file, bool hidden) const
 {
     FILE* fp = fopen(file, "w");
     if (fp) {
-        save(fp);
+        if (hidden && !mars.debug) {
+            //boolean is defined in mars.h as int
+            boolean oriDebugVal = mars.debug;
+            mars.debug = 1;
+            save(fp);
+            mars.debug = oriDebugVal;
+        } else {
+            save(fp);
+        }
         fclose(fp);
     }
 }
@@ -685,16 +710,27 @@ void MvRequest :: addValueToAll(const char* reqname, const char* parname, double
 }
 #endif
 
-int MvRequest::countParameters() const
+int MvRequest::countParameters(bool includeHidden) const
 {
     if (!CurrentRequest)
         return 0;
     int n        = 0;
     parameter* p = CurrentRequest->params;
+    parameter* lastp = p;
     while (p) {
         n++;
+        lastp = p;
         p = p->next;
     }
+    // here, 'hidden' means that it starts with a double underscore, as in "__strings"
+    if (!includeHidden) {
+        if (lastp &&
+            lastp->name &&
+            strlen(lastp->name) > 1 &&
+            lastp->name[0] == '_' &&
+            lastp->name[1] == '_')
+            n--;
+    }
     return n;
 }
 
@@ -849,7 +885,50 @@ void MvRequest::update(const MvRequest& r)
     }
 }
 
-void MvRequest ::update_value(request* r, const char* parname, const char* valname, boolean append)
+// FI 20201103: does it need to check for subrequests and default_values?
+MvRequest MvRequest::convertLetterCase(bool upper)
+{
+    if (CurrentRequest == NULL)
+        return MvRequest(NULL, false);
+
+    string spar;
+    request* a = clone_all_requests(FirstRequest);
+    request* b = a;
+    while (b) {
+        // Convert verb
+        spar = b->name;
+        if (upper)
+            std::transform(spar.begin(), spar.end(), spar.begin(), ::toupper);
+        else
+            std::transform(spar.begin(), spar.end(), spar.begin(), ::tolower);
+
+        strfree(b->name);
+        b->name = strcache(spar.c_str());
+
+        // Convert parameter names
+        parameter* p = b->params;
+        MvRequest reqAux;
+        while (p) {
+            spar = p->name;
+            if (upper)
+                std::transform(spar.begin(), spar.end(), spar.begin(), ::toupper);
+            else
+                std::transform(spar.begin(), spar.end(), spar.begin(), ::tolower);
+
+            // Update parameter name
+            strfree(p->name);
+            p->name = strcache(spar.c_str());
+
+            p = p->next;
+        }
+
+        b = b->next;
+    }
+
+    return MvRequest(a, false);
+}
+
+void MvRequest::update_value(request* r, const char* parname, const char* valname, boolean append)
 {
     parameter* p;
     value* v;
@@ -1421,3 +1500,35 @@ bool MvRequest::checkOneParameter(MvRequest& req, const string& param)
 
     return true;
 }
+
+// Replace all the "." values of param "_PATH" to "./".
+void MvRequest::replaceDotInPath(MvRequest& in)
+{
+    MvRequest r;
+    while (in) {
+        MvRequest rCurrent = in.justOneRequest();
+        if (const char* ch = in("_PATH")) {
+//            marslog(LOG_INFO,"replaceDotInPath: found _PATH=%s", ch);
+            if (strcmp(ch, ".") == 0) {
+                marslog(LOG_INFO,"replaceDotInPath: replace _PATH");
+                rCurrent("_PATH") = "./";
+            }            
+        }
+        int n = in.countParameters();
+        for(int i=0; i < n; i++) {
+            const char* pch = in.getParameter(i);
+            MvRequest sr = in.getSubrequest(pch);
+            if (sr) {
+//                marslog(LOG_INFO, "replaceDotInPath: check subrequest=%s", pch);
+                replaceDotInPath(sr);
+                rCurrent(pch) = sr;
+            }
+        }
+//        marslog(LOG_INFO, "current request=");
+//        in.justOneRequest().print();
+        r = r + rCurrent;
+        in.advance();
+    }
+    in.rewind();
+    in = r;
+}
