@@ -484,6 +484,9 @@ public:
 	 */
     void update(const MvRequest&);
 
+    // Convert request to upper/lower case
+    MvRequest convertLetterCase(bool upper=true);
+
     // -----
 
     //! Adds double value 'v' to list parameter 'p'
@@ -618,6 +621,8 @@ public:
     bool checkParameters(MvRequest&, std::vector<string>&);
     bool checkParameters(MvRequest&, std::vector<string>&, string&);
     bool checkOneParameter(MvRequest&, const string&);
+
+    static void replaceDotInPath(MvRequest& in);
 };
 
 //! Convenience class (not used currently)
