@@ -286,7 +286,7 @@ static const char* scan_file(const char* file)
         char c;
         short s;
         long l;
-        char ch[cMAXSHIFT + 4];
+        char ch[cMAXSHIFT + 6]; //-- must be at least 14 chars
     } buf;
     memset(&buf, 0, sizeof(buf));
 
