@@ -27,6 +27,13 @@ public:
     static double dewPointFromQ(double p, double t, double q, const std::string& formula);
     static double speed(double u, double v);
     static double direction(double u, double v);
+    static double saturationSpecHumidity(double t, double p, bool flag);
+    static bool saturationLevel(double t, double p, double q, double &pSat, double &tSat, bool flag);
+    static double potentialTemperature(double t, double p);
+    static double potentialTemperaturePressureTerm(double p);
+    static double equivalentPotentialTemperature(double t, double p, double q, bool flag);
+    static double saturatedEquivalentPotentialTemperature(double t, double p, bool flag);
+    static double saturatedEquivalentPotentialTemperatureWithPTerm(double t, double p, double pTerm, bool flag);
 };
 
 #endif  // MVSCI_H
