@@ -1,6 +1,6 @@
 /***************************** LICENSE START ***********************************
 
- Copyright 2012 ECMWF and INPE. This software is distributed under the terms
+ Copyright 2019 ECMWF and INPE. This software is distributed under the terms
  of the Apache License version 2.0. In applying this license, ECMWF does not
  waive the privileges and immunities granted to it by virtue of its status as
  an Intergovernmental Organization or submit itself to any jurisdiction.
@@ -165,59 +165,35 @@ bool MvScmProfileData::acceptChange(const MvProfileChange& ch) const
 //
 //=========================================================
 
-void MvScmDim::init(NcFile& nc, string name)
+void MvScmDim::init(MvNetCDF& nc, string name)
 {
     name_ = name;
-    //	NcDim *dim;
 
-    //We need this solution because nc.get_dim(name_.c_str());
-    //crahes when the dimension does not exist
-
-    int dnum   = nc.num_dims();
-    bool found = false;
-    for (int i = 0; i < dnum; i++) {
-        NcDim* dim = nc.get_dim(i);
-        if (dim && strcmp(dim->name(), name.c_str()) == 0) {
-            size_ = dim->size();
-            found = true;
-            break;
-        }
-    }
-
-    if (!found)
-        return;
-
-    int varNum = nc.num_vars();
-    for (int i = 0; i < varNum; i++) {
-        NcVar* var = nc.get_var(i);
-        if (var && strcmp(var->name(), name_.c_str()) == 0) {
+    if (MvNcDim* dim = nc.getDimension(name)) {
+        size_ = dim->size();
+        if (MvNcVar *var = nc.getVariable(name)) {
             setVar(var);
-            return;
         }
     }
 }
 
-void MvScmDim::setVar(NcVar* var)
+void MvScmDim::setVar(MvNcVar* var)
 {
     values_.clear();
 
-    if (!var)
+    if (!var || size_ <=0)
         return;
 
-    if (var->num_dims() != 1)
+    if (var->getNumberOfDimensions() != 1) {
         return;
-
-    if (strcmp(var->get_dim(0)->name(), name_.c_str()) == 0) {
-        int num = size_;
-        long counts[1];
-        float* vals = new float[num];
-
-        counts[0] = num;
-        var->get(vals, counts);
-        values_ = vector<float>(vals, vals + num);
-        delete[] vals;
     }
-    else {
+
+    MvNcDim* dim = var->getDimension(0);
+
+    if (dim && strcmp(dim->name(), name_.c_str()) == 0) {
+        values_ = vector<float>();
+        var->get(values_, size_);
+    } else {
         for (int i = 0; i < size_; i++)
             values_.push_back(i + 1);
     }
@@ -225,24 +201,17 @@ void MvScmDim::setVar(NcVar* var)
     setAttributes(var);
 }
 
-void MvScmDim::setAttributes(NcVar* var)
+void MvScmDim::setAttributes(MvNcVar* var)
 {
-    int n = var->num_atts();
+    int n = var->getNumberOfAttributes();
     for (int i = 0; i < n; i++) {
-        NcAtt* att = var->get_att(i);
-        if (att) {
-            if (strcmp(att->name(), "long_name") == 0 && att->num_vals() > 0) {
-                char* ch = att->as_string(0);
-                if (ch)
-                    longName_ = string(ch);
+        if (MvNcAtt* att = var->getAttribute(i)) {
+            if (att->sname() == "long_name" && att->values()) {
+                longName_ = att->as_string(0);
             }
-            else if (strcmp(att->name(), "units") == 0 && att->num_vals() > 0) {
-                char* ch = att->as_string(0);
-                if (ch)
-                    units_ = string(ch);
-            }
-
-            delete att;
+            else if (att->sname() == "units" && att->values()) {
+                units_ = att->as_string(0);
+            }           
         }
     }
 }
@@ -253,7 +222,7 @@ void MvScmDim::setAttributes(NcVar* var)
 //
 //=========================================================
 
-MvScmVar::MvScmVar(LevelType levelType, NcVar* var, const MvScmDim& timeDim) :
+MvScmVar::MvScmVar(LevelType levelType, MvNcVar* var, const MvScmDim& timeDim) :
     levelType_(levelType),
     changed_(false),
     presentInFile_(true),
@@ -266,21 +235,18 @@ MvScmVar::MvScmVar(LevelType levelType, NcVar* var, const MvScmDim& timeDim) :
 
     int tNum = timeDim.size();
     long counts[1];
-    float* vals = new float[1];
 
     for (int i = 0; i < tNum; i++) {
+        vector<float> vals;
         counts[0] = 1;
-        var->set_cur(i);
+        var->setCurrent(i);
         var->get(vals, counts);
-        data_.push_back(vector<float>(vals, vals + 1));
-
+        data_.push_back(vals);
         dataOri_.push_back(vector<float>());
     }
-
-    delete[] vals;
 }
 
-MvScmVar::MvScmVar(LevelType levelType, NcVar* var, const MvScmDim& timeDim, const MvScmDim& levDim) :
+MvScmVar::MvScmVar(LevelType levelType, MvNcVar* var, const MvScmDim& timeDim, const MvScmDim& levDim) :
     levelType_(levelType),
     changed_(false),
     presentInFile_(true),
@@ -291,21 +257,19 @@ MvScmVar::MvScmVar(LevelType levelType, NcVar* var, const MvScmDim& timeDim, con
     setName(var);
     setAttributes(var);
 
-    int tNum   = timeDim.size();
+    int tNum = timeDim.size();
     int levNum = levDim.size();
     long counts[2];
-    float* vals = new float[levNum];
 
     for (int i = 0; i < tNum; i++) {
+        vector<float> vals;
         counts[0] = 1;
         counts[1] = levNum;
-        var->set_cur(i, 0);
+        var->setCurrent(i,0);
         var->get(vals, counts);
-        data_.push_back(vector<float>(vals, vals + levNum));
+        data_.push_back(vals);
         dataOri_.push_back(vector<float>());
     }
-
-    delete[] vals;
 }
 
 //Create a new variable that is not present in the file
@@ -360,31 +324,22 @@ string MvScmVar::units() const
         return units_;
 }
 
-void MvScmVar::setName(NcVar* var)
+void MvScmVar::setName(MvNcVar* var)
 {
-    const char* ch = var->name();
-    if (ch)
-        name_ = string(ch);
+    name_ = var->sname();
 }
 
-void MvScmVar::setAttributes(NcVar* var)
+void MvScmVar::setAttributes(MvNcVar* var)
 {
-    int n = var->num_atts();
+    int n = var->getNumberOfAttributes();
     for (int i = 0; i < n; i++) {
-        NcAtt* att = var->get_att(i);
-        if (att) {
-            if (strcmp(att->name(), "long_name") == 0 && att->num_vals() > 0) {
-                char* ch = att->as_string(0);
-                if (ch)
-                    longName_ = string(ch);
+        if (MvNcAtt* att = var->getAttribute(i)) {
+            if (att->sname() == "long_name" && att->values()) {
+                longName_ = att->as_string(0);
             }
-            else if (strcmp(att->name(), "units") == 0 && att->num_vals() > 0) {
-                char* ch = att->as_string(0);
-                if (ch)
-                    units_ = string(ch);
-            }
-
-            delete att;
+            else if (att->sname() == "units" && att->values()) {
+                units_ = att->as_string(0);
+            }           
         }
     }
 }
@@ -539,17 +494,17 @@ bool MvScmVar::changed(int ts, int lev)
 }
 
 
-bool MvScmVar::saveChanges(NcFile& nc)
+bool MvScmVar::saveChanges(MvNetCDF& nc)
 {
     if (!changed_)
         return true;
 
     if (presentInFile_) {
-        NcVar* outVar = 0;
+        MvNcVar* outVar = nullptr;
 
-        for (int i = 0; i < nc.num_vars(); i++) {
-            NcVar* v = nc.get_var(i);
-            if (v && strcmp(nc.get_var(i)->name(), name_.c_str()) == 0) {
+        for (int i = 0; i < nc.getNumberOfVariables(); i++) {
+            MvNcVar* v = nc.getVariable(i);
+            if (v && strcmp(v->name(), name_.c_str()) == 0) {
                 outVar = v;
                 break;
             }
@@ -567,19 +522,16 @@ bool MvScmVar::saveChanges(NcFile& nc)
                     counts[1] = data_.at(ts).size();
 
                     if (unitsConverter_) {
-                        float* vals = new float[data_.at(ts).size()];
-                        for (unsigned int i = 0; i < data_.at(ts).size(); i++) {
+                        vector<float> vals(data_.at(ts).size());
+                        for (size_t i = 0; i < data_.at(ts).size(); i++) {
                             vals[i] = unitsConverter_->convertFrom(data_.at(ts).at(i));
                         }
-                        outVar->set_cur(ts, 0);
-                        outVar->put(vals, counts);
-
-                        delete[] vals;
+                        outVar->setCurrent(ts, 0);
+                        outVar->put(vals, counts[0], counts[1]);
                     }
                     else {
-                        float* vals = &(data_.at(ts)[0]);
-                        outVar->set_cur(ts, 0);
-                        outVar->put(vals, counts);
+                        outVar->setCurrent(ts, 0);
+                        outVar->put(data_.at(ts), counts[0], counts[1]);
                     }
                 }
 
@@ -588,17 +540,14 @@ bool MvScmVar::saveChanges(NcFile& nc)
                     counts[0] = 1;
 
                     if (unitsConverter_) {
-                        float* vals = new float[1];
-                        vals[0]     = unitsConverter_->convertFrom(data_.at(ts).at(0));
-                        outVar->set_cur(ts);
-                        outVar->put(vals, counts);
-
-                        delete[] vals;
+                        vector<float> vals;
+                        vals.push_back(unitsConverter_->convertFrom(data_.at(ts).at(0)));
+                        outVar->setCurrent(ts);
+                        outVar->put(vals, counts[0]);
                     }
                     else {
-                        float* vals = &(data_.at(ts)[0]);
-                        outVar->set_cur(ts);
-                        outVar->put(vals, counts);
+                        outVar->setCurrent(ts);
+                        outVar->put(data_.at(ts), counts[0]);
                     }
                 }
             }
@@ -806,17 +755,15 @@ MvScm::~MvScm()
 
 void MvScm::decodeId()
 {
-    NcFile nc(fileName_.c_str());
+    MvNetCDF nc(fileName_,'r');
 
     //Get id
-    int n = nc.num_atts();
+    int n = nc.getNumberOfAttributes();
     for (int i = 0; i < n; i++) {
-        NcAtt* att = nc.get_att(i);
-        if (att != NULL && att->name() != NULL &&
-            strcmp(att->name(), "dataID") == 0 && att->num_vals() > 0) {
-            char* v = att->as_string(0);
-            if (v)
-                id_ = string(v);
+        MvNcAtt* att = nc.getAttribute(i);
+        if (att != nullptr && att->name() != nullptr &&
+            strcmp(att->name(), "dataID") == 0 && att->values()) {
+            id_ = att->as_string(0);
             break;
         }
     }
@@ -892,7 +839,7 @@ void MvScm::mapScmVars()
 
 void MvScm::decode()
 {
-    NcFile nc(fileName_.c_str());
+    MvNetCDF nc(fileName_);
 
     //Init dimensions
     timeDim_.init(nc, dimName_["time"]);
@@ -901,9 +848,9 @@ void MvScm::decode()
     soilLevDim_.init(nc, dimName_["soil"]);
 
     //Get variables
-    int varNum = nc.num_vars();
+    int varNum = nc.getNumberOfVariables();
     for (int i = 0; i < varNum; i++) {
-        NcVar* var = nc.get_var(i);
+        MvNcVar* var = nc.getVariable(i);
         decodeVar(var);
     }
 
@@ -924,7 +871,7 @@ void MvScm::decode()
 	}*/
 }
 
-void MvScm::decodeVar(NcVar* var)
+void MvScm::decodeVar(MvNcVar* var)
 {
     if (!var)
         return;
@@ -938,11 +885,9 @@ void MvScm::decodeVar(NcVar* var)
     }
 
     std::set<string> dims;
-    for (int i = 0; i < var->num_dims(); i++) {
-        NcDim* dim     = var->get_dim(i);
-        const char* ch = dim->name();
-        if (ch)
-            dims.insert(string(ch));
+    for (int i = 0; i < var->getNumberOfDimensions(); i++) {
+        MvNcDim* dim     = var->getDimension(i);
+        dims.insert(dim->sname());
     }
 
 
@@ -1000,7 +945,7 @@ void MvScm::decodeVar(NcVar* var)
 void MvScm::save()
 {
     //Open progvar
-    NcFile nc(fileName_.c_str(), NcFile::Write);
+    MvNetCDF nc(fileName_, 'w');
 
     for (unsigned int i = 0; i < ml_.size(); i++) {
         ml_.at(i)->saveChanges(nc);
@@ -1155,11 +1100,10 @@ void MvScm::needConsistency(bool b)
 int MvScm::modelLevelNum(const string& fileName)
 {
     //Open file
-    NcFile nc(fileName.c_str());
+    MvNetCDF nc(fileName);
 
     int num    = -1;
-    NcDim* dim = nc.get_dim("nlev");
-    if (dim) {
+    if (MvNcDim* dim = nc.getDimension("nlev")) {
         num = dim->size();
     }
 
@@ -1173,18 +1117,17 @@ int MvScm::modelLevelNum(const string& fileName)
 bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFileName, const string& diagvar2FileName)
 {
     //Open progvar
-    NcFile nc(progvarFileName.c_str(), NcFile::Write);
+    MvNetCDF nc(progvarFileName, 'w');
 
     //Get dims from progvar
-    vector<NcDim*> dims;
-    for (int i = 0; i < nc.num_dims(); i++) {
-        NcDim* dim = nc.get_dim(i);
+    vector<MvNcDim*> dims;
+    for (int i = 0; i < nc.getNumberOfDimensions(); i++) {
+        MvNcDim* dim = nc.getDimension(i);
         if (dim) {
-            dims.push_back(dim);
-            cout << dim->name() << " " << dim->size() << endl;
+            dims.push_back(dim);            
         }
         else {
-            cout << "bad dim" << endl;
+            std::cout << "MvScm::mergeOutFiles --> bad dimension at position=" << i << endl;
         }
     }
 
@@ -1192,7 +1135,7 @@ bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFi
     // Diag
     //---------------------
 
-    NcFile ncDiag(diagvarFileName.c_str(), NcFile::ReadOnly);
+    MvNetCDF ncDiag(diagvarFileName, 'r');
 
     //Dimensions
     if (!addDimensionsToFile(ncDiag, nc, dims)) {
@@ -1200,9 +1143,9 @@ bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFi
     }
 
     //Variables
-    int varNum = ncDiag.num_vars();
+    int varNum = ncDiag.getNumberOfVariables();
     for (int i = 0; i < varNum; i++) {
-        NcVar* var = ncDiag.get_var(i);
+        MvNcVar* var = ncDiag.getVariable(i);
         addVarToFile(var, nc, dims);
     }
     ncDiag.close();
@@ -1211,7 +1154,7 @@ bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFi
     // Diag2
     //---------------------
 
-    NcFile ncDiag2(diagvar2FileName.c_str(), NcFile::ReadOnly);
+    MvNetCDF ncDiag2(diagvar2FileName, 'r');
 
     //Dimensions
     if (!addDimensionsToFile(ncDiag2, nc, dims)) {
@@ -1220,16 +1163,16 @@ bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFi
 
 
     //Variables
-    varNum = ncDiag2.num_vars();
+    varNum = ncDiag2.getNumberOfVariables();
     for (int i = 0; i < varNum; i++) {
-        NcVar* var = ncDiag2.get_var(i);
+        MvNcVar* var = ncDiag2.getVariable(i);
         addVarToFile(var, nc, dims);
     }
     ncDiag2.close();
 
 
     //Add global attributes
-    nc.add_att("dataID", "SCM_OUTPUT");
+    nc.addAttribute("dataID", "SCM_OUTPUT");
 
     nc.close();
 
@@ -1237,14 +1180,12 @@ bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFi
 }
 
 
-bool MvScm::addDimensionsToFile(NcFile& inNc, NcFile& outNc, std::vector<NcDim*>& dims)
+bool MvScm::addDimensionsToFile(MvNetCDF& inNc, MvNetCDF& outNc, std::vector<MvNcDim*>& dims)
 {
-    for (int i = 0; i < inNc.num_dims(); i++) {
-        NcDim* dim = inNc.get_dim(i);
+    for (int i = 0; i < inNc.getNumberOfDimensions(); i++) {
+        MvNcDim* dim = inNc.getDimension(i);
         bool found = false;
-        for (unsigned int j = 0; j < dims.size(); j++) {
-            cout << dims[j]->name() << " " << dims[j]->size() << endl;
-
+        for (unsigned int j = 0; j < dims.size(); j++) {           
             if (strcmp(dim->name(), dims.at(j)->name()) == 0) {
                 if (dim->size() != dims.at(j)->size()) {
                     return false;
@@ -1255,32 +1196,30 @@ bool MvScm::addDimensionsToFile(NcFile& inNc, NcFile& outNc, std::vector<NcDim*>
             }
         }
         if (!found) {
-            dims.push_back(outNc.add_dim(dim->name(), dim->size()));
+            dims.push_back(outNc.addDimension(dim->sname(), dim->size()));
         }
     }
 
     return true;
 }
 
-void MvScm::addVarToFile(NcVar* inVar, NcFile& outNc, const std::vector<NcDim*>& outDims)
+void MvScm::addVarToFile(MvNcVar* inVar, MvNetCDF& outNc, const std::vector<MvNcDim*>& outDims)
 {
-    cout << inVar->name() << endl;
-
     //Check var name
-    for (int i = 0; i < outNc.num_vars(); i++) {
-        NcVar* v = outNc.get_var(i);
+    for (int i = 0; i < outNc.getNumberOfVariables(); i++) {
+        MvNcVar* v = outNc.getVariable(i);
         if (v && strcmp(v->name(), inVar->name()) == 0) {
-            cout << v->name() << endl;
+            //cout << v->name() << endl;
             return;
         }
     }
 
     //Check dims
-    vector<NcDim*> dims;
-    for (int i = 0; i < inVar->num_dims(); i++) {
-        NcDim* dim = inVar->get_dim(i);
+    vector<MvNcDim*> dims;
+    for (int i = 0; i < inVar->getNumberOfDimensions(); i++) {
+        MvNcDim* dim = inVar->getDimension(i);
         if (dim) {
-            cout << dim->name() << " " << dim->size() << endl;
+            //cout << dim->sname() << " " << dim->size() << endl;
             for (unsigned int j = 0; j < outDims.size(); j++) {
                 if (strcmp(dim->name(), outDims.at(j)->name()) == 0 &&
                     dim->size() == outDims.at(j)->size()) {
@@ -1295,56 +1234,51 @@ void MvScm::addVarToFile(NcVar* inVar, NcFile& outNc, const std::vector<NcDim*>&
     }
 
     //Create var
-    NcVar* outVar = 0;
-    if (inVar->num_dims() == 0) {
-        outVar = outNc.add_var(inVar->name(), inVar->type());
+    MvNcVar* outVar = 0;
+    if (inVar->getNumberOfDimensions() == 0) {
+        outVar = outNc.addVariable(inVar->sname(), inVar->type(), -1);
     }
-    else if (inVar->num_dims() == 1) {
-        outVar = outNc.add_var(inVar->name(), inVar->type(), dims[0]);
+    else if (inVar->getNumberOfDimensions() == 1 && dims.size() == 1) {
+        outVar = outNc.addVariable(inVar->sname(), inVar->type(), 1,
+                                   const_cast<const MvNcDim**>(dims.data()));
     }
-    else if (inVar->num_dims() == 2) {
-        outVar = outNc.add_var(inVar->name(), inVar->type(), dims[0], dims[1]);
+    else if (inVar->getNumberOfDimensions() == 2 && dims.size() == 2) {
+        outVar = outNc.addVariable(inVar->sname(), inVar->type(), 2,
+                                   const_cast<const MvNcDim**>(dims.data()));
     }
     else {
         return;
     }
 
     //Add attributes
-    for (int i = 0; i < inVar->num_atts(); i++) {
-        NcAtt* att = inVar->get_att(i);
-        if (att) {
-            if (att->type() == ncChar) {
-                char* v = new char[att->num_vals()];
-                for (int j = 0; j < att->num_vals(); j++) {
-                    v[j] = att->as_char(j);
-                }
-                outVar->add_att(att->name(), att->num_vals(), v);
-                delete[] v;
-            }
-            delete att;
+    for (int i = 0; i < inVar->getNumberOfAttributes(); i++) {
+        if (MvNcAtt* att = inVar->getAttribute(i)) {
+            outVar->addAttribute(att);
         }
     }
 
     //Add values_
-    if (inVar->num_dims() == 0) {
-        float vals;
-        inVar->get(&vals, 0, 0, 0, 0, 0);
-        outVar->put(&vals, 0, 0, 0, 0, 0);
+    if (inVar->getNumberOfDimensions() == 0) {
+        std::vector<float> vals;
+        inVar->get(vals, 0, 0, 0, 0, 0);
+        outVar->put(vals, 0, 0, 0, 0, 0);
     }
-    if (inVar->num_dims() == 1) {
+    if (inVar->getNumberOfDimensions() == 1) {
         long counts[1];
         counts[0]   = dims[0]->size();
-        float* vals = new float[counts[0]];
-        inVar->get(vals, counts);
-        outVar->put(vals, counts);
+        //float* vals = new float[counts[0]];
+        std::vector<float> vals;
+        inVar->get(vals, counts[0]);
+        outVar->put(vals, counts[0]);
     }
-    if (inVar->num_dims() == 2) {
+    if (inVar->getNumberOfDimensions() == 2) {
         long counts[2];
         counts[0]   = dims[0]->size();
         counts[1]   = dims[1]->size();
-        float* vals = new float[counts[0] * counts[1]];
-        inVar->get(vals, counts);
-        outVar->put(vals, counts);
+        std::vector<float> vals;
+        //float* vals = new float[counts[0] * counts[1]];
+        inVar->get(vals, counts[0], counts[1]);
+        outVar->put(vals, counts[0], counts[1]);
     }
 }
 
