@@ -200,10 +200,16 @@ void MvQMessagePanel::loadKeyProfileCore(MvKeyProfile* prof)
         connect(loader_, SIGNAL(profileReady(MvKeyProfile*)),
                 this, SLOT(slotKeyProfileReady(MvKeyProfile*)));
 
-        connect(loader_, SIGNAL(started()),
+//        connect(loader_, SIGNAL(started()),
+//                this, SLOT(slotKeyProfileLoadStarted()));
+
+        connect(loader_, SIGNAL(loadStarted()),
                 this, SLOT(slotKeyProfileLoadStarted()));
 
-        connect(loader_, SIGNAL(finished()),
+//        connect(loader_, SIGNAL(finished()),
+//                this, SLOT(slotKeyProfileLoadFinished()));
+
+        connect(loader_, SIGNAL(loadFinished()),
                 this, SLOT(slotKeyProfileLoadFinished()));
 
         connect(loader_, SIGNAL(profileProgress(int)),
@@ -224,6 +230,7 @@ void MvQMessagePanel::slotKeyProfileLoadStarted()
 void MvQMessagePanel::slotKeyProfileLoadFinished()
 {
     progWidget_->hide();
+    emit keyProfileLoadFinished();
 }
 
 void MvQMessagePanel::slotKeyProfileLoadProgress(int loadPercent)
@@ -285,6 +292,8 @@ void MvQMessagePanel::slotKeyProfileReady(MvKeyProfile* prof)
         progBar_->setRange(0, 100);
         progBar_->reset();
     }
+
+    emit keyProfileReady();
 }
 
 void MvQMessagePanel::selectMessage(int msgCnt)
