@@ -79,8 +79,10 @@ signals:
     void messageSelected(int);
     void profileLoaded();
     void messageScanProgess(int);
+    void keyProfileReady();
     void keyProfileChanged();
     void keyProfileLoadProgress(int);
+    void keyProfileLoadFinished();
     void messageNumDetermined();
 
 protected:
