@@ -26,27 +26,33 @@
 
 using namespace std;
 
+class QMainWindow;
+
 class MvQApplication : public QApplication, public MvApplication
 {
     Q_OBJECT
 
 public:
-    // Constructor
     MvQApplication(int& ac, char** av, const char* name = NULL);
-
-    // Destructor
     virtual ~MvQApplication();
+    void registerToDesktop(QMainWindow* win);
+    static void writePidToFile(const MvRequest& r);
 
 public slots:
     void slotDataReceived(int);
     void processDropRequest(MvRequest*);
 
+protected:
+    virtual void messageCallback(svcid* id, request* r);
+
 private:
     // No copy allowed
     MvQApplication(const MvQApplication&);
     MvQApplication& operator=(const MvQApplication&) { return *this; }
+    static void messageCallbackCore(svcid* id, request* r, void* obj);
 
     QSocketNotifier* sn_;
+    QMainWindow* win_ {nullptr};
     char* desktopName_;
 };
 
