@@ -12,6 +12,7 @@
 #define CODEITEMWIDGET_HPP_
 
 #include <QWidget>
+#include <QSettings>
 
 #include "ui_PlainTextWidget.h"
 
@@ -26,12 +27,15 @@ public:
     PlainTextEdit* editor() const;
     MessageLabel* messageLabel() const;
     void clear();
+    void readSettings(QSettings& settings, QString);
+    void writeSettings(QSettings& settings, QString);
 
 protected Q_SLOTS:
     void on_searchTb__clicked();
     void on_gotoLineTb__clicked();
     void on_fontSizeUpTb__clicked();
     void on_fontSizeDownTb__clicked();
+    void showLineNumbersClicked(bool);
 
 Q_SIGNALS:
     void editorFontSizeChanged();
