@@ -325,8 +325,8 @@ public:
 #ifdef QT_DEBUG
         if (p != d->documentSize) {
             if (doc->q->readCharacter(p) != chunkData.at(offset)) {
-                qDebug() << "got" << chunkData.at(offset) << "at" << offset << "in" << chunk << "of size" << chunkData.size()
-                         << "expected" << doc->q->readCharacter(p) << "at document pos" << pos;
+                //qDebug() << "got" << chunkData.at(offset) << "at" << offset << "in" << chunk << "of size" << chunkData.size()
+                //         << "expected" << doc->q->readCharacter(p) << "at document pos" << pos;
             }
             Q_ASSERT(chunkData.at(offset) == doc->q->readCharacter(p));
         }
