@@ -12,6 +12,9 @@
 
 #include "MvQAbstractMessageScanner.h"
 
+#include <map>
+#include <string>
+
 class MvEccBufrMessage;
 class BufrMetaData;
 
@@ -31,8 +34,13 @@ signals:
     void progress(int, MvKeyProfile*, int, int, std::vector<MvEccBufrMessage*>);
 
 protected:
+    bool useThreadForScanning(qint64 fSize) const;
+    bool precomputeMessageNum() const;
+    void run();
+    void loadKeyProfile(MvKeyProfile* prof);
     void readMessages(MvKeyProfile* prof);
-    void readMessage(MvKeyProfile* prof, codes_handle* ch, int msgCnt, int profIndex);
+    //void readMessage(MvKeyProfile* prof, codes_handle* ch, int msgCnt, int profIndex);
+    void readMessage(MvKeyProfile* prof, codes_bufr_header* bh, int profIndex);
 
     BufrMetaData* bufrData_;
 };
