@@ -28,6 +28,8 @@ signals:
     void progress(int percent, MvKeyProfile* chunkProf, int chunkStart, int chunkSize);
 
 protected:
+    bool useThreadForScanning(qint64 fSize) const;
+    bool precomputeMessageNum() const;
     void readMessages(MvKeyProfile* prof);
     void readMessage(MvKeyProfile* prof, codes_handle* ch, int msgCnt, int profIndex);
 
