@@ -15,31 +15,15 @@
 
 #include "MvQOdbMetaData.h"
 
-#ifdef METVIEW_ODB_NEW
+#include <odc/api/ColumnType.h>
+#include <odc/Reader.h>
 
-//#include <odb_api/odblib/odb_api.h>
-#ifdef ODB_ECKIT
-#include <odb_api/ColumnType.h>
-#include <odb_api/Reader.h>
-#else
-#include <odb_api/odblib/ColumnType.h>
-#include <odb_api/odblib/Reader.h>
-#endif
+//using namespace odb;
 
-using namespace odb;
 
-extern "C" {
-#ifdef ODB_ECKIT
-#include <odb_api/odbcapi.h>
-#else
-#include <odb_api/odblib/odbcapi.h>
-#endif
-}
+static QMap<odc::api::ColumnType, MvQOdbColumn::OdbColumnType> typeIdMap;
+static QMap<odc::api::ColumnType, QString> typeIdNameMap;
 
-static QMap<ColumnType, MvQOdbColumn::OdbColumnType> typeIdMap;
-static QMap<ColumnType, QString> typeIdNameMap;
-
-#endif
 
 void MvQOdbTable::findLinks()
 {
@@ -75,23 +59,21 @@ MvQOdbMetaData::MvQOdbMetaData(string path, string odbVersion)
         odbVersion_ = InvalidVersion;
     }
 
-#ifdef METVIEW_ODB_NEW
     if (typeIdMap.isEmpty()) {
-        typeIdMap[odb::IGNORE]   = MvQOdbColumn::None;
-        typeIdMap[odb::INTEGER]  = MvQOdbColumn::Int;
-        typeIdMap[odb::REAL]     = MvQOdbColumn::Float;
-        typeIdMap[odb::STRING]   = MvQOdbColumn::String;
-        typeIdMap[odb::BITFIELD] = MvQOdbColumn::Bitfield;
-        typeIdMap[odb::DOUBLE]   = MvQOdbColumn::Double;
+        typeIdMap[odc::api::IGNORE]   = MvQOdbColumn::None;
+        typeIdMap[odc::api::INTEGER]  = MvQOdbColumn::Int;
+        typeIdMap[odc::api::REAL]     = MvQOdbColumn::Float;
+        typeIdMap[odc::api::STRING]   = MvQOdbColumn::String;
+        typeIdMap[odc::api::BITFIELD] = MvQOdbColumn::Bitfield;
+        typeIdMap[odc::api::DOUBLE]   = MvQOdbColumn::Double;
 
-        typeIdNameMap[odb::IGNORE]   = "none";
-        typeIdNameMap[odb::INTEGER]  = "int";
-        typeIdNameMap[odb::REAL]     = "float";
-        typeIdNameMap[odb::STRING]   = "string";
-        typeIdNameMap[odb::BITFIELD] = "bitfield";
-        typeIdNameMap[odb::DOUBLE]   = "double";
+        typeIdNameMap[odc::api::IGNORE]   = "none";
+        typeIdNameMap[odc::api::INTEGER]  = "int";
+        typeIdNameMap[odc::api::REAL]     = "float";
+        typeIdNameMap[odc::api::STRING]   = "string";
+        typeIdNameMap[odc::api::BITFIELD] = "bitfield";
+        typeIdNameMap[odc::api::DOUBLE]   = "double";
     }
-#endif
 
     if (odbVersion_ == Version1) {
         loadSchemaFile();
@@ -459,16 +441,14 @@ void MvQOdbMetaData::getTreePosRange(int& xr, int& yr)
     }
 }
 
-#ifdef METVIEW_ODB_NEW
-
 void MvQOdbMetaData::loadOdbHeader()
 {
-    odb_start();
-    odb::Reader oda(path_.toStdString());
+    //odb_start();
+    odc::Reader oda(path_.toStdString());
 
-    odb::Reader::iterator it = oda.begin();
+    odc::Reader::iterator it = oda.begin();
 
-    for (MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
+    for (odc::core::MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
         MvQOdbColumn* acol = new MvQOdbColumn;
 
         string s = (*itc)->name();
@@ -510,5 +490,3 @@ void MvQOdbMetaData::loadOdbHeader()
 
     //qDebug() << "odb columns"  << columns_.size() << columns_.size() << columnNum();
 }
-
-#endif
