@@ -568,9 +568,6 @@ void GeoTool::slotCoordChanged()
 void GeoTool::slotAreaSelection(double blLat, double blLon, double trLat, double trLon)
 {
     // A new area was selected graphically. Update text coordinates.
-
-    qDebug() << "New area";
-
     char buf[48];
     sprintf(buf, "%.2f/%.2f/%.2f/%.2f", blLat, blLon, trLat, trLon);
     coordEdit_->setText(tr(buf));
@@ -594,9 +591,6 @@ void GeoTool::slotAreaIsUndefined()
 void GeoTool::slotLineSelection(double lat1, double lon1, double lat2, double lon2)
 {
     // A new area was selected graphically. Update text coordinates.
-
-    qDebug() << "New line";
-
     char buf[48];
     sprintf(buf, "%.2f/%.2f/%.2f/%.2f", lat1, lon1, lat2, lon2);
     coordEdit_->setText(tr(buf));
@@ -620,9 +614,6 @@ void GeoTool::slotLineIsUndefined()
 void GeoTool::slotPointSelection(double lat, double lon)
 {
     // A new area was selected graphically. Update text coordinates.
-
-    qDebug() << "New point";
-
     char buf[48];
     sprintf(buf, "%.2f/%.2f", lat, lon);
     coordEdit_->setText(tr(buf));
