@@ -51,6 +51,7 @@ SymbolTranslator symbolTranslatorInstance("PSYMB");
 TextTranslator textTranslatorInstance("PTEXT");
 TextTranslator mtextTranslatorInstance("MTEXT");
 ThermoTranslator mthermoTranslatorInstance("MTHERMO");
+ThermoGridTranslator mthermoGridTranslatorInstance("MTHERMOGRID");
 VoidTranslator mboxplotTranslatorInstance("MBOXPLOT");
 VoidTranslator input2TranslatorInstance("INPUT_XY_POINTS");
 VoidTranslator input3TranslatorInstance("INPUT_GEO_POINTS");
@@ -882,6 +883,17 @@ ThermoTranslator::Execute(const MvRequest& visdefRequest, const MvRequest& duReq
     return magicsRequest;
 }
 
+MvRequest
+ThermoGridTranslator::Execute(const MvRequest& req)
+{
+    assert(strcmp(req.getVerb(), "MTHERMOGRID") == 0);
+    MvRequest magicsRequest = req;
+    if (const char* ch = magicsRequest("THERMO_GRID_LAYER_MODE")) {
+        magicsRequest.unsetParam("THERMO_GRID_LAYER_MODE");
+    }
+    return magicsRequest;
+}
+
 MvRequest
 TableTranslator::Execute(const MvRequest& request)
 {
