@@ -468,6 +468,21 @@ public:
     }
 };
 
+class ThermoGridTranslator : public MagicsTranslator
+{
+public:
+    ThermoGridTranslator(const char* actionName) :
+        MagicsTranslator(actionName) {}
+
+    ~ThermoGridTranslator() {}
+
+    MvRequest Execute(const MvRequest&, const MvRequest&) override {return MvRequest("EMPTY");}
+    MvRequest Execute(const MvRequest&) override;
+    MvRequest Execute(const MvRequest&, const MvRequest&, const MvRequest&) override {return MvRequest("EMPTY");}
+};
+
+
+
 class TableTranslator : public MagicsTranslator
 {
 public:
