@@ -456,6 +456,10 @@ void MapView::DescribeYourself(ObjectInfo& description)
         string sjson = (const char*)tmpRequest("_ZOOM_DEFINITION");
         MagPlusService::Instance().decode(req, sjson);
 
+        // in zoom mode we cannot have these params
+        tmpRequest.unsetParam("AREA_MODE");
+        tmpRequest.unsetParam("AREA_NAME");
+
         // Translate Magics request to a Metview request
         if ((const char*)req("subpage_map_projection"))
             tmpRequest("MAP_PROJECTION") = (const char*)req("subpage_map_projection");
