@@ -233,13 +233,10 @@ void MvQAreaSelection::mouseMoveEventFromView(QMouseEvent* event)
     else if (currentAction_ == ResizeAction) {
         QPointF dp = pos - dragPos_;
 
-        qDebug() << "resize" << pos << dragPos_;
-
         //Current control rect
         QRectF rOri = controlRect();
         QRectF r    = updateControlRect(currentAction_, dp);
 
-
         if (r.isEmpty() ||
             fabs(r.width()) <= 8. || fabs(r.height()) <= 8. ||
             r.width() < 0. || r.height() < 0.) {
@@ -247,13 +244,9 @@ void MvQAreaSelection::mouseMoveEventFromView(QMouseEvent* event)
             return;
         }
 
-        qDebug() << "resize" << r;
-
         if (r.width() < rOri.width() || r.height() < rOri.height()) {
             QRectF plotRect = mapRectFromScene(zoomLayout_->mapToScene(zoomLayout_->boundingRect()).boundingRect());
             if (!plotRect.contains(pos)) {
-                qDebug() << "   resize"
-                         << "out";
                 dragPos_ = pos;
                 return;
             }
@@ -714,4 +707,4 @@ void MvQAreaSelection::checkHandleSize() const
         handle_[i].setWidth(handleSize_);
         handle_[i].setHeight(handleSize_);
     }
-}
\ No newline at end of file
+}
