@@ -15,6 +15,7 @@
 #include <QMouseEvent>
 #include <QPainter>
 #include <QStringList>
+#include <QStyleOptionViewItem>
 
 #include "MgQLayerItem.h"
 #include "MgQPlotScene.h"
@@ -42,7 +43,7 @@ void MvQLayerDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opti
 {
     int id = index.data(MvQLayerModel::LevelRole).toInt();
     if (id == 0 && index.column() == 0) {
-        QStyleOptionViewItemV4 vopt(option);
+        QStyleOptionViewItem vopt(option);
         initStyleOption(&vopt, index);
 
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
