@@ -192,14 +192,10 @@ void MvQLineSelection::mousePressEventFromView(QMouseEvent* event)
         if ((zoomLayout_ = plotScene_->firstProjectorItem()) != 0 &&
             checkPointInLineArea(dragPos_) == true) {
             QPointF xp = dragPos_ - line_.p1();
-
-            qDebug() << "xp" << dragPos_ << xp;
-
             updateHandles();
 
             resizeId_ = -1;
             for (int i = 0; i < handle_.count(); i++) {
-                qDebug() << "handle" << i << handle_[i];
                 //If a handle is selected it starts a resize action
                 if (handle_[i].contains(xp)) {
                     resizeId_ = i;
@@ -279,16 +275,6 @@ void MvQLineSelection::mouseMoveEventFromView(QMouseEvent* event)
         else if (resizeId_ == 1)
             ln = QLineF(line_.p1(), p);
 
-        qDebug() << "resize" << ln;
-
-        /*if(r.isNull() || 
-		   fabs(r.width()) <= 8. || fabs(r.height()) <=8. || 
-		   r.width() < 0. || r.height() < 0.)
-		{
-			qDebug() << "resize false" << line_;
-			return;
-		}*/
-
         prepareGeometryChange();
         line_        = ln;
         dragPos_     = pos;
@@ -297,9 +283,6 @@ void MvQLineSelection::mouseMoveEventFromView(QMouseEvent* event)
     }
     else if (currentAction_ == MoveAction) {
         QPointF dp = pos - dragPos_;
-
-        qDebug() << "move" << dp << line_;
-
         checkMoveDelta(dp);
 
         prepareGeometryChange();
@@ -470,9 +453,6 @@ void MvQLineSelection::setLine(double lat1, double lon1, double lat2, double lon
     QPointF gp0(x1, y1);
     QPointF gp1(x2, y2);
 
-    qDebug() << zoomLayout_->containsGeoCoords(gp0);
-    qDebug() << zoomLayout_->containsGeoCoords(gp1);
-
     if (zoomLayout_->containsGeoCoords(gp0) &&
         zoomLayout_->containsGeoCoords(gp1)) {
         zoomLayout_->mapFromGeoToSceneCoords(gp0, sp0);
@@ -697,9 +677,6 @@ bool MvQLineSelection::checkPointInLineArea(QPointF& p)
         QPointF d2   = p - p2;
         double lsp   = d.x() * d2.x() + d.y() * d2.y();
         double d2len = sqrt(d2.x() * d2.x() + d2.y() * d2.y());
-
-        qDebug() << "dp" << dp << lsp << dlen << d2len;
-
         if (lsp > 0 && dlen > maxd && d2len > maxd) {
             return false;
         }
@@ -719,4 +696,4 @@ void MvQLineSelection::checkHandleSize() const
         handle_[i].setWidth(handleSize_);
         handle_[i].setHeight(handleSize_);
     }
-}
\ No newline at end of file
+}
