@@ -41,7 +41,6 @@ MvQMagnifierSlider::MvQMagnifierSlider(QList<float>& values, int actIndex, QColo
 
     for (int i = 0; i < values.count(); i++) {
         int lightFactor = 100 + static_cast<int>(100. * static_cast<float>(i) / static_cast<float>(values.count()));
-        qDebug() << lightFactor;
         cells_.push_back(new MvQMagnifierFactorCell(values[i], colour.lighter(lightFactor)));
     }
 }
@@ -146,7 +145,7 @@ bool MvQMagnifierSlider::shiftHandler(float x, float y, int& index)
 
     index = static_cast<int>((cellBarEndAngle_ - angle) / cellSweepAngle_);
 
-    qDebug() << x << y << xc << yc << dfi << index;
+    //qDebug() << x << y << xc << yc << dfi << index;
 
     if (index >= 0 && index < cells_.count() && index != actCellIndex_) {
         return true;
