@@ -224,12 +224,6 @@ Presentable::~Presentable()
         // safely call the child's destructor
         delete pt;
     }
-
-    set<PresentableObserver*> o = observers_;
-    observers_.clear();
-
-    for (set<PresentableObserver*>::iterator j = o.begin(); j != o.end(); ++j)
-        (*j)->Dead(this);
 }
 
 string
@@ -1536,9 +1530,11 @@ bool Presentable::CheckDrawTask()
 
 void Presentable::NotifyObservers()
 {
+/*
     set<PresentableObserver*> o = observers_;
     for (set<PresentableObserver*>::iterator j = o.begin(); j != o.end(); ++j)
         (*j)->Notify(*this);
+*/
 }
 
 void Presentable::GetDataUnitInfo(MvRequest& out)
@@ -1811,44 +1807,3 @@ void Presentable::RemoveIcon(const int iconId)
     this->DrawTask();
 }
 
-#if 0
-void Presentable::Add(PresentableObserver* o)
-{
-	observers_.insert(o);
-}
-
-void Presentable::Remove(PresentableObserver* o)
-{
-	observers_.erase(o);
-}
-
-void PresentableObserver::Observe(Presentable& p)
-{
-	p.Add(this);
-	observed_.insert(&p);
-}
-
-void PresentableObserver::Forget(Presentable& p)
-{
-	p.Remove(this);
-	observed_.erase(&p);
-}
-
-void PresentableObserver::ForgetAll()
-{
-	set<Presentable*>& o = observed_;
-	for(set<Presentable*>::iterator j= o.begin(); j != o.end(); ++j)
-		(*j)->Remove(this);
-	observed_.clear();
-}
-
-PresentableObserver::~PresentableObserver()
-{
-	ForgetAll();
-}
-#endif
-
-void PresentableObserver::Dead(Presentable* p)
-{
-    observed_.erase(p);
-}
