@@ -59,6 +59,7 @@
 #include "MvQZoomStackWidget.h"
 #include "MvQMethods.h"
 
+#include "LayerControlWidget.h"
 #include "MvKeyProfile.h"
 
 #include "MagPlusService.h"
@@ -139,10 +140,12 @@ uPlot::uPlot(QWidget* parent) :
     dataWidget_ = new MvQDataWidget(plotScene_, plotView_);
 
     //-------------------------------
-    //
-    //
+    // Layer control widget
+    // Contains both the layer contents and data
     //-------------------------------
 
+    layerControlWidget_ = new LayerControlWidget(layerWidget_, dataWidget_, this);
+
     //-------------------
     // Placemarks widget
     //-------------------
@@ -190,8 +193,9 @@ uPlot::uPlot(QWidget* parent) :
     controlLayout->addWidget(controlTab_, 1);
 
     controlTab_->addTab(stepWidget_, tr("Frames"));
-    controlTab_->addTab(layerWidget_, tr("Layers"));
-    controlTab_->addTab(dataWidget_, tr("Data"));
+    controlTab_->addTab(layerControlWidget_, tr("Layers"));
+    //controlTab_->addTab(layerWidget_, tr("Layers"));
+    //controlTab_->addTab(dataWidget_, tr("Data"));
 
 #ifdef PLACEMARK
     controlTab_->addTab(placeMarkWidget_, tr("Placemarks"));
@@ -1242,9 +1246,11 @@ void uPlot::slotPlotScaleChanged()
 
 void uPlot::slotControlTabChanged(int index)
 {
+#if 0
     if (index == 2) {
         dataWidget_->resetLayerList();
     }
+#endif
 }
 
 void uPlot::writeSettings()
