@@ -19,7 +19,7 @@ uPlotApp::uPlotApp(int& ac, char** av, const char* name) :
     //	InstallResources();
 
     // Register this service
-    registerTMvServe(*this, 0);
+    registerTMvServe(*this, 0, "_UPLOT_MANAGER_ID", true);
 }
 
 uPlotApp::~uPlotApp()
