@@ -49,8 +49,8 @@
 #include "MvQPlotView.h"
 #include "MvQZoomStackWidget.h"
 
-#ifdef METVIEW_ODB_NEW
-#include "odb_api/odbcapi.h"
+#if defined(METVIEW_ODB)
+#include <odc/api/odc.h>
 #endif
 
 
@@ -994,14 +994,14 @@ void uPlotBase::slotShowAboutBox()
     QMap<MvQAbout::Version, QString> text;
     text[MvQAbout::MagicsVersion] = magicsVersion;
 
-#if defined METVIEW_ODB
-    const char* odbapi_version = odb_api_version();
-    QString odbapiVersion(odbapi_version);
-    text[MvQAbout::OdbApiVersion] = odbapiVersion;
+#if defined(METVIEW_ODB)
+    const char* odc_ver;
+    odc_version(&odc_ver);
+    text[MvQAbout::OdcVersion] = odc_ver;
 #endif
 
     MvQAbout about("uPlot", "",
-                   MvQAbout::GribApiVersion | MvQAbout::MetviewVersion | MvQAbout::MagicsVersion | MvQAbout::OdbApiVersion,
+                   MvQAbout::GribApiVersion | MvQAbout::MetviewVersion | MvQAbout::MagicsVersion | MvQAbout::OdcVersion,
                    text);
 
     about.exec();
