@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/action/calc/FormulaAction.h"
 
@@ -34,8 +31,7 @@ namespace mir {
 namespace action {
 
 
-FormulaAction::FormulaAction(const param::MIRParametrisation& parametrisation):
-    Action(parametrisation) {
+FormulaAction::FormulaAction(const param::MIRParametrisation& parametrisation) : Action(parametrisation) {
 
     std::string formula;
     ASSERT(parametrisation.get("formula", formula));
@@ -51,9 +47,9 @@ FormulaAction::FormulaAction(const param::MIRParametrisation& parametrisation):
     std::vector<std::string> v;
     parse1(metadata, v);
 
-    for (auto j = v.begin(); j != v.end(); ++j) {
+    for (auto& j : v) {
         std::vector<std::string> w;
-        parse2(*j, w);
+        parse2(j, w);
         ASSERT(w.size() == 2);
 
         metadata_[w[0]] = s2l(w[1]);
@@ -70,26 +66,24 @@ FormulaAction::~FormulaAction() = default;
 
 bool FormulaAction::sameAs(const Action& other) const {
     auto o = dynamic_cast<const FormulaAction*>(&other);
-    return o && (formula_->sameAs(*o->formula_)) && (metadata_ == o->metadata_);
+    return (o != nullptr) && (formula_->sameAs(*o->formula_)) && (metadata_ == o->metadata_);
 }
 
 
-void FormulaAction::print(std::ostream &out) const {
+void FormulaAction::print(std::ostream& out) const {
     out << "FormulaAction[" << *formula_ << ", metadata=" << metadata_ << "]";
 }
 
 
 void FormulaAction::execute(context::Context& ctx) const {
-
-    eckit::AutoTiming timing(ctx.statistics().timer_, ctx.statistics().calcTiming_);
+    auto timing(ctx.statistics().calcTimer());
 
     formula_->perform(ctx);
 
-    data::MIRField& field = ctx.field();
+    auto& field = ctx.field();
     for (size_t i = 0; i < field.dimensions(); i++) {
         field.metadata(i, metadata_);
     }
-
 }
 
 
@@ -98,9 +92,8 @@ const char* FormulaAction::name() const {
 }
 
 
-static ActionBuilder< FormulaAction > __action("calc.formula");
+static ActionBuilder<FormulaAction> __action("calc.formula");
 
 
 }  // namespace action
 }  // namespace mir
-
