@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/action/interpolate/Gridded2GridDef.h"
 
@@ -29,7 +26,7 @@ namespace action {
 namespace interpolate {
 
 
-Gridded2GridDef::Gridded2GridDef(const param::MIRParametrisation& parametrisation):
+Gridded2GridDef::Gridded2GridDef(const param::MIRParametrisation& parametrisation) :
     Gridded2UnrotatedGrid(parametrisation) {
     ASSERT(parametrisation_.userParametrisation().get("griddef", griddef_));
 }
@@ -40,16 +37,17 @@ Gridded2GridDef::~Gridded2GridDef() = default;
 
 bool Gridded2GridDef::sameAs(const Action& other) const {
     auto o = dynamic_cast<const Gridded2GridDef*>(&other);
-    return o && (griddef_ == o->griddef_) && Gridded2GriddedInterpolation::sameAs(other);
+    return (o != nullptr) && (griddef_ == o->griddef_) && Gridded2GriddedInterpolation::sameAs(other);
 }
 
 
 void Gridded2GridDef::custom(std::ostream& out) const {
     out << "Gridded2GridDef["
-        "griddef=.../" << eckit::PathName(griddef_).baseName()
-        << "]";
+           "griddef=.../"
+        << eckit::PathName(griddef_).baseName() << "]";
 }
 
+
 void Gridded2GridDef::print(std::ostream& out) const {
     out << "Gridded2GridDef["
         << "griddef=" << griddef_ << ",";
@@ -62,16 +60,15 @@ const repres::Representation* Gridded2GridDef::outputRepresentation() const {
     return new repres::other::UnstructuredGrid(griddef_);
 }
 
+
 const char* Gridded2GridDef::name() const {
     return "Gridded2GridDef";
 }
 
-namespace {
-static ActionBuilder< Gridded2GridDef > grid2grid("interpolate.grid2griddef");
-}
+
+static ActionBuilder<Gridded2GridDef> grid2grid("interpolate.grid2griddef");
 
 
 }  // namespace interpolate
 }  // namespace action
 }  // namespace mir
-
