@@ -26,7 +26,7 @@ public:
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     Gridded2NamedGrid(const param::MIRParametrisation&);
 
@@ -74,7 +74,7 @@ protected:
 private:
     // -- Members
 
-    std::string gridname_;
+    std::string grid_;
 
     // -- Methods
     // None
