@@ -3,26 +3,21 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/action/io/Copy.h"
 
 #include <iostream>
 
-#include "eckit/log/Statistics.h"
-
 #include "mir/action/context/Context.h"
+#include "mir/api/MIREstimation.h"
 #include "mir/output/MIROutput.h"
 #include "mir/util/MIRStatistics.h"
-#include "mir/api/MIREstimation.h"
 
 
 namespace mir {
@@ -30,10 +25,8 @@ namespace action {
 namespace io {
 
 
-Copy::Copy(const param::MIRParametrisation& parametrisation, output::MIROutput& output):
-    Action(parametrisation),
-    output_(output) {
-}
+Copy::Copy(const param::MIRParametrisation& parametrisation, output::MIROutput& output) :
+    Action(parametrisation), output_(output) {}
 
 
 Copy::~Copy() = default;
@@ -41,7 +34,7 @@ Copy::~Copy() = default;
 
 bool Copy::sameAs(const Action& other) const {
     auto o = dynamic_cast<const Copy*>(&other);
-    return o && output_.sameAs(o->output_);
+    return (o != nullptr) && output_.sameAs(o->output_);
 }
 
 
@@ -56,7 +49,7 @@ void Copy::custom(std::ostream& out) const {
 
 
 void Copy::execute(context::Context& ctx) const {
-    eckit::AutoTiming timing(ctx.statistics().timer_, ctx.statistics().saveTiming_);
+    auto timing(ctx.statistics().saveTimer());
     output_.copy(parametrisation_, ctx);
 }
 
@@ -70,6 +63,7 @@ bool Copy::isEndAction() const {
     return true;
 }
 
+
 void Copy::estimate(context::Context&, api::MIREstimation& estimation) const {
     estimation.sameAsInput();
 }
@@ -78,4 +72,3 @@ void Copy::estimate(context::Context&, api::MIREstimation& estimation) const {
 }  // namespace io
 }  // namespace action
 }  // namespace mir
-
