@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_action_io_Save_h
 #define mir_action_io_Save_h
@@ -26,7 +23,7 @@ class MIRInput;
 namespace output {
 class MIROutput;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -36,23 +33,24 @@ namespace io {
 
 class Save : public Action {
 public:
-
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     Save(const param::MIRParametrisation&, input::MIRInput&, output::MIROutput&);
+    Save(const Save&) = delete;
 
     // -- Destructor
 
-    virtual ~Save(); // Change to virtual if base class
+    virtual ~Save();
 
     // -- Convertors
     // None
 
     // -- Operators
-    // None
+
+    Save& operator=(const Save&) = delete;
 
     // -- Methods
     // None
@@ -67,13 +65,12 @@ public:
     // None
 
 protected:
-
     // -- Members
     // None
 
     // -- Methods
 
-    void print(std::ostream&) const; // Change to virtual if base class
+    void print(std::ostream&) const;
     void custom(std::ostream&) const;
 
     // -- Overridden methods
@@ -86,27 +83,22 @@ protected:
     // None
 
 private:
-
-    // No copy allowed
-
-    Save(const Save&);
-    Save &operator=(const Save&);
-
     // -- Members
 
-    input::MIRInput &input_;
-    output::MIROutput &output_;
+    input::MIRInput& input_;
+    output::MIROutput& output_;
 
     // -- Methods
     // None
 
     // -- Overridden methods
 
+    // From Action
     virtual void execute(context::Context&) const;
     virtual bool sameAs(const Action&) const;
     virtual const char* name() const;
     virtual bool isEndAction() const;
-    virtual void estimate(context::Context&, api::MIREstimation& estimation) const;
+    virtual void estimate(context::Context&, api::MIREstimation&) const;
 
     // -- Class members
     // None
@@ -115,10 +107,7 @@ private:
     // None
 
     // -- Friends
-
-    //friend ostream& operator<<(ostream& s,const Save& p)
-    //  { p.print(s); return s; }
-
+    // None
 };
 
 
@@ -128,4 +117,3 @@ private:
 
 
 #endif
-
