@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/action/plan/Executor.h"
 
@@ -30,21 +27,16 @@ namespace mir {
 namespace action {
 
 
-namespace {
-
 static eckit::Mutex* local_mutex           = nullptr;
 static std::map<std::string, Executor*>* m = nullptr;
-
-static pthread_once_t once = PTHREAD_ONCE_INIT;
-
+static pthread_once_t once                 = PTHREAD_ONCE_INIT;
 static void init() {
     local_mutex = new eckit::Mutex();
     m           = new std::map<std::string, Executor*>();
 }
-}
 
-Executor::Executor(const std::string &name):
-    name_(name) {
+
+Executor::Executor(const std::string& name) : name_(name) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -52,13 +44,12 @@ Executor::Executor(const std::string &name):
     (*m)[name] = this;
 }
 
-Executor::~Executor()  {
+Executor::~Executor() {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     ASSERT(m->find(name_) != m->end());
     m->erase(name_);
-
 }
 
 void Executor::list(std::ostream& out) {
@@ -66,7 +57,7 @@ void Executor::list(std::ostream& out) {
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     std::set<std::string> seen;
-    const char *sep = "";
+    const char* sep = "";
     for (auto& j : *m) {
         std::string name = j.first.substr(0, j.first.find("."));
         if (seen.find(name) == seen.end()) {
@@ -98,13 +89,10 @@ const Executor& Executor::lookup(const param::MIRParametrisation& params) {
         throw eckit::SeriousBug("No Executor called " + name);
     }
 
-
-    (*j).second->parametrisation(params);
-
-    return *(*j).second;
+    j->second->parametrisation(params);
+    return *(j->second);
 }
 
 
 }  // namespace action
 }  // namespace mir
-
