@@ -27,7 +27,7 @@ public:
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     ShToNamedGrid(const param::MIRParametrisation&);
 
@@ -56,7 +56,7 @@ public:
 private:
     // -- Members
 
-    std::string gridname_;
+    std::string grid_;
 
     // -- Methods
     // None
