@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/action/transform/ShTruncate.h"
 
@@ -20,10 +17,10 @@
 #include "eckit/exception/Exceptions.h"
 
 #include "mir/action/context/Context.h"
+#include "mir/api/MIREstimation.h"
 #include "mir/data/MIRField.h"
 #include "mir/param/MIRParametrisation.h"
 #include "mir/repres/Representation.h"
-#include "mir/api/MIREstimation.h"
 #include "mir/repres/sh/SphericalHarmonics.h"
 
 
@@ -32,9 +29,7 @@ namespace action {
 namespace transform {
 
 
-ShTruncate::ShTruncate(const param::MIRParametrisation &parametrisation):
-    Action(parametrisation),
-    truncation_(0) {
+ShTruncate::ShTruncate(const param::MIRParametrisation& parametrisation) : Action(parametrisation), truncation_(0) {
     ASSERT(parametrisation.userParametrisation().get("truncation", truncation_));
 
     ASSERT(truncation_ > 0);
@@ -46,14 +41,13 @@ ShTruncate::~ShTruncate() = default;
 
 bool ShTruncate::sameAs(const Action& other) const {
     auto o = dynamic_cast<const ShTruncate*>(&other);
-    return o && (truncation_ == o->truncation_);
+    return (o != nullptr) && (truncation_ == o->truncation_);
 }
 
 
-void ShTruncate::print(std::ostream &out) const {
+void ShTruncate::print(std::ostream& out) const {
     out << "ShTruncate["
-        <<  "truncation=" << truncation_
-        << "]";
+        << "truncation=" << truncation_ << "]";
 }
 
 
@@ -69,15 +63,15 @@ void ShTruncate::execute(context::Context& ctx) const {
         const MIRValuesVector& values = field.values(i);
         MIRValuesVector result;
 
-        const repres::Representation* repres = representation->truncate(truncation_, values, result);
-
-        if (repres) { // NULL if nothing happend
-            field.representation(repres); // Assumes representation will be the same
+        auto* repres = representation->truncate(truncation_, values, result);
+        if (repres != nullptr) {           // NULL if nothing happend
+            field.representation(repres);  // Assumes representation will be the same
             field.update(result, i);
         }
     }
 }
 
+
 void ShTruncate::estimate(context::Context& ctx, api::MIREstimation& estimation) const {
     data::MIRField& field = ctx.field();
     estimation.truncation(truncation_);
@@ -89,12 +83,10 @@ const char* ShTruncate::name() const {
     return "ShTruncate";
 }
 
-namespace {
-static ActionBuilder< ShTruncate > __action("transform.sh-truncate");
-}
+
+static ActionBuilder<ShTruncate> __action("transform.sh-truncate");
 
 
 }  // namespace transform
 }  // namespace action
 }  // namespace mir
-
