@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_api_MIRJob_h
 #define mir_api_MIRJob_h
@@ -33,7 +30,7 @@ class MIROutput;
 namespace util {
 class MIRStatistics;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -43,11 +40,10 @@ class MIREstimation;
 
 class MIRJob : public param::SimpleParametrisation, public eckit::Configured {
 public:
-
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     MIRJob();
 
@@ -66,10 +62,10 @@ public:
     void execute(input::MIRInput&, output::MIROutput&) const;
     void execute(input::MIRInput&, output::MIROutput&, util::MIRStatistics&) const;
 
-    void estimate(input::MIRInput&, output::MIROutput&, MIREstimation& ) const;
+    void estimate(input::MIRInput&, output::MIROutput&, MIREstimation&) const;
 
-    MIRJob& set(const std::string& name, const std::string &value);
-    MIRJob& set(const std::string& name, const char *value);
+    MIRJob& set(const std::string& name, const std::string& value);
+    MIRJob& set(const std::string& name, const char* value);
     MIRJob& set(const std::string& name, float value);
     MIRJob& set(const std::string& name, double value);
     MIRJob& set(const std::string& name, int value);
@@ -110,7 +106,6 @@ public:
     // None
 
 protected:
-
     // -- Members
     // None
 
@@ -127,16 +122,15 @@ protected:
     // None
 
 private:
-
     // -- Members
     // None
 
     // -- Methods
 
-    template<class T>
+    template <class T>
     MIRJob& _setScalar(const std::string& name, const T& value);
 
-    template<class T>
+    template <class T>
     MIRJob& _setVector(const std::string& name, const T& value, size_t outputCount = 4);
 
     // -- Overridden methods
@@ -152,7 +146,6 @@ private:
 
     // -- Friends
     // None
-
 };
 
 
