@@ -3,16 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @author Tiago Quintino
-/// @date Apr 2015
-
 
 #ifndef mir_caching_legendre_FileLoader_h
 #define mir_caching_legendre_FileLoader_h
@@ -31,20 +27,19 @@ class FileLoader : public LegendreLoader {
 public:
     FileLoader(const param::MIRParametrisation&, const eckit::PathName&);
 
-    ~FileLoader(); // Change to virtual if base class
+    virtual ~FileLoader();
 
     static bool shared();
 
 protected:
-    void print(std::ostream&) const; // Change to virtual if base class
+    virtual void print(std::ostream&) const;
 
 private:
-    eckit::Buffer buffer_;
-
     virtual const void* address() const;
     virtual size_t size() const;
     virtual bool inSharedMemory() const;
 
+    eckit::Buffer buffer_;
 };
 
 
@@ -54,4 +49,3 @@ private:
 
 
 #endif
-
