@@ -3,16 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @author Tiago Quintino
-/// @date Apr 2015
-
 
 #include "mir/caching/legendre/NoLoader.h"
 
@@ -24,8 +20,8 @@ namespace caching {
 namespace legendre {
 
 
-NoLoader::NoLoader(const param::MIRParametrisation& parametrisation, const eckit::PathName& path)
-    : LegendreLoader(parametrisation, path) {}
+NoLoader::NoLoader(const param::MIRParametrisation& parametrisation, const eckit::PathName& path) :
+    LegendreLoader(parametrisation, path) {}
 
 NoLoader::~NoLoader() = default;
 
@@ -34,7 +30,7 @@ void NoLoader::print(std::ostream& out) const {
 }
 
 const void* NoLoader::address() const {
-    return 0;
+    return nullptr;
 }
 
 size_t NoLoader::size() const {
@@ -50,12 +46,9 @@ bool NoLoader::shared() {
 }
 
 
-namespace {
 static LegendreLoaderBuilder<NoLoader> loader("none");
-}
 
 
 }  // namespace legendre
 }  // namespace caching
 }  // namespace mir
-
