@@ -22,9 +22,7 @@ namespace compare {
 
 
 FieldInfo::FieldInfo(const std::string& path, off_t offset, size_t length) :
-    path_(path),
-    offset_(offset),
-    length_(length) {}
+    path_(path), offset_(offset), length_(length) {}
 
 void FieldInfo::print(std::ostream& out) const {
     out << "FieldInfo[path=" << path_ << ",offset=" << offset_ << ",length=" << length_ << "]";
