@@ -3,16 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date   May 2016
-
 
 #ifndef mir_compare_GribField_h
 #define mir_compare_GribField_h
@@ -34,13 +30,10 @@ namespace compare {
 
 class GribField : public FieldBase {
 public:
-
-    static Field field(const char* buffer, size_t size,
-                       const std::string& path, off_t offset,
+    static Field field(const char* buffer, size_t size, const std::string& path, off_t offset,
                        const std::vector<std::string>& ignore);
 
 private:
-
     GribField(const std::string& path, off_t offset, size_t length);
 
     void insert(const std::string& key, const std::string& value);
@@ -56,16 +49,16 @@ private:
     void gridtype(const std::string&);
     void gridname(const std::string&);
 
-    void resol(size_t resol);
-    void numberOfPoints(long n);
+    void resol(long);
+    void numberOfPoints(long);
 
-    void param(long n);
-    void accuracy(long n);
-    void decimalScaleFactor(long n);
-    void packing(const std::string& packing);
+    void param(long);
+    void accuracy(long);
+    void decimalScaleFactor(long);
+    void packing(const std::string&);
 
 
-    void missingValuesPresent(bool on);
+    void missingValuesPresent(bool);
 
     std::map<std::string, std::string>::const_iterator begin() const;
 
@@ -92,24 +85,23 @@ private:
 
     size_t numberOfPoints() const;
 
-    const std::string& format() const ;
+    const std::string& format() const;
+    bool canCompareFieldValues() const;
 
-    std::ostream& printGrid(std::ostream &out) const;
+    std::ostream& printGrid(std::ostream&) const;
 
 public:
-
     static void addOptions(std::vector<eckit::option::Option*>& options);
-    static void setOptions(const eckit::option::CmdArgs &args);
+    static void setOptions(const eckit::option::CmdArgs& args);
 
 private:
-
     // virtual bool equal_to(const GribField&) const;
     virtual bool wrapped() const;
     virtual bool less_than(const FieldBase&) const;
     virtual void whiteListEntries(std::ostream&) const;
     virtual size_t differences(const FieldBase&) const;
     virtual std::ostream& printDifference(std::ostream&, const FieldBase&) const;
-    virtual void compareExtra(std::ostream&, const FieldBase&) const ;
+    virtual void compareExtra(std::ostream&, const FieldBase&) const;
     virtual bool same(const FieldBase&) const;
     virtual bool match(const FieldBase&) const;
     virtual void json(eckit::JSON&) const;
@@ -118,7 +110,7 @@ private:
 
     long param_;
 
-    bool area_;
+    // area
     double north_;
     double west_;
     double south_;
@@ -127,17 +119,16 @@ private:
     long accuracy_;
     long decimalScaleFactor_;
 
-    bool grid_;
+    // grid
     double west_east_;
     double north_south_;
 
-    bool rotation_;
+    // rotation
     double rotation_latitude_;
     double rotation_longitude_;
 
     std::string packing_;
 
-    bool hasMissing_;
     long resol_;
     std::string gridname_;
     std::string gridtype_;
@@ -145,17 +136,20 @@ private:
 
     long numberOfPoints_;
 
+    bool area_;
+    bool grid_;
+    bool rotation_;
+    bool hasMissing_;
+
 private:
+    void print(std::ostream& out) const;
 
-    void print(std::ostream &out) const;
-
-    static void setGrid(GribField& field, grib_handle *h);
-    static void setArea(GribField& field, grib_handle *h);
-
+    static void setGrid(GribField&, grib_handle*);
+    static void setArea(GribField&, grib_handle*);
 };
 
 
-} // namespace mir
-} // namespace compare
+}  // namespace compare
+}  // namespace mir
 
 #endif
