@@ -14,22 +14,20 @@
 #define mir_config_LibMir_h
 
 #include <string>
-#include <vector>
 
 #include "eckit/system/Library.h"
 
+
 namespace mir {
 
+
 class LibMir : public eckit::system::Library {
 public:
-    using keywords_t = std::vector<std::string>;
-
     LibMir();
     static const LibMir& instance();
 
     static std::string cacheDir();
     static bool caching();
-    static keywords_t postProcess();
 
 protected:
     const void* addr() const;
@@ -37,6 +35,7 @@ protected:
     virtual std::string gitsha1(unsigned int count) const;
 };
 
+
 }  // namespace mir
 
 
