@@ -3,22 +3,19 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_data_MIRField_h
 #define mir_data_MIRField_h
 
 #include <iosfwd>
-#include <string>
 #include <map>
+#include <string>
 
 #include "eckit/thread/Mutex.h"
 
@@ -29,14 +26,14 @@ namespace mir {
 namespace data {
 class Field;
 class MIRFieldStats;
-}
+}  // namespace data
 namespace param {
 class MIRParametrisation;
 }
 namespace repres {
 class Representation;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -45,11 +42,10 @@ namespace data {
 
 class MIRField {
 public:
-
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     /// @note not in Field
     MIRField(const MIRField& other);
@@ -58,7 +54,7 @@ public:
 
     // -- Destructor
 
-    ~MIRField(); // Change to virtual if base class
+    ~MIRField();  // Change to virtual if base class
 
     // -- Convertors
     // None
@@ -76,14 +72,14 @@ public:
     /// Resize to one, and keep only which
     void select(size_t which);
 
-    void representation(const repres::Representation *);
-    const repres::Representation *representation() const;
+    void representation(const repres::Representation*);
+    const repres::Representation* representation() const;
 
     /// @warning Takes ownership of the vector
     void update(MIRValuesVector&, size_t which, bool recomputeHasMissing = false);
 
     const MIRValuesVector& values(size_t which) const;
-    MIRValuesVector& direct(size_t which);   // Non-const version for direct update (Filter)
+    MIRValuesVector& direct(size_t which);  // Non-const version for direct update (Filter)
 
     void metadata(size_t which, const std::map<std::string, long>&);
     void metadata(size_t which, const std::string& name, long value);
@@ -97,6 +93,9 @@ public:
 
     void validate() const;
 
+    void handle(size_t which, size_t handle);
+    size_t handle(size_t which) const;
+
     MIRFieldStats statistics(size_t i) const;
 
     // -- Overridden methods
@@ -109,13 +108,12 @@ public:
     // None
 
 protected:
-
     // -- Members
     // None
 
     // -- Methods
 
-    void print(std::ostream &) const; // Change to virtual if base class
+    void print(std::ostream&) const;  // Change to virtual if base class
 
     // -- Overridden methods
     // None
@@ -127,11 +125,10 @@ protected:
     // None
 
 private:
-
     // -- Members
 
     mutable eckit::Mutex mutex_;
-    Field *field_;
+    Field* field_;
 
     // -- Methods
 
@@ -149,31 +146,37 @@ private:
 
     // -- Friends
 
-    friend std::ostream &operator<<(std::ostream &s, const MIRField &p) {
+    friend std::ostream& operator<<(std::ostream& s, const MIRField& p) {
         p.print(s);
         return s;
     }
-
 };
 
 
 class FieldFactory {
     std::string name_;
     virtual MIRField* make(const param::MIRParametrisation&, bool hasMissing, double missingValue) = 0;
+
+    FieldFactory(const FieldFactory&) = delete;
+    FieldFactory& operator=(const FieldFactory&) = delete;
+
 protected:
     FieldFactory(const std::string&);
     virtual ~FieldFactory();
+
 public:
     static void list(std::ostream&);
-    static MIRField* build(const std::string& name, const param::MIRParametrisation&, bool hasMissing, double missingValue);
+    static MIRField* build(const std::string& name, const param::MIRParametrisation&, bool hasMissing,
+                           double missingValue);
 };
 
 
-template<class T>
+template <class T>
 class FieldBuilder : public FieldFactory {
     virtual MIRField* make(const param::MIRParametrisation& param, bool hasMissing, double missingValue) {
         return new T(param, hasMissing, missingValue);
     }
+
 public:
     FieldBuilder(const std::string& name) : FieldFactory(name) {}
 };
