@@ -23,13 +23,7 @@ namespace data {
 MIRFieldStats::MIRFieldStats() : count_(0), missing_(0), min_(0), max_(0), mean_(0), sqsum_(0), stdev_(0) {}
 
 MIRFieldStats::MIRFieldStats(const MIRValuesVector& vs, size_t missing) :
-    count_(vs.size()),
-    missing_(missing),
-    min_(0),
-    max_(0),
-    mean_(0),
-    sqsum_(0),
-    stdev_(0) {
+    count_(vs.size()), missing_(missing), min_(0), max_(0), mean_(0), sqsum_(0), stdev_(0) {
 
     if (count_ > 0) {
 
