@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -16,7 +17,6 @@
 #include "eckit/exception/Exceptions.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
-#include "eckit/thread/Once.h"
 
 #include "mir/config/LibMir.h"
 
@@ -31,31 +31,27 @@ Space::Space() = default;
 Space::~Space() = default;
 
 
-namespace {
-static pthread_once_t once = PTHREAD_ONCE_INIT;
-static eckit::Mutex* local_mutex = nullptr;
-static std::map< std::string, SpaceChooser* >* m = nullptr;
+static pthread_once_t once                     = PTHREAD_ONCE_INIT;
+static eckit::Mutex* local_mutex               = nullptr;
+static std::map<std::string, SpaceChooser*>* m = nullptr;
 static void init() {
     local_mutex = new eckit::Mutex();
-    m = new std::map< std::string, SpaceChooser* >();
+    m           = new std::map<std::string, SpaceChooser*>();
 }
-}  // (anonymous namespace)
 
 
 SpaceChooser::SpaceChooser(const std::string& name, Space* choice, size_t component, size_t dimensions) :
-    name_(name),
-    choice_(choice),
-    component_(component),
-    dimensions_(dimensions) {
+    name_(name), choice_(choice), component_(component), dimensions_(dimensions) {
     pthread_once(&once, init);
-    eckit::AutoLock< eckit::Mutex > lock(local_mutex);
+    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     if (m->find(name) != m->end()) {
         throw eckit::SeriousBug("SpaceChooser: duplicate '" + name + "'");
     }
 
     if (component_ >= dimensions_) {
-        throw eckit::SeriousBug("SpaceChooser: '" + name + "' component (" + std::to_string(component_) + ") is not below dimensions (" + std::to_string(dimensions_) + ")");
+        throw eckit::SeriousBug("SpaceChooser: '" + name + "' component (" + std::to_string(component_) +
+                                ") is not below dimensions (" + std::to_string(dimensions_) + ")");
     }
 
     (*m)[name] = this;
@@ -100,4 +96,3 @@ void SpaceChooser::list(std::ostream& out) {
 
 }  // namespace data
 }  // namespace mir
-
