@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -102,6 +103,9 @@ private:
 
 class SpaceChooser {
 private:
+    SpaceChooser(const SpaceChooser&) = delete;
+    SpaceChooser& operator=(const SpaceChooser&) = delete;
+
     std::string name_;
     Space* choice_;
     const size_t component_;
