@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include <iostream>
 
@@ -25,7 +22,7 @@ namespace mir {
 namespace input {
 
 
-EmptyInput::EmptyInput(): calls_(0) {
+EmptyInput::EmptyInput() : calls_(0) {
     parametrisation_.set("gridded", true);
     parametrisation_.set("gridType", "none");
 }
@@ -35,8 +32,8 @@ EmptyInput::~EmptyInput() = default;
 
 
 bool EmptyInput::sameAs(const MIRInput& other) const {
-    auto o = dynamic_cast<const EmptyInput *>(&other);
-    return o;
+    auto o = dynamic_cast<const EmptyInput*>(&other);
+    return (o != nullptr);
 }
 
 
@@ -45,7 +42,7 @@ bool EmptyInput::next() {
 }
 
 
-const param::MIRParametrisation &EmptyInput::parametrisation(size_t which) const {
+const param::MIRParametrisation& EmptyInput::parametrisation(size_t which) const {
     ASSERT(which == 0);
     return parametrisation_;
 }
@@ -56,19 +53,16 @@ data::MIRField EmptyInput::field() const {
 }
 
 
-void EmptyInput::print(std::ostream &out) const {
+void EmptyInput::print(std::ostream& out) const {
     out << "EmptyInput[...]";
 }
 
 
-void EmptyInput::latitudes(std::vector<double>&) const {
-}
+void EmptyInput::latitudes(std::vector<double>&) const {}
 
 
-void EmptyInput::longitudes(std::vector<double>&) const {
-}
+void EmptyInput::longitudes(std::vector<double>&) const {}
 
 
 }  // namespace input
 }  // namespace mir
-
