@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/input/GeoPointsFileInput.h"
 
@@ -32,34 +29,23 @@
 namespace mir {
 namespace input {
 
-// See https://software.ecmwf.int/wiki/display/METV/Geopoints
 
+// See https://software.ecmwf.int/wiki/display/METV/Geopoints
 GeoPointsFileInput::GeoPointsFileInput(const std::string& path, int which) :
     path_(path),
-    which_(which),
     next_(0),
-    hasMissing_(false),
+    footprint_(size_t(eckit::PathName(path).size())),
     missingValue_(3e38),
-    footprint_(0) {
-
-    // For now, this should give an ovwerestimate of the memory footprint
-    footprint_ = eckit::PathName(path).size();
-
+    which_(which),
+    hasMissing_(false) {  // For now, this should overestimate the memory footprint
 
     std::ifstream in(path_.c_str());
     if (!in) {
         throw eckit::CantOpenFile(path_);
     }
 
-    char magic = in.peek();
-    size_t count = 0;
-
-    if (magic == '#') {
-        count = readText(in);
-    }
-    else {
-        count = readBinary(in);
-    }
+    auto magic   = char(in.peek());
+    size_t count = (magic == '#' ? readText(in) : readBinary(in));
 
     if (count == 0) {
         std::ostringstream oss;
@@ -84,13 +70,10 @@ GeoPointsFileInput::GeoPointsFileInput(const std::string& path, int which) :
     ASSERT(dimensions_);
 
 
-    repres::other::UnstructuredGrid::check(std::string("GeoPointsFileInput from ") + path,
-                                           latitudes_,
-                                           longitudes_);
-
-
+    repres::other::UnstructuredGrid::check(std::string("GeoPointsFileInput from ") + path, latitudes_, longitudes_);
 }
 
+
 GeoPointsFileInput::~GeoPointsFileInput() = default;
 
 
@@ -104,14 +87,20 @@ size_t GeoPointsFileInput::readText(std::ifstream& in) {
     bool data = false;
     int count = 0;
 
-    enum { STANDARD = 0, XYV, XY_VECTOR, POLAR_VECTOR } format = STANDARD;
+    enum
+    {
+        STANDARD = 0,
+        XYV,
+        XY_VECTOR,
+        POLAR_VECTOR
+    } format = STANDARD;
 
     while (in.getline(line, sizeof(line))) {
 
         if (std::strncmp(line, "#GEO", 4) == 0) {
             count++;
 
-            if (which_ >= 0 && count  > which_ + 1) {
+            if (which_ >= 0 && count > which_ + 1) {
                 break;
             }
 
@@ -131,10 +120,12 @@ size_t GeoPointsFileInput::readText(std::ifstream& in) {
             parse(line + 8, v);
             ASSERT(v.size() == 1);
 
-            format = v[0] == "XYV" ?          XYV :
-                     v[0] == "XY_VECTOR" ?    XY_VECTOR :
-                     v[0] == "POLAR_VECTOR" ? POLAR_VECTOR :
-                     throw eckit::SeriousBug(path_ + " invalid format line '" + line + "'");
+            format = v[0] == "XYV" ? XYV
+                                   : v[0] == "XY_VECTOR"
+                                         ? XY_VECTOR
+                                         : v[0] == "POLAR_VECTOR"
+                                               ? POLAR_VECTOR
+                                               : throw eckit::SeriousBug(path_ + " invalid format line '" + line + "'");
         }
 
         if (!data && std::strncmp(line, "# ", 2) == 0) {
@@ -145,12 +136,7 @@ size_t GeoPointsFileInput::readText(std::ifstream& in) {
         }
 
         if (!data && std::strncmp(line, "#DATA", 5) == 0) {
-            if (which_ < 0) {
-                data = true;
-            }
-            else {
-                data = (count == which_ + 1);
-            }
+            data = (which_ < 0) || (count == which_ + 1);
             continue;
         }
 
@@ -158,14 +144,14 @@ size_t GeoPointsFileInput::readText(std::ifstream& in) {
             std::vector<std::string> v;
             parse(line, v);
             if (v.size() >= 3) {
-                latitudes_  .push_back(s2d(v[format == XYV ? 1 : 0]));
-                longitudes_ .push_back(s2d(v[format == XYV ? 0 : 1]));
+                latitudes_.push_back(s2d(v[format == XYV ? 1 : 0]));
+                longitudes_.push_back(s2d(v[format == XYV ? 0 : 1]));
                 values_.push_back(s2d(v.back()));
             }
         }
     }
 
-    return count;
+    return size_t(count);
 }
 
 
@@ -186,7 +172,7 @@ size_t GeoPointsFileInput::readBinary(std::ifstream& in) {
         ASSERT(what == "GEO");
 
         count++;
-        if (which_ >= 0 && int(count)  > which_ + 1) {
+        if (which_ >= 0 && int(count) > which_ + 1) {
             break;
         }
 
@@ -203,14 +189,15 @@ size_t GeoPointsFileInput::readBinary(std::ifstream& in) {
         ASSERT(format == "XYV");
 
         for (;;) {
-            std::string k, v;
-            s >> k;
-            if (k == "-") {
+            std::string key;
+            std::string value;
+            s >> key;
+            if (key == "-") {
                 break;
             }
-            s >> v;
+            s >> value;
 
-            fieldParametrisation_.set(k, v);
+            fieldParametrisation_.set(key, value);
         }
 
         size_t n;
@@ -219,11 +206,8 @@ size_t GeoPointsFileInput::readBinary(std::ifstream& in) {
         longitudes_.resize(n);
         values_.resize(n);
         for (size_t i = 0; i < n; ++i) {
-            s >> longitudes_[i]
-              >> latitudes_[i]
-              >> values_[i];
+            s >> longitudes_[i] >> latitudes_[i] >> values_[i];
         }
-
     }
 
 
@@ -231,23 +215,22 @@ size_t GeoPointsFileInput::readBinary(std::ifstream& in) {
 }
 
 
-
-
 bool GeoPointsFileInput::resetMissingValue(double& missingValue) {
 
     // geopoints hard-coded value, all values have to be below
-    missingValue = 3e38;
+    missingValue    = 3e38;
     bool hasMissing = (values_.end() != std::find(values_.begin(), values_.end(), missingValue));
 
     // find the non-missing max value
     bool allMissing = true;
-    double max = missingValue;
+    double max      = missingValue;
     for (const double& v : values_) {
         ASSERT(v <= missingValue);
         if (v != missingValue) {
             allMissing = false;
-            if (max == missingValue || max < v)
+            if (max == missingValue || max < v) {
                 max = v;
+            }
         }
     }
 
@@ -263,8 +246,9 @@ bool GeoPointsFileInput::resetMissingValue(double& missingValue) {
 
     if (hasMissing) {
         for (double& v : values_) {
-            if (v == missingValue)
+            if (v == missingValue) {
                 v = tempMissingValue;
+            }
         }
     }
 
@@ -277,7 +261,7 @@ bool GeoPointsFileInput::resetMissingValue(double& missingValue) {
 
 bool GeoPointsFileInput::sameAs(const MIRInput& other) const {
     auto o = dynamic_cast<const GeoPointsFileInput*>(&other);
-    return o && (path_ == o->path_);
+    return (o != nullptr) && (path_ == o->path_);
 }
 
 
@@ -291,7 +275,7 @@ size_t GeoPointsFileInput::dimensions() const {
 }
 
 
-const param::MIRParametrisation &GeoPointsFileInput::parametrisation(size_t which) const {
+const param::MIRParametrisation& GeoPointsFileInput::parametrisation(size_t which) const {
     ASSERT(which == 0);
     return fieldParametrisation_;
 }
@@ -309,12 +293,10 @@ data::MIRField GeoPointsFileInput::field() const {
 }
 
 
-void GeoPointsFileInput::print(std::ostream &out) const {
+void GeoPointsFileInput::print(std::ostream& out) const {
     out << "GeoPointsFileInput["
-        "path=" << path_
-        << ",which=" << which_
-        << ",dimensions=" << dimensions_
-        << "]";
+           "path="
+        << path_ << ",which=" << which_ << ",dimensions=" << dimensions_ << "]";
 }
 
 
@@ -338,9 +320,8 @@ size_t GeoPointsFileInput::footprint() const {
 }
 
 
-static MIRInputBuilder< GeoPointsFileInput > __mirinput(0x2347454f); // "#GEO"
+static MIRInputBuilder<GeoPointsFileInput> __mirinput(0x2347454f);  // "#GEO"
 
 
 }  // namespace input
 }  // namespace mir
-
