@@ -3,20 +3,19 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/lsm/NoneLSM.h"
 
 #include <iostream>
+
 #include "eckit/exception/Exceptions.h"
+
 #include "mir/lsm/NoMask.h"
 
 
@@ -24,48 +23,40 @@ namespace mir {
 namespace lsm {
 
 
-namespace {
 static NoneLSM __lsm_selection("none");
-}
 
 
-NoneLSM::NoneLSM(const std::string &name):
-  LSMSelection(name) {
-}
+NoneLSM::NoneLSM(const std::string& name) : LSMSelection(name) {}
 
 
 NoneLSM::~NoneLSM() = default;
 
 
 Mask& NoneLSM::noMask() {
-  static NoMask none;
-  return none;
+    static NoMask none;
+    return none;
 }
 
 
-void NoneLSM::print(std::ostream &out) const {
-  out << "NoneLSM[" << name_ << "]";
+void NoneLSM::print(std::ostream& out) const {
+    out << "NoneLSM[" << name_ << "]";
 }
 
 
-Mask *NoneLSM::create(const param::MIRParametrisation&,
-                      const repres::Representation&,
-                      const std::string&) const {
-  return new NoMask();
+Mask* NoneLSM::create(const param::MIRParametrisation&, const repres::Representation&, const std::string&) const {
+    return new NoMask();
 }
 
 
-std::string NoneLSM::cacheKey(const param::MIRParametrisation&,
-                              const repres::Representation&,
+std::string NoneLSM::cacheKey(const param::MIRParametrisation&, const repres::Representation&,
                               const std::string&) const {
-  return "none";
+    return "none";
 }
 
 std::string NoneLSM::cacheName() const {
-  NOTIMP;
+    NOTIMP;
 }
 
 
 }  // namespace lsm
 }  // namespace mir
-
