@@ -3,16 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @author Tiago Quintino
-/// @date May 2015
-
 
 #ifndef mir_method_Cropping_h
 #define mir_method_Cropping_h
@@ -28,29 +24,25 @@ namespace method {
 
 class Cropping {
 public:
-
     Cropping();
-
+    Cropping(const Cropping&);
     ~Cropping();
 
+    Cropping& operator=(const Cropping&);
+    bool operator==(const Cropping&) const;
+
+    operator bool() const { return active_; }
+
     void hash(eckit::MD5&) const;
+    bool sameAs(const Cropping&) const;
 
-    bool operator==(const Cropping& other) const;
-
-    operator bool() const {
-        return active_;
-    }
-
-    void boundingBox(const util::BoundingBox& bbox);
+    void boundingBox(const util::BoundingBox&);
     const util::BoundingBox& boundingBox() const;
 
 protected:
-
-
     void print(std::ostream&) const;
 
 private:
-
     util::BoundingBox bbox_;
     bool active_;
 
@@ -58,7 +50,6 @@ private:
         p.print(s);
         return s;
     }
-
 };
 
 
@@ -67,4 +58,3 @@ private:
 
 
 #endif
-
