@@ -97,7 +97,7 @@ bool MethodWeighted::sameAs(const Method& other) const {
     auto o = dynamic_cast<const MethodWeighted*>(&other);
     return (o != nullptr) && (lsmWeightAdjustment_ == o->lsmWeightAdjustment_) && (pruneEpsilon_ == o->pruneEpsilon_) &&
            (sameNonLinearities(nonLinear_, o->nonLinear_)) &&
-           lsm::LandSeaMasks::sameLandSeaMasks(parametrisation_, o->parametrisation_) && cropping_ == o->cropping_;
+           lsm::LandSeaMasks::sameLandSeaMasks(parametrisation_, o->parametrisation_) && cropping_.sameAs(o->cropping_);
 }
 
 
@@ -142,22 +142,23 @@ const WeightMatrix& MethodWeighted::getMatrix(context::Context& ctx, const repre
     // TODO: add (possibly) missing unique identifiers
     // NOTE: key has to be relatively short, to avoid filesystem "File name too long" errors
     // Check with $getconf -a | grep -i name
-    std::string disk_key = std::string(name()) + "/" + shortName_in + "/" + shortName_out + "-";
     eckit::MD5 hash;
-    hash << *this << shortName_in << shortName_out << in.boundingBox() << out.boundingBox() << pruneEpsilon_
-         << lsmWeightAdjustment_;
+    hash << *this << shortName_in << shortName_out << in.boundingBox() << out.boundingBox();
 
-    disk_key += hash;
+    std::string version_str;
+    auto v = version();
+    if (v) {
+        version_str = std::to_string(v) + "/";
+    }
+
+    std::string disk_key =
+        std::string(name()) + "/" + version_str + shortName_in + "/" + shortName_out + "-" + std::string(hash);
     std::string memory_key = disk_key;
 
     // Add masks if any
     if (masks.active()) {
-
-        std::string masks_key = "-lsm-";
-        masks_key += masks.cacheName();
-
+        std::string masks_key = "-lsm-" + masks.cacheName();
         memory_key += masks_key;
-
         if (masks.cacheable()) {
             disk_key += masks_key;
         }
@@ -165,8 +166,8 @@ const WeightMatrix& MethodWeighted::getMatrix(context::Context& ctx, const repre
 
 
     {
-        auto j           = matrix_cache.find(memory_key);
-        const bool found = j != matrix_cache.end();
+        auto j     = matrix_cache.find(memory_key);
+        auto found = j != matrix_cache.end();
         log << "MethodWeighted::getMatrix cache key: " << memory_key << " " << timer.elapsed() - here << "s, "
             << (found ? "found" : "not found") << " in memory cache" << std::endl;
         if (found) {
@@ -282,8 +283,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
 
 
     // Make sure another thread to no evict anything from the cache while we are using it
-    caching::InMemoryCacheUser<WeightMatrix> matrix_use(matrix_cache, ctx.statistics().matrixCache_);
-
+    auto cacheUse(ctx.statistics().cacheUser(matrix_cache));
 
     static bool check_stats = eckit::Resource<bool>("mirCheckStats", false);
 
@@ -488,9 +488,21 @@ void MethodWeighted::applyMasks(WeightMatrix& W, const lsm::LandSeaMasks& masks)
 
 void MethodWeighted::hash(eckit::MD5& md5) const {
     md5.add(name());
+    md5 << pruneEpsilon_;
+    md5 << lsmWeightAdjustment_;
     for (auto& n : nonLinear_) {
         n->hash(md5);
     }
+
+    auto v = version();
+    if (v != 0) {
+        md5.add(v);
+    }
+}
+
+
+int MethodWeighted::version() const {
+    return 0;
 }
 
 
