@@ -3,17 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Florian Rathgeber
-/// @author Pedro Maciel
-/// @author Tiago Quintino
-/// @date May 2015
-
 
 #include "mir/method/WeightMatrix.h"
 
@@ -32,17 +27,17 @@ namespace mir {
 namespace method {
 
 
-//----------------------------------------------------------------------------------------------------------------------
-
-
 WeightMatrix::WeightMatrix(SparseMatrix::Allocator* alloc) : SparseMatrix(alloc) {}
 
-WeightMatrix::WeightMatrix(const eckit::PathName& path) : SparseMatrix() {
+
+WeightMatrix::WeightMatrix(const eckit::PathName& path) {
     load(path);
 }
 
+
 WeightMatrix::WeightMatrix(WeightMatrix::Size rows, WeightMatrix::Size cols) : SparseMatrix(rows, cols) {}
 
+
 void WeightMatrix::setFromTriplets(const std::vector<WeightMatrix::Triplet>& triplets) {
     ASSERT(rows());
     ASSERT(cols());
@@ -52,18 +47,21 @@ void WeightMatrix::setFromTriplets(const std::vector<WeightMatrix::Triplet>& tri
     swap(M);
 }
 
+
 void WeightMatrix::print(std::ostream& os) const {
     os << "WeightMatrix[";
     SparseMatrix::print(os);
     os << "]";
 }
 
+
 void WeightMatrix::multiply(const WeightMatrix::Vector& values, WeightMatrix::Vector& result) const {
 
     /// @todo linear algebra backend should depend on parametrisation
     eckit::linalg::LinearAlgebra::backend().spmv(*this, values, result);
 }
 
+
 void WeightMatrix::multiply(const WeightMatrix::Matrix& values, WeightMatrix::Matrix& result) const {
 
     // eckit::Log::debug<LibMir>() << "MethodWeighted::multiply: "
@@ -83,15 +81,17 @@ void WeightMatrix::multiply(const WeightMatrix::Matrix& values, WeightMatrix::Ma
     // when interpolating, the general case is for single-column values/result vectors
     if (values.cols() == 1) {
         // FIXME: remove this const cast once Vector provides read-only view
-        eckit::linalg::Vector vi(const_cast<double *>(values.data()), values.rows());
+        eckit::linalg::Vector vi(const_cast<double*>(values.data()), values.rows());
         eckit::linalg::Vector vo(result.data(), result.rows());
 
         eckit::linalg::LinearAlgebra::backend().spmv(*this, vi, vo);
-    } else {
+    }
+    else {
         eckit::linalg::LinearAlgebra::backend().spmm(*this, values, result);
     }
 }
 
+
 void WeightMatrix::cleanup(const double& pruneEpsilon) {
 
     size_t fixed = 0;
@@ -99,7 +99,7 @@ void WeightMatrix::cleanup(const double& pruneEpsilon) {
 
     for (Size i = 0; i < rows(); ++i) {
 
-        double removed = 0;
+        double removed  = 0;
         size_t non_zero = 0;
 
         for (iterator it = begin(i); it != end(i); ++it) {
@@ -110,35 +110,38 @@ void WeightMatrix::cleanup(const double& pruneEpsilon) {
                     *it = 0;
                     fixed++;
                 }
-            } else {
+            }
+            else {
                 non_zero++;
             }
             count++;
         }
 
-        if (removed && non_zero) {
+        if ((removed != 0.) && (non_zero > 0)) {
             double d = removed / non_zero;
             for (iterator it = begin(i); it != end(i); ++it) {
                 const double a = *it;
-                if (a) {
+                if (a != 0.) {
                     *it = a + d;
                 }
             }
         }
     }
 
-    if (fixed) {
-        size_t r = rows();
-        size_t c = cols();
+    if (fixed > 0) {
+        size_t r     = rows();
+        size_t c     = cols();
         size_t total = r * c;
         eckit::Log::debug<LibMir>() << "WeightMatrix::cleanup fixed " << Pretty(fixed, {"value"}) << " out of "
-                                    << Pretty(count) << " (matrix is " << Pretty(r) << "x"
-                                    << Pretty(c) << ", total=" << Pretty(total) << ")" << std::endl;
+                                    << Pretty(count) << " (matrix is " << Pretty(r) << "x" << Pretty(c)
+                                    << ", total=" << Pretty(total) << ")" << std::endl;
     }
-    prune(0.0);
+
+    prune(0.);
 }
 
-void WeightMatrix::validate(const char *when) const {
+
+void WeightMatrix::validate(const char* when) const {
 
     bool logErrors = (eckit::Log::debug<LibMir>());
 
@@ -148,10 +151,10 @@ void WeightMatrix::validate(const char *when) const {
 
         // check for W(i,j)<0, or W(i,j)>1, or sum(W(i,:))!=(0,1)
         double sum = 0.;
-        bool ok  = true;
+        bool ok    = true;
 
         for (const_iterator it = begin(i); it != end(i); ++it) {
-            const double &a = *it;
+            const double& a = *it;
             ok &= eckit::types::is_approximately_greater_or_equal(a, 0.) &&
                   eckit::types::is_approximately_greater_or_equal(1., a);
             sum += a;
@@ -163,7 +166,7 @@ void WeightMatrix::validate(const char *when) const {
         if (!ok && logErrors) {
 
             if (errors < 50) {
-                if (!errors) {
+                if (errors == 0) {
                     eckit::Log::debug<LibMir>() << "WeightMatrix::validate(" << when << ") failed " << std::endl;
                 }
 
@@ -178,7 +181,8 @@ void WeightMatrix::validate(const char *when) const {
                 }
 
                 eckit::Log::debug<LibMir>() << " sum=" << sum << ", 1-sum " << (1 - sum) << std::endl;
-            } else if (errors == 50) {
+            }
+            else if (errors == 50) {
                 eckit::Log::debug<LibMir>() << "..." << std::endl;
             }
             errors++;
