@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -12,7 +13,6 @@
 #include "mir/method/gridbox/GridBoxMethod.h"
 
 #include <algorithm>
-#include <cmath>
 #include <forward_list>
 #include <sstream>
 #include <vector>
@@ -52,7 +52,7 @@ GridBoxMethod::~GridBoxMethod() = default;
 
 bool GridBoxMethod::sameAs(const Method& other) const {
     auto o = dynamic_cast<const GridBoxMethod*>(&other);
-    return o && name() == o->name() && MethodWeighted::sameAs(*o);
+    return (o != nullptr) && name() == o->name() && MethodWeighted::sameAs(*o);
 }
 
 
@@ -137,6 +137,7 @@ void GridBoxMethod::assemble(util::MIRStatistics&, WeightMatrix& W, const repres
             ASSERT(area > 0.);
 
             double sumSmallAreas = 0.;
+            bool areaMatch       = false;
             for (auto& c : closest) {
                 auto j        = c.payload();
                 auto smallBox = inBoxes.at(j);
@@ -147,12 +148,16 @@ void GridBoxMethod::assemble(util::MIRStatistics&, WeightMatrix& W, const repres
 
                     triplets.emplace_back(WeightMatrix::Triplet(i, j, smallArea / area));
                     sumSmallAreas += smallArea;
+
+                    if ((areaMatch = eckit::types::is_approximately_equal(area, sumSmallAreas, 1. /*m^2*/))) {
+                        break;
+                    }
                 }
             }
 
 
             // insert the interpolant weights into the global (sparse) interpolant matrix
-            if (!triplets.empty() && eckit::types::is_approximately_equal(area, sumSmallAreas, 1. /*m^2*/)) {
+            if (areaMatch) {
                 std::copy(triplets.begin(), triplets.end(), std::back_inserter(weights_triplets));
             }
             else {
@@ -166,7 +171,7 @@ void GridBoxMethod::assemble(util::MIRStatistics&, WeightMatrix& W, const repres
     }
     log << "Intersected " << Pretty(weights_triplets.size(), gridBoxes) << std::endl;
 
-    if (nbFailures) {
+    if (nbFailures > 0) {
         auto& warning = eckit::Log::warning();
         warning << "Failed to intersect " << Pretty(nbFailures, gridBoxes) << ":";
         size_t count = 0;
