@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date May 2015
-
 
 #include "mir/method/knn/KNearestNeighbours.h"
 
@@ -37,14 +34,7 @@ namespace method {
 namespace knn {
 
 
-KNearestNeighbours::KNearestNeighbours(const param::MIRParametrisation& param) : MethodWeighted(param) {
-
-    std::string name = "nearest-neighbour-with-lowest-index";
-    param.get("nearest-method", name);
-
-    picker_.reset(pick::PickFactory::build(name, param));
-    ASSERT(picker_);
-}
+KNearestNeighbours::KNearestNeighbours(const param::MIRParametrisation& param) : MethodWeighted(param) {}
 
 
 KNearestNeighbours::~KNearestNeighbours() = default;
@@ -52,35 +42,27 @@ KNearestNeighbours::~KNearestNeighbours() = default;
 
 bool KNearestNeighbours::sameAs(const Method& other) const {
     auto o = dynamic_cast<const KNearestNeighbours*>(&other);
-    return o
-            && picker_->sameAs(*(o->picker_))
-            && distanceWeighting().sameAs(o->distanceWeighting());
+    return (o != nullptr) && pick().sameAs(o->pick()) && distanceWeighting().sameAs(o->distanceWeighting());
 }
 
 
 void KNearestNeighbours::hash(eckit::MD5& md5) const {
-    md5 << *picker_;
+    md5 << pick();
     md5 << distanceWeighting();
 }
 
 
-void KNearestNeighbours::assemble(
-        util::MIRStatistics& stats,
-        WeightMatrix& W,
-        const repres::Representation& in,
-        const repres::Representation& out) const {
+void KNearestNeighbours::assemble(util::MIRStatistics& stats, WeightMatrix& W, const repres::Representation& in,
+                                  const repres::Representation& out) const {
 
     // assemble with specific distance weighting method
-    assemble(stats, W, in, out, distanceWeighting());
+    assemble(stats, W, in, out, pick(), distanceWeighting());
 }
 
 
-void KNearestNeighbours::assemble(
-        util::MIRStatistics&,
-        WeightMatrix& W,
-        const repres::Representation& in,
-        const repres::Representation& out,
-        const distance::DistanceWeighting& distanceWeighting ) const {
+void KNearestNeighbours::assemble(util::MIRStatistics&, WeightMatrix& W, const repres::Representation& in,
+                                  const repres::Representation& out, const pick::Pick& pick,
+                                  const distance::DistanceWeighting& distanceWeighting) const {
     auto& log = eckit::Log::debug<LibMir>();
 
     log << *this << "::assemble (input: " << in << ", output: " << out << ")" << std::endl;
@@ -94,7 +76,7 @@ void KNearestNeighbours::assemble(
 
     // init structure used to fill in sparse matrix
     std::vector<WeightMatrix::Triplet> weights_triplets;
-    weights_triplets.reserve(nbOutputPoints * picker_->n());
+    weights_triplets.reserve(nbOutputPoints * pick.n());
 
     std::vector<search::PointSearch::PointValueType> closest;
     std::vector<WeightMatrix::Triplet> triplets;
@@ -104,15 +86,21 @@ void KNearestNeighbours::assemble(
         double search = 0;
         double insert = 0;
 
-        const std::unique_ptr<repres::Iterator> it(out.iterator());
         size_t ip = 0;
-        while (it->next()) {
+        for (const std::unique_ptr<repres::Iterator> it(out.iterator()); it->next(); ++ip) {
             ASSERT(ip < nbOutputPoints);
             if (++progress) {
                 log << "KNearestNeighbours: k-d tree"
-                       "\n" "search: " << search << "s"
-                       "\n" "insert: " << insert << "s"
-                       "\n" << sptree << std::endl;
+                       "\n"
+                       "search: "
+                    << search
+                    << "s"
+                       "\n"
+                       "insert: "
+                    << insert
+                    << "s"
+                       "\n"
+                    << sptree << std::endl;
                 search = insert = 0;
             }
 
@@ -124,8 +112,11 @@ void KNearestNeighbours::assemble(
                 // search
                 {
                     double t = timer.elapsed();
-                    picker_->pick(sptree, p, closest);
+                    pick.pick(sptree, p, closest);
                     search += timer.elapsed() - t;
+                    if (closest.empty()) {
+                        continue;
+                    }
                 }
 
                 // calculate weights
@@ -138,10 +129,7 @@ void KNearestNeighbours::assemble(
                     std::copy(triplets.begin(), triplets.end(), std::back_inserter(weights_triplets));
                     insert += timer.elapsed() - t;
                 }
-
             }
-
-            ++ip;
         }
     }
 
@@ -157,9 +145,7 @@ void KNearestNeighbours::assemble(
 void KNearestNeighbours::print(std::ostream& out) const {
     out << "KNearestNeighbours[";
     MethodWeighted::print(out);
-    out << ",nearestMethod=" << (*picker_)
-        << ",distanceWeighting=" << distanceWeighting()
-        << "]";
+    out << ",nearestMethod=" << pick() << ",distanceWeighting=" << distanceWeighting() << "]";
 }
 
 
@@ -171,4 +157,3 @@ bool KNearestNeighbours::canIntroduceMissingValues() const {
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
