@@ -3,22 +3,19 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date May 2015
-
 
 #include "mir/method/knn/NearestLSM.h"
 
 #include <memory>
 
 #include "mir/lsm/LandSeaMasks.h"
+#include "mir/method/knn/pick/Pick.h"
 #include "mir/param/RuntimeParametrisation.h"
 
 
@@ -27,28 +24,27 @@ namespace method {
 namespace knn {
 
 
-NearestLSM::NearestLSM(const param::MIRParametrisation& param) :
-    KNearestNeighbours(param),
-    distanceWeighting_(param) {
+NearestLSM::NearestLSM(const param::MIRParametrisation& param) : KNearestNeighbours(param), distanceWeighting_(param) {
+
+    std::string nearestMethod = "nclosest";
+    param.get("nearest-method", nearestMethod);
+    pick_.reset(pick::PickFactory::build(nearestMethod, param));
 }
 
 
 NearestLSM::~NearestLSM() = default;
 
 
-void NearestLSM::assemble(
-    util::MIRStatistics& stats,
-    WeightMatrix& W,
-    const repres::Representation& in,
-    const repres::Representation& out) const {
+void NearestLSM::assemble(util::MIRStatistics& stats, WeightMatrix& W, const repres::Representation& in,
+                          const repres::Representation& out) const {
 
     // get distance weighting method
     std::unique_ptr<const distance::DistanceWeighting> method(
-                distanceWeighting_.distanceWeighting(parametrisation_, getMasks(in, out)) );
+        distanceWeighting_.distanceWeighting(parametrisation_, getMasks(in, out)));
     ASSERT(method);
 
     // assemble with specific distance weighting method
-    KNearestNeighbours::assemble(stats, W, in, out, *method);
+    KNearestNeighbours::assemble(stats, W, in, out, *pick_, *method);
 }
 
 
@@ -73,7 +69,8 @@ lsm::LandSeaMasks NearestLSM::getMasks(const repres::Representation& in, const r
 }
 
 
-static bool sameLsm(const param::MIRParametrisation& parametrisation1, const param::MIRParametrisation& parametrisation2) {
+static bool sameLsm(const param::MIRParametrisation& parametrisation1,
+                    const param::MIRParametrisation& parametrisation2) {
     param::RuntimeParametrisation runtime1(parametrisation1);
     setParametrisation(parametrisation1, runtime1);
 
@@ -86,9 +83,13 @@ static bool sameLsm(const param::MIRParametrisation& parametrisation1, const par
 
 bool NearestLSM::sameAs(const Method& other) const {
     auto o = dynamic_cast<const NearestLSM*>(&other);
-    return o
-           && KNearestNeighbours::sameAs(other)
-           && sameLsm(parametrisation_, o->parametrisation_);
+    return (o != nullptr) && KNearestNeighbours::sameAs(other) && sameLsm(parametrisation_, o->parametrisation_);
+}
+
+
+const pick::Pick& NearestLSM::pick() const {
+    ASSERT(pick_);
+    return *pick_;
 }
 
 
@@ -102,12 +103,9 @@ const char* NearestLSM::name() const {
 }
 
 
-namespace {
-static MethodBuilder< NearestLSM > __method("nearest-lsm");
-}
+static MethodBuilder<NearestLSM> __method("nearest-lsm");
 
 
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
