@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -16,8 +17,8 @@
 #include "eckit/exception/Exceptions.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
-#include "eckit/thread/Once.h"
 #include "eckit/utils/MD5.h"
+
 #include "mir/config/LibMir.h"
 #include "mir/param/MIRParametrisation.h"
 
@@ -28,29 +29,22 @@ namespace knn {
 namespace distance {
 
 
-namespace {
-
-
-static eckit::Mutex* local_mutex = nullptr;
-static std::map< std::string, DistanceWeightingWithLSMFactory* > *m = nullptr;
-static pthread_once_t once = PTHREAD_ONCE_INIT;
-
-
+static eckit::Mutex* local_mutex                                  = nullptr;
+static std::map<std::string, DistanceWeightingWithLSMFactory*>* m = nullptr;
+static pthread_once_t once                                        = PTHREAD_ONCE_INIT;
 static void init() {
     local_mutex = new eckit::Mutex();
-    m = new std::map< std::string, DistanceWeightingWithLSMFactory* >();
+    m           = new std::map<std::string, DistanceWeightingWithLSMFactory*>();
 }
 
 
-}  // (anonymous namespace)
-
-
 DistanceWeightingWithLSM::DistanceWeightingWithLSM(const param::MIRParametrisation& parametrisation) {
     std::string name = "nearest-lsm-with-lowest-index";
     parametrisation.get("distance-weighting-with-lsm", name);
 
     if (!DistanceWeightingWithLSMFactory::has(name)) {
-        DistanceWeightingWithLSMFactory::list(eckit::Log::error() << "No DistanceWeightingWithLSMFactory '" << name << "', choices are:\n");
+        DistanceWeightingWithLSMFactory::list(eckit::Log::error()
+                                              << "No DistanceWeightingWithLSMFactory '" << name << "', choices are:\n");
         throw eckit::SeriousBug("No DistanceWeightingWithLSMFactory '" + name + "'");
     }
 
@@ -58,7 +52,8 @@ DistanceWeightingWithLSM::DistanceWeightingWithLSM(const param::MIRParametrisati
 }
 
 
-const DistanceWeighting* DistanceWeightingWithLSM::distanceWeighting(const param::MIRParametrisation& parametrisation, const lsm::LandSeaMasks& lsm) const {
+const DistanceWeighting* DistanceWeightingWithLSM::distanceWeighting(const param::MIRParametrisation& parametrisation,
+                                                                     const lsm::LandSeaMasks& lsm) const {
     return DistanceWeightingWithLSMFactory::build(method_, parametrisation, lsm);
 }
 
@@ -67,7 +62,7 @@ bool DistanceWeightingWithLSM::sameAs(const DistanceWeighting& other) const {
     auto o = dynamic_cast<const DistanceWeightingWithLSM*>(&other);
 
     // Note: LSM's themselves are not used for this distinction!
-    return o && method_ == o->method_;
+    return (o != nullptr) && method_ == o->method_;
 }
 
 
@@ -83,10 +78,9 @@ void DistanceWeightingWithLSM::hash(eckit::MD5& h) const {
 }
 
 
-DistanceWeightingWithLSMFactory::DistanceWeightingWithLSMFactory(const std::string& name) :
-    name_(name) {
+DistanceWeightingWithLSMFactory::DistanceWeightingWithLSMFactory(const std::string& name) : name_(name) {
     pthread_once(&once, init);
-    eckit::AutoLock< eckit::Mutex > lock(local_mutex);
+    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     if (m->find(name) != m->end()) {
         throw eckit::SeriousBug("DistanceWeightingWithLSMFactory: duplicated DistanceWeightingWithLSM '" + name + "'");
@@ -103,7 +97,9 @@ DistanceWeightingWithLSMFactory::~DistanceWeightingWithLSMFactory() {
 }
 
 
-const DistanceWeighting* DistanceWeightingWithLSMFactory::build(const std::string& name, const param::MIRParametrisation& param, const lsm::LandSeaMasks& lsm) {
+const DistanceWeighting* DistanceWeightingWithLSMFactory::build(const std::string& name,
+                                                                const param::MIRParametrisation& param,
+                                                                const lsm::LandSeaMasks& lsm) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -140,4 +136,3 @@ bool DistanceWeightingWithLSMFactory::has(const std::string& name) {
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
