@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -29,36 +30,31 @@ namespace distance {
 
 struct Choice {
     explicit Choice(bool sameType, double distance, size_t index) :
-        sameType_(size_t(sameType)),
-        distance_(distance),
-        index_(index) {}
+        sameType_(size_t(sameType)), distance_(distance), index_(index) {}
     size_t sameType_;
     double distance_;
     size_t index_;
 
     bool operator<(const Choice& other) {
-    return sameType_ >  other.sameType_ || (
-           sameType_ == other.sameType_ && (
-           eckit::types::is_strictly_greater    (other.distance_, distance_) || (
-           eckit::types::is_approximately_equal (other.distance_, distance_) &&
-           index_ < other.index_ )));
+        return sameType_ > other.sameType_ ||
+               (sameType_ == other.sameType_ &&
+                (eckit::types::is_strictly_greater(other.distance_, distance_) ||
+                 (eckit::types::is_approximately_equal(other.distance_, distance_) && index_ < other.index_)));
     }
 };
 
 
-NearestLSMWithLowestIndex::NearestLSMWithLowestIndex(const param::MIRParametrisation&, const lsm::LandSeaMasks& landSeaMasks) :
-    imask_(landSeaMasks.inputMask()),
-    omask_(landSeaMasks.outputMask()) {
+NearestLSMWithLowestIndex::NearestLSMWithLowestIndex(const param::MIRParametrisation& parametrisation,
+                                                     const lsm::LandSeaMasks& landSeaMasks) :
+    DistanceWeightingWithLSM(parametrisation), imask_(landSeaMasks.inputMask()), omask_(landSeaMasks.outputMask()) {
     ASSERT(!imask_.empty());
     ASSERT(!omask_.empty());
 }
 
 
-void NearestLSMWithLowestIndex::operator()(
-        size_t ip,
-        const Point3& point,
-        const std::vector<search::PointSearch::PointValueType>& neighbours,
-        std::vector<WeightMatrix::Triplet>& triplets ) const {
+void NearestLSMWithLowestIndex::operator()(size_t ip, const Point3& point,
+                                           const std::vector<search::PointSearch::PointValueType>& neighbours,
+                                           std::vector<WeightMatrix::Triplet>& triplets) const {
 
     ASSERT(!neighbours.empty());
     ASSERT(ip < omask_.size());
@@ -82,7 +78,7 @@ void NearestLSMWithLowestIndex::operator()(
 
 bool NearestLSMWithLowestIndex::sameAs(const DistanceWeighting& other) const {
     auto o = dynamic_cast<const NearestLSMWithLowestIndex*>(&other);
-    return o;
+    return (o != nullptr);
 }
 
 
@@ -105,4 +101,3 @@ static DistanceWeightingWithLSMBuilder<NearestLSMWithLowestIndex> __distance("ne
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
