@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -21,15 +22,12 @@ namespace knn {
 namespace distance {
 
 
-NearestNeighbour::NearestNeighbour(const param::MIRParametrisation&) {
-}
+NearestNeighbour::NearestNeighbour(const param::MIRParametrisation&) {}
 
 
-void NearestNeighbour::operator()(
-        size_t ip,
-        const Point3&,
-        const std::vector<search::PointSearch::PointValueType>& neighbours,
-        std::vector<WeightMatrix::Triplet>& triplets ) const {
+void NearestNeighbour::operator()(size_t ip, const Point3&,
+                                  const std::vector<search::PointSearch::PointValueType>& neighbours,
+                                  std::vector<WeightMatrix::Triplet>& triplets) const {
 
     ASSERT(!neighbours.empty());
     triplets.assign(1, WeightMatrix::Triplet(ip, neighbours.front().payload(), 1.));
@@ -38,7 +36,7 @@ void NearestNeighbour::operator()(
 
 bool NearestNeighbour::sameAs(const DistanceWeighting& other) const {
     auto o = dynamic_cast<const NearestNeighbour*>(&other);
-    return o;
+    return (o != nullptr);
 }
 
 
@@ -61,4 +59,3 @@ static DistanceWeightingBuilder<NearestNeighbour> __distance("nearest-neighbour"
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
