@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -70,7 +71,7 @@ size_t NearestNeighbourWithLowestIndex::n() const {
 
 bool NearestNeighbourWithLowestIndex::sameAs(const Pick& other) const {
     auto o = dynamic_cast<const NearestNeighbourWithLowestIndex*>(&other);
-    return o;
+    return (o != nullptr);
 }
 
 
