@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date May 2015
-
 
 #include "mir/method/other/PseudoLaplace.h"
 
@@ -34,12 +31,9 @@ namespace method {
 namespace other {
 
 
-PseudoLaplace::PseudoLaplace(const param::MIRParametrisation& param) :
-    MethodWeighted(param),
-    nclosest_(4) {
+PseudoLaplace::PseudoLaplace(const param::MIRParametrisation& param) : MethodWeighted(param), nclosest_(4) {
 
     param.get("nclosest", nclosest_);
-
 }
 
 
@@ -47,21 +41,22 @@ PseudoLaplace::~PseudoLaplace() = default;
 
 
 const char* PseudoLaplace::name() const {
-    return  "pseudo-laplace";
+    return "pseudo-laplace";
 }
 
 
-void PseudoLaplace::hash( eckit::MD5& md5) const {
+void PseudoLaplace::hash(eckit::MD5& md5) const {
     MethodWeighted::hash(md5);
     md5 << nclosest_;
 }
 
 bool PseudoLaplace::sameAs(const Method& other) const {
     auto o = dynamic_cast<const PseudoLaplace*>(&other);
-    return o && (nclosest_ == o->nclosest_) && MethodWeighted::sameAs(other);
+    return (o != nullptr) && (nclosest_ == o->nclosest_) && MethodWeighted::sameAs(other);
 }
 
-void PseudoLaplace::assemble(util::MIRStatistics&, WeightMatrix& W, const repres::Representation& in, const repres::Representation& out) const {
+void PseudoLaplace::assemble(util::MIRStatistics&, WeightMatrix& W, const repres::Representation& in,
+                             const repres::Representation& out) const {
     using eckit::geometry::XX;
     using eckit::geometry::YY;
     using eckit::geometry::ZZ;
@@ -75,8 +70,8 @@ void PseudoLaplace::assemble(util::MIRStatistics&, WeightMatrix& W, const repres
     const size_t out_npts = out.numberOfPoints();
 
     // init structure used to fill in sparse matrix
-    std::vector< WeightMatrix::Triplet > weights_triplets;
-    weights_triplets.reserve( out_npts * nclosest_ );
+    std::vector<WeightMatrix::Triplet> weights_triplets;
+    weights_triplets.reserve(out_npts * nclosest_);
 
     std::vector<search::PointSearch::PointValueType> closest;
 
@@ -103,10 +98,21 @@ void PseudoLaplace::assemble(util::MIRStatistics&, WeightMatrix& W, const repres
         // then calculate the nearest neighbour weights
         weights.resize(npts, 0.0);
 
-        double Ixx(0), Ixy(0), Ixz(0), Iyy(0), Iyz(0), Izz(0), Rx(0), Ry(0), Rz(0), Lx, Ly, Lz;
+        double Ixx(0);
+        double Ixy(0);
+        double Ixz(0);
+        double Iyy(0);
+        double Iyz(0);
+        double Izz(0);
+        double Rx(0);
+        double Ry(0);
+        double Rz(0);
+        double Lx;
+        double Ly;
+        double Lz;
 
         for (size_t j = 0; j < npts; ++j) {
-            Point3 np  = closest[j].point();
+            Point3 np = closest[j].point();
 
             const double dx = np[XX] - p[XX];
             const double dy = np[YY] - p[YY];
@@ -167,12 +173,9 @@ void PseudoLaplace::print(std::ostream& out) const {
 }
 
 
-namespace {
-static MethodBuilder< PseudoLaplace > __method("pseudo-laplace");
-}
+static MethodBuilder<PseudoLaplace> __method("pseudo-laplace");
 
 
 }  // namespace other
 }  // namespace method
 }  // namespace mir
-
