@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date May 2015
-
 
 #ifndef mir_method_other_PseudoLaplace_H
 #define mir_method_other_PseudoLaplace_H
@@ -24,28 +21,24 @@ namespace method {
 namespace other {
 
 
-class PseudoLaplace: public MethodWeighted {
+class PseudoLaplace : public MethodWeighted {
 
     size_t nclosest_;  ///< Number of closest points to search for
 
 public:
-
     PseudoLaplace(const param::MIRParametrisation&);
 
     virtual ~PseudoLaplace();
 
 protected:
-
-    virtual void hash( eckit::MD5& ) const;
+    virtual void hash(eckit::MD5&) const;
 
 private:
-
-    virtual void assemble(util::MIRStatistics&, WeightMatrix&, const repres::Representation& in, const repres::Representation& out) const;
+    virtual void assemble(util::MIRStatistics&, WeightMatrix&, const repres::Representation& in,
+                          const repres::Representation& out) const;
     virtual void print(std::ostream&) const;
     virtual const char* name() const;
     virtual bool sameAs(const Method& other) const;
-
-
 };
 
 
@@ -55,4 +48,3 @@ private:
 
 
 #endif
-
