@@ -3,12 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
 #include "mir/netcdf/CellMethodOutputVariable.h"
 
@@ -21,21 +21,17 @@
 namespace mir {
 namespace netcdf {
 
-CellMethodOutputVariable::CellMethodOutputVariable(Dataset &owner,
-        const std::string &name,
-        const std::vector<Dimension *> &dimensions):
-    OutputVariable(owner, name, dimensions)
-{
-}
+CellMethodOutputVariable::CellMethodOutputVariable(Dataset& owner, const std::string& name,
+                                                   const std::vector<Dimension*>& dimensions) :
+    OutputVariable(owner, name, dimensions) {}
 
 CellMethodOutputVariable::~CellMethodOutputVariable() = default;
 
-void CellMethodOutputVariable::print(std::ostream &out) const {
+void CellMethodOutputVariable::print(std::ostream& out) const {
     out << "CellMethodOutputVariable[name=" << name_ << "]";
 }
 
-void CellMethodOutputVariable::merge(const Variable &other, MergePlan &plan)
-{
+void CellMethodOutputVariable::merge(const Variable& other, MergePlan& plan) {
     Variable::merge(other, plan);
     plan.add(new MergeDataStep(*this, other));
 }
