@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Jan 2015
-
 
 #include "mir/netcdf/Codec.h"
 
@@ -29,103 +26,116 @@
 namespace mir {
 namespace netcdf {
 
+
 Codec::Codec() = default;
 
+
 Codec::~Codec() = default;
 
-void Codec::decode(std::vector<double> &) const {
+
+void Codec::decode(std::vector<double>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<double> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::decode(std::vector<float> &) const {
+
+void Codec::decode(std::vector<float>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<float> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::decode(std::vector<long> &) const {
+
+void Codec::decode(std::vector<long>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<long> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::decode(std::vector<short> &) const {
+
+void Codec::decode(std::vector<short>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<short> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::decode(std::vector<unsigned char> &) const {
+
+void Codec::decode(std::vector<unsigned char>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<unsigned char> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::decode(std::vector<long long> &) const {
+
+void Codec::decode(std::vector<long long>&) const {
     std::ostringstream os;
     os << "Variable::decode(std::vector<long long> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<double> &) const {
+
+void Codec::encode(std::vector<double>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<double> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<float> &) const {
+
+void Codec::encode(std::vector<float>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<float> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<long> &) const {
+
+void Codec::encode(std::vector<long>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<long> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<short> &) const {
+
+void Codec::encode(std::vector<short>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<short> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<unsigned char> &) const {
+
+void Codec::encode(std::vector<unsigned char>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<unsigned char> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::encode(std::vector<long long> &) const {
+
+void Codec::encode(std::vector<long long>&) const {
     std::ostringstream os;
     os << "Variable::encode(std::vector<long long> &) not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
-void Codec::addAttributes(Variable &) const {
+
+void Codec::addAttributes(Variable&) const {
     std::ostringstream os;
     os << "Variable::addAttributes() not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
+
 void Codec::updateAttributes(int /*nc*/, int /*varid*/, const std::string& /*path*/) {
     std::ostringstream os;
     os << "Variable::updateAttributes() not implemented for " << *this;
     throw eckit::SeriousBug(os.str());
 }
 
+
 bool Codec::timeAxis() const {
     return false;
 }
 
 
-//=========================================================================
-
-
-namespace {
 static pthread_once_t once                     = PTHREAD_ONCE_INIT;
 static eckit::Mutex* local_mutex               = nullptr;
 static std::map<std::string, CodecFactory*>* m = nullptr;
@@ -133,11 +143,9 @@ static void init() {
     local_mutex = new eckit::Mutex();
     m           = new std::map<std::string, CodecFactory*>();
 }
-}  // (anonymous namespace)
 
 
-CodecFactory::CodecFactory(const std::string &name):
-    name_(name) {
+CodecFactory::CodecFactory(const std::string& name) : name_(name) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -157,7 +165,7 @@ CodecFactory::~CodecFactory() {
 }
 
 
-Codec *CodecFactory::build(const std::string& name, const Variable& variable) {
+Codec* CodecFactory::build(const std::string& name, const Variable& variable) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -169,7 +177,7 @@ Codec *CodecFactory::build(const std::string& name, const Variable& variable) {
         throw eckit::SeriousBug("CodecFactory: unknown '" + name + "'");
     }
 
-    return (*j).second->make(variable);
+    return j->second->make(variable);
 }
 
 
