@@ -3,20 +3,19 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
-
 
 #include "mir/netcdf/Curvilinear.h"
 
 #include <cmath>
 #include <iostream>
 
-#include "eckit/types/Types.h"
+#include "eckit/exception/Exceptions.h"
 
 #include "mir/netcdf/Dimension.h"
 #include "mir/netcdf/HyperCube.h"
@@ -26,13 +25,10 @@
 namespace mir {
 namespace netcdf {
 
-Curvilinear::Curvilinear(const Variable &variable,
-                         const std::vector<double>& latitudes,
-                         const std::vector<double>& longitudes):
-    GridSpec(variable),
-    latitudes_(latitudes),
-    longitudes_(longitudes)
-{
+
+Curvilinear::Curvilinear(const Variable& variable, const std::vector<double>& latitudes,
+                         const std::vector<double>& longitudes) :
+    GridSpec(variable), latitudes_(latitudes), longitudes_(longitudes) {
     ASSERT(latitudes_.size() == longitudes_.size());
     ASSERT(latitudes_.size() >= 2);
 
@@ -49,28 +45,25 @@ Curvilinear::Curvilinear(const Variable &variable,
     }
 }
 
+
 Curvilinear::~Curvilinear() = default;
 
 
-void Curvilinear::print(std::ostream& s) const
-{
+void Curvilinear::print(std::ostream& s) const {
     s << "Curvilinear[points=" << latitudes_.size() << "]";
 }
 
+
 bool Curvilinear::has(const std::string& name) const {
-    // std::cout << "has " << name << std::endl;
-    if (name == "gridded") {
-        return true;
-    }
+    // eckit::Log::info() << "has " << name << std::endl;
 
-    // std::cout << "Curvilinear::has " << name << " failed" << std::endl;
-
-
-    return false;
+    // Note: only "gridded" is supported
+    return (name == "gridded");
 }
 
-bool Curvilinear::get(const std::string &name, std::vector<double> &values) const {
-    // std::cout << "get " << name << std::endl;
+
+bool Curvilinear::get(const std::string& name, std::vector<double>& values) const {
+    // eckit::Log::info() << "get " << name << std::endl;
 
     if (name == "latitudes") {
         values = latitudes_;
@@ -83,31 +76,33 @@ bool Curvilinear::get(const std::string &name, std::vector<double> &values) cons
     }
 
     return false;
-
 }
 
-bool Curvilinear::get(const std::string&name, long& value) const {
-    // std::cout << "get " << name << std::endl;
 
-    // std::cout << "Curvilinear::get " << name << " failed" << std::endl;
+bool Curvilinear::get(const std::string& /*name*/, long& /*value*/) const {
+    // eckit::Log::info() << "get " << name << std::endl;
+
+    // eckit::Log::info() << "Curvilinear::get " << name << " failed" << std::endl;
 
     return false;
 }
 
-bool Curvilinear::get(const std::string&name, std::string& value) const {
-    // std::cout << "get " << name << std::endl;
+
+bool Curvilinear::get(const std::string& name, std::string& value) const {
+    // eckit::Log::info() << "get " << name << std::endl;
     if (name == "gridType") {
         value = "unstructured_grid";
         return true;
     }
 
-    // std::cout << "Curvilinear::get " << name << " failed" << std::endl;
+    // eckit::Log::info() << "Curvilinear::get " << name << " failed" << std::endl;
 
 
     return false;
 }
 
-bool Curvilinear::get(const std::string &name, double &value) const {
+
+bool Curvilinear::get(const std::string& name, double& value) const {
 
     if (name == "north") {
         value = north_;
@@ -130,32 +125,28 @@ bool Curvilinear::get(const std::string &name, double &value) const {
     }
 
 
-
-    // std::cout << "Curvilinear::get " << name << " failed" << std::endl;
+    // eckit::Log::info() << "Curvilinear::get " << name << " failed" << std::endl;
 
 
     return false;
 }
 
 
-//================================================================
-
-static bool check_axis(const Variable &variable, const Variable & axis, std::vector<double>& v) {
+static bool check_axis(const Variable& variable, const Variable& axis, std::vector<double>& v) {
 
 
-
-    auto axis_dimensions = axis.dimensions();
+    auto axis_dimensions     = axis.dimensions();
     auto variable_dimensions = variable.dimensions();
 
     if (axis_dimensions.size() != 2) {
         return false;
     }
 
-    if (variable_dimensions[variable_dimensions.size() - 2 ] != axis_dimensions[0]) {
+    if (variable_dimensions[variable_dimensions.size() - 2] != axis_dimensions[0]) {
         return false;
     }
 
-    if (variable_dimensions[variable_dimensions.size() - 1 ] != axis_dimensions[1]) {
+    if (variable_dimensions[variable_dimensions.size() - 1] != axis_dimensions[1]) {
         return false;
     }
 
@@ -165,44 +156,30 @@ static bool check_axis(const Variable &variable, const Variable & axis, std::vec
     return true;
 }
 
+
 inline double sign(double x) {
-    return (x > 0) - (x < 0);
+    return (x > 0. ? 1. : (x < 0. ? -1. : 0.));
 }
 
-GridSpec* Curvilinear::guess(const Variable &variable,
-                             const Variable &latitudes,
-                             const Variable &longitudes) {
+
+GridSpec* Curvilinear::guess(const Variable& variable, const Variable& latitudes, const Variable& longitudes) {
 
     if (variable.numberOfDimensions() < 2) {
-        return 0;
+        return nullptr;
     }
 
-
     std::vector<double> lats;
-    if (!check_axis(variable, latitudes, lats)) {
-        return 0;
-    }
-
     std::vector<double> lons;
-    if (!check_axis(variable, longitudes, lons)) {
-        return 0;
+    if (!check_axis(variable, latitudes, lats) || !check_axis(variable, longitudes, lons)) {
+        return nullptr;
     }
 
-//
-
     auto dimensions = latitudes.dimensions();
     ASSERT(dimensions.size() == 2);
 
-
-    // for(size_t i = 0; i < lats.size(); i++) {
-    //     std::cout << lats[i] << ' ' << lons[i] << std::endl;
-    // }
-
-
     struct Index {
         size_t ni_;
         size_t nj_;
-
         size_t operator()(size_t i, size_t j) { return i + j * ni_; }
     };
 
@@ -211,7 +188,6 @@ GridSpec* Curvilinear::guess(const Variable &variable,
     index.nj_ = dimensions[0]->count();
 
     /*
-
         (x1, y1) --------------- (x4, y4)
             |                        |
             |                        |
@@ -220,13 +196,12 @@ GridSpec* Curvilinear::guess(const Variable &variable,
         (x2, y2) --------------- (x3, y3)
     */
 
+    eckit::Log::info() << "Curvilinear " << index.ni_ << " " << index.nj_ << std::endl;
 
-    std::cout << "Curvilinear " << index.ni_ << " " << index.nj_ << std::endl;
+    double s = 0.;
+    for (size_t i = 0; i < index.ni_ - 1; i++) {
 
-    double s;
-        for (size_t i = 0; i < index.ni_ - 1; i++) {
-
-    for (size_t j = 0; j < index.nj_ - 1; j++) {
+        for (size_t j = 0; j < index.nj_ - 1; j++) {
 
 
             double x1 = lons[index(i, j)];
@@ -245,38 +220,35 @@ GridSpec* Curvilinear::guess(const Variable &variable,
             double t2 = x1 * y3 - x3 * y1 + x3 * y4 - x4 * y3 + x4 * y1 - x1 * y4;
 
 
-
             if (i == 0 && j == 0) {
                 eckit::Log::info() << "First " << t1 << "  " << t2 << std::endl;
                 eckit::Log::info() << x1 << "/" << y1 << " ================ " << x4 << "/" << y4 << std::endl;
-
-                eckit::Log::info() << x2 << "/" << y2  << " ================ " << x3 << "/" << y3 << std::endl;
-                s = sign(t1?t1:t2);
+                eckit::Log::info() << x2 << "/" << y2 << " ================ " << x3 << "/" << y3 << std::endl;
+                s = sign(t1 != 0. ? t1 : t2);
             }
 
             if (sign(t1) != s) {
                 eckit::Log::info() << "Sign of " << t1 << " is not " << s << std::endl;
-                return 0;
+                return nullptr;
             }
 
             if (sign(t2) != s) {
                 eckit::Log::info() << "Sign of " << t2 << " is not " << s << std::endl;
-                return 0;
+                return nullptr;
             }
 
             // double t3 = x1 * y2 - x2 * y1 + x2 * y4 - x4 * y2 + x4 * y1 - x1 * y4;
             // double t4 = * y3 - x3 * y2 + x3 * y4 - x4 * y3 + x4 * y2 - x2 * y4;
 
-            // std::cout << a << std::endl;
+            // eckit::Log::info() << a << std::endl;
         }
     }
 
     return new Curvilinear(variable, lats, lons);
-
 }
 
 
-void Curvilinear::reorder(MIRValuesVector& values) const {
+void Curvilinear::reorder(MIRValuesVector& /*values*/) const {
     // size_t ni = latitudes_.size();
     // size_t nj = longitudes_.size();
 
@@ -303,4 +275,3 @@ static GridSpecGuesserBuilder<Curvilinear> builder(3);
 
 }  // namespace netcdf
 }  // namespace mir
-
