@@ -3,55 +3,53 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
-
 
 #include <numeric>
 
 #include "eckit/exception/Exceptions.h"
-#include "eckit/types/Types.h"
 
-#include "mir/netcdf/DataInputVariable.h"
 #include "mir/netcdf/Attribute.h"
+#include "mir/netcdf/DataInputVariable.h"
 #include "mir/netcdf/DataOutputVariable.h"
+#include "mir/netcdf/Dataset.h"
+#include "mir/netcdf/Dimension.h"
 #include "mir/netcdf/Field.h"
 #include "mir/netcdf/Matrix.h"
-#include "mir/netcdf/Dimension.h"
-#include "mir/netcdf/Dataset.h"
 
 
 namespace mir {
 namespace netcdf {
 
-DataInputVariable::DataInputVariable(Dataset &owner,
-                                     const std::string &name,
-                                     int id,
-                                     const std::vector<Dimension *> &dimensions):
-    InputVariable(owner, name, id, dimensions)
-{
-}
+
+DataInputVariable::DataInputVariable(Dataset& owner, const std::string& name, int id,
+                                     const std::vector<Dimension*>& dimensions) :
+    InputVariable(owner, name, id, dimensions) {}
+
 
 DataInputVariable::~DataInputVariable() = default;
 
-Variable *DataInputVariable::makeOutputVariable(Dataset &owner,
-        const std::string &name,
-        const std::vector<Dimension *> &dimensions) const {
+
+Variable* DataInputVariable::makeOutputVariable(Dataset& owner, const std::string& name,
+                                                const std::vector<Dimension*>& dimensions) const {
     return new DataOutputVariable(owner, name, dimensions);
 }
 
-void DataInputVariable::print(std::ostream &out) const {
+
+void DataInputVariable::print(std::ostream& out) const {
     out << "DataInputVariable[name=" << name_ << ",nc=" << ncname() << "]";
 }
 
-const std::string &DataInputVariable::ncname() const {
+
+const std::string& DataInputVariable::ncname() const {
     auto j = attributes_.find("standard_name");
     if (j != attributes_.end()) {
-        ncname_ = (*j).second->asString();
+        ncname_ = j->second->asString();
         return ncname_;
     }
     return name();
@@ -67,6 +65,7 @@ void DataInputVariable::addCoordinateVariable(const Variable* v) {
     coordinates_.push_back(v);
 }
 
+
 Variable* DataInputVariable::addMissingCoordinates() {
     for (auto d : dimensions_) {
         bool found = false;
@@ -74,27 +73,23 @@ Variable* DataInputVariable::addMissingCoordinates() {
             found = (d->name() == (*c)->name());
         }
         if (!found) {
-            eckit::Log::warning() << "Variable '"
-                                  << name()
-                                  << ": dimension '"
-                                  << d->name()
-                                  << "' not listed in coordinates"
-                                  << std::endl;
+            eckit::Log::warning() << "Variable '" << name() << ": dimension '" << d->name()
+                                  << "' not listed in coordinates" << std::endl;
 
             if (dataset_.hasVariable(d->name())) {
                 addCoordinateVariable(&dataset_.variable(d->name()));
             }
-
         }
     }
     return this;
 }
 
 
-void DataInputVariable::collectField(std::vector<Field *>& fields) const {
+void DataInputVariable::collectField(std::vector<Field*>& fields) const {
     fields.push_back(new Field(*this));
 }
 
+
 size_t DataInputVariable::count2DValues() const {
 
     std::vector<size_t> dims;
@@ -108,10 +103,10 @@ size_t DataInputVariable::count2DValues() const {
     dims.pop_back();
 
 
-    return std::accumulate(dims.begin(), dims.end(), 1ul, std::multiplies<size_t>());
-
+    return std::accumulate(dims.begin(), dims.end(), size_t(1), std::multiplies<size_t>());
 }
 
+
 void DataInputVariable::get2DValues(MIRValuesVector& values, size_t index) const {
 
     std::vector<size_t> dims;
@@ -134,12 +129,11 @@ void DataInputVariable::get2DValues(MIRValuesVector& values, size_t index) const
     dims.pop_back();
     dims.pop_back();
 
-    std::vector<size_t>  coords(dims.size());
-    for (int i = int(dims.size()) - 1; i >= 0; i--)
-    {
-        auto j = size_t(i);
+    std::vector<size_t> coords(dims.size());
+    for (int i = int(dims.size()) - 1; i >= 0; i--) {
+        auto j    = size_t(i);
         coords[j] = (index % dims[j]);
-        index    /= dims[j];
+        index /= dims[j];
     }
 
     for (size_t j = 0; j < coords.size(); ++j) {
@@ -159,8 +153,7 @@ const char* DataInputVariable::kind() const {
 }
 
 
-
-void DataInputVariable::dumpAttributes(std::ostream &s, const char* prefix) const {
+void DataInputVariable::dumpAttributes(std::ostream& s, const char* prefix) const {
     s << prefix << "Coordinates:" << std::endl;
     for (auto c : coordinates_) {
         s << prefix << "    " << *c << std::endl;
@@ -181,4 +174,3 @@ std::vector<std::string> DataInputVariable::coordinates() const {
 
 }  // namespace netcdf
 }  // namespace mir
-
