@@ -3,28 +3,32 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
-#ifndef mir_netcdf_InputDimension
-#define mir_netcdf_InputDimension
+#ifndef mir_netcdf_InputDimension_h
+#define mir_netcdf_InputDimension_h
 
 #include "mir/netcdf/Dimension.h"
 
+
 namespace mir {
 namespace netcdf {
 
+
 class InputDimension : public Dimension {
+    InputDimension(const InputDimension&) = delete;
+    InputDimension& operator=(const InputDimension&) = delete;
+
 public:
-    InputDimension(Dataset &owner, const std::string &name, int id, size_t len);
+    InputDimension(Dataset& owner, const std::string& name, int id, size_t len);
     virtual ~InputDimension();
 
 private:
-
     // Members
 
     int id_;
@@ -32,13 +36,15 @@ private:
     // -- Methods
 
     // From Dimension
-    virtual void print(std::ostream &s) const;
-    virtual void clone(Dataset &owner) const;
+    virtual void print(std::ostream&) const;
+    virtual void clone(Dataset& owner) const;
     virtual int id() const;
     virtual void realDimensions(std::vector<size_t>& dims) const;
-
 };
 
-}
-}
+
+}  // namespace netcdf
+}  // namespace mir
+
+
 #endif
