@@ -3,43 +3,50 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
-#ifndef mir_netcdf_MergeDataStep
-#define mir_netcdf_MergeDataStep
+#ifndef mir_netcdf_MergeDataStep_h
+#define mir_netcdf_MergeDataStep_h
 
 #include "mir/netcdf/Step.h"
 
+
+namespace mir {
+namespace netcdf {
+class Variable;
+}
+}  // namespace mir
+
+
 namespace mir {
 namespace netcdf {
 
-class Variable;
 
-
-class MergeDataStep : public Step  {
+class MergeDataStep : public Step {
 public:
-
-    MergeDataStep( Variable &out, const Variable &in);
+    MergeDataStep(Variable& out, const Variable& in);
     ~MergeDataStep();
 
 private:
-
     // Members
 
-    Variable &out_;
-    const Variable &in_;
+    Variable& out_;
+    const Variable& in_;
 
     // -- Methods
-    virtual void print(std::ostream &out) const;
+    virtual void print(std::ostream& out) const;
     virtual int rank() const;
-    virtual void execute(MergePlan &plan);
+    virtual void execute(MergePlan& plan);
 };
 
-}
-}
+
+}  // namespace netcdf
+}  // namespace mir
+
+
 #endif
