@@ -3,15 +3,15 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
-#ifndef mir_netcdf_Reshape
-#define mir_netcdf_Reshape
+#ifndef mir_netcdf_Reshape_h
+#define mir_netcdf_Reshape_h
 
 #include "eckit/memory/Counted.h"
 #include "mir/netcdf/HyperCube.h"
@@ -20,21 +20,19 @@
 namespace mir {
 namespace netcdf {
 
+
 class Reshape : public eckit::Counted {
 public:
-
-    Reshape(const HyperCube &cube, size_t which, size_t where, size_t count, char tag);
+    Reshape(const HyperCube& cube, size_t which, size_t where, size_t count, char tag);
 
     size_t operator()(size_t) const;
 
     bool merge(const Reshape& other);
 
 protected:
-
     ~Reshape();
 
 private:
-
     // -- Members
     HyperCube::Dimensions cube_;
     HyperCube::Dimensions mul_;
@@ -47,17 +45,18 @@ private:
 
     // -- Methods
 
-    void print(std::ostream &s) const;
+    void print(std::ostream&) const;
 
     // - Friend
-    friend std::ostream &operator<<(std::ostream &s, const Reshape &v)
-    {
+    friend std::ostream& operator<<(std::ostream& s, const Reshape& v) {
         v.print(s);
         return s;
     }
 };
 
 
-}
-}
+}  // namespace netcdf
+}  // namespace mir
+
+
 #endif
