@@ -3,15 +3,15 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
-#ifndef mir_netcdf_SimpleOutputVariable
-#define mir_netcdf_SimpleOutputVariable
+#ifndef mir_netcdf_SimpleOutputVariable_h
+#define mir_netcdf_SimpleOutputVariable_h
 
 #include "mir/netcdf/OutputVariable.h"
 
@@ -19,14 +19,19 @@
 namespace mir {
 namespace netcdf {
 
+
 class SimpleOutputVariable : public OutputVariable {
 public:
-    SimpleOutputVariable(Dataset &owner, const std::string &name, const std::vector<Dimension *> &dimensions);
+    SimpleOutputVariable(Dataset& owner, const std::string& name, const std::vector<Dimension*>& dimensions);
     virtual ~SimpleOutputVariable();
+
 private:
-    virtual void print(std::ostream &s) const;
+    virtual void print(std::ostream&) const;
 };
 
-}
-}
+
+}  // namespace netcdf
+}  // namespace mir
+
+
 #endif
