@@ -3,39 +3,35 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// Baudouin Raoult - ECMWF Jan 2015
 
-#ifndef mir_netcdf_GregorianDateCodec
-#define mir_netcdf_GregorianDateCodec
+#ifndef mir_netcdf_GregorianDateCodec_h
+#define mir_netcdf_GregorianDateCodec_h
 
 #include "mir/netcdf/Calendar.h"
-#include "eckit/types/DateTime.h"
+
 
 namespace mir {
 namespace netcdf {
 
 
-
-class ThreeSixtyCalendar : public Calendar
-{
+class ThreeSixtyCalendar : public Calendar {
 public:
-
-    ThreeSixtyCalendar(const Variable& variable);
+    ThreeSixtyCalendar(const Variable&);
     virtual ~ThreeSixtyCalendar();
 
 private:
-
-    // -- Methods
-
-    virtual void print(std::ostream &s) const;
-
+    virtual void print(std::ostream&) const;
 };
 
-}
-}
+
+}  // namespace netcdf
+}  // namespace mir
+
+
 #endif
