@@ -3,19 +3,18 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
 
+#include "mir/output/GeoPointsOutput.h"
 
 #include <sstream>
+
 #include "eckit/exception/Exceptions.h"
-#include "mir/output/GeoPointsOutput.h"
 
 
 namespace mir {
@@ -24,9 +23,7 @@ namespace output {
 // See https://software.ecmwf.int/wiki/display/METV/Geopoints
 
 
-GeoPointsOutput::GeoPointsOutput():
-    once_(true) {
-}
+GeoPointsOutput::GeoPointsOutput() : once_(true) {}
 
 
 GeoPointsOutput::~GeoPointsOutput() = default;
@@ -44,8 +41,7 @@ bool GeoPointsOutput::once() {
 }
 
 
-bool GeoPointsOutput::sameParametrisation(const param::MIRParametrisation&,
-                                          const param::MIRParametrisation&) const {
+bool GeoPointsOutput::sameParametrisation(const param::MIRParametrisation&, const param::MIRParametrisation&) const {
     return true;
 }
 
@@ -57,4 +53,3 @@ bool GeoPointsOutput::printParametrisation(std::ostream&, const param::MIRParame
 
 }  // namespace output
 }  // namespace mir
-
