@@ -22,12 +22,7 @@ namespace mir {
 namespace output {
 
 
-GribMemoryOutput::GribMemoryOutput(void* message, size_t size) :
-    message_(message),
-    size_(size),
-    length_(0),
-    saved_(0),
-    interpolated_(0) {}
+GribMemoryOutput::GribMemoryOutput(void* message, size_t size) : message_(message), size_(size), length_(0) {}
 
 
 GribMemoryOutput::~GribMemoryOutput() = default;
@@ -41,13 +36,6 @@ void GribMemoryOutput::out(const void* message, size_t length, bool interpolated
     ASSERT(length <= size_);
     length_ = length;
     ::memcpy(message_, message, length);
-
-    if (interpolated) {
-        interpolated_++;
-    }
-    else {
-        saved_++;
-    }
 }
 
 
