@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/output/MIROutput.h"
 
@@ -19,7 +16,7 @@
 #include "eckit/filesystem/PathName.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
-#include "eckit/thread/Once.h"
+
 #include "mir/config/LibMir.h"
 #include "mir/output/GribFileOutput.h"
 #include "mir/param/MIRParametrisation.h"
@@ -35,19 +32,14 @@ MIROutput::MIROutput() = default;
 MIROutput::~MIROutput() = default;
 
 
-namespace {
-
-
-static pthread_once_t once = PTHREAD_ONCE_INIT;
-static eckit::Mutex* local_mutex = nullptr;
-static std::map<std::string, MIROutputFactory* > *m_formats = nullptr;
-static std::map<std::string, MIROutputFactory* > *m_extensions = nullptr;
-
-
+static pthread_once_t once                                    = PTHREAD_ONCE_INIT;
+static eckit::Mutex* local_mutex                              = nullptr;
+static std::map<std::string, MIROutputFactory*>* m_formats    = nullptr;
+static std::map<std::string, MIROutputFactory*>* m_extensions = nullptr;
 static void init() {
-    local_mutex = new eckit::Mutex();
-    m_formats = new std::map<std::string, MIROutputFactory* >();
-    m_extensions = new std::map<std::string, MIROutputFactory* >();
+    local_mutex  = new eckit::Mutex();
+    m_formats    = new std::map<std::string, MIROutputFactory*>();
+    m_extensions = new std::map<std::string, MIROutputFactory*>();
 }
 
 
@@ -60,7 +52,8 @@ struct OutputFromExtension : public MIROutputFactory {
 
         auto j = m_extensions->find(ext);
         if (j == m_extensions->cend()) {
-            list(eckit::Log::debug<LibMir>() << "OutputFromExtension: unknown extension '" << ext << "', choices are: ");
+            list(eckit::Log::debug<LibMir>()
+                 << "OutputFromExtension: unknown extension '" << ext << "', choices are: ");
             eckit::Log::debug<LibMir>() << ", returning 'grib'" << std::endl;
 
             return new GribFileOutput(p);
@@ -81,22 +74,15 @@ struct OutputFromExtension : public MIROutputFactory {
         }
     }
 
-    OutputFromExtension() : MIROutputFactory("extension") {
-    }
+    OutputFromExtension() : MIROutputFactory("extension") {}
 
-    ~OutputFromExtension() {
-        m_extensions->clear();
-    }
+    ~OutputFromExtension() { m_extensions->clear(); }
 
 } static _extension;
 
 
-}  // (anonymous namespace)
-
-
 MIROutputFactory::MIROutputFactory(const std::string& name, const std::vector<std::string>& extensions) :
-    name_(name),
-    extensions_(extensions) {
+    name_(name), extensions_(extensions) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -121,7 +107,7 @@ MIROutputFactory::MIROutputFactory(const std::string& name, const std::vector<st
 
 MIROutputFactory::~MIROutputFactory() {
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
-    if (m_formats) {
+    if (m_formats != nullptr) {
         m_formats->erase(name_);
     }
 }
@@ -130,10 +116,9 @@ MIROutputFactory::~MIROutputFactory() {
 MIROutput* MIROutputFactory::build(const std::string& path, const param::MIRParametrisation& parametrisation) {
     const param::MIRParametrisation& user = parametrisation.userParametrisation();
 
-    std::string format = user.has("dryrun") ? "empty"
-                       : user.has("griddef") ? "geopoints"
-                       : user.has("latitudes") || user.has("longitudes") ? "geopoints"
-                       : "extension"; // maybe "grib"??
+    std::string format = user.has("griddef") || user.has("latitudes") || user.has("longitudes")
+                             ? "geopoints"
+                             : "extension";  // maybe "grib"??
 
     user.get("format", format);
 
@@ -161,10 +146,17 @@ void MIROutputFactory::list(std::ostream& out) {
 }
 
 
+size_t MIROutput::set(const param::MIRParametrisation& param, context::Context& ctx) {
+    // redirect to save
+    return save(param, ctx);
+}
+
+
 void MIROutput::prepare(const param::MIRParametrisation&, action::ActionPlan&, input::MIRInput&, output::MIROutput&) {
     // do nothing
 }
 
+
 void MIROutput::estimate(const param::MIRParametrisation&, api::MIREstimation&, context::Context&) const {
     std::ostringstream oss;
     oss << "MIROutput::estimate not implemented for " << *this;
@@ -174,4 +166,3 @@ void MIROutput::estimate(const param::MIRParametrisation&, api::MIREstimation&,
 
 }  // namespace output
 }  // namespace mir
-
