@@ -13,25 +13,28 @@
 #ifndef mir_packing_ArchivedValue_h
 #define mir_packing_ArchivedValue_h
 
-
 #include "mir/packing/Packer.h"
 
+
 namespace mir {
 namespace packing {
 
 
 class ArchivedValue : public Packer {
 public:
+    // -- Types
+    // None
+
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
-    ArchivedValue(const std::string& name);
+    using Packer::Packer;
 
     // -- Destructor
 
-    virtual ~ArchivedValue();  // Change to virtual if base class
+    virtual ~ArchivedValue();
 
     // -- Convertors
     // None
@@ -40,6 +43,7 @@ public:
     // None
 
     // -- Methods
+    // None
 
     // -- Overridden methods
     // None
@@ -48,15 +52,14 @@ public:
     // None
 
     // -- Class methods
-
+    // None
 
 protected:
     // -- Members
+    // None
 
     // -- Methods
-
-
-    virtual void print(std::ostream&) const;  // Change to virtual if base class
+    // None
 
     // -- Overridden methods
     // None
@@ -68,16 +71,15 @@ protected:
     // None
 
 private:
-    // No copy allowed
-
-    ArchivedValue(const ArchivedValue&);
-    ArchivedValue& operator=(const ArchivedValue&);
-
     // -- Members
     // None
 
     // -- Methods
 
+    virtual void print(std::ostream&) const;
+    virtual void fill(grib_info&, const repres::Representation&) const;
+    virtual std::string type(const repres::Representation*) const;
+
     // -- Overridden methods
     // None
 
@@ -85,8 +87,7 @@ private:
     // None
 
     // -- Class methods
-
-    virtual void fill(grib_info&, const repres::Representation&) const;
+    // None
 
     // -- Friends
     // None
