@@ -17,6 +17,7 @@
 #include "eckit/exception/Exceptions.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
+
 #include "mir/config/LibMir.h"
 
 
@@ -24,38 +25,58 @@ namespace mir {
 namespace packing {
 
 
-static eckit::Mutex* local_mutex         = nullptr;
-static std::map<std::string, Packer*>* m = nullptr;
-static pthread_once_t once               = PTHREAD_ONCE_INIT;
+static pthread_once_t once                      = PTHREAD_ONCE_INIT;
+static eckit::Mutex* local_mutex                = nullptr;
+static std::map<std::string, PackerFactory*>* m = nullptr;
 static void init() {
     local_mutex = new eckit::Mutex();
-    m           = new std::map<std::string, Packer*>();
+    m           = new std::map<std::string, PackerFactory*>();
 }
 
 
-Packer::Packer(const std::string& name) : name_(name) {
+Packer::Packer(const param::MIRParametrisation&, const param::MIRParametrisation&) {}
+
+
+Packer::~Packer() = default;
+
+
+PackerFactory::PackerFactory(const std::string& name) : name_(name) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     if (m->find(name) != m->end()) {
-        throw eckit::SeriousBug("Packer: duplicate '" + name + "'");
+        throw eckit::SeriousBug("PackerFactory: duplicate '" + name + "'");
     }
 
-    ASSERT(m->find(name) == m->end());
     (*m)[name] = this;
 }
 
 
-Packer::~Packer() {
-    pthread_once(&once, init);
+PackerFactory::~PackerFactory() {
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
-    ASSERT(m->find(name_) != m->end());
     m->erase(name_);
 }
 
 
-void Packer::list(std::ostream& out) {
+Packer* PackerFactory::build(const std::string& name, const param::MIRParametrisation& user,
+                             const param::MIRParametrisation& field) {
+    pthread_once(&once, init);
+    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+
+    eckit::Log::debug<LibMir>() << "PackerFactory: looking for '" << name << "'" << std::endl;
+
+    auto j = m->find(name);
+    if (j == m->end()) {
+        list(eckit::Log::error() << "PackerFactory: unknown '" << name << "', choices are: ");
+        throw eckit::SeriousBug("PackerFactory: unknown '" + name + "'");
+    }
+
+    return j->second->make(user, field);
+}
+
+
+void PackerFactory::list(std::ostream& out) {
     pthread_once(&once, init);
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
@@ -67,21 +88,5 @@ void Packer::list(std::ostream& out) {
 }
 
 
-const Packer& Packer::lookup(const std::string& name) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
-
-    eckit::Log::debug<LibMir>() << "Packer: looking for '" << name << "'" << std::endl;
-
-    auto j = m->find(name);
-    if (j == m->end()) {
-        list(eckit::Log::error() << "Packer: unknown '" << name << "', choices are: ");
-        throw eckit::SeriousBug("Packer: unknown '" + name + "'");
-    }
-
-    return *(j->second);
-}
-
-
 }  // namespace packing
 }  // namespace mir
