@@ -3,35 +3,28 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/Gridded.h"
 
+#include "mir/api/MIREstimation.h"
 #include "mir/util/Domain.h"
 #include "mir/util/Grib.h"
-#include "mir/api/MIREstimation.h"
 
 
 namespace mir {
 namespace repres {
 
 
-Gridded::Gridded(const param::MIRParametrisation& parametrisation) :
-    bbox_(parametrisation) {
-}
+Gridded::Gridded(const param::MIRParametrisation& parametrisation) : bbox_(parametrisation) {}
 
 
-Gridded::Gridded(const util::BoundingBox& bbox) :
-    bbox_(bbox) {
-}
+Gridded::Gridded(const util::BoundingBox& bbox) : bbox_(bbox) {}
 
 
 Gridded::~Gridded() = default;
@@ -41,12 +34,12 @@ Gridded::Gridded() = default;
 
 
 void Gridded::setComplexPacking(grib_info& info) const {
-    info.packing.packing_type = GRIB_UTIL_PACKING_TYPE_GRID_COMPLEX;
+    info.packing.packing_type = CODES_UTIL_PACKING_TYPE_GRID_COMPLEX;
 }
 
 
 void Gridded::setSimplePacking(grib_info& info) const {
-    info.packing.packing_type = GRIB_UTIL_PACKING_TYPE_GRID_SIMPLE;
+    info.packing.packing_type = CODES_UTIL_PACKING_TYPE_GRID_SIMPLE;
 }
 
 
@@ -56,11 +49,10 @@ void Gridded::setGivenPacking(grib_info&) const {
 
 
 util::Domain Gridded::domain() const {
-
-    const Latitude& n = includesNorthPole()? Latitude::NORTH_POLE : bbox_.north();
-    const Latitude& s = includesSouthPole()? Latitude::SOUTH_POLE : bbox_.south();
+    const Latitude& n  = includesNorthPole() ? Latitude::NORTH_POLE : bbox_.north();
+    const Latitude& s  = includesSouthPole() ? Latitude::SOUTH_POLE : bbox_.south();
     const Longitude& w = bbox_.west();
-    const Longitude& e = isPeriodicWestEast()? bbox_.west() + Longitude::GLOBE : bbox_.east();
+    const Longitude& e = isPeriodicWestEast() ? bbox_.west() + Longitude::GLOBE : bbox_.east();
 
     return util::Domain(n, w, s, e);
 }
@@ -76,11 +68,10 @@ bool Gridded::getLongestElementDiagonal(double&) const {
 }
 
 void Gridded::estimate(api::MIREstimation& estimation) const {
-    estimation.packing("grid_simple"); // Will be overriden
+    estimation.packing("grid_simple");  // Will be overriden
     estimation.representation(factory());
 }
 
 
 }  // namespace repres
 }  // namespace mir
-
