@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_repres_Representation_h
 #define mir_repres_Representation_h
@@ -46,7 +43,7 @@ class BoundingBox;
 class Domain;
 class GridBox;
 class MeshGeneratorParameters;
-}
+}  // namespace util
 
 namespace api {
 class MIRJob;
@@ -60,7 +57,7 @@ namespace api {
 class MIREstimation;
 }
 
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -69,7 +66,6 @@ namespace repres {
 
 class Representation : public eckit::Counted {
 public:
-
     // -- Exceptions
     // None
 
@@ -85,9 +81,6 @@ public:
 
     // -- Methods
 
-
-    // --------------------
-
     virtual const std::string& uniqueName() const;
     virtual bool sameAs(const Representation&) const;
 
@@ -105,7 +98,7 @@ public:
     virtual util::BoundingBox extendBoundingBox(const util::BoundingBox&) const;
     virtual bool extendBoundingBoxOnIntersect() const;
 
-    virtual size_t frame(MIRValuesVector&, size_t size, double missingValue, bool estimate=false) const;
+    virtual size_t frame(MIRValuesVector&, size_t size, double missingValue, bool estimate = false) const;
 
     virtual const Representation* globalise(data::MIRField&) const;
 
@@ -133,7 +126,7 @@ public:
 
     virtual std::vector<util::GridBox> gridBoxes() const;
 
-    virtual std::string factory() const; // Return factory name
+    virtual std::string factory() const;  // Return factory name
 
     // -- Overridden methods
     // None
@@ -145,7 +138,6 @@ public:
     // None
 
 protected:
-
     // -- Destructor
 
     virtual ~Representation();
@@ -174,7 +166,6 @@ protected:
     // None
 
 private:
-
     // -- Members
     // None
 
@@ -196,30 +187,35 @@ private:
         p.print(s);
         return s;
     }
-
 };
 
 
 class RepresentationHandle {
     const Representation* representation_;
+
 public:
-    RepresentationHandle(const Representation* r);
+    RepresentationHandle(const Representation*);
+    RepresentationHandle(const RepresentationHandle&);
     ~RepresentationHandle();
-    const Representation* operator->() const {
-        return representation_;
-    }
-    operator const Representation*() const {
-        return representation_;
-    }
+    const Representation* operator->() const { return representation_; }
+    operator const Representation*() const { return representation_; }
+
+private:
+    RepresentationHandle& operator=(const RepresentationHandle&) = delete;
 };
 
 
 class RepresentationFactory {
     std::string name_;
-    virtual Representation* make(const param::MIRParametrisation&) = 0 ;
+    virtual Representation* make(const param::MIRParametrisation&) = 0;
+
+    RepresentationFactory(const RepresentationFactory&) = delete;
+    RepresentationFactory& operator=(const RepresentationFactory&) = delete;
+
 protected:
     RepresentationFactory(const std::string&);
     virtual ~RepresentationFactory();
+
 public:
     // This is 'const' as the representation uses reference counting
     // Represention should always be immutable
@@ -228,11 +224,10 @@ public:
 };
 
 
-template<class T>
+template <class T>
 class RepresentationBuilder : public RepresentationFactory {
-    virtual Representation* make(const param::MIRParametrisation& param) {
-        return new T(param);
-    }
+    virtual Representation* make(const param::MIRParametrisation& param) { return new T(param); }
+
 public:
     RepresentationBuilder(const std::string& name) : RepresentationFactory(name) {}
 };
