@@ -23,15 +23,7 @@ namespace gauss {
 
 GaussianIterator::GaussianIterator(const std::vector<double>& latitudes, const util::BoundingBox& bbox, size_t N,
                                    ni_type Ni, const util::Rotation& rotation) :
-    Iterator(rotation),
-    latitudes_(latitudes),
-    bbox_(bbox),
-    N_(N),
-    pl_(std::move(Ni)),
-    Ni_(0),
-    i_(0),
-    j_(0),
-    count_(0) {
+    Iterator(rotation), latitudes_(latitudes), bbox_(bbox), N_(N), pl_(std::move(Ni)), Ni_(0), i_(0), j_(0), count_(0) {
 
     // position to first latitude and first/last longitude
     // NOTE: latitudes_ span the globe, sorted from North-to-South, k_ positions the North
