@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/gauss/reduced/Classic.h"
 
@@ -66,9 +63,7 @@ void Classic::fill(grib_info& info) const {
 
 void Classic::fill(api::MIRJob& job) const {
     Reduced::fill(job);
-    std::stringstream os;
-    os << "N" << N_;
-    job.set("gridname", os.str());
+    job.set("grid", "N" + std::to_string(N_));
 }
 
 
@@ -80,7 +75,7 @@ void Classic::makeName(std::ostream& out) const {
 
 bool Classic::sameAs(const Representation& other) const {
     auto o = dynamic_cast<const Classic*>(&other);
-    return o && Reduced::sameAs(other);
+    return (o != nullptr) && Reduced::sameAs(other);
 }
 
 
@@ -93,4 +88,3 @@ atlas::Grid Classic::atlasGrid() const {
 }  // namespace gauss
 }  // namespace repres
 }  // namespace mir
-
