@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/gauss/reduced/RotatedClassic.h"
 
@@ -26,21 +23,18 @@ namespace gauss {
 namespace reduced {
 
 
-RotatedClassic::RotatedClassic(size_t N, const util::Rotation& rotation, const util::BoundingBox& bbox, double angularPrecision):
-    Classic(N, bbox, angularPrecision),
-    rotation_(rotation) {
-}
+RotatedClassic::RotatedClassic(size_t N, const util::Rotation& rotation, const util::BoundingBox& bbox,
+                               double angularPrecision) :
+    Classic(N, bbox, angularPrecision), rotation_(rotation) {}
 
 
 RotatedClassic::~RotatedClassic() = default;
 
 
-void RotatedClassic::print(std::ostream &out) const {
+void RotatedClassic::print(std::ostream& out) const {
     out << "RotatedClassic["
-            "N=" << N_
-        << ",bbox=" << bbox_
-        << ",rotation=" << rotation_
-        << "]";
+           "N="
+        << N_ << ",bbox=" << bbox_ << ",rotation=" << rotation_ << "]";
 }
 
 
@@ -60,15 +54,16 @@ Iterator* RotatedClassic::iterator() const {
 }
 
 
-void RotatedClassic::fill(grib_info &info) const  {
+void RotatedClassic::fill(grib_info& info) const {
     Classic::fill(info);
     rotation_.fill(info);
-    info.grid.grid_type = GRIB_UTIL_GRID_SPEC_REDUCED_ROTATED_GG;
+    info.grid.grid_type = CODES_UTIL_GRID_SPEC_REDUCED_ROTATED_GG;
 }
 
 
-void RotatedClassic::fill(api::MIRJob&) const  {
-    NOTIMP;
+void RotatedClassic::fill(api::MIRJob& job) const {
+    Classic::fill(job);
+    rotation_.fill(job);
 }
 
 
@@ -86,4 +81,3 @@ const Gridded* RotatedClassic::croppedRepresentation(const util::BoundingBox& bb
 }  // namespace gauss
 }  // namespace repres
 }  // namespace mir
-
