@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/gauss/reduced/RotatedOctahedral.h"
 
@@ -26,10 +23,9 @@ namespace gauss {
 namespace reduced {
 
 
-RotatedOctahedral::RotatedOctahedral(size_t N, const util::Rotation& rotation, const util::BoundingBox& bbox, double angularPrecision) :
-    Octahedral(N, bbox, angularPrecision),
-    rotation_(rotation) {
-}
+RotatedOctahedral::RotatedOctahedral(size_t N, const util::Rotation& rotation, const util::BoundingBox& bbox,
+                                     double angularPrecision) :
+    Octahedral(N, bbox, angularPrecision), rotation_(rotation) {}
 
 
 RotatedOctahedral::~RotatedOctahedral() = default;
@@ -37,10 +33,8 @@ RotatedOctahedral::~RotatedOctahedral() = default;
 
 void RotatedOctahedral::print(std::ostream& out) const {
     out << "RotatedOctahedral["
-            "N=" << N_
-        << ",bbox=" << bbox_
-        << ",rotation=" << rotation_
-        << "]";
+           "N="
+        << N_ << ",bbox=" << bbox_ << ",rotation=" << rotation_ << "]";
 }
 
 
@@ -60,15 +54,16 @@ Iterator* RotatedOctahedral::iterator() const {
 }
 
 
-void RotatedOctahedral::fill(grib_info& info) const  {
+void RotatedOctahedral::fill(grib_info& info) const {
     Octahedral::fill(info);
     rotation_.fill(info);
-    info.grid.grid_type = GRIB_UTIL_GRID_SPEC_REDUCED_ROTATED_GG;
+    info.grid.grid_type = CODES_UTIL_GRID_SPEC_REDUCED_ROTATED_GG;
 }
 
 
-void RotatedOctahedral::fill(api::MIRJob&) const  {
-    NOTIMP;
+void RotatedOctahedral::fill(api::MIRJob& job) const {
+    Octahedral::fill(job);
+    rotation_.fill(job);
 }
 
 
@@ -86,4 +81,3 @@ const Gridded* RotatedOctahedral::croppedRepresentation(const util::BoundingBox&
 }  // namespace gauss
 }  // namespace repres
 }  // namespace mir
-
