@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_repres_latlon_RegularLL_h
 #define mir_repres_latlon_RegularLL_h
@@ -26,15 +23,13 @@ namespace latlon {
 
 class RegularLL : public LatLon {
 public:
-
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     RegularLL(const param::MIRParametrisation&);
-    RegularLL(const util::Increments&,
-              const util::BoundingBox& = util::BoundingBox(),
+    RegularLL(const util::Increments&, const util::BoundingBox& = util::BoundingBox(),
               const PointLatLon& reference = PointLatLon(0, 0));
 
     // -- Destructor
@@ -60,7 +55,6 @@ public:
     // None
 
 private:
-
     // -- Members
     // None
 
@@ -95,9 +89,8 @@ private:
 
     // -- Friends
 
-    //friend ostream& operator<<(ostream& s,const RegularLL& p)
+    // friend ostream& operator<<(ostream& s,const RegularLL& p)
     //  { p.print(s); return s; }
-
 };
 
 
@@ -107,4 +100,3 @@ private:
 
 
 #endif
-
