@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/other/None.h"
 
@@ -23,11 +20,12 @@ namespace repres {
 namespace other {
 
 
-None::None(const param::MIRParametrisation&) {
-}
-
 None::None() = default;
 
+
+None::None(const param::MIRParametrisation&) {}
+
+
 None::~None() = default;
 
 
@@ -36,13 +34,9 @@ void None::print(std::ostream& out) const {
 }
 
 
-
-namespace {
 static RepresentationBuilder<None> builder("none");
-}
 
 
 }  // namespace other
 }  // namespace repres
 }  // namespace mir
-
