@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -11,15 +12,19 @@
 
 #include "mir/repres/regular/RegularGrid.h"
 
-#include <cmath>
 #include <ostream>
 
+#include "eckit/config/Resource.h"
+#include "eckit/exception/Exceptions.h"
 #include "eckit/log/Log.h"
 #include "eckit/utils/MD5.h"
+#include "eckit/utils/StringTools.h"
 
 #include "mir/config/LibMir.h"
 #include "mir/param/MIRParametrisation.h"
 #include "mir/repres/Iterator.h"
+#include "mir/util/Assert.h"
+#include "mir/util/Domain.h"
 #include "mir/util/Grib.h"
 #include "mir/util/MeshGeneratorParameters.h"
 #include "mir/util/Pretty.h"
@@ -29,7 +34,8 @@ namespace mir {
 namespace repres {
 namespace regular {
 
-RegularGrid::RegularGrid(const param::MIRParametrisation& param, RegularGrid::Projection projection) {
+
+RegularGrid::RegularGrid(const param::MIRParametrisation& param, const RegularGrid::Projection& projection) {
 
     ASSERT(projection);
 
@@ -38,67 +44,106 @@ RegularGrid::RegularGrid(const param::MIRParametrisation& param, RegularGrid::Pr
     param.get("earthMajorAxis", earthMajorAxis_ = radius_);
     param.get("earthMinorAxis", earthMinorAxis_ = radius_);
 
-    size_t nx = 0;
-    size_t ny = 0;
-    ASSERT(param.get("numberOfPointsAlongXAxis", nx) && nx > 0);
-    ASSERT(param.get("numberOfPointsAlongYAxis", ny) && ny > 0);
+    auto get_long_first_key = [](const param::MIRParametrisation& param, const std::vector<std::string>& keys) -> long {
+        long value = 0;
+        for (auto key : keys) {
+            if (param.get(key, value)) {
+                return value;
+            }
+        }
+        throw eckit::SeriousBug("RegularGrid: couldn't find any key: " + eckit::StringTools::join(", ", keys));
+    };
+
+    long nx = get_long_first_key(param, {"numberOfPointsAlongXAxis", "Ni"});
+    long ny = get_long_first_key(param, {"numberOfPointsAlongYAxis", "Nj"});
+    ASSERT(nx > 0);
+    ASSERT(ny > 0);
 
     std::vector<double> grid;
-    ASSERT(param.get("grid", grid) && grid.size() == 2);
-    double dx = grid[0];
-    double dy = grid[1];
-    ASSERT(dx > 0);
-    ASSERT(dy > 0);
+    ASSERT(param.get("grid", grid));
+    ASSERT_KEYWORD_GRID_SIZE(grid.size());
 
-    // y[0] > y[1], for the "canonical" scanningMode (iScansPositively, jScansNegatively)
     Point2 firstLL;
     ASSERT(param.get("latitudeOfFirstGridPointInDegrees", firstLL[LLCOORDS::LAT]));
     ASSERT(param.get("longitudeOfFirstGridPointInDegrees", firstLL[LLCOORDS::LON]));
 
+    bool plusx = true;   // iScansPositively != 0
+    bool plusy = false;  // jScansPositively == 0
+    param.get("iScansPositively", plusx);
+    param.get("jScansPositively", plusy);
+
     Point2 first = projection.xy(firstLL);
-    Point2 last  = first + Point2{(nx - 1) * dx, (1 - int(ny)) * dy};
-
-    x_ = {first[XYZCOORDS::XX], last[XYZCOORDS::XX], long(nx)};
-    y_ = {first[XYZCOORDS::YY], last[XYZCOORDS::YY], long(ny)};
-    ASSERT(x_.front() < x_.back());
-    ASSERT(y_.front() > y_.back());
+    param.get("first_point_bottom_left", firstPointBottomLeft_ = false);
 
+    x_    = {first.x(), first.x() + grid[0] * (firstPointBottomLeft_ || plusx ? nx - 1 : 1 - nx), nx};
+    y_    = {first.y(), first.y() + grid[1] * (firstPointBottomLeft_ || plusy ? ny - 1 : 1 - ny), ny};
     grid_ = {x_, y_, projection};
 
-    ::atlas::RectangularDomain range({x_.front(), x_.back()}, {y_.front(), y_.back()}, "meters");
-    ::atlas::RectangularLonLatDomain bbox = projection.lonlatBoundingBox(range);
+    util::RectangularDomain range({x_.min(), x_.max()}, {y_.min(), y_.max()}, "meters");
+    auto bbox = projection.lonlatBoundingBox(range);
     ASSERT(bbox);
 
     bbox_ = {bbox.north(), bbox.west(), bbox.south(), bbox.east()};
 }
 
+
 RegularGrid::~RegularGrid() = default;
 
-void RegularGrid::print(std::ostream& out) const {
-    out << "RegularGrid["
-            "x=" << x_.spec()
-        << ",y=" << y_.spec()
-        << ",projection=" << grid_.projection().spec()
-        << ",bbox=" << bbox_
-        << "]";
+
+RegularGrid::Projection::Spec RegularGrid::make_proj_spec(const param::MIRParametrisation& param) {
+
+    static bool useProjIfAvailable = eckit::Resource<bool>("$MIR_USE_PROJ_IF_AVAILABLE", true);
+
+    std::string proj;
+    param.get("proj", proj);
+
+    if (proj.empty() || !useProjIfAvailable || !::atlas::projection::ProjectionFactory::has("proj")) {
+        return {};
+    }
+
+    Projection::Spec spec("type", "proj");
+    spec.set("proj", proj);
+
+    std::string projSource;
+    if (param.get("projSource", projSource) && !projSource.empty()) {
+        spec.set("proj_source", projSource);
+    }
+
+    std::string projGeocentric;
+    if (param.get("projGeocentric", projGeocentric) && !projGeocentric.empty()) {
+        spec.set("proj_geocentric", projGeocentric);
+    }
+
+    return spec;
 }
 
+
+void RegularGrid::print(std::ostream& out) const {
+    out << "RegularGrid[x=" << x_.spec() << ",y=" << y_.spec() << ",projection=" << grid_.projection().spec()
+        << ",firstPointBottomLeft=" << firstPointBottomLeft_ << ",bbox=" << bbox_ << "]";
+}
+
+
 bool RegularGrid::extendBoundingBoxOnIntersect() const {
     return true;
 }
 
+
 size_t RegularGrid::numberOfPoints() const {
     return x_.size() * y_.size();
 }
 
+
 ::atlas::Grid RegularGrid::atlasGrid() const {
     return grid_;
 }
 
+
 bool RegularGrid::isPeriodicWestEast() const {
     return false;
 }
 
+
 void RegularGrid::fill(grib_info& info) const {
 
     // GRIB2 encoding of user-provided radius or semi-major/minor axis
@@ -112,8 +157,10 @@ void RegularGrid::fill(grib_info& info) const {
                     GribExtraSetting::set(info, "radius", spec.getDouble("radius", radius_));
                     break;
                 case 3:
-                    GribExtraSetting::set(info, "earthMajorAxis", spec.getDouble("semi_major_axis", earthMajorAxis_) / 1000.);
-                    GribExtraSetting::set(info, "earthMinorAxis", spec.getDouble("semi_minor_axis", earthMinorAxis_) / 1000.);
+                    GribExtraSetting::set(info, "earthMajorAxis",
+                                          spec.getDouble("semi_major_axis", earthMajorAxis_) / 1000.);
+                    GribExtraSetting::set(info, "earthMinorAxis",
+                                          spec.getDouble("semi_minor_axis", earthMinorAxis_) / 1000.);
                     break;
                 case 7:
                     GribExtraSetting::set(info, "earthMajorAxis", spec.getDouble("semi_major_axis", earthMajorAxis_));
@@ -133,30 +180,42 @@ void RegularGrid::fill(grib_info& info) const {
             GribExtraSetting::set(info, "earthMinorAxis", spec.getDouble("semi_minor_axis"));
         }
     }
+
+    // scanningMode
+    info.grid.iScansNegatively = x_.back() < x_.front() ? 1 : 0;
+    info.grid.jScansPositively = y_.front() < y_.back() ? 1 : 0;
 }
 
+
 bool RegularGrid::includesNorthPole() const {
     return bbox_.north() == Latitude::NORTH_POLE;
 }
 
+
 bool RegularGrid::includesSouthPole() const {
     return bbox_.south() == Latitude::SOUTH_POLE;
 }
 
-void RegularGrid::reorder(long scanningMode, mir::data::MIRValuesVector& values) const {
-    GribReorder::reorder(values, scanningMode, x_.size(), y_.size());
+
+void RegularGrid::reorder(long, mir::data::MIRValuesVector&) const {
+    // do not reorder, iterator is doing the right thing
+    // FIXME this function should not be overriding to do nothing
 }
 
+
 void RegularGrid::validate(const MIRValuesVector& values) const {
     const size_t count = numberOfPoints();
+
     eckit::Log::debug<LibMir>() << "RegularGrid::validate checked " << Pretty(values.size(), {"value"})
-                                << ", numberOfPoints: " << Pretty(count) << "." << std::endl;
-    ASSERT(values.size() == count);
+                                << ", iterator counts " << Pretty(count) << " (" << domain() << ")." << std::endl;
+
+    ASSERT_VALUES_SIZE_EQ_ITERATOR_COUNT("RegularGrid", values.size(), count);
 }
 
+
 Iterator* RegularGrid::iterator() const {
 
-    class AtlasRegularIterator : public Iterator {
+    class RegularGridIterator : public Iterator {
         Projection projection_;
         const LinearSpacing& x_;
         const LinearSpacing& y_;
@@ -169,7 +228,7 @@ Iterator* RegularGrid::iterator() const {
         size_t count_;
 
         void print(std::ostream& out) const {
-            out << "AtlasRegularIterator[";
+            out << "RegularGridIterator[";
             Iterator::print(out);
             out << ",i=" << i_ << ",j=" << j_ << ",count=" << count_ << "]";
         }
@@ -177,8 +236,8 @@ Iterator* RegularGrid::iterator() const {
         bool next(Latitude& _lat, Longitude& _lon) {
             if (j_ < nj_ && i_ < ni_) {
                 pLonLat_ = projection_.lonlat({x_[i_], y_[j_]});
-                _lat = lat(pLonLat_.lat());
-                _lon = lon(pLonLat_.lon());
+                _lat     = lat(pLonLat_.lat());
+                _lon     = lon(pLonLat_.lon());
 
                 if (++i_ == ni_) {
                     i_ = 0;
@@ -192,31 +251,22 @@ Iterator* RegularGrid::iterator() const {
         }
 
     public:
-        AtlasRegularIterator(Projection projection, const LinearSpacing& x, const LinearSpacing& y) :
-            projection_(std::move(projection)),
-            x_(x),
-            y_(y),
-            ni_(x.size()),
-            nj_(y.size()),
-            i_(0),
-            j_(0),
-            count_(0) {
-            // ensure iScansPositively, jScansNegatively
-            ASSERT(x_.front() < x_.back());
-            ASSERT(y_.front() > y_.back());
-        }
-        AtlasRegularIterator(const AtlasRegularIterator&) = delete;
-        AtlasRegularIterator& operator=(const AtlasRegularIterator&) = delete;
+        RegularGridIterator(Projection projection, const LinearSpacing& x, const LinearSpacing& y) :
+            projection_(std::move(projection)), x_(x), y_(y), ni_(x.size()), nj_(y.size()), i_(0), j_(0), count_(0) {}
+        RegularGridIterator(const RegularGridIterator&) = delete;
+        RegularGridIterator& operator=(const RegularGridIterator&) = delete;
     };
 
-    return new AtlasRegularIterator(grid_.projection(), x_, y_);
+    return new RegularGridIterator(grid_.projection(), x_, y_);
 }
 
+
 void RegularGrid::makeName(std::ostream& out) const {
     eckit::MD5 h;
     h << grid_.projection().spec();
     h << x_.spec();
     h << y_.spec();
+    h << firstPointBottomLeft_;
     if (shapeOfTheEarthProvided_) {
         h << shapeOfTheEarth_;
         h << radius_;
@@ -227,6 +277,7 @@ void RegularGrid::makeName(std::ostream& out) const {
     out << "RegularGrid-" << (type.empty() ? "" : type + "-") << h.digest();
 }
 
+
 bool RegularGrid::sameAs(const Representation& other) const {
     auto name = [](const RegularGrid& repres) {
         std::stringstream str;
@@ -235,15 +286,17 @@ bool RegularGrid::sameAs(const Representation& other) const {
     };
 
     auto o = dynamic_cast<const RegularGrid*>(&other);
-    return o && name(*this) == name(*o);
+    return (o != nullptr) && name(*this) == name(*o);
 }
 
+
 void RegularGrid::fill(util::MeshGeneratorParameters& params) const {
     if (params.meshGenerator_.empty()) {
         params.meshGenerator_ = "structured";
     }
 }
 
+
 }  // namespace regular
 }  // namespace repres
 }  // namespace mir
