@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_repres_sh_SphericalHarmonics_h
 #define mir_repres_sh_SphericalHarmonics_h
@@ -26,12 +23,11 @@ namespace sh {
 
 
 class SphericalHarmonics : public Representation {
-  public:
-
+public:
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     SphericalHarmonics(const param::MIRParametrisation&);
     SphericalHarmonics(size_t truncation);
@@ -48,29 +44,16 @@ class SphericalHarmonics : public Representation {
 
     // -- Methods
 
-    static void truncate(
-            size_t truncation_from,
-            size_t truncation_to,
-            const MIRValuesVector& in,
-            MIRValuesVector& out);
+    static void truncate(size_t truncation_from, size_t truncation_to, const MIRValuesVector& in, MIRValuesVector& out);
 
-    static size_t number_of_complex_coefficients(size_t truncation) {
-        return (truncation + 1) * (truncation + 2) / 2;
-    }
+    static size_t number_of_complex_coefficients(size_t truncation) { return (truncation + 1) * (truncation + 2) / 2; }
 
-    static void interlace_spectra(
-            MIRValuesVector& interlaced,
-            const MIRValuesVector& spectra,
-            size_t truncation,
-            size_t numberOfComplexCoefficients,
-            size_t index,
-            size_t indexTotal);
+    static void interlace_spectra(MIRValuesVector& interlaced, const MIRValuesVector& spectra, size_t truncation,
+                                  size_t numberOfComplexCoefficients, size_t index, size_t indexTotal);
 
     // -- Overridden methods
 
-    util::Domain domain() const {
-        return util::Domain();
-    }
+    util::Domain domain() const { return util::Domain(); }
 
     // -- Class members
     // None
@@ -78,14 +61,13 @@ class SphericalHarmonics : public Representation {
     // -- Class methods
     // None
 
-  protected:
-
+protected:
     // -- Members
     // None
 
     // -- Methods
 
-    void print(std::ostream&) const; // Change to virtual if base class
+    void print(std::ostream&) const;  // Change to virtual if base class
 
     // -- Overridden methods
     // None
@@ -96,9 +78,7 @@ class SphericalHarmonics : public Representation {
     // -- Class methods
     // None
 
-  private:
-
-
+private:
     // No copy allowed
 
     SphericalHarmonics(const SphericalHarmonics&);
@@ -115,14 +95,11 @@ class SphericalHarmonics : public Representation {
     // -- Overridden methods
 
     virtual void fill(grib_info&) const;
-    virtual void fill(api::MIRJob &) const;
+    virtual void fill(api::MIRJob&) const;
     virtual void estimate(api::MIREstimation&) const;
     virtual std::string factory() const;
 
-    virtual const Representation* truncate(
-            size_t truncation,
-            const MIRValuesVector&,
-            MIRValuesVector&) const;
+    virtual const Representation* truncate(size_t truncation, const MIRValuesVector&, MIRValuesVector&) const;
     virtual size_t truncation() const;
 
     virtual void comparison(std::string&) const;
@@ -146,9 +123,8 @@ class SphericalHarmonics : public Representation {
 
     // -- Friends
 
-    //friend ostream& operator<<(ostream& s,const SphericalHarmonics& p)
+    // friend ostream& operator<<(ostream& s,const SphericalHarmonics& p)
     //  { p.print(s); return s; }
-
 };
 
 
@@ -158,4 +134,3 @@ class SphericalHarmonics : public Representation {
 
 
 #endif
-
