@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/unsupported/AzimuthRange.h"
 
@@ -24,33 +21,28 @@ namespace mir {
 namespace repres {
 
 
-AzimuthRange::AzimuthRange(const param::MIRParametrisation &parametrisation) {
-}
+AzimuthRange::AzimuthRange(const param::MIRParametrisation& /*parametrisation*/) {}
 
 
-AzimuthRange::AzimuthRange() {
-}
+AzimuthRange::AzimuthRange() = default;
 
 
 AzimuthRange::~AzimuthRange() = default;
 
 
-void AzimuthRange::print(std::ostream &out) const {
+void AzimuthRange::print(std::ostream& out) const {
     out << "AzimuthRange["
         << "]";
 }
 
 
-void AzimuthRange::fill(grib_info &info) const  {
+void AzimuthRange::fill(grib_info& /*info*/) const {
     NOTIMP;
 }
 
 
-namespace {
-static RepresentationBuilder<AzimuthRange> azimuthRange("azimuth_range"); // Name is what is returned by grib_api
-}
+static RepresentationBuilder<AzimuthRange> azimuthRange("azimuth_range");
 
 
 }  // namespace repres
 }  // namespace mir
-
