@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/unsupported/EquatorialAzimuthalEquidistant.h"
 
@@ -24,33 +21,29 @@ namespace mir {
 namespace repres {
 
 
-EquatorialAzimuthalEquidistant::EquatorialAzimuthalEquidistant(const param::MIRParametrisation &parametrisation) {
-}
+EquatorialAzimuthalEquidistant::EquatorialAzimuthalEquidistant(const param::MIRParametrisation& /*parametrisation*/) {}
 
 
-EquatorialAzimuthalEquidistant::EquatorialAzimuthalEquidistant() {
-}
+EquatorialAzimuthalEquidistant::EquatorialAzimuthalEquidistant() = default;
 
 
 EquatorialAzimuthalEquidistant::~EquatorialAzimuthalEquidistant() = default;
 
 
-void EquatorialAzimuthalEquidistant::print(std::ostream &out) const {
+void EquatorialAzimuthalEquidistant::print(std::ostream& out) const {
     out << "EquatorialAzimuthalEquidistant["
         << "]";
 }
 
 
-void EquatorialAzimuthalEquidistant::fill(grib_info &info) const  {
+void EquatorialAzimuthalEquidistant::fill(grib_info& /*info*/) const {
     NOTIMP;
 }
 
 
-namespace {
-static RepresentationBuilder<EquatorialAzimuthalEquidistant> equatorialAzimuthalEquidistant("equatorial_azimuthal_equidistant"); // Name is what is returned by grib_api
-}
+static RepresentationBuilder<EquatorialAzimuthalEquidistant> equatorialAzimuthalEquidistant(
+    "equatorial_azimuthal_equidistant");
 
 
 }  // namespace repres
 }  // namespace mir
-
