@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "mir/repres/unsupported/StretchedRotatedGG.h"
 
@@ -24,33 +21,28 @@ namespace mir {
 namespace repres {
 
 
-StretchedRotatedGG::StretchedRotatedGG(const param::MIRParametrisation &parametrisation) {
-}
+StretchedRotatedGG::StretchedRotatedGG(const param::MIRParametrisation& /*parametrisation*/) {}
 
 
-StretchedRotatedGG::StretchedRotatedGG() {
-}
+StretchedRotatedGG::StretchedRotatedGG() = default;
 
 
 StretchedRotatedGG::~StretchedRotatedGG() = default;
 
 
-void StretchedRotatedGG::print(std::ostream &out) const {
+void StretchedRotatedGG::print(std::ostream& out) const {
     out << "StretchedRotatedGG["
         << "]";
 }
 
 
-void StretchedRotatedGG::fill(grib_info &info) const  {
+void StretchedRotatedGG::fill(grib_info& /*info*/) const {
     NOTIMP;
 }
 
 
-namespace {
-static RepresentationBuilder<StretchedRotatedGG> stretchedRotatedGG("stretched_rotated_gg"); // Name is what is returned by grib_api
-}
+static RepresentationBuilder<StretchedRotatedGG> stretchedRotatedGG("stretched_rotated_gg");
 
 
 }  // namespace repres
 }  // namespace mir
-
