@@ -3,17 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @author Peter Bispham
-/// @date Apr 2015
-
 
 #include "mir/search/tree/TreeMappedAnonymousMemory.h"
 
@@ -25,8 +20,7 @@ namespace tree {
 
 TreeMappedAnonymousMemory::TreeMappedAnonymousMemory(const repres::Representation& r,
                                                      const param::MIRParametrisation&) :
-    TreeMapped(r, "/dev/zero") {
-}
+    TreeMapped(r, "/dev/zero") {}
 
 
 static TreeBuilder<TreeMappedAnonymousMemory> builder("mapped-anonymous-memory");
