@@ -3,22 +3,17 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @author Peter Bispham
-/// @date Apr 2015
-
 
 #include "mir/search/tree/TreeMappedFile.h"
 
-#include "eckit/utils/Tokenizer.h"
 #include "eckit/filesystem/PathExpander.h"
+#include "eckit/utils/Tokenizer.h"
 
 #include "mir/repres/Representation.h"
 
@@ -28,10 +23,7 @@ namespace search {
 namespace tree {
 
 
-// -----------------------------------------------------------------------------
-
-
-template<class T>
+template <class T>
 eckit::PathName TreeMappedFile<T>::treePath(const repres::Representation& r, bool makeUnique) {
 
     // LocalPathName::unique and LocalPathName::mkdir call mkdir, make sure to use umask = 0
@@ -39,26 +31,22 @@ eckit::PathName TreeMappedFile<T>::treePath(const repres::Representation& r, boo
 
     static const long VERSION = 2;
 
-    const std::string relative = "mir/search/"
-            + std::to_string(VERSION)
-            + "/"
-            + r.uniqueName()
-            + ".kdtree";
+    const std::string relative = "mir/search/" + std::to_string(VERSION) + "/" + r.uniqueName() + ".kdtree";
 
-    auto writable = [](const eckit::PathName& path) -> bool {
-        return (::access(path.asString().c_str(), W_OK) == 0);
-    };
+    auto writable = [](const eckit::PathName& path) -> bool { return (::access(path.asString().c_str(), W_OK) == 0); };
 
     for (eckit::PathName path : T::roots()) {
 
-        if(not path.exists()) {
+        if (not path.exists()) {
 
-            if(not writable(path.dirName()))
+            if (not writable(path.dirName())) {
                 continue;
+            }
 
             try {
                 path.mkdir(0777);
-            } catch (eckit::FailedSystemCall&) {
+            }
+            catch (eckit::FailedSystemCall&) {
                 // ignore
             }
         }
@@ -73,7 +61,8 @@ eckit::PathName TreeMappedFile<T>::treePath(const repres::Representation& r, boo
             path = eckit::PathName::unique(path);
         }
 
-        eckit::Log::debug<LibMir>() << "TreeMappedFile: path '" << path  << "'" << (makeUnique ? " (unique)" : "") << std::endl;
+        eckit::Log::debug<LibMir>() << "TreeMappedFile: path '" << path << "'" << (makeUnique ? " (unique)" : "")
+                                    << std::endl;
         return path;
     }
 
@@ -81,7 +70,7 @@ eckit::PathName TreeMappedFile<T>::treePath(const repres::Representation& r, boo
 }
 
 
-template<class T>
+template <class T>
 eckit::PathName TreeMappedFile<T>::lockFile(const std::string& path) {
     eckit::AutoUmask umask(0);
 
@@ -91,9 +80,6 @@ eckit::PathName TreeMappedFile<T>::lockFile(const std::string& path) {
 }
 
 
-// -----------------------------------------------------------------------------
-
-
 class TreeMappedCacheFile : public TreeMappedFile<TreeMappedCacheFile> {
     using P = TreeMappedFile<TreeMappedCacheFile>;
     static std::vector<std::string> getRoots() {
@@ -104,12 +90,15 @@ class TreeMappedCacheFile : public TreeMappedFile<TreeMappedCacheFile> {
         parse(cacheDir, tmp);
 
         std::vector<std::string> r;
+        r.reserve(tmp.size());
+
         for (const auto& root : tmp) {
             r.emplace_back(eckit::PathExpander::expand(root));
         }
 
         return r;
     }
+
 public:
     using P::P;
     static std::vector<std::string> roots() {
@@ -122,15 +111,13 @@ public:
 static TreeBuilder<TreeMappedCacheFile> builder1("mapped-cache-file");
 
 
-// -----------------------------------------------------------------------------
-
-
 class TreeMappedTempFile : public TreeMappedFile<TreeMappedTempFile> {
     using P = TreeMappedFile<TreeMappedTempFile>;
+
 public:
     using P::P;
     static std::vector<std::string> roots() {
-        static std::vector<std::string> _root {"/tmp"};
+        static std::vector<std::string> _root{"/tmp"};
         return _root;
     }
 };
@@ -142,4 +129,3 @@ static TreeBuilder<TreeMappedTempFile> builder2("mapped-temporary-file");
 }  // namespace tree
 }  // namespace search
 }  // namespace mir
-
