@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #ifndef mir_stats_Comparator_h
 #define mir_stats_Comparator_h
@@ -27,16 +24,15 @@ class MIRField;
 namespace param {
 class MIRParametrisation;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
 namespace stats {
 
 
-class Comparator  {
+class Comparator {
 public:
-
     // -- Exceptions
     // None
 
@@ -70,7 +66,6 @@ public:
     // None
 
 protected:
-
     // -- Members
 
     const param::MIRParametrisation& parametrisation1_;
@@ -90,7 +85,6 @@ protected:
     // None
 
 private:
-
     // -- Members
     // None
 
@@ -112,31 +106,34 @@ private:
         r.print(out);
         return out;
     }
-
 };
 
 
 class ComparatorFactory {
-private:
     std::string name_;
     virtual Comparator* make(const param::MIRParametrisation&, const param::MIRParametrisation&) = 0;
+
+    ComparatorFactory(const ComparatorFactory&) = delete;
+    ComparatorFactory& operator=(const ComparatorFactory&) = delete;
+
 protected:
     ComparatorFactory(const std::string&);
     virtual ~ComparatorFactory();
+
 public:
     static void list(std::ostream&);
     static Comparator* build(const std::string&, const param::MIRParametrisation&, const param::MIRParametrisation&);
 };
 
 
-template<class T>
+template <class T>
 class ComparatorBuilder : public ComparatorFactory {
     virtual Comparator* make(const param::MIRParametrisation& param1, const param::MIRParametrisation& param2) {
         return new T(param1, param2);
     }
+
 public:
-    ComparatorBuilder(const std::string& name) : ComparatorFactory(name) {
-    }
+    ComparatorBuilder(const std::string& name) : ComparatorFactory(name) {}
 };
 
 
