@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -24,7 +25,7 @@ class MIRField;
 namespace param {
 class MIRParametrisation;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -33,7 +34,6 @@ namespace stats {
 
 class Method {
 public:
-
     // -- Exceptions
     // None
 
@@ -71,7 +71,6 @@ public:
     // None
 
 protected:
-
     // -- Members
 
     const param::MIRParametrisation& parametrisation_;
@@ -91,7 +90,6 @@ protected:
     // None
 
 private:
-
     // -- Members
     // None
 
@@ -113,7 +111,6 @@ private:
         r.print(out);
         return out;
     }
-
 };
 
 
@@ -121,24 +118,27 @@ class MethodFactory {
 private:
     std::string name_;
     virtual Method* make(const param::MIRParametrisation&) = 0;
+
+    MethodFactory(const MethodFactory&) = delete;
+    MethodFactory& operator=(const MethodFactory&) = delete;
+
 protected:
     MethodFactory(const std::string&);
     virtual ~MethodFactory();
+
 public:
     static void list(std::ostream&);
     static Method* build(const std::string&, const param::MIRParametrisation&);
 };
 
 
-template<class T>
+template <class T>
 class MethodBuilder : public MethodFactory {
 private:
-    Method* make(const param::MIRParametrisation& param) {
-        return new T(param);
-    }
+    Method* make(const param::MIRParametrisation& param) { return new T(param); }
+
 public:
-    MethodBuilder(const std::string& name) : MethodFactory(name) {
-    }
+    MethodBuilder(const std::string& name) : MethodFactory(name) {}
 };
 
 
@@ -147,4 +147,3 @@ public:
 
 
 #endif
-
