@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -27,8 +28,16 @@ namespace stats {
 namespace detail {
 
 
-enum AngleScale { DEGREE, RADIAN };
-enum AngleSpace { ASYMMETRIC, SYMMETRIC };
+enum AngleScale
+{
+    DEGREE,
+    RADIAN
+};
+enum AngleSpace
+{
+    ASYMMETRIC,
+    SYMMETRIC
+};
 
 
 /// Angle statistics in degrees [-180,180] or radians [-π,π]
@@ -52,20 +61,13 @@ private:
         return a;
     }
 
-    T normalise(T a) const {
-        return normalise(a, min_, globe_);
-    }
+    T normalise(T a) const { return normalise(a, min_, globe_); }
 
-    std::complex<T> decompose(const T& a) const {
-        return std::polar(1., a * descale_);
-    }
+    std::complex<T> decompose(const T& a) const { return std::polar(1., a * descale_); }
 
-    T recompose(const std::complex<T>& c) const {
-        return normalise(std::arg(c) * rescale_);
-    }
+    T recompose(const std::complex<T>& c) const { return normalise(std::arg(c) * rescale_); }
 
 public:
-
     AngleT() :
         rescale_(std::numeric_limits<T>::signaling_NaN()),
         descale_(std::numeric_limits<T>::signaling_NaN()),
@@ -74,49 +76,40 @@ public:
         NOTIMP;  // ensure specialisation
     }
 
-    void reset() {
-        centralMoments_.reset();
-    }
+    void reset() { centralMoments_.reset(); }
 
     T difference(const T& a, const T& b) const {
         auto d = std::abs(normalise(b) - normalise(a));
         return std::min(globe_ - d, d);
     }
 
-    void operator()(const T& v) {
-        centralMoments_(decompose(v));
-    }
+    void operator()(const T& v) { centralMoments_(decompose(v)); }
 
-    void operator+=(const AngleT& other) {
-        centralMoments_ += other.centralMoments_;
-    }
+    void operator+=(const AngleT& other) { centralMoments_ += other.centralMoments_; }
 
-    T mean() const {
-        return recompose(centralMoments_.mean());
-    }
+    T mean() const { return recompose(centralMoments_.mean()); }
 
-    T variance() const {
-        return recompose(centralMoments_.variance());
-    }
+    T variance() const { return recompose(centralMoments_.variance()); }
 
-    T standardDeviation() const {
-        return recompose(centralMoments_.standardDeviation());
-    }
+    T standardDeviation() const { return recompose(centralMoments_.standardDeviation()); }
 
     void print(std::ostream& out) const {
         out << "Angle["
-                "mean="   << mean()
-            << ",stddev=" << standardDeviation()
-            << "]";
+               "mean="
+            << mean() << ",stddev=" << standardDeviation() << "]";
     }
 };
 
 
 // Available angle statistics
-template<> AngleT<double, AngleScale::DEGREE, AngleSpace::ASYMMETRIC>::AngleT::AngleT();
-template<> AngleT<double, AngleScale::DEGREE, AngleSpace::SYMMETRIC>::AngleT::AngleT();
-template<> AngleT<double, AngleScale::RADIAN, AngleSpace::ASYMMETRIC>::AngleT::AngleT();
-template<> AngleT<double, AngleScale::RADIAN, AngleSpace::SYMMETRIC>::AngleT::AngleT();
+template <>
+AngleT<double, AngleScale::DEGREE, AngleSpace::ASYMMETRIC>::AngleT::AngleT();
+template <>
+AngleT<double, AngleScale::DEGREE, AngleSpace::SYMMETRIC>::AngleT::AngleT();
+template <>
+AngleT<double, AngleScale::RADIAN, AngleSpace::ASYMMETRIC>::AngleT::AngleT();
+template <>
+AngleT<double, AngleScale::RADIAN, AngleSpace::SYMMETRIC>::AngleT::AngleT();
 
 
 }  // namespace detail
