@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -22,13 +23,13 @@ namespace stats {
 namespace method {
 
 
-template<typename STATS>
+template <typename STATS>
 void MethodT<STATS>::resize(size_t N) {
     vector_t::resize(N);
 }
 
 
-template<typename STATS>
+template <typename STATS>
 void MethodT<STATS>::execute(const data::MIRField& field) {
     ASSERT(!empty());
     Counter::reset(field);
@@ -48,7 +49,7 @@ void MethodT<STATS>::execute(const data::MIRField& field) {
 }
 
 
-template<typename STATS>
+template <typename STATS>
 void MethodT<STATS>::mean(data::MIRField& field) const {
     const auto missingValue = field.missingValue();
 
@@ -60,15 +61,15 @@ void MethodT<STATS>::mean(data::MIRField& field) const {
 
     for (auto& s : *this) {
         auto& value = *(v++);
-        auto stat = s.mean();
-        value = stat == stat ? stat : missingValue;
+        auto stat   = s.mean();
+        value       = stat == stat ? stat : missingValue;
     }
 
     field.update(statistics, 0, true);
 }
 
 
-template<typename STATS>
+template <typename STATS>
 void MethodT<STATS>::variance(data::MIRField& field) const {
     const auto missingValue = field.missingValue();
 
@@ -80,14 +81,14 @@ void MethodT<STATS>::variance(data::MIRField& field) const {
 
     for (auto& s : *this) {
         auto stat = s.variance();
-        *v = stat == stat ? stat : missingValue;
+        *v        = stat == stat ? stat : missingValue;
     }
 
     field.update(statistics, 0, true);
 }
 
 
-template<typename STATS>
+template <typename STATS>
 void MethodT<STATS>::stddev(data::MIRField& field) const {
     const auto missingValue = field.missingValue();
 
@@ -99,17 +100,21 @@ void MethodT<STATS>::stddev(data::MIRField& field) const {
 
     for (auto& s : *this) {
         auto stat = s.standardDeviation();
-        *v = stat == stat ? stat : missingValue;
+        *v        = stat == stat ? stat : missingValue;
     }
 
     field.update(statistics, 0, true);
 }
 
 
-static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::DEGREE, detail::AngleSpace::ASYMMETRIC>>> __stats1("angle.degree.asymmetric");
-static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::DEGREE, detail::AngleSpace::SYMMETRIC>>> __stats2("angle.degree.symmetric");
-static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::RADIAN, detail::AngleSpace::ASYMMETRIC>>> __stats3("angle.radian.asymmetric");
-static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::RADIAN, detail::AngleSpace::SYMMETRIC>>> __stats4("angle.radian.symmetric");
+static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::DEGREE, detail::AngleSpace::ASYMMETRIC>>>
+    __stats1("angle.degree.asymmetric");
+static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::DEGREE, detail::AngleSpace::SYMMETRIC>>>
+    __stats2("angle.degree.symmetric");
+static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::RADIAN, detail::AngleSpace::ASYMMETRIC>>>
+    __stats3("angle.radian.asymmetric");
+static MethodBuilder<MethodT<detail::AngleT<double, detail::AngleScale::RADIAN, detail::AngleSpace::SYMMETRIC>>>
+    __stats4("angle.radian.symmetric");
 static MethodBuilder<MethodT<detail::CentralMomentsT<double>>> __stats5("central-moments");
 static MethodBuilder<MethodT<detail::ScalarT<double>>> __stats6("scalar");
 
@@ -117,4 +122,3 @@ static MethodBuilder<MethodT<detail::ScalarT<double>>> __stats6("scalar");
 }  // namespace method
 }  // namespace stats
 }  // namespace mir
-
