@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -50,8 +51,8 @@ SimplePackingEntropy::~SimplePackingEntropy() = default;
 
 
 void SimplePackingEntropy::reset() {
-    entropy_ = std::numeric_limits<double>::quiet_NaN();
-    scale_   = std::numeric_limits<double>::quiet_NaN();
+    entropy_     = std::numeric_limits<double>::quiet_NaN();
+    scale_       = std::numeric_limits<double>::quiet_NaN();
     bucketCount_ = 0;
 }
 
@@ -89,10 +90,10 @@ void SimplePackingEntropy::execute(const data::MIRField& field) {
 
     // set/fill buckets and compute entropy
     std::vector<size_t> buckets(bucketCount_);
-    scale_ = (bucketCount_ - 1)  / (_max - _min);
+    scale_ = (bucketCount_ - 1) / (_max - _min);
     buckets.assign(bucketCount_, 0);
 
-    const auto N = double(count());
+    const auto N               = double(count());
     const double one_over_log2 = 1. / M_LN2;
 
     Counter::reset(field);
@@ -117,19 +118,13 @@ void SimplePackingEntropy::execute(const data::MIRField& field) {
 void SimplePackingEntropy::print(std::ostream& out) const {
     out << "SimplePackingEntropy[";
     Counter::print(out);
-    out << ",entropy=" << entropy()
-        << ",scale=" << scale()
-        << ",bucketCount="  << bucketCount()
-        << "]";
+    out << ",entropy=" << entropy() << ",scale=" << scale() << ",bucketCount=" << bucketCount() << "]";
 }
 
 
-namespace {
 static StatisticsBuilder<SimplePackingEntropy> __stats("simple-packing-entropy");
-}
 
 
 }  // namespace statistics
 }  // namespace stats
 }  // namespace mir
-
