@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -21,8 +22,8 @@ namespace eckit {
 namespace option {
 class CmdArgs;
 class Option;
-}
-}
+}  // namespace option
+}  // namespace eckit
 
 
 namespace mir {
@@ -31,20 +32,15 @@ namespace tools {
 
 class MIRTool : public eckit::Tool {
 protected:
-
     using options_t = std::vector<eckit::option::Option*>;
 
     virtual void run();
 
     virtual void execute(const eckit::option::CmdArgs& args) = 0;
 
-    virtual int numberOfPositionalArguments() const {
-        return -1;
-    }
+    virtual int numberOfPositionalArguments() const { return -1; }
 
-    virtual int minimumPositionalArguments() const {
-        return numberOfPositionalArguments();
-    }
+    virtual int minimumPositionalArguments() const { return numberOfPositionalArguments(); }
 
     virtual void init(const eckit::option::CmdArgs&);
 
@@ -53,11 +49,9 @@ protected:
     options_t options_;
 
 public:
-
     virtual void usage(const std::string& tool) const = 0;
 
-    MIRTool(int argc, char **argv);
-
+    MIRTool(int argc, char** argv);
 };
 
 
