@@ -15,6 +15,8 @@
 
 #include <cmath>
 
+#include "mir/util/Types.h"
+
 
 namespace mir {
 namespace util {
@@ -32,6 +34,12 @@ inline double radian_to_degree(const double& a) {
 }
 
 
+/// @return longitude in degree within range [minimum, minimum + 360[
+inline double normalise_longitude(const double& lon, const double& minimum) {
+    return Longitude(lon).normalise(minimum).value();
+}
+
+
 }  // namespace util
 }  // namespace mir
 
