@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -26,15 +27,15 @@
 
 namespace mir {
 namespace util {
-namespace {
 
-static void out(std::vector<std::vector<bool> > &bitmap, long row, const std::string &line, bool on, long &prev) {
+static void out(std::vector<std::vector<bool> >& bitmap, long row, const std::string& line, bool on, long& prev) {
 
     ASSERT(row >= 0);
 
     if (prev >= 0) {
-        for (long i = prev + 1; i < row; i++) {
-            bitmap[i] = bitmap[prev];
+        auto prevu = size_t(prev);
+        for (auto i = prevu + 1; i < size_t(row); i++) {
+            bitmap[i] = bitmap[prevu];
         }
     }
 
@@ -50,13 +51,13 @@ static void out(std::vector<std::vector<bool> > &bitmap, long row, const std::st
     t1(line, r);
 
 
-    ASSERT(row >= 0 && row < long(bitmap.size()));
-    std::vector<bool> &v = bitmap[row];
+    ASSERT(0 <= row && row < long(bitmap.size()));
+    auto& v = bitmap[size_t(row)];
 
-    for (size_t i = 0; i < r.size() ; i++) {
+    for (auto& i : r) {
 
         std::vector<std::string> s;
-        t2(r[i], s);
+        t2(i, s);
         ASSERT(s.size() == 1 || s.size() == 2);
         if (s.size() == 1) {
             s.push_back(s[0]);
@@ -66,12 +67,10 @@ static void out(std::vector<std::vector<bool> > &bitmap, long row, const std::st
         long b = s2l(s[1]) - 1;
 
         if (a >= 0) {
+            ASSERT(a < long(v.size()));
+            ASSERT(0 <= b && b < long(v.size()));
 
-
-            ASSERT(a >= 0 && a < long(v.size()));
-            ASSERT(b >= 0 && b < long(v.size()));
-
-            for (int j = a; j <= b ; j++) {
+            for (auto j = size_t(a); j <= size_t(b); j++) {
                 v[j] = on;
             }
         }
@@ -79,13 +78,7 @@ static void out(std::vector<std::vector<bool> > &bitmap, long row, const std::st
 }
 
 
-}  // (unnamed namespace)
-
-
-Bitmap::Bitmap(const std::string& path):
-    path_(path),
-    width_(0),
-    height_(0) {
+Bitmap::Bitmap(const std::string& path) : path_(path), width_(0), height_(0) {
 
     std::vector<std::string> v;
     eckit::Tokenizer parse(":");
@@ -105,33 +98,32 @@ void Bitmap::disseminationBitmap(const std::string& path) {
     int c;
     std::string s;
 
-    while ( (c = fgetc(file)) != EOF) {
+    while ((c = fgetc(file)) != EOF) {
 
         switch (c) {
 
-        case ' ':
-        case '\t':
-        case '\n':
-        case '\r':
-            break;
-
-        default:
-            s += char(tolower(c));
-            break;
+            case ' ':
+            case '\t':
+            case '\n':
+            case '\r':
+                break;
 
+            default:
+                s += char(tolower(c));
+                break;
         }
     }
 
-    bool on = s.find("values=on") == s.npos;
+    bool on = s.find("values=on") == std::string::npos;
 
     size_t pos = s.find("size=");
     ASSERT(pos != s.npos);
     pos += 5;
-    int  n = 0;
+    size_t n = 0;
     while (pos < s.size()) {
         if (s[pos] == ':') {
             height_ = n;
-            n = 0;
+            n       = 0;
             pos++;
             continue;
         }
@@ -156,7 +148,7 @@ void Bitmap::disseminationBitmap(const std::string& path) {
     std::vector<std::vector<bool> > bitmap(height_, std::vector<bool>(width_, !on));
 
     std::string t;
-    long row = -1;
+    long row  = -1;
     long prev = -1;
     eckit::Translator<std::string, long> s2l;
 
@@ -164,7 +156,7 @@ void Bitmap::disseminationBitmap(const std::string& path) {
 
         if (s[pos] == ':') {
             row = s2l(t) - 1;
-            t = "";
+            t   = "";
             pos++;
             continue;
         }
@@ -176,7 +168,7 @@ void Bitmap::disseminationBitmap(const std::string& path) {
             continue;
         }
 
-        if (isalpha(s[pos])) {
+        if (isalpha(s[pos]) != 0) {
             break;
         }
 
@@ -185,16 +177,15 @@ void Bitmap::disseminationBitmap(const std::string& path) {
     }
 
     out(bitmap, row, t, on, prev);
-    out(bitmap, height_ - 1, t, on, prev);
+    out(bitmap, long(height_ - 1), t, on, prev);
 
     // out(bitmap);
 
     std::swap(bitmap, bitmap_);
 }
 
-void Bitmap::prodgenBitmap(const std::string& path, const std::string& destination, const std::string& number)
-{
-    char  line[1024];
+void Bitmap::prodgenBitmap(const std::string& path, const std::string& destination, const std::string& number) {
+    char line[1024];
     std::ifstream in(path.c_str());
     if (!in) {
         throw eckit::CantOpenFile(path);
@@ -208,11 +199,11 @@ void Bitmap::prodgenBitmap(const std::string& path, const std::string& destinati
 
         std::string dest(line, line + 5);
         size_t num = s2l(std::string(line + 6, line + 9));
-        bool ok = (num == no && destination == dest);
+        bool ok    = (num == no && destination == dest);
 
         size_t size = 0;
-        for (const char *c = line + 10; c != line + 20; ++c) {
-            if (::isdigit(*c)) {
+        for (const char* c = line + 10; c != line + 20; ++c) {
+            if (::isdigit(*c) != 0) {
                 size *= 10;
                 size += *c - '0';
             }
@@ -230,9 +221,9 @@ void Bitmap::prodgenBitmap(const std::string& path, const std::string& destinati
             len += strlen(line);
 
             if (ok) {
-                const char *p = line;
+                const char* p = line;
 
-                while (*p) {
+                while (*p != 0) {
                     bitmap[k++] = (*p == '1');
                     p++;
                 }
@@ -243,10 +234,9 @@ void Bitmap::prodgenBitmap(const std::string& path, const std::string& destinati
             }
         }
 
-        if (ok)
-        {
+        if (ok) {
             height_ = 1;
-            width_ = bitmap.size();
+            width_  = bitmap.size();
             bitmap_.resize(1);
             std::swap(bitmap_[0], bitmap);
             return;
@@ -262,7 +252,7 @@ void Bitmap::prodgenBitmap(const std::string& path, const std::string& destinati
 Bitmap::~Bitmap() = default;
 
 
-void Bitmap::print(std::ostream &out) const {
+void Bitmap::print(std::ostream& out) const {
     out << "Bitmap[path=" << path_ << "]";
 }
 
@@ -272,15 +262,13 @@ size_t Bitmap::footprint() const {
     result += path_.capacity();
     result += bitmap_.capacity() * sizeof(std::vector<bool>);
 
-    for(auto j = bitmap_.begin(); j != bitmap_.end(); ++j) {
-        result += (*j).capacity() * sizeof(bool);
+    for (auto& j : bitmap_) {
+        result += j.capacity() * sizeof(bool);
     }
 
     return result;
 }
 
 
-
 }  // namespace util
 }  // namespace mir
-
