@@ -3,31 +3,25 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date   April 2016
-
 
 #include <iostream>
 
-#include "mir/util/FormulaNumber.h"
 #include "mir/action/context/Context.h"
+#include "mir/util/FormulaNumber.h"
 
 
 namespace mir {
 namespace util {
 
 
-FormulaNumber::FormulaNumber(const param::MIRParametrisation &parametrisation, double value):
-    Formula(parametrisation),
-    value_(value) {
-}
+FormulaNumber::FormulaNumber(const param::MIRParametrisation& parametrisation, double value) :
+    Formula(parametrisation), value_(value) {}
 
 FormulaNumber::~FormulaNumber() = default;
 
@@ -42,7 +36,7 @@ void FormulaNumber::execute(mir::context::Context& ctx) const {
 
 bool FormulaNumber::sameAs(const mir::action::Action& other) const {
     auto o = dynamic_cast<const FormulaNumber*>(&other);
-    return o && (value_ == o->value_);
+    return (o != nullptr) && (value_ == o->value_);
 }
 
 
@@ -51,5 +45,5 @@ const char* FormulaNumber::name() const {
 }
 
 
-} // namespace util
-} // namespace mir
+}  // namespace util
+}  // namespace mir
