@@ -3,16 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date April 2016
-
 
 #include "mir/util/Function.h"
 
@@ -21,7 +17,6 @@
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/thread/AutoLock.h"
-#include "eckit/thread/Once.h"
 #include "eckit/thread/Mutex.h"
 
 
@@ -29,27 +24,17 @@ namespace mir {
 namespace util {
 
 
-namespace {
-
-
-static eckit::Mutex *local_mutex = nullptr;
-static std::map<std::string, Function *> *m = nullptr;
-
-static pthread_once_t once = PTHREAD_ONCE_INIT;
-
+static eckit::Mutex* local_mutex           = nullptr;
+static std::map<std::string, Function*>* m = nullptr;
+static pthread_once_t once                 = PTHREAD_ONCE_INIT;
 static void init() {
     local_mutex = new eckit::Mutex();
-    m = new std::map<std::string, Function *>();
-}
-
+    m           = new std::map<std::string, Function*>();
 }
 
 
-Function::Function(const std::string& name):
-    name_(name) {
-
+Function::Function(const std::string& name) : name_(name) {
     pthread_once(&once, init);
-
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
     ASSERT(m->find(name) == m->end());
@@ -59,31 +44,36 @@ Function::Function(const std::string& name):
 
 Function::~Function() {
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+
     m->erase(name_);
 }
 
 
-
-const Function& Function::lookup(const std::string &name) {
-
+const Function& Function::lookup(const std::string& name) {
     pthread_once(&once, init);
-
     eckit::AutoLock<eckit::Mutex> lock(local_mutex);
-    std::map<std::string, Function *>::const_iterator j = m->find(name);
-
 
+    auto j = m->find(name);
     if (j == m->end()) {
-        eckit::Log::error() << "No Function for [" << name << "]" << std::endl;
-        eckit::Log::error() << "Functions are:" << std::endl;
-        for (j = m->begin() ; j != m->end() ; ++j)
-            eckit::Log::error() << "   " << (*j).first << std::endl;
-        throw eckit::SeriousBug(std::string("No Function called ") + name);
+        list(eckit::Log::error() << "Function: unknown '" << name << "', choices are: ");
+        throw eckit::SeriousBug("Function: unknown '" + name + "'");
     }
 
-    return *(*j).second;
+    return *(j->second);
 }
 
 
-} // namespace util
-} // namespace mir
+void Function::list(std::ostream& out) {
+    pthread_once(&once, init);
+    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
 
+    auto sep = "";
+    for (auto& j : *m) {
+        out << sep << j.first;
+        sep = ", ";
+    }
+}
+
+
+}  // namespace util
+}  // namespace mir
