@@ -3,20 +3,17 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Tiago Quintino
-/// @author Pedro Maciel
-/// @date April 2016
-
 
 #ifndef mir_util_Function_h
 #define mir_util_Function_h
 
+#include <iosfwd>
 #include <string>
 
 
@@ -24,7 +21,7 @@ namespace mir {
 namespace context {
 class Context;
 }
-}
+}  // namespace mir
 
 
 namespace mir {
@@ -33,7 +30,6 @@ namespace util {
 
 class Function {
 public:
-
     Function(const std::string&);
 
     Function(const Function&) = delete;
@@ -45,21 +41,19 @@ public:
 
     static const Function& lookup(const std::string&);
 
-private:
+    static void list(std::ostream&);
 
+private:
     virtual void print(std::ostream&) const = 0;
 
 protected:
-
     const std::string name_;
 
 private:
-
-    friend std::ostream &operator<<(std::ostream &s, const Function &p) {
+    friend std::ostream& operator<<(std::ostream& s, const Function& p) {
         p.print(s);
         return s;
     }
-
 };
 
 
@@ -68,4 +62,3 @@ private:
 
 
 #endif
-
