@@ -3,14 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-
 
 #ifndef mir_util_Grib_h
 #define mir_util_Grib_h
@@ -22,56 +20,58 @@
 #include "eckit/exception/Exceptions.h"
 
 
-inline bool grib_call(int e, const char *call, bool missingOK = false) {
+inline bool grib_call(int e, const char* call, bool missingOK = false) {
     if (e) {
-        if(missingOK && (e == GRIB_NOT_FOUND)) {
+        if (missingOK && (e == CODES_NOT_FOUND)) {
             return false;
         }
 
         std::ostringstream os;
-        os << call << ": " << grib_get_error_message(e);
+        os << call << ": " << codes_get_error_message(e);
         throw eckit::SeriousBug(os.str());
     }
     return true;
 }
 
-#undef GRIB_CALL
-#define GRIB_CALL(a) grib_call(a, #a)
-#define GRIB_ERROR(a, b) grib_call(a, b)
 
+#define GRIB_CALL(a) grib_call(a, #a)
 #define GRIB_GET(a) grib_call(a, #a, true)
+#define GRIB_ERROR(a, b) grib_call(a, b)
 
 
 struct grib_info {
-    grib_util_grid_spec grid;
-    grib_util_packing_spec packing;
+    codes_util_grid_spec grid;
+    codes_util_packing_spec packing;
 };
 
 
 class HandleDeleter {
-    grib_handle *h_;
+    grib_handle* h_;
+
 public:
-    HandleDeleter(grib_handle *h) : h_(h) {}
+    HandleDeleter(grib_handle* h) : h_(h) { ASSERT(h); }
     HandleDeleter(const HandleDeleter&) = delete;
     void operator=(const HandleDeleter&) = delete;
-    ~HandleDeleter() { grib_handle_delete(h_); }
+    ~HandleDeleter() { codes_handle_delete(h_); }
 };
 
 
 class GKeyIteratorDeleter {
-    grib_keys_iterator *h_;
+    codes_keys_iterator* h_;
+
 public:
-    GKeyIteratorDeleter(grib_keys_iterator* h) : h_(h) {}
+    GKeyIteratorDeleter(codes_keys_iterator* h) : h_(h) {}
     GKeyIteratorDeleter(const GKeyIteratorDeleter&) = delete;
     void operator=(const GKeyIteratorDeleter&) = delete;
-    ~GKeyIteratorDeleter() { grib_keys_iterator_delete(h_); }
+    ~GKeyIteratorDeleter() { codes_keys_iterator_delete(h_); }
 };
 
 
 class BKeyIteratorDeleter {
-    bufr_keys_iterator *h_;
+    codes_bufr_keys_iterator* h_;
+
 public:
-    BKeyIteratorDeleter(bufr_keys_iterator* h) : h_(h) {}
+    BKeyIteratorDeleter(codes_bufr_keys_iterator* h) : h_(h) {}
     BKeyIteratorDeleter(const BKeyIteratorDeleter&) = delete;
     void operator=(const BKeyIteratorDeleter&) = delete;
     ~BKeyIteratorDeleter() { codes_bufr_keys_iterator_delete(h_); }
