@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -18,14 +19,13 @@ namespace mir {
 
 
 struct LongitudeIncrement {
-    explicit LongitudeIncrement(const Longitude& increment=Longitude(0)) : increment_(increment) {}
+    explicit LongitudeIncrement(const Longitude& increment = Longitude(0)) : increment_(increment) {}
     const LongitudeIncrement& operator=(const Longitude& l) {
         increment_ = l;
         return *this;
     }
-    const Longitude& longitude() const {
-        return increment_;
-    }
+    const Longitude& longitude() const { return increment_; }
+
 private:
     Longitude increment_;
 };
@@ -35,4 +35,3 @@ private:
 
 
 #endif
-
