@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -69,13 +70,20 @@ private:
 public:
     MIRClimateFilter(int argc, char** argv) : MIRTool(argc, argv) {
         using eckit::linalg::LinearAlgebra;
-        options_.push_back(new eckit::option::VectorOption<size_t>("k", "Range of neighbour points to weight (k, default [4, infty[)", 2));
-        options_.push_back(new eckit::option::SimpleOption<double>("distance", "Climate filter radius [m] of neighbours to weight (default 1.)"));
-        options_.push_back(new eckit::option::SimpleOption<double>("delta", "Climate filter width of filter edge [m], must be greater than 'distance' (default 1000.)"));
-        options_.push_back(new eckit::option::SimpleOption<double>("weight-min", "Climate filter point minimum relative weight ([0, 1], default 0.001)"));
-        options_.push_back(new eckit::option::SimpleOption<bool>("no-backend", "No linear algebra backend (minimum memory requirements)"));
-        options_.push_back(new eckit::option::FactoryOption<LinearAlgebra>("backend", "Linear algebra backend (default '" + LinearAlgebra::backend().name() + "')"));
-        options_.push_back(new eckit::option::FactoryOption<search::TreeFactory>("point-search-trees", "k-d tree control"));
+        options_.push_back(new eckit::option::VectorOption<size_t>(
+            "k", "Range of neighbour points to weight (k, default [4, infty[)", 2));
+        options_.push_back(new eckit::option::SimpleOption<double>(
+            "distance", "Climate filter radius [m] of neighbours to weight (default 1.)"));
+        options_.push_back(new eckit::option::SimpleOption<double>(
+            "delta", "Climate filter width of filter edge [m], must be greater than 'distance' (default 1000.)"));
+        options_.push_back(new eckit::option::SimpleOption<double>(
+            "weight-min", "Climate filter point minimum relative weight ([0, 1], default 0.001)"));
+        options_.push_back(new eckit::option::SimpleOption<bool>(
+            "no-backend", "No linear algebra backend (minimum memory requirements)"));
+        options_.push_back(new eckit::option::FactoryOption<LinearAlgebra>(
+            "backend", "Linear algebra backend (default '" + LinearAlgebra::backend().name() + "')"));
+        options_.push_back(
+            new eckit::option::FactoryOption<search::TreeFactory>("point-search-trees", "k-d tree control"));
     }
 };
 
@@ -139,7 +147,7 @@ void MIRClimateFilter::execute(const eckit::option::CmdArgs& args) {
         repres::RepresentationHandle rep(ctx.field().representation());
         {
             auto ll = dynamic_cast<const repres::latlon::RegularLL*>(static_cast<const repres::Representation*>(rep));
-            if (!ll || !rep->domain().isGlobal() || ctx.field().hasMissing()) {
+            if ((ll == nullptr) || !rep->domain().isGlobal() || ctx.field().hasMissing()) {
                 throw eckit::UserError("MIRClimateFilter: input field should be global regular_ll, no missing values");
             }
             Ni = ll->Ni();
@@ -170,7 +178,8 @@ void MIRClimateFilter::execute(const eckit::option::CmdArgs& args) {
             param->get("scanningMode", scan);
             ASSERT(scan == 0L);
 
-            double max, min;
+            double max;
+            double min;
             ASSERT(param->get("south", min = 0));
             ASSERT(param->get("north", max = 0));
             ASSERT(min < max);
@@ -200,11 +209,10 @@ void MIRClimateFilter::execute(const eckit::option::CmdArgs& args) {
                 if (++progress) {
                     log << "   latitude: " << lat[j] << " degree"
                         << "\n   farthest: " << farthest << " m"
-                        << "\n   closest: " << eckit::Seconds(tClosest)
-                        << "\n   matrix A: " << eckit::Seconds(tMatrixA)
+                        << "\n   closest: " << eckit::Seconds(tClosest) << "\n   matrix A: " << eckit::Seconds(tMatrixA)
                         << "\n   vector Y: " << eckit::Seconds(tVectorY)
-                        << "\n   vector X: " << eckit::Seconds(tVectorX)
-                        << "\n" << tree << std::endl;
+                        << "\n   vector X: " << eckit::Seconds(tVectorX) << "\n"
+                        << tree << std::endl;
                     tClosest = tMatrixA = tVectorY = tVectorX = farthest = 0;
                 }
 
@@ -270,7 +278,7 @@ void MIRClimateFilter::execute(const eckit::option::CmdArgs& args) {
                         auto c = n % Ni;
 
                         for (size_t i = 0, i0 = j * Ni, c0 = r * Ni; i < Ni; ++i) {
-                            if (!w) {
+                            if (w == 0) {
                                 output[i0 + i] = a * input[c0 + (c + i) % Ni];
                             }
                             else {
