@@ -3,15 +3,12 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-/// @author Baudouin Raoult
-/// @author Pedro Maciel
-/// @date Apr 2015
-
 
 #include "eckit/log/Log.h"
 #include "eckit/option/CmdArgs.h"
@@ -30,11 +27,9 @@ class MIRConfig : public mir::tools::MIRTool {
 
     void execute(const eckit::option::CmdArgs&);
 
-    void usage(const std::string &tool) const;
+    void usage(const std::string& tool) const;
 
-    int minimumPositionalArguments() const {
-        return 0;
-    }
+    int minimumPositionalArguments() const { return 0; }
 
     void display(const mir::param::MIRParametrisation& metadata, const std::string& key) const {
         using namespace mir ::param;
@@ -54,26 +49,34 @@ class MIRConfig : public mir::tools::MIRTool {
     }
 
 public:
+    // -- Constructors
 
-    // -- Contructors
-
-    MIRConfig(int argc, char **argv) : mir::tools::MIRTool(argc, argv) {
+    MIRConfig(int argc, char** argv) : mir::tools::MIRTool(argc, argv) {
         using eckit::option::SimpleOption;
         options_.push_back(new SimpleOption<long>("param-id", "Display configuration with paramId"));
         options_.push_back(new SimpleOption<std::string>("key", "Display configuration with specific key"));
     }
-
 };
 
 
-void MIRConfig::usage(const std::string &tool) const {
-    eckit::Log::info()
-            << "\n" "Usage: " << tool << " [--key=key] [[--param-id=value]|[input1.grib [input2.grib [...]]]]"
-            "\n" "Examples: "
-            "\n" "  % " << tool << ""
-            "\n" "  % " << tool << " --param-id=157"
-            "\n" "  % " << tool << " --key=lsm input1.grib input2.grib"
-            << std::endl;
+void MIRConfig::usage(const std::string& tool) const {
+    eckit::Log::info() << "\n"
+                          "Usage: "
+                       << tool
+                       << " [--key=key] [[--param-id=value]|[input1.grib [input2.grib [...]]]]"
+                          "\n"
+                          "Examples: "
+                          "\n"
+                          "  % "
+                       << tool
+                       << ""
+                          "\n"
+                          "  % "
+                       << tool
+                       << " --param-id=157"
+                          "\n"
+                          "  % "
+                       << tool << " --key=lsm input1.grib input2.grib" << std::endl;
 }
 
 
@@ -85,7 +88,7 @@ void MIRConfig::execute(const eckit::option::CmdArgs& args) {
 
     // Display configuration for a paramId
     long paramId = 0;
-    if (args.get("param-id", paramId) || !args.count()) {
+    if (args.get("param-id", paramId) || args.count() == 0) {
 
         class DummyField : public mir::param::FieldParametrisation {
             long paramId_;
@@ -97,13 +100,14 @@ void MIRConfig::execute(const eckit::option::CmdArgs& args) {
                 }
                 return FieldParametrisation::get(name, value);
             }
+
         public:
             DummyField(long paramId) : paramId_(paramId) {}
         };
 
         display(DummyField(paramId), key);
-
-    } else {
+    }
+    else {
 
         for (size_t i = 0; i < args.count(); i++) {
 
@@ -113,14 +117,11 @@ void MIRConfig::execute(const eckit::option::CmdArgs& args) {
                 mir::input::MIRInput& input = grib;
                 display(input.parametrisation(), key);
             }
-
         }
-
     }
 }
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     MIRConfig tool(argc, argv);
     return tool.start();
 }
-
