@@ -3,6 +3,7 @@
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ *
  * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
@@ -14,17 +15,17 @@
 #include "eckit/log/Log.h"
 #include "eckit/testing/Test.h"
 
-#include "mir/config/LibMir.h"
-#include "mir/action/plan/Action.h"
-#include "mir/action/plan/ActionNode.h"
-#include "mir/action/plan/ActionGraph.h"
-#include "mir/action/plan/ActionPlan.h"
 #include "mir/action/misc/AreaCropper.h"
+#include "mir/action/plan/Action.h"
+#include "mir/action/plan/ActionGraph.h"
+#include "mir/action/plan/ActionNode.h"
+#include "mir/action/plan/ActionPlan.h"
 #include "mir/api/MIRWatcher.h"
-#include "mir/param/RuntimeParametrisation.h"
+#include "mir/config/LibMir.h"
 #include "mir/param/DefaultParametrisation.h"
+#include "mir/param/RuntimeParametrisation.h"
 
-//define EXPECTV(a) log << "\tEXPECT(" << #a <<")" << std::endl; EXPECT(a)
+// define EXPECTV(a) log << "\tEXPECT(" << #a <<")" << std::endl; EXPECT(a)
 
 
 namespace mir {
@@ -33,8 +34,7 @@ namespace unit {
 
 
 struct TestWatcher : api::MIRWatcher {
-    void print(std::ostream&) const {
-    }
+    void print(std::ostream&) const {}
     bool failure(std::exception& e, const mir::action::Action& action) {
         eckit::Log::error() << "Exception: '" << e.what() << "' on " << action << std::endl;
         throw;
@@ -109,9 +109,9 @@ CASE("ActionGraph") {
 }
 
 
-} // namespace unit
-} // namespace tests
-} // namespace mir
+}  // namespace unit
+}  // namespace tests
+}  // namespace mir
 
 
 int main(int argc, char** argv) {
